#!/bin/sh
cd `dirname "$0"`
case $1 in
  p1) timeout -s 9 2 ../source/replace.exe '-?' 'a&'  < ../inputs/temp-test/1.inp.1.1 > ../outputs/t1
    if diff ../outputs/t1 ../originals/t1 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2) timeout -s 9 2 ../source/replace.exe ' ' '@%@&'  < ../inputs/temp-test/777.inp.334.1 > ../outputs/t2
    if diff ../outputs/t2 ../originals/t2 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3) timeout -s 9 2 ../source/replace.exe ' ' 'NEW'  < ../inputs/temp-test/550.inp.238.1 > ../outputs/t3
    if diff ../outputs/t3 ../originals/t3 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4) timeout -s 9 2 ../source/replace.exe ' ' 'NEW'  < ../inputs/temp-test/551.inp.238.3 > ../outputs/t4
    if diff ../outputs/t4 ../originals/t4 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5) timeout -s 9 2 ../source/replace.exe ' ' 'rY NCDt+32Ilu>dr~s^1Q{0*{RLN>Muz'  < ../inputs/input/ruin.1224 > ../outputs/t5
    if diff ../outputs/t5 ../originals/t5 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p6) timeout -s 9 2 ../source/replace.exe ' '  < ../inputs/input/ruin.1160 > ../outputs/t6
    if diff ../outputs/t6 ../originals/t6 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p7) timeout -s 9 2 ../source/replace.exe ' *' '@%&a'  < ../inputs/temp-test/2298.inp.975.1 > ../outputs/t7
    if diff ../outputs/t7 ../originals/t7 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p8) timeout -s 9 2 ../source/replace.exe ' *' 'a&'  < ../inputs/temp-test/1839.inp.782.1 > ../outputs/t8
    if diff ../outputs/t8 ../originals/t8 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p9) timeout -s 9 2 ../source/replace.exe ' *' 'a&'  < ../inputs/temp-test/1840.inp.782.2 > ../outputs/t9
    if diff ../outputs/t9 ../originals/t9 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p10) timeout -s 9 2 ../source/replace.exe ' *' 'a&'  < ../inputs/temp-test/1841.inp.782.3 > ../outputs/t10
    if diff ../outputs/t10 ../originals/t10 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p11) timeout -s 9 2 ../source/replace.exe ' *-' '@t'  < ../inputs/temp-test/1828.inp.778.1 > ../outputs/t11
    if diff ../outputs/t11 ../originals/t11 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p12) timeout -s 9 2 ../source/replace.exe ' *-' '@t'  < ../inputs/temp-test/1829.inp.778.2 > ../outputs/t12
    if diff ../outputs/t12 ../originals/t12 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p13) timeout -s 9 2 ../source/replace.exe ' *-' '@t'  < ../inputs/temp-test/1830.inp.778.3 > ../outputs/t13
    if diff ../outputs/t13 ../originals/t13 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p14) timeout -s 9 2 ../source/replace.exe ' *?' ''  < ../inputs/temp-test/1964.inp.834.1 > ../outputs/t14
    if diff ../outputs/t14 ../originals/t14 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p15) timeout -s 9 2 ../source/replace.exe ' *?' ''  < ../inputs/temp-test/1965.inp.834.2 > ../outputs/t15
    if diff ../outputs/t15 ../originals/t15 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p16) timeout -s 9 2 ../source/replace.exe ' *[0-9]-? [^a-c]@[*-^a-c]' ''  < ../inputs/temp-test/758.inp.325.1 > ../outputs/t16
    if diff ../outputs/t16 ../originals/t16 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p17) timeout -s 9 2 ../source/replace.exe ' *[0-9]-? [^a-c]@[*-^a-c]' ''  < ../inputs/temp-test/759.inp.325.3 > ../outputs/t17
    if diff ../outputs/t17 ../originals/t17 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p18) timeout -s 9 2 ../source/replace.exe ' *[0-9]@[[9-B]??[0-9]-[^-[^0-9]-[a-c][^a-c]' 'NEW'  < ../inputs/temp-test/1133.inp.487.1 > ../outputs/t18
    if diff ../outputs/t18 ../originals/t18 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p19) timeout -s 9 2 ../source/replace.exe ' *[0-9]@[[9-B]??[0-9]-[^-[^0-9]-[a-c][^a-c]' 'NEW'  < ../inputs/temp-test/1134.inp.487.2 > ../outputs/t19
    if diff ../outputs/t19 ../originals/t19 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p20) timeout -s 9 2 ../source/replace.exe ' *[9-B]' 'a&'  < ../inputs/temp-test/1274.inp.547.1 > ../outputs/t20
    if diff ../outputs/t20 ../originals/t20 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p21) timeout -s 9 2 ../source/replace.exe ' *[9-B]' 'a&'  < ../inputs/temp-test/1275.inp.547.3 > ../outputs/t21
    if diff ../outputs/t21 ../originals/t21 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p22) timeout -s 9 2 ../source/replace.exe ' *^-]-' '@n'  < ../inputs/temp-test/956.inp.412.1 > ../outputs/t22
    if diff ../outputs/t22 ../originals/t22 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p23) timeout -s 9 2 ../source/replace.exe ' *^-]-' '@n'  < ../inputs/temp-test/957.inp.412.2 > ../outputs/t23
    if diff ../outputs/t23 ../originals/t23 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p24) timeout -s 9 2 ../source/replace.exe ' *a-c]' '&a@%'  < ../inputs/temp-test/74.inp.32.1 > ../outputs/t24
    if diff ../outputs/t24 ../originals/t24 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p25) timeout -s 9 2 ../source/replace.exe ' *a-c]' '&a@%'  < ../inputs/temp-test/75.inp.32.3 > ../outputs/t25
    if diff ../outputs/t25 ../originals/t25 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p26) timeout -s 9 2 ../source/replace.exe ' -[][^9-B][a-c][9-B]' '@%&a'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t26
    if diff ../outputs/t26 ../originals/t26 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p27) timeout -s 9 2 ../source/replace.exe ' -[^9-B]*$' '@%&a'  < ../inputs/temp-test/528.inp.229.1 > ../outputs/t27
    if diff ../outputs/t27 ../originals/t27 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p28) timeout -s 9 2 ../source/replace.exe ' -[^9-B]*' '@%&a'  < ../inputs/temp-test/528.inp.229.1 > ../outputs/t28
    if diff ../outputs/t28 ../originals/t28 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p29) timeout -s 9 2 ../source/replace.exe ' -[^9-B]?*'  < ../inputs/temp-test/528.inp.229.1 > ../outputs/t29
    if diff ../outputs/t29 ../originals/t29 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p30) timeout -s 9 2 ../source/replace.exe ' -[^9-B][][a-c][9-B]' '@%&a'  < ../inputs/temp-test/528.inp.229.1 > ../outputs/t30
    if diff ../outputs/t30 ../originals/t30 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p31) timeout -s 9 2 ../source/replace.exe ' -[^9-B][^][a-c][9-B]' '@%&a'  < ../inputs/temp-test/528.inp.229.1 > ../outputs/t31
    if diff ../outputs/t31 ../originals/t31 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p32) timeout -s 9 2 ../source/replace.exe ' -[^9-B][a-c]*$' '@%&a'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t32
    if diff ../outputs/t32 ../originals/t32 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p33) timeout -s 9 2 ../source/replace.exe ' -[^9-B][a-c]*' '@%&a'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t33
    if diff ../outputs/t33 ../originals/t33 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p34) timeout -s 9 2 ../source/replace.exe ' -[^9-B][a-c]?*' '@%&a'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t34
    if diff ../outputs/t34 ../originals/t34 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p35) timeout -s 9 2 ../source/replace.exe ' -[^9-B][a-c][9-B]'   < ../inputs/temp-test/529.inp.229.2 > ../outputs/t35
    if diff ../outputs/t35 ../originals/t35 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p36) timeout -s 9 2 ../source/replace.exe ' -[^9-B][a-c][9-B]' '@%&a'  < ../inputs/temp-test/528.inp.229.1 > ../outputs/t36
    if diff ../outputs/t36 ../originals/t36 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p37) timeout -s 9 2 ../source/replace.exe ' -[^9-B][a-c][9-B]' '@%&a'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t37
    if diff ../outputs/t37 ../originals/t37 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p38) timeout -s 9 2 ../source/replace.exe ' -[^9-B][a-c][9-B]'  < ../inputs/temp-test/528.inp.229.1 > ../outputs/t38
    if diff ../outputs/t38 ../originals/t38 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p39) timeout -s 9 2 ../source/replace.exe ' -[^][^9-B][a-c][9-B]' '@%&a'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t39
    if diff ../outputs/t39 ../originals/t39 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p40) timeout -s 9 2 ../source/replace.exe ' -]' 'a@nb@tc'  < ../inputs/temp-test/1638.inp.698.1 > ../outputs/t40
    if diff ../outputs/t40 ../originals/t40 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p41) timeout -s 9 2 ../source/replace.exe ' -c*[^a-c]' 'NEW'  < ../inputs/temp-test/477.inp.209.1 > ../outputs/t41
    if diff ../outputs/t41 ../originals/t41 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p42) timeout -s 9 2 ../source/replace.exe ' -c*[^a-c]' 'NEW'  < ../inputs/temp-test/478.inp.209.2 > ../outputs/t42
    if diff ../outputs/t42 ../originals/t42 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p43) timeout -s 9 2 ../source/replace.exe ' -c*[^a-c]' 'NEW'  < ../inputs/temp-test/479.inp.209.3 > ../outputs/t43
    if diff ../outputs/t43 ../originals/t43 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p44) timeout -s 9 2 ../source/replace.exe ' ?' '&'  < ../inputs/temp-test/54.inp.23.1 > ../outputs/t44
    if diff ../outputs/t44 ../originals/t44 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p45) timeout -s 9 2 ../source/replace.exe ' [a-c]' '&'  < ../inputs/temp-test/634.inp.274.1 > ../outputs/t45
    if diff ../outputs/t45 ../originals/t45 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p46) timeout -s 9 2 ../source/replace.exe ' [a-c]' '&'  < ../inputs/temp-test/635.inp.274.2 > ../outputs/t46
    if diff ../outputs/t46 ../originals/t46 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p47) timeout -s 9 2 ../source/replace.exe ' [a-c]' '&'  < ../inputs/temp-test/636.inp.274.3 > ../outputs/t47
    if diff ../outputs/t47 ../originals/t47 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p48) timeout -s 9 2 ../source/replace.exe ' [a-c]' '&@n'  < ../inputs/temp-test/634.inp.274.1 > ../outputs/t48
    if diff ../outputs/t48 ../originals/t48 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p49) timeout -s 9 2 ../source/replace.exe ' [a-c]' '&@n'  < ../inputs/temp-test/635.inp.274.2 > ../outputs/t49
    if diff ../outputs/t49 ../originals/t49 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p50) timeout -s 9 2 ../source/replace.exe ' [a-c]' '&@n'  < ../inputs/temp-test/636.inp.274.3 > ../outputs/t50
    if diff ../outputs/t50 ../originals/t50 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p51) timeout -s 9 2 ../source/replace.exe ' [a-c]' '&@nfoo'  < ../inputs/temp-test/635.inp.274.2 > ../outputs/t51
    if diff ../outputs/t51 ../originals/t51 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p52) timeout -s 9 2 ../source/replace.exe ' ^a-]' 'NEW'  < ../inputs/temp-test/2186.inp.925.1 > ../outputs/t52
    if diff ../outputs/t52 ../originals/t52 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p53) timeout -s 9 2 ../source/replace.exe ' ^a-]' 'NEW'  < ../inputs/temp-test/2187.inp.925.2 > ../outputs/t53
    if diff ../outputs/t53 ../originals/t53 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p54) timeout -s 9 2 ../source/replace.exe '!$' '^'  < ../inputs/input/ruin.1470 > ../outputs/t54
    if diff ../outputs/t54 ../originals/t54 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p55) timeout -s 9 2 ../source/replace.exe '!' 'JeQwMtQsX"@?#Q1)jO;[#@Y^SE,&N$~<>FK'  < ../inputs/input/ruin.677 > ../outputs/t55
    if diff ../outputs/t55 ../originals/t55 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p56) timeout -s 9 2 ../source/replace.exe '!' '\-'  < ../inputs/input/ruin.1946 > ../outputs/t56
    if diff ../outputs/t56 ../originals/t56 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p57) timeout -s 9 2 ../source/replace.exe '!' 'f)n'\'':Ig"_@4},'  < ../inputs/input/ruin.1784 > ../outputs/t57
    if diff ../outputs/t57 ../originals/t57 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p58) timeout -s 9 2 ../source/replace.exe '!2' 4  < ../inputs/moni/f7.inp > ../outputs/t58
    if diff ../outputs/t58 ../originals/t58 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p59) timeout -s 9 2 ../source/replace.exe '"' '6'  < ../inputs/input/ruin.197 > ../outputs/t59
    if diff ../outputs/t59 ../originals/t59 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p60) timeout -s 9 2 ../source/replace.exe '"@@' 'm'  < ../inputs/input/ruin.1890 > ../outputs/t60
    if diff ../outputs/t60 ../originals/t60 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p61) timeout -s 9 2 ../source/replace.exe '##[0-9]?[a-b]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t61
    if diff ../outputs/t61 ../originals/t61 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p62) timeout -s 9 2 ../source/replace.exe '#' '&'  < ../inputs/input/ruin.1044 > ../outputs/t62
    if diff ../outputs/t62 ../originals/t62 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p63) timeout -s 9 2 ../source/replace.exe '#' '&G:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_J'  < ../inputs/input/ruin.1044 > ../outputs/t63
    if diff ../outputs/t63 ../originals/t63 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p64) timeout -s 9 2 ../source/replace.exe '#' '_W$'  < ../inputs/input/ruin.1198 > ../outputs/t64
    if diff ../outputs/t64 ../originals/t64 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p65) timeout -s 9 2 ../source/replace.exe '#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO-[^--z]-[^a--b][^0-9]@* *?-c' '@n'  < ../inputs/temp-test/902.inp.388.1 > ../outputs/t65
    if diff ../outputs/t65 ../originals/t65 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p66) timeout -s 9 2 ../source/replace.exe '$ -[^9-B][a-c][9-B]' '@%&a'  < ../inputs/temp-test/528.inp.229.1 > ../outputs/t66
    if diff ../outputs/t66 ../originals/t66 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p67) timeout -s 9 2 ../source/replace.exe '$ -[^9-B][a-c][9-B]' '@%&a'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t67
    if diff ../outputs/t67 ../originals/t67 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p68) timeout -s 9 2 ../source/replace.exe '$$**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t68
    if diff ../outputs/t68 ../originals/t68 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p69) timeout -s 9 2 ../source/replace.exe '$%**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t69
    if diff ../outputs/t69 ../originals/t69 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p70) timeout -s 9 2 ../source/replace.exe '$%-[@n][^a--b]$' 'NEW'  < ../inputs/temp-test/216.inp.96.11 > ../outputs/t70
    if diff ../outputs/t70 ../originals/t70 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p71) timeout -s 9 2 ../source/replace.exe '$%? ' 'a@nb@tc'  < ../inputs/temp-test/218.inp.97.5 > ../outputs/t71
    if diff ../outputs/t71 ../originals/t71 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p72) timeout -s 9 2 ../source/replace.exe '$%?@*' 'NEW'  < ../inputs/temp-test/523.inp.226.5 > ../outputs/t72
    if diff ../outputs/t72 ../originals/t72 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p73) timeout -s 9 2 ../source/replace.exe '$%?^$' '@%&a'  < ../inputs/temp-test/513.inp.223.10 > ../outputs/t73
    if diff ../outputs/t73 ../originals/t73 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p74) timeout -s 9 2 ../source/replace.exe '$%@*?' '@%&a'  < ../inputs/temp-test/199.inp.89.5 > ../outputs/t74
    if diff ../outputs/t74 ../originals/t74 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p75) timeout -s 9 2 ../source/replace.exe '$%[^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/527.inp.228.5 > ../outputs/t75
    if diff ../outputs/t75 ../originals/t75 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p76) timeout -s 9 2 ../source/replace.exe '$'   < ../inputs/moni/f7.inp > ../outputs/t76
    if diff ../outputs/t76 ../originals/t76 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p77) timeout -s 9 2 ../source/replace.exe '$' '%'  < ../inputs/input/ruin.1122 > ../outputs/t77
    if diff ../outputs/t77 ../originals/t77 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p78) timeout -s 9 2 ../source/replace.exe '$' ''\''Z y<j$`3-b6{hC,KW4dJZ\tWkm'  < ../inputs/input/ruin.1104 > ../outputs/t78
    if diff ../outputs/t78 ../originals/t78 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p79) timeout -s 9 2 ../source/replace.exe '$' 'F]"8mW1FGw`iK4QO;MuiQ4{%mW1FGw`iK4QO;MuiQ4{%mW1FGw`iK4QO;MuiQ4{%mW1FGw`iK4QO;MuiQ4{%`#tLmW1FGw`iK4QO;MuiQ4{%mW1FGw`iK4QO;MuiQ4{%mW1FGw`iK4QO;MuiQ4{%mW1FGw`iK4QO;MuiQ4{%mW1FGw`iK4QO;MuiQ4{%R:h2`^Ndy W4p?5Yd9N%7tp~'  < ../inputs/input/ruin.154 > ../outputs/t79
    if diff ../outputs/t79 ../originals/t79 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p80) timeout -s 9 2 ../source/replace.exe '$' 'K'  < ../inputs/input/ruin.1121 > ../outputs/t80
    if diff ../outputs/t80 ../originals/t80 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p81) timeout -s 9 2 ../source/replace.exe '$' 'Pb'  < ../inputs/input/ruin.1111 > ../outputs/t81
    if diff ../outputs/t81 ../originals/t81 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p82) timeout -s 9 2 ../source/replace.exe '$' 'X'\'',id`ucU?Bhj!aeGJ~qW=F*9LTRouw#I-quWg}}wkR8Cwfff{{JGSTC2v7(*^3wSqSn{{\Jx9r8a'  < ../inputs/input/ruin.130 > ../outputs/t82
    if diff ../outputs/t82 ../originals/t82 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p83) timeout -s 9 2 ../source/replace.exe '$' 'xv'\''%;99C.L6GYG|5'\''B4JA{:,!;i0:/n+[q}2g+Q+T[#; `w&%3:]~,5M]m.'  < ../inputs/input/ruin.1118 > ../outputs/t83
    if diff ../outputs/t83 ../originals/t83 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p84) timeout -s 9 2 ../source/replace.exe '$- ' '&'  < ../inputs/temp-test/524.inp.227.1 > ../outputs/t84
    if diff ../outputs/t84 ../originals/t84 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p85) timeout -s 9 2 ../source/replace.exe '$-'   < ../inputs/temp-test/215.inp.96.8 > ../outputs/t85
    if diff ../outputs/t85 ../originals/t85 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p86) timeout -s 9 2 ../source/replace.exe '$-' '&@n'   < ../inputs/temp-test/215.inp.96.8 > ../outputs/t86
    if diff ../outputs/t86 ../originals/t86 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p87) timeout -s 9 2 ../source/replace.exe '$-*[][^0-9]' '&'  < ../inputs/temp-test/201.inp.90.3 > ../outputs/t87
    if diff ../outputs/t87 ../originals/t87 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p88) timeout -s 9 2 ../source/replace.exe '$-*[^0-9]$' '&'  < ../inputs/temp-test/202.inp.90.6 > ../outputs/t88
    if diff ../outputs/t88 ../originals/t88 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p89) timeout -s 9 2 ../source/replace.exe '$-*[^0-9]' '&'  < ../inputs/temp-test/200.inp.90.1 > ../outputs/t89
    if diff ../outputs/t89 ../originals/t89 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p90) timeout -s 9 2 ../source/replace.exe '$-*[^0-9]' '&'  < ../inputs/temp-test/201.inp.90.3 > ../outputs/t90
    if diff ../outputs/t90 ../originals/t90 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p91) timeout -s 9 2 ../source/replace.exe '$-*[^0-9]' '&@n' < ../inputs/temp-test/201.inp.90.3 > ../outputs/t91
    if diff ../outputs/t91 ../originals/t91 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p92) timeout -s 9 2 ../source/replace.exe '$-*[^0-9]'  < ../inputs/temp-test/201.inp.90.3 > ../outputs/t92
    if diff ../outputs/t92 ../originals/t92 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p93) timeout -s 9 2 ../source/replace.exe '$-*[^][^0-9]' '&'  < ../inputs/temp-test/201.inp.90.3 > ../outputs/t93
    if diff ../outputs/t93 ../originals/t93 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p94) timeout -s 9 2 ../source/replace.exe '$-[@n][^a--b]$' 'NEW'  < ../inputs/temp-test/215.inp.96.8 > ../outputs/t94
    if diff ../outputs/t94 ../originals/t94 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p95) timeout -s 9 2 ../source/replace.exe '$-[@n][^a--b]' 'NEW'  < ../inputs/temp-test/213.inp.96.1 > ../outputs/t95
    if diff ../outputs/t95 ../originals/t95 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p96) timeout -s 9 2 ../source/replace.exe '$-[@n][^a--b]' 'NEW'  < ../inputs/temp-test/214.inp.96.3 > ../outputs/t96
    if diff ../outputs/t96 ../originals/t96 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p97) timeout -s 9 2 ../source/replace.exe '$-[][@n][^a--b]$' 'NEW'  < ../inputs/temp-test/215.inp.96.8 > ../outputs/t97
    if diff ../outputs/t97 ../originals/t97 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p98) timeout -s 9 2 ../source/replace.exe '$-[^][@n][^a--b]$' 'NEW'  < ../inputs/temp-test/215.inp.96.8 > ../outputs/t98
    if diff ../outputs/t98 ../originals/t98 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p99) timeout -s 9 2 ../source/replace.exe '$? ' 'a@nb@tc'  < ../inputs/temp-test/217.inp.97.1 > ../outputs/t99
    if diff ../outputs/t99 ../originals/t99 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p100) timeout -s 9 2 ../source/replace.exe '$?-[^-z][0-9]' '&a@%'  < ../inputs/temp-test/224.inp.100.1 > ../outputs/t100
    if diff ../outputs/t100 ../originals/t100 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p101) timeout -s 9 2 ../source/replace.exe '$?-[^-z][0-9]'  < ../inputs/temp-test/224.inp.100.1 > ../outputs/t101
    if diff ../outputs/t101 ../originals/t101 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p102) timeout -s 9 2 ../source/replace.exe '$?@*'   < ../inputs/temp-test/522.inp.226.3 > ../outputs/t102
    if diff ../outputs/t102 ../originals/t102 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p103) timeout -s 9 2 ../source/replace.exe '$?@*' '@%&a'  < ../inputs/temp-test/532.inp.231.1 > ../outputs/t103
    if diff ../outputs/t103 ../originals/t103 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p104) timeout -s 9 2 ../source/replace.exe '$?@*' 'NEW'  < ../inputs/temp-test/521.inp.226.1 > ../outputs/t104
    if diff ../outputs/t104 ../originals/t104 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p105) timeout -s 9 2 ../source/replace.exe '$?@*' 'NEW'  < ../inputs/temp-test/522.inp.226.3 > ../outputs/t105
    if diff ../outputs/t105 ../originals/t105 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p106) timeout -s 9 2 ../source/replace.exe '$?[^--z]c[^9-B][^9-B]c*?[9-B]c-' '@t'  < ../inputs/temp-test/530.inp.230.1 > ../outputs/t106
    if diff ../outputs/t106 ../originals/t106 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p107) timeout -s 9 2 ../source/replace.exe '$?[^--z]c[^9-B][^9-B]c*?[9-B]c-' '@t'  < ../inputs/temp-test/531.inp.230.4 > ../outputs/t107
    if diff ../outputs/t107 ../originals/t107 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p108) timeout -s 9 2 ../source/replace.exe '$?^'   < ../inputs/temp-test/512.inp.223.3 > ../outputs/t108
    if diff ../outputs/t108 ../originals/t108 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p109) timeout -s 9 2 ../source/replace.exe '$?^' '@%&a'  < ../inputs/temp-test/511.inp.223.1 > ../outputs/t109
    if diff ../outputs/t109 ../originals/t109 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p110) timeout -s 9 2 ../source/replace.exe '$?^' '@%&a'  < ../inputs/temp-test/512.inp.223.3 > ../outputs/t110
    if diff ../outputs/t110 ../originals/t110 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p111) timeout -s 9 2 ../source/replace.exe '$@*?' '@%&a'  < ../inputs/temp-test/198.inp.89.1 > ../outputs/t111
    if diff ../outputs/t111 ../originals/t111 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p112) timeout -s 9 2 ../source/replace.exe '$@[*-?[a-c$' 'a@nb@tc'  < ../inputs/temp-test/210.inp.93.8 > ../outputs/t112
    if diff ../outputs/t112 ../originals/t112 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p113) timeout -s 9 2 ../source/replace.exe '$@[*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/207.inp.93.1 > ../outputs/t113
    if diff ../outputs/t113 ../originals/t113 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p114) timeout -s 9 2 ../source/replace.exe '$@[*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/208.inp.93.2 > ../outputs/t114
    if diff ../outputs/t114 ../originals/t114 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p115) timeout -s 9 2 ../source/replace.exe '$@[*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/209.inp.93.3 > ../outputs/t115
    if diff ../outputs/t115 ../originals/t115 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p116) timeout -s 9 2 ../source/replace.exe '$@[*-?[a-c'  < ../inputs/temp-test/207.inp.93.1 > ../outputs/t116
    if diff ../outputs/t116 ../originals/t116 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p117) timeout -s 9 2 ../source/replace.exe '$[^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/525.inp.228.1 > ../outputs/t117
    if diff ../outputs/t117 ../originals/t117 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p118) timeout -s 9 2 ../source/replace.exe '$[^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/526.inp.228.3 > ../outputs/t118
    if diff ../outputs/t118 ../originals/t118 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p119) timeout -s 9 2 ../source/replace.exe '$[^0-9]?-?[^a--b]' '&a@%'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t119
    if diff ../outputs/t119 ../originals/t119 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p120) timeout -s 9 2 ../source/replace.exe '$[^9-B]@['   < ../inputs/temp-test/219.inp.98.1 > ../outputs/t120
    if diff ../outputs/t120 ../originals/t120 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p121) timeout -s 9 2 ../source/replace.exe '$[^9-B]@[' 'a@n'  < ../inputs/temp-test/219.inp.98.1 > ../outputs/t121
    if diff ../outputs/t121 ../originals/t121 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p122) timeout -s 9 2 ../source/replace.exe '$[^9-B]@[' 'a@n'  < ../inputs/temp-test/220.inp.98.2 > ../outputs/t122
    if diff ../outputs/t122 ../originals/t122 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p123) timeout -s 9 2 ../source/replace.exe '$[^9-B]@[' 'a@n'  < ../inputs/temp-test/221.inp.98.3 > ../outputs/t123
    if diff ../outputs/t123 ../originals/t123 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p124) timeout -s 9 2 ../source/replace.exe '$[^9-B][9-B]'   < ../inputs/temp-test/205.inp.91.3 > ../outputs/t124
    if diff ../outputs/t124 ../originals/t124 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p125) timeout -s 9 2 ../source/replace.exe '$[^9-B][9-B]' '&@n'  < ../inputs/temp-test/205.inp.91.3 > ../outputs/t125
    if diff ../outputs/t125 ../originals/t125 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p126) timeout -s 9 2 ../source/replace.exe '$[^9-B][9-B]' '@%&a'  < ../inputs/temp-test/203.inp.91.1 > ../outputs/t126
    if diff ../outputs/t126 ../originals/t126 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p127) timeout -s 9 2 ../source/replace.exe '$[^9-B][9-B]' '@%&a'  < ../inputs/temp-test/204.inp.91.2 > ../outputs/t127
    if diff ../outputs/t127 ../originals/t127 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p128) timeout -s 9 2 ../source/replace.exe '$[^9-B][9-B]' '@%&a'  < ../inputs/temp-test/205.inp.91.3 > ../outputs/t128
    if diff ../outputs/t128 ../originals/t128 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p129) timeout -s 9 2 ../source/replace.exe '$[^9-B][9-B]*$'   < ../inputs/temp-test/205.inp.91.3 > ../outputs/t129
    if diff ../outputs/t129 ../originals/t129 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p130) timeout -s 9 2 ../source/replace.exe '$[^9-B][9-B][]' '@%&a'  < ../inputs/temp-test/205.inp.91.3 > ../outputs/t130
    if diff ../outputs/t130 ../originals/t130 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p131) timeout -s 9 2 ../source/replace.exe '$[^9-B][9-B][^]' '@%&a'  < ../inputs/temp-test/205.inp.91.3 > ../outputs/t131
    if diff ../outputs/t131 ../originals/t131 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p132) timeout -s 9 2 ../source/replace.exe '$[^a-c][9-B]'   < ../inputs/temp-test/222.inp.99.1 > ../outputs/t132
    if diff ../outputs/t132 ../originals/t132 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p133) timeout -s 9 2 ../source/replace.exe '$[^a-c][9-B]' '@%&a'  < ../inputs/temp-test/222.inp.99.1 > ../outputs/t133
    if diff ../outputs/t133 ../originals/t133 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p134) timeout -s 9 2 ../source/replace.exe '$[^a-c][9-B]' '@%&a'  < ../inputs/temp-test/223.inp.99.3 > ../outputs/t134
    if diff ../outputs/t134 ../originals/t134 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p135) timeout -s 9 2 ../source/replace.exe '$[^a-c]a-]' 'NEW'  < ../inputs/temp-test/211.inp.94.1 > ../outputs/t135
    if diff ../outputs/t135 ../originals/t135 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p136) timeout -s 9 2 ../source/replace.exe '$[a-c?$' 'a&'  < ../inputs/temp-test/520.inp.225.8 > ../outputs/t136
    if diff ../outputs/t136 ../originals/t136 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p137) timeout -s 9 2 ../source/replace.exe '$[a-c?'   < ../inputs/temp-test/516.inp.225.1 > ../outputs/t137
    if diff ../outputs/t137 ../originals/t137 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p138) timeout -s 9 2 ../source/replace.exe '$[a-c?'   < ../inputs/temp-test/519.inp.225.4 > ../outputs/t138
    if diff ../outputs/t138 ../originals/t138 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p139) timeout -s 9 2 ../source/replace.exe '$[a-c?' 'a&'  < ../inputs/temp-test/516.inp.225.1 > ../outputs/t139
    if diff ../outputs/t139 ../originals/t139 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p140) timeout -s 9 2 ../source/replace.exe '$[a-c?' 'a&'  < ../inputs/temp-test/517.inp.225.2 > ../outputs/t140
    if diff ../outputs/t140 ../originals/t140 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p141) timeout -s 9 2 ../source/replace.exe '$[a-c?' 'a&'  < ../inputs/temp-test/518.inp.225.3 > ../outputs/t141
    if diff ../outputs/t141 ../originals/t141 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p142) timeout -s 9 2 ../source/replace.exe '$[a-c?' 'a&'  < ../inputs/temp-test/519.inp.225.4 > ../outputs/t142
    if diff ../outputs/t142 ../originals/t142 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p143) timeout -s 9 2 ../source/replace.exe '$^-?[^9-B]' 'a@n'  < ../inputs/temp-test/510.inp.222.4 > ../outputs/t143
    if diff ../outputs/t143 ../originals/t143 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p144) timeout -s 9 2 ../source/replace.exe '$a' ''  < ../inputs/moni/f7.inp > ../outputs/t144
    if diff ../outputs/t144 ../originals/t144 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p145) timeout -s 9 2 ../source/replace.exe '$c*[^a-'   < ../inputs/temp-test/514.inp.224.1 > ../outputs/t145
    if diff ../outputs/t145 ../originals/t145 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p146) timeout -s 9 2 ../source/replace.exe '$c*[^a-' 'a@nb@tc'  < ../inputs/temp-test/514.inp.224.1 > ../outputs/t146
    if diff ../outputs/t146 ../originals/t146 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p147) timeout -s 9 2 ../source/replace.exe '$c*[^a-' 'a@nb@tc'  < ../inputs/temp-test/515.inp.224.3 > ../outputs/t147
    if diff ../outputs/t147 ../originals/t147 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p148) timeout -s 9 2 ../source/replace.exe '$c[^0-9]' '&a@%'  < ../inputs/temp-test/212.inp.95.1 > ../outputs/t148
    if diff ../outputs/t148 ../originals/t148 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p149) timeout -s 9 2 ../source/replace.exe '$c[^0-9]'  < ../inputs/temp-test/212.inp.95.1 > ../outputs/t149
    if diff ../outputs/t149 ../originals/t149 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p150) timeout -s 9 2 ../source/replace.exe '% ' 'NEW'  < ../inputs/temp-test/552.inp.238.7 > ../outputs/t150
    if diff ../outputs/t150 ../originals/t150 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p151) timeout -s 9 2 ../source/replace.exe '% *' 'a&'  < ../inputs/temp-test/1842.inp.782.7 > ../outputs/t151
    if diff ../outputs/t151 ../originals/t151 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p152) timeout -s 9 2 ../source/replace.exe '% *^-]-$' '@n'  < ../inputs/temp-test/958.inp.412.11 > ../outputs/t152
    if diff ../outputs/t152 ../originals/t152 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p153) timeout -s 9 2 ../source/replace.exe '%*$' ':m9#`%w*An#HIw)ZLBs!y-|, 5 M_m9u_Lao'  < ../inputs/input/ruin.1258 > ../outputs/t153
    if diff ../outputs/t153 ../originals/t153 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p154) timeout -s 9 2 ../source/replace.exe '%*$' 'D9RnxwW@{i=z85OwG0--kJo<'  < ../inputs/input/ruin.1554 > ../outputs/t154
    if diff ../outputs/t154 ../originals/t154 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p155) timeout -s 9 2 ../source/replace.exe '%*$' 'U'  < ../inputs/input/ruin.1536 > ../outputs/t155
    if diff ../outputs/t155 ../originals/t155 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p156) timeout -s 9 2 ../source/replace.exe '%*$' 'i'  < ../inputs/input/ruin.1625 > ../outputs/t156
    if diff ../outputs/t156 ../originals/t156 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p157) timeout -s 9 2 ../source/replace.exe '%*$' 'nQ;+jYa.#8vT9@X-GD(e4]YKBjzXF(V+MTO]u;aGY^jo'\''q:'  < ../inputs/input/ruin.1390 > ../outputs/t157
    if diff ../outputs/t157 ../originals/t157 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p158) timeout -s 9 2 ../source/replace.exe '%*$' 66  < ../inputs/moni/f7.inp > ../outputs/t158
    if diff ../outputs/t158 ../originals/t158 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p159) timeout -s 9 2 ../source/replace.exe '%*' ' <+%@x-,=f$.L5#T(AD4Q@iix)H`Ce K,+UO#:wj,q7KJO@]d~.N,<'\''Hi73GN$Gl(HX1C'  < ../inputs/input/ruin.328 > ../outputs/t159
    if diff ../outputs/t159 ../originals/t159 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p160) timeout -s 9 2 ../source/replace.exe '%*' '0'  < ../inputs/input/ruin.1821 > ../outputs/t160
    if diff ../outputs/t160 ../originals/t160 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p161) timeout -s 9 2 ../source/replace.exe '%*' 'G'  < ../inputs/input/ruin.1088 > ../outputs/t161
    if diff ../outputs/t161 ../originals/t161 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p162) timeout -s 9 2 ../source/replace.exe '%*' 'a'  < ../inputs/moni/f7.inp > ../outputs/t162
    if diff ../outputs/t162 ../originals/t162 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p163) timeout -s 9 2 ../source/replace.exe '%*' 'lc_lv50iK!'\''g`jS`LIK\!&3W>wi_0pbHri'  < ../inputs/input/ruin.1845 > ../outputs/t163
    if diff ../outputs/t163 ../originals/t163 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p164) timeout -s 9 2 ../source/replace.exe '%*' 'q'  < ../inputs/input/ruin.1973 > ../outputs/t164
    if diff ../outputs/t164 ../originals/t164 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p165) timeout -s 9 2 ../source/replace.exe '%*' 's'  < ../inputs/input/ruin.1058 > ../outputs/t165
    if diff ../outputs/t165 ../originals/t165 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p166) timeout -s 9 2 ../source/replace.exe '%*' 's7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp'  < ../inputs/input/ruin.1058 > ../outputs/t166
    if diff ../outputs/t166 ../originals/t166 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p167) timeout -s 9 2 ../source/replace.exe '%*' 't'  < ../inputs/input/ruin.526 > ../outputs/t167
    if diff ../outputs/t167 ../originals/t167 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p168) timeout -s 9 2 ../source/replace.exe '%*' 'yh'  < ../inputs/input/ruin.1653 > ../outputs/t168
    if diff ../outputs/t168 ../originals/t168 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p169) timeout -s 9 2 ../source/replace.exe '%*' '|/2:-r3lyg[Iq$dLi?"/#U'  < ../inputs/input/ruin.308 > ../outputs/t169
    if diff ../outputs/t169 ../originals/t169 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p170) timeout -s 9 2 ../source/replace.exe '%*?$' 'vLd?Rz=SEH)PEv2'  < ../inputs/input/ruin.1265 > ../outputs/t170
    if diff ../outputs/t170 ../originals/t170 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p171) timeout -s 9 2 ../source/replace.exe '%*?$'  < ../inputs/input/ruin.1265 > ../outputs/t171
    if diff ../outputs/t171 ../originals/t171 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p172) timeout -s 9 2 ../source/replace.exe '%*@@$' '^^+p&y=3[ZYIgTBk:JTg x?51<dbL'  < ../inputs/input/ruin.1331 > ../outputs/t172
    if diff ../outputs/t172 ../originals/t172 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p173) timeout -s 9 2 ../source/replace.exe '%*@@p&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIgTBk$' '^^+p&y=3[ZYIgTBk:JTg x?51<dbL'  < ../inputs/input/ruin.1331 > ../outputs/t173
    if diff ../outputs/t173 ../originals/t173 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p174) timeout -s 9 2 ../source/replace.exe '%*B]ddB]@t]*[@t@][9-B]B]ddB]@t]*[@t@][9-B]B]ddB]@t]*[@t@][9-B]B]ddB]@t]*[@t@][9-B]B]ddB]@t]*[@t@][9-B]B]ddB]@t]*[@t@][9-B]B]ddB]@t]*[@t@][9-B]' ' <+%@x-,=f$.L5#T(AD4Q@iix)H`Ce K,+UO#:wj,q7KJO@]d~.N,<'\''Hi73GN$Gl(HX1C'  < ../inputs/input/ruin.328 > ../outputs/t174
    if diff ../outputs/t174 ../originals/t174 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p175) timeout -s 9 2 ../source/replace.exe '%*[O]D?'   < ../inputs/input/ruin.1161 > ../outputs/t175
    if diff ../outputs/t175 ../originals/t175 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p176) timeout -s 9 2 ../source/replace.exe '%*[O]D?' 'dR{6FgfE'  < ../inputs/input/ruin.1161 > ../outputs/t176
    if diff ../outputs/t176 ../originals/t176 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p177) timeout -s 9 2 ../source/replace.exe '%*\1Pf2' 'g'  < ../inputs/input/ruin.4 > ../outputs/t177
    if diff ../outputs/t177 ../originals/t177 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p178) timeout -s 9 2 ../source/replace.exe '%*^' 'y8sdW9T'  < ../inputs/input/ruin.1065 > ../outputs/t178
    if diff ../outputs/t178 ../originals/t178 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p179) timeout -s 9 2 ../source/replace.exe '%- ' '@t'  < ../inputs/temp-test/1790.inp.761.7 > ../outputs/t179
    if diff ../outputs/t179 ../originals/t179 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p180) timeout -s 9 2 ../source/replace.exe '%- [^@n]?[^0-9]?[0-9]?$' '@%&a'  < ../inputs/temp-test/163.inp.73.10 > ../outputs/t180
    if diff ../outputs/t180 ../originals/t180 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p181) timeout -s 9 2 ../source/replace.exe '%-' '%s$0#=(`Y2,;:8*/t"3Yn=VCI-|H6q[k%+sNf3%f`xvS*o(uD'  < ../inputs/input/ruin.1972 > ../outputs/t181
    if diff ../outputs/t181 ../originals/t181 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p182) timeout -s 9 2 ../source/replace.exe '%-' ''  < ../inputs/temp-test/1650.inp.703.5 > ../outputs/t182
    if diff ../outputs/t182 ../originals/t182 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p183) timeout -s 9 2 ../source/replace.exe '%-' 'NEW'  < ../inputs/temp-test/725.inp.312.5 > ../outputs/t183
    if diff ../outputs/t183 ../originals/t183 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p184) timeout -s 9 2 ../source/replace.exe '%-' 'a&'  < ../inputs/temp-test/1312.inp.563.7 > ../outputs/t184
    if diff ../outputs/t184 ../originals/t184 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p185) timeout -s 9 2 ../source/replace.exe '%-*-' '@n'  < ../inputs/temp-test/2009.inp.852.5 > ../outputs/t185
    if diff ../outputs/t185 ../originals/t185 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p186) timeout -s 9 2 ../source/replace.exe '%-*?$' '&a@%'  < ../inputs/temp-test/1103.inp.474.11 > ../outputs/t186
    if diff ../outputs/t186 ../originals/t186 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p187) timeout -s 9 2 ../source/replace.exe '%-*?' '&a@%'  < ../inputs/temp-test/1102.inp.474.5 > ../outputs/t187
    if diff ../outputs/t187 ../originals/t187 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p188) timeout -s 9 2 ../source/replace.exe '%--%[^9-B][0-9]--[0-9]*-$' '@%@&'  < ../inputs/temp-test/18.inp.8.11 > ../outputs/t188
    if diff ../outputs/t188 ../originals/t188 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p189) timeout -s 9 2 ../source/replace.exe '%--*a-c]?[^0-9]$' '@n'  < ../inputs/temp-test/1154.inp.496.10 > ../outputs/t189
    if diff ../outputs/t189 ../originals/t189 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p190) timeout -s 9 2 ../source/replace.exe '%--@*-[^-z]-?[^--z][^9-B]?$' '&a@%'  < ../inputs/temp-test/503.inp.219.10 > ../outputs/t190
    if diff ../outputs/t190 ../originals/t190 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p191) timeout -s 9 2 ../source/replace.exe '%--@*-[^-z]-?[^--z][^9-B]?' '&a@%'  < ../inputs/temp-test/501.inp.219.5 > ../outputs/t191
    if diff ../outputs/t191 ../originals/t191 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p192) timeout -s 9 2 ../source/replace.exe '%--[0-9]?-?$' 'NEW'  < ../inputs/temp-test/2061.inp.873.10 > ../outputs/t192
    if diff ../outputs/t192 ../originals/t192 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p193) timeout -s 9 2 ../source/replace.exe '%--[^9-B][0-9]--[0-9]*-$' '@%@&'  < ../inputs/temp-test/18.inp.8.11 > ../outputs/t193
    if diff ../outputs/t193 ../originals/t193 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p194) timeout -s 9 2 ../source/replace.exe '%-?$' '&'  < ../inputs/temp-test/375.inp.162.10 > ../outputs/t194
    if diff ../outputs/t194 ../originals/t194 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p195) timeout -s 9 2 ../source/replace.exe '%-?$' 'a&'  < ../inputs/temp-test/1079.inp.464.10 > ../outputs/t195
    if diff ../outputs/t195 ../originals/t195 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p196) timeout -s 9 2 ../source/replace.exe '%-??[^0-9][9-B][^9-B]$' 'a&'  < ../inputs/temp-test/39.inp.16.11 > ../outputs/t196
    if diff ../outputs/t196 ../originals/t196 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p197) timeout -s 9 2 ../source/replace.exe '%-?@[[^9-B]---?' 'a@n'  < ../inputs/temp-test/966.inp.416.5 > ../outputs/t197
    if diff ../outputs/t197 ../originals/t197 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p198) timeout -s 9 2 ../source/replace.exe '%-?[^0-9]?' '&'  < ../inputs/temp-test/466.inp.203.5 > ../outputs/t198
    if diff ../outputs/t198 ../originals/t198 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p199) timeout -s 9 2 ../source/replace.exe '%-@**' 'NEW'  < ../inputs/temp-test/1838.inp.781.5 > ../outputs/t199
    if diff ../outputs/t199 ../originals/t199 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p200) timeout -s 9 2 ../source/replace.exe '%-@t$' ''  < ../inputs/temp-test/42.inp.17.11 > ../outputs/t200
    if diff ../outputs/t200 ../originals/t200 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p201) timeout -s 9 2 ../source/replace.exe '%-[9-B]' '&'  < ../inputs/temp-test/1336.inp.573.5 > ../outputs/t201
    if diff ../outputs/t201 ../originals/t201 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p202) timeout -s 9 2 ../source/replace.exe '%-[@n][^a--b]$'   < ../inputs/temp-test/216.inp.96.11 > ../outputs/t202
    if diff ../outputs/t202 ../originals/t202 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p203) timeout -s 9 2 ../source/replace.exe '%-[@n][^a--b]$' 'NEW'  < ../inputs/temp-test/216.inp.96.11 > ../outputs/t203
    if diff ../outputs/t203 ../originals/t203 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p204) timeout -s 9 2 ../source/replace.exe '%-[@n][^a--b]*$' 'NEW'  < ../inputs/temp-test/216.inp.96.11 > ../outputs/t204
    if diff ../outputs/t204 ../originals/t204 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p205) timeout -s 9 2 ../source/replace.exe '%-[@n][^a--b]*' 'NEW'  < ../inputs/temp-test/216.inp.96.11 > ../outputs/t205
    if diff ../outputs/t205 ../originals/t205 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p206) timeout -s 9 2 ../source/replace.exe '%-[][@n][^a--b]$' 'NEW'  < ../inputs/temp-test/216.inp.96.11 > ../outputs/t206
    if diff ../outputs/t206 ../originals/t206 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p207) timeout -s 9 2 ../source/replace.exe '%-[^0-9]' 'NEW'  < ../inputs/temp-test/2013.inp.854.7 > ../outputs/t207
    if diff ../outputs/t207 ../originals/t207 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p208) timeout -s 9 2 ../source/replace.exe '%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]%-[^9-B]' 'NEW'  < ../inputs/temp-test/892.inp.383.5 > ../outputs/t208
    if diff ../outputs/t208 ../originals/t208 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p209) timeout -s 9 2 ../source/replace.exe '%-[^9-B]' 'NEW'  < ../inputs/temp-test/892.inp.383.5 > ../outputs/t209
    if diff ../outputs/t209 ../originals/t209 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p210) timeout -s 9 2 ../source/replace.exe '%-[^9-B]' 'a@nb@tc'  < ../inputs/temp-test/1717.inp.731.7 > ../outputs/t210
    if diff ../outputs/t210 ../originals/t210 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p211) timeout -s 9 2 ../source/replace.exe '%-[^9-B][^0-9] $' 'a@n'  < ../inputs/temp-test/2026.inp.859.11 > ../outputs/t211
    if diff ../outputs/t211 ../originals/t211 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p212) timeout -s 9 2 ../source/replace.exe '%-[^9-B][^0-9][_-z]?-^*?$' '@n'  < ../inputs/temp-test/1051.inp.452.11 > ../outputs/t212
    if diff ../outputs/t212 ../originals/t212 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p213) timeout -s 9 2 ../source/replace.exe '%-[^][@n][^a--b]$' 'NEW'  < ../inputs/temp-test/216.inp.96.11 > ../outputs/t213
    if diff ../outputs/t213 ../originals/t213 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p214) timeout -s 9 2 ../source/replace.exe '%-[^a-c]' '@%@&'  < ../inputs/temp-test/863.inp.371.5 > ../outputs/t214
    if diff ../outputs/t214 ../originals/t214 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p215) timeout -s 9 2 ../source/replace.exe '%-[^a-c]' 'b@t'  < ../inputs/temp-test/1654.inp.704.5 > ../outputs/t215
    if diff ../outputs/t215 ../originals/t215 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p216) timeout -s 9 2 ../source/replace.exe '%-]-' '@n'  < ../inputs/temp-test/1123.inp.483.7 > ../outputs/t216
    if diff ../outputs/t216 ../originals/t216 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p217) timeout -s 9 2 ../source/replace.exe '%-][^0-9]' 'a@nb@tc'  < ../inputs/temp-test/580.inp.249.7 > ../outputs/t217
    if diff ../outputs/t217 ../originals/t217 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p218) timeout -s 9 2 ../source/replace.exe '%-^$' ''  < ../inputs/temp-test/575.inp.247.10 > ../outputs/t218
    if diff ../outputs/t218 ../originals/t218 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p219) timeout -s 9 2 ../source/replace.exe '%-^$' '@%&a'  < ../inputs/temp-test/1249.inp.535.10 > ../outputs/t219
    if diff ../outputs/t219 ../originals/t219 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p220) timeout -s 9 2 ../source/replace.exe '%-^-]$' '@%&a'  < ../inputs/temp-test/2311.inp.980.11 > ../outputs/t220
    if diff ../outputs/t220 ../originals/t220 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p221) timeout -s 9 2 ../source/replace.exe '%-^?*' ''  < ../inputs/temp-test/575.inp.247.10 > ../outputs/t221
    if diff ../outputs/t221 ../originals/t221 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p222) timeout -s 9 2 ../source/replace.exe '%-c---[^0-9][0-9][9-B]-' '@n'  < ../inputs/temp-test/1034.inp.444.5 > ../outputs/t222
    if diff ../outputs/t222 ../originals/t222 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p223) timeout -s 9 2 ../source/replace.exe '%-c?' '@%@&'  < ../inputs/temp-test/605.inp.260.5 > ../outputs/t223
    if diff ../outputs/t223 ../originals/t223 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p224) timeout -s 9 2 ../source/replace.exe '%.$' 'D'  < ../inputs/input/ruin.1460 > ../outputs/t224
    if diff ../outputs/t224 ../originals/t224 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p225) timeout -s 9 2 ../source/replace.exe '%? '   < ../inputs/temp-test/218.inp.97.5 > ../outputs/t225
    if diff ../outputs/t225 ../originals/t225 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p226) timeout -s 9 2 ../source/replace.exe '%? ' 'a@nb@tc'  < ../inputs/temp-test/218.inp.97.5 > ../outputs/t226
    if diff ../outputs/t226 ../originals/t226 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p227) timeout -s 9 2 ../source/replace.exe '%? *' '@t'  < ../inputs/temp-test/859.inp.369.5 > ../outputs/t227
    if diff ../outputs/t227 ../originals/t227 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p228) timeout -s 9 2 ../source/replace.exe '%?$' '2'  < ../inputs/input/ruin.1261 > ../outputs/t228
    if diff ../outputs/t228 ../originals/t228 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p229) timeout -s 9 2 ../source/replace.exe '%?$' '9e1'  < ../inputs/input/ruin.1325 > ../outputs/t229
    if diff ../outputs/t229 ../originals/t229 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p230) timeout -s 9 2 ../source/replace.exe '%?$' 'AP'  < ../inputs/input/ruin.202 > ../outputs/t230
    if diff ../outputs/t230 ../originals/t230 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p231) timeout -s 9 2 ../source/replace.exe '%?$' 'L<5GMRl"'\''7Wl'\''3=ure'\''wFll;_2}wNR7cy/'  < ../inputs/input/ruin.1356 > ../outputs/t231
    if diff ../outputs/t231 ../originals/t231 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p232) timeout -s 9 2 ../source/replace.exe '%?$' 'TU#\gNe$1p#Jb0WI'  < ../inputs/input/ruin.1320 > ../outputs/t232
    if diff ../outputs/t232 ../originals/t232 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p233) timeout -s 9 2 ../source/replace.exe '%?$' '\'  < ../inputs/input/ruin.1440 > ../outputs/t233
    if diff ../outputs/t233 ../originals/t233 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p234) timeout -s 9 2 ../source/replace.exe '%?$' 'k (M~}|3y!1|/)<WQV:Mkr1'  < ../inputs/input/ruin.774 > ../outputs/t234
    if diff ../outputs/t234 ../originals/t234 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p235) timeout -s 9 2 ../source/replace.exe '%?$' 'oN5<e4k|K|}HrFB=iZSgZHM$1+R*ygT'  < ../inputs/input/ruin.1872 > ../outputs/t235
    if diff ../outputs/t235 ../originals/t235 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p236) timeout -s 9 2 ../source/replace.exe '%?$'  < ../inputs/input/ruin.1261 > ../outputs/t236
    if diff ../outputs/t236 ../originals/t236 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p237) timeout -s 9 2 ../source/replace.exe '%?' ')]CS#C@X3[0J\$&a[[@mGOQ'  < ../inputs/input/ruin.1876 > ../outputs/t237
    if diff ../outputs/t237 ../originals/t237 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p238) timeout -s 9 2 ../source/replace.exe '%?' '+'  < ../inputs/input/ruin.556 > ../outputs/t238
    if diff ../outputs/t238 ../originals/t238 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p239) timeout -s 9 2 ../source/replace.exe '%?' '.RM'  < ../inputs/input/ruin.1857 > ../outputs/t239
    if diff ../outputs/t239 ../originals/t239 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p240) timeout -s 9 2 ../source/replace.exe '%?' '/*XX9X]4-DijN '  < ../inputs/input/ruin.727 > ../outputs/t240
    if diff ../outputs/t240 ../originals/t240 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p241) timeout -s 9 2 ../source/replace.exe '%?' '1'  < ../inputs/input/ruin.1671 > ../outputs/t241
    if diff ../outputs/t241 ../originals/t241 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p242) timeout -s 9 2 ../source/replace.exe '%?' '6b/]'  < ../inputs/input/ruin.219 > ../outputs/t242
    if diff ../outputs/t242 ../originals/t242 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p243) timeout -s 9 2 ../source/replace.exe '%?' '7 EB+%@FvoUS  '  < ../inputs/input/ruin.1526 > ../outputs/t243
    if diff ../outputs/t243 ../originals/t243 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p244) timeout -s 9 2 ../source/replace.exe '%?' 'Q!I*e$7'  < ../inputs/input/ruin.1457 > ../outputs/t244
    if diff ../outputs/t244 ../originals/t244 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p245) timeout -s 9 2 ../source/replace.exe '%?' 'd6|=C@vL&W124Sl,6$@BY9x[JBrfpE<o0p,J"WO\A/HIDw'  < ../inputs/input/ruin.585 > ../outputs/t245
    if diff ../outputs/t245 ../originals/t245 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p246) timeout -s 9 2 ../source/replace.exe '%?' 'k'  < ../inputs/input/ruin.1361 > ../outputs/t246
    if diff ../outputs/t246 ../originals/t246 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p247) timeout -s 9 2 ../source/replace.exe '%?' 'n'  < ../inputs/input/ruin.233 > ../outputs/t247
    if diff ../outputs/t247 ../originals/t247 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p248) timeout -s 9 2 ../source/replace.exe '%?' 'qwZj/of[4fLna,@rHHd<;;1Imlc@Ya*B'  < ../inputs/input/ruin.1094 > ../outputs/t248
    if diff ../outputs/t248 ../originals/t248 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p249) timeout -s 9 2 ../source/replace.exe '%?' 'w'  < ../inputs/input/ruin.1257 > ../outputs/t249
    if diff ../outputs/t249 ../originals/t249 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p250) timeout -s 9 2 ../source/replace.exe '%?' '}=$="fk-Rix[&n#bBsqn8i!#\<p1+jntBsBI74.+2qg+$7!x/R'  < ../inputs/input/ruin.1500 > ../outputs/t250
    if diff ../outputs/t250 ../originals/t250 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p251) timeout -s 9 2 ../source/replace.exe '%?*$' 'w'  < ../inputs/input/ruin.1257 > ../outputs/t251
    if diff ../outputs/t251 ../originals/t251 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p252) timeout -s 9 2 ../source/replace.exe '%?*@*' 'NEW'  < ../inputs/temp-test/523.inp.226.5 > ../outputs/t252
    if diff ../outputs/t252 ../originals/t252 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p253) timeout -s 9 2 ../source/replace.exe '%?-$' '@t'  < ../inputs/temp-test/1871.inp.793.11 > ../outputs/t253
    if diff ../outputs/t253 ../originals/t253 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p254) timeout -s 9 2 ../source/replace.exe '%?-' '@n'  < ../inputs/temp-test/913.inp.393.5 > ../outputs/t254
    if diff ../outputs/t254 ../originals/t254 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p255) timeout -s 9 2 ../source/replace.exe '%?? *' 'NEW'  < ../inputs/temp-test/1531.inp.655.5 > ../outputs/t255
    if diff ../outputs/t255 ../originals/t255 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p256) timeout -s 9 2 ../source/replace.exe '%??-?[^@n][a-]-@*[^a--b][0-9]-$' '@%&a'  < ../inputs/temp-test/2249.inp.953.11 > ../outputs/t256
    if diff ../outputs/t256 ../originals/t256 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p257) timeout -s 9 2 ../source/replace.exe '%??[@n]-?[9-B]-^-]??[9-B]-*[^0-9]-' '@n'  < ../inputs/temp-test/1347.inp.578.7 > ../outputs/t257
    if diff ../outputs/t257 ../originals/t257 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p258) timeout -s 9 2 ../source/replace.exe '%??^[^9-B]@*?@**$' '@n'  < ../inputs/temp-test/251.inp.111.11 > ../outputs/t258
    if diff ../outputs/t258 ../originals/t258 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p259) timeout -s 9 2 ../source/replace.exe '%??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**??^[^9-B]@*?@**$' '@n'  < ../inputs/temp-test/251.inp.111.11 > ../outputs/t259
    if diff ../outputs/t259 ../originals/t259 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p260) timeout -s 9 2 ../source/replace.exe '%?@![$]@n' ''  < ../inputs/input/ruin.967 > ../outputs/t260
    if diff ../outputs/t260 ../originals/t260 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p261) timeout -s 9 2 ../source/replace.exe '%?@*$' '@%&a'  < ../inputs/temp-test/534.inp.231.11 > ../outputs/t261
    if diff ../outputs/t261 ../originals/t261 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p262) timeout -s 9 2 ../source/replace.exe '%?@*$' 'b@t'  < ../inputs/temp-test/935.inp.402.10 > ../outputs/t262
    if diff ../outputs/t262 ../originals/t262 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p263) timeout -s 9 2 ../source/replace.exe '%?@*'   < ../inputs/temp-test/523.inp.226.5 > ../outputs/t263
    if diff ../outputs/t263 ../originals/t263 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p264) timeout -s 9 2 ../source/replace.exe '%?@*' 'NEW'  < ../inputs/temp-test/523.inp.226.5 > ../outputs/t264
    if diff ../outputs/t264 ../originals/t264 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p265) timeout -s 9 2 ../source/replace.exe '%?@@' '&a@%'  < ../inputs/temp-test/2230.inp.945.7 > ../outputs/t265
    if diff ../outputs/t265 ../originals/t265 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p266) timeout -s 9 2 ../source/replace.exe '%?[-$' 'a&'  < ../inputs/temp-test/784.inp.337.11 > ../outputs/t266
    if diff ../outputs/t266 ../originals/t266 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p267) timeout -s 9 2 ../source/replace.exe '%?[0-9][9-B]-$' 'a&'  < ../inputs/temp-test/1974.inp.838.11 > ../outputs/t267
    if diff ../outputs/t267 ../originals/t267 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p268) timeout -s 9 2 ../source/replace.exe '%?[9-B][^a-c]' '@t'  < ../inputs/temp-test/939.inp.403.5 > ../outputs/t268
    if diff ../outputs/t268 ../originals/t268 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p269) timeout -s 9 2 ../source/replace.exe '%?[9-B]^a-c]-[a-c]-[^0-9]- *?-^a-]' 'NEW'  < ../inputs/temp-test/1019.inp.438.5 > ../outputs/t269
    if diff ../outputs/t269 ../originals/t269 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p270) timeout -s 9 2 ../source/replace.exe '%?[@@][^0-9][a-c]?-[^0-9]- [^9-B]$' 'NEW'  < ../inputs/temp-test/1129.inp.485.10 > ../outputs/t270
    if diff ../outputs/t270 ../originals/t270 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p271) timeout -s 9 2 ../source/replace.exe '%?[]^$' '@%&a'  < ../inputs/temp-test/513.inp.223.10 > ../outputs/t271
    if diff ../outputs/t271 ../originals/t271 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p272) timeout -s 9 2 ../source/replace.exe '%?[^9-B][^9-B]A' 'a@n'  < ../inputs/temp-test/1808.inp.768.5 > ../outputs/t272
    if diff ../outputs/t272 ../originals/t272 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p273) timeout -s 9 2 ../source/replace.exe '%?[^@@][^--z]c-[^0-9][9-B]??' 'a@n'  < ../inputs/temp-test/305.inp.136.5 > ../outputs/t273
    if diff ../outputs/t273 ../originals/t273 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p274) timeout -s 9 2 ../source/replace.exe '%?[^@n]^[@@][0-9]??-]' 'NEW'  < ../inputs/temp-test/1127.inp.484.5 > ../outputs/t274
    if diff ../outputs/t274 ../originals/t274 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p275) timeout -s 9 2 ../source/replace.exe '%?[^@n]^[@@][0-9]??-]temp-test/1183.intemp-test/1183.intemp-test/1183.intemp-test/1183.intemp-test/1183.intemp-test/1183.intemp-test/1183.intemp-test/1183.intemp-test/1183.intemp-test/1183.intemp-test/1183.i-*[^a-b]-*-*[^a-b]-*-*[^a-b]-*-*[^a-b]-*n' 'NEW'  < ../inputs/temp-test/1127.inp.484.5 > ../outputs/t275
    if diff ../outputs/t275 ../originals/t275 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p276) timeout -s 9 2 ../source/replace.exe '%?[^@t]$' 'NEW'  < ../inputs/temp-test/1485.inp.637.10 > ../outputs/t276
    if diff ../outputs/t276 ../originals/t276 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p277) timeout -s 9 2 ../source/replace.exe '%?[^]^$' '@%&a'  < ../inputs/temp-test/513.inp.223.10 > ../outputs/t277
    if diff ../outputs/t277 ../originals/t277 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p278) timeout -s 9 2 ../source/replace.exe '%?[^a--b][0-9]A*[9-B]??[^9-B]?-' 'b@t'  < ../inputs/temp-test/1414.inp.606.7 > ../outputs/t278
    if diff ../outputs/t278 ../originals/t278 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p279) timeout -s 9 2 ../source/replace.exe '%?[^a-c]-^?-[a-c]-?c*?[^9-B]-?' 'NEW'  < ../inputs/temp-test/1588.inp.676.7 > ../outputs/t279
    if diff ../outputs/t279 ../originals/t279 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p280) timeout -s 9 2 ../source/replace.exe '%?[a--b]@[*[0-9][^a-c]?@*[0-9][- *[^@@][-z][9-B]- *-[a-c]$' 'NEW'  < ../inputs/temp-test/1743.inp.741.10 > ../outputs/t280
    if diff ../outputs/t280 ../originals/t280 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p281) timeout -s 9 2 ../source/replace.exe '%?[a-]$' '@t'  < ../inputs/temp-test/2165.inp.915.10 > ../outputs/t281
    if diff ../outputs/t281 ../originals/t281 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p282) timeout -s 9 2 ../source/replace.exe '%?[a-c$' 'a@n'  < ../inputs/temp-test/770.inp.330.10 > ../outputs/t282
    if diff ../outputs/t282 ../originals/t282 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p283) timeout -s 9 2 ../source/replace.exe '%?[a-c-?' 'a@nb@tc'  < ../inputs/temp-test/2201.inp.932.5 > ../outputs/t283
    if diff ../outputs/t283 ../originals/t283 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p284) timeout -s 9 2 ../source/replace.exe '%?[a-c-?' 'a@nb@tc'  < ../inputs/temp-test/2202.inp.932.7 > ../outputs/t284
    if diff ../outputs/t284 ../originals/t284 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p285) timeout -s 9 2 ../source/replace.exe '%?^$'   < ../inputs/temp-test/513.inp.223.10 > ../outputs/t285
    if diff ../outputs/t285 ../originals/t285 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p286) timeout -s 9 2 ../source/replace.exe '%?^$' '@%&a'  < ../inputs/temp-test/513.inp.223.10 > ../outputs/t286
    if diff ../outputs/t286 ../originals/t286 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p287) timeout -s 9 2 ../source/replace.exe '%?^*$' 'a@n'  < ../inputs/temp-test/1242.inp.533.11 > ../outputs/t287
    if diff ../outputs/t287 ../originals/t287 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p288) timeout -s 9 2 ../source/replace.exe '%?^*' '&a@%'  < ../inputs/temp-test/977.inp.420.7 > ../outputs/t288
    if diff ../outputs/t288 ../originals/t288 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p289) timeout -s 9 2 ../source/replace.exe '%?c*$' '@n'  < ../inputs/temp-test/350.inp.153.11 > ../outputs/t289
    if diff ../outputs/t289 ../originals/t289 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p290) timeout -s 9 2 ../source/replace.exe '%?c*$' '@n@'  < ../inputs/temp-test/350.inp.153.11 > ../outputs/t290
    if diff ../outputs/t290 ../originals/t290 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p291) timeout -s 9 2 ../source/replace.exe '%@(' 'y:s*EV b!c[n@w>v'  < ../inputs/input/ruin.1752 > ../outputs/t291
    if diff ../outputs/t291 ../originals/t291 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p292) timeout -s 9 2 ../source/replace.exe '%@*$'  < ../inputs/temp-test/199.inp.89.5 > ../outputs/t292
    if diff ../outputs/t292 ../originals/t292 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p293) timeout -s 9 2 ../source/replace.exe '%@**-$' '&a@%'  < ../inputs/temp-test/137.inp.63.11 > ../outputs/t293
    if diff ../outputs/t293 ../originals/t293 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p294) timeout -s 9 2 ../source/replace.exe '%@**-' '&a@%'  < ../inputs/temp-test/136.inp.63.5 > ../outputs/t294
    if diff ../outputs/t294 ../originals/t294 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p295) timeout -s 9 2 ../source/replace.exe '%@**-' '@t'  < ../inputs/temp-test/1492.inp.639.5 > ../outputs/t295
    if diff ../outputs/t295 ../originals/t295 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p296) timeout -s 9 2 ../source/replace.exe '%@**--[0-9]?a-c][^-$' '&'  < ../inputs/temp-test/280.inp.125.10 > ../outputs/t296
    if diff ../outputs/t296 ../originals/t296 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p297) timeout -s 9 2 ../source/replace.exe '%@*-[^0-9]-@[[^a-c] ' 'NEW'  < ../inputs/temp-test/1489.inp.638.5 > ../outputs/t297
    if diff ../outputs/t297 ../originals/t297 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p298) timeout -s 9 2 ../source/replace.exe '%@*?' '&@n' < ../inputs/temp-test/199.inp.89.5 > ../outputs/t298
    if diff ../outputs/t298 ../originals/t298 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p299) timeout -s 9 2 ../source/replace.exe '%@*?' '@%&a'  < ../inputs/temp-test/199.inp.89.5 > ../outputs/t299
    if diff ../outputs/t299 ../originals/t299 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p300) timeout -s 9 2 ../source/replace.exe '%@*?'  < ../inputs/temp-test/199.inp.89.5 > ../outputs/t300
    if diff ../outputs/t300 ../originals/t300 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p301) timeout -s 9 2 ../source/replace.exe '%@@ ' 'L^2'\''NNI-~vNzrKq>fKK]A mg,@5N/o2s\V7N>'  < ../inputs/input/ruin.1640 > ../outputs/t301
    if diff ../outputs/t301 ../originals/t301 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p302) timeout -s 9 2 ../source/replace.exe '%@@$' ' J5VXPw6h<vW[6**p36MrPLqh'\''Q'  < ../inputs/input/ruin.1167 > ../outputs/t302
    if diff ../outputs/t302 ../originals/t302 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p303) timeout -s 9 2 ../source/replace.exe '%@@$' '@atD,[O7M4J)7%|eNA;t(aw'  < ../inputs/input/ruin.1732 > ../outputs/t303
    if diff ../outputs/t303 ../originals/t303 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p304) timeout -s 9 2 ../source/replace.exe '%@@$' 'C=K8]r8DZs;rx:9A7J^=P3r4Te2f&G1'  < ../inputs/input/ruin.1708 > ../outputs/t304
    if diff ../outputs/t304 ../originals/t304 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p305) timeout -s 9 2 ../source/replace.exe '%@@$' 'H'  < ../inputs/input/ruin.324 > ../outputs/t305
    if diff ../outputs/t305 ../originals/t305 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p306) timeout -s 9 2 ../source/replace.exe '%@@$' 'KV5^u_vH*;0X>-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^c4^sOw%oe5'\''AZr@KBq'  < ../inputs/input/ruin.1341 > ../outputs/t306
    if diff ../outputs/t306 ../originals/t306 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p307) timeout -s 9 2 ../source/replace.exe '%@@$' 'KV5^u_vH*;0X>c4^sOw%oe5'\''AZr@KBq'  < ../inputs/input/ruin.1341 > ../outputs/t307
    if diff ../outputs/t307 ../originals/t307 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p308) timeout -s 9 2 ../source/replace.exe '%@@$' 'zAlI%9cFthJlYpJ\@u|j6dDwUDk?N}i+ Z,hIh$"#iu4zV'  < ../inputs/input/ruin.515 > ../outputs/t308
    if diff ../outputs/t308 ../originals/t308 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p309) timeout -s 9 2 ../source/replace.exe '%@@$?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*?[^--z]c[^9-B][^9-B]c?*' 'KV5^u_vH*;0X>c4^sOw%oe5'\''AZr@KBq'  < ../inputs/input/ruin.1341 > ../outputs/t309
    if diff ../outputs/t309 ../originals/t309 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p310) timeout -s 9 2 ../source/replace.exe '%@@$@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?t]*[@t@][9-B]-*[0-9]][@t]*[@t@][9-B]t]*[@t@][9-B]-*[0-9]][@t]*[@t@][9-B]' 'H'  < ../inputs/input/ruin.324 > ../outputs/t310
    if diff ../outputs/t310 ../originals/t310 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p311) timeout -s 9 2 ../source/replace.exe '%@@' ' B!ls?r*Bk.lC'\''l<T+]?*;};+pT+]:0qdY0\L"V0w*T2'  < ../inputs/input/ruin.767 > ../outputs/t311
    if diff ../outputs/t311 ../originals/t311 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p312) timeout -s 9 2 ../source/replace.exe '%@@' '6'  < ../inputs/input/ruin.190 > ../outputs/t312
    if diff ../outputs/t312 ../originals/t312 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p313) timeout -s 9 2 ../source/replace.exe '%@@' '7'  < ../inputs/input/ruin.209 > ../outputs/t313
    if diff ../outputs/t313 ../originals/t313 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p314) timeout -s 9 2 ../source/replace.exe '%@@' '<'  < ../inputs/input/ruin.1961 > ../outputs/t314
    if diff ../outputs/t314 ../originals/t314 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p315) timeout -s 9 2 ../source/replace.exe '%@@' 'A'  < ../inputs/input/ruin.23 > ../outputs/t315
    if diff ../outputs/t315 ../originals/t315 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p316) timeout -s 9 2 ../source/replace.exe '%@@' 'C#6L=cT|[<GnK><~'  < ../inputs/input/ruin.152 > ../outputs/t316
    if diff ../outputs/t316 ../originals/t316 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p317) timeout -s 9 2 ../source/replace.exe '%@@' 'E'  < ../inputs/input/ruin.1281 > ../outputs/t317
    if diff ../outputs/t317 ../originals/t317 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p318) timeout -s 9 2 ../source/replace.exe '%@@' 'H'  < ../inputs/input/ruin.90 > ../outputs/t318
    if diff ../outputs/t318 ../originals/t318 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p319) timeout -s 9 2 ../source/replace.exe '%@@' 'Hgsuo[7/`Q'  < ../inputs/input/ruin.123 > ../outputs/t319
    if diff ../outputs/t319 ../originals/t319 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p320) timeout -s 9 2 ../source/replace.exe '%@@' 'JOmk4tJ'  < ../inputs/input/ruin.223 > ../outputs/t320
    if diff ../outputs/t320 ../originals/t320 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p321) timeout -s 9 2 ../source/replace.exe '%@@' 'KJ={Rl7_z1X$p:%SG'  < ../inputs/input/ruin.1477 > ../outputs/t321
    if diff ../outputs/t321 ../originals/t321 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p322) timeout -s 9 2 ../source/replace.exe '%@@' 'M.10\?_|(0803q:sHHzal#;;M<2`.,HRVz"'\''il'  < ../inputs/input/ruin.133 > ../outputs/t322
    if diff ../outputs/t322 ../originals/t322 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p323) timeout -s 9 2 ../source/replace.exe '%@@' 'V@'  < ../inputs/input/ruin.1083 > ../outputs/t323
    if diff ../outputs/t323 ../originals/t323 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p324) timeout -s 9 2 ../source/replace.exe '%@@' 'Yp'  < ../inputs/input/ruin.3 > ../outputs/t324
    if diff ../outputs/t324 ../originals/t324 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p325) timeout -s 9 2 ../source/replace.exe '%@@' 'b04ZLrhsr,4"4&K!&ZA1"ZA;]/XF3SXotQ'  < ../inputs/input/ruin.1226 > ../outputs/t325
    if diff ../outputs/t325 ../originals/t325 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p326) timeout -s 9 2 ../source/replace.exe '%@@' 'i'  < ../inputs/input/ruin.472 > ../outputs/t326
    if diff ../outputs/t326 ../originals/t326 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p327) timeout -s 9 2 ../source/replace.exe '%@@' 'j'  < ../inputs/input/ruin.38 > ../outputs/t327
    if diff ../outputs/t327 ../originals/t327 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p328) timeout -s 9 2 ../source/replace.exe '%@@' 'j'  < ../inputs/input/ruin.441 > ../outputs/t328
    if diff ../outputs/t328 ../originals/t328 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p329) timeout -s 9 2 ../source/replace.exe '%@@' 'k'  < ../inputs/input/ruin.1730 > ../outputs/t329
    if diff ../outputs/t329 ../originals/t329 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p330) timeout -s 9 2 ../source/replace.exe '%@@' 'm|~+U+9'\''<y9E'  < ../inputs/input/ruin.1120 > ../outputs/t330
    if diff ../outputs/t330 ../originals/t330 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p331) timeout -s 9 2 ../source/replace.exe '%@@' 'sI1TM{>'\''bMi-}&'  < ../inputs/input/ruin.477 > ../outputs/t331
    if diff ../outputs/t331 ../originals/t331 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p332) timeout -s 9 2 ../source/replace.exe '%@@' 'tU/3F0P2)T;xy=$:fIU'  < ../inputs/input/ruin.781 > ../outputs/t332
    if diff ../outputs/t332 ../originals/t332 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p333) timeout -s 9 2 ../source/replace.exe '%@@' 'w'  < ../inputs/input/ruin.1634 > ../outputs/t333
    if diff ../outputs/t333 ../originals/t333 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p334) timeout -s 9 2 ../source/replace.exe '%@@' '}Y}'  < ../inputs/input/ruin.1314 > ../outputs/t334
    if diff ../outputs/t334 ../originals/t334 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p335) timeout -s 9 2 ../source/replace.exe '%@@*$' 'm|~+U+9'\''<y9E'  < ../inputs/input/ruin.1120 > ../outputs/t335
    if diff ../outputs/t335 ../originals/t335 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p336) timeout -s 9 2 ../source/replace.exe '%@@*' 'p'  < ../inputs/input/ruin.283 > ../outputs/t336
    if diff ../outputs/t336 ../originals/t336 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p337) timeout -s 9 2 ../source/replace.exe '%@@*[^9-B] *-c*[-' '&a@%'  < ../inputs/temp-test/1497.inp.641.7 > ../outputs/t337
    if diff ../outputs/t337 ../originals/t337 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p338) timeout -s 9 2 ../source/replace.exe '%@@=' ')&hL~6sDzLioa!)wc9QfBOO'\''qiXG^o1*za&dr |;Z%Nn^h*rq'  < ../inputs/input/ruin.399 > ../outputs/t338
    if diff ../outputs/t338 ../originals/t338 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p339) timeout -s 9 2 ../source/replace.exe '%@@?$' '>A('  < ../inputs/input/ruin.751 > ../outputs/t339
    if diff ../outputs/t339 ../originals/t339 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p340) timeout -s 9 2 ../source/replace.exe '%@@@@@@$' 'PxkC zwUtqc`<IFt"RoQ!F'\''D9z7OL;xo$/o&6XdE=StMNWl|iTbck%*z'  < ../inputs/input/ruin.525 > ../outputs/t340
    if diff ../outputs/t340 ../originals/t340 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p341) timeout -s 9 2 ../source/replace.exe '%@@@@\x[^v]@@' '/!OJ=t,WAMc%C'  < ../inputs/input/ruin.344 > ../outputs/t341
    if diff ../outputs/t341 ../originals/t341 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p342) timeout -s 9 2 ../source/replace.exe '%@@\' '_e/7aN*GF0pWy#='  < ../inputs/input/ruin.310 > ../outputs/t342
    if diff ../outputs/t342 ../originals/t342 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p343) timeout -s 9 2 ../source/replace.exe '%@[*[9-B]' '&'  < ../inputs/temp-test/492.inp.215.5 > ../outputs/t343
    if diff ../outputs/t343 ../originals/t343 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p344) timeout -s 9 2 ../source/replace.exe '%@[*[9-B]@' '&'  < ../inputs/temp-test/492.inp.215.5 > ../outputs/t344
    if diff ../outputs/t344 ../originals/t344 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p345) timeout -s 9 2 ../source/replace.exe '%@[*[a-c]$' 'NEW'  < ../inputs/temp-test/1372.inp.588.11 > ../outputs/t345
    if diff ../outputs/t345 ../originals/t345 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p346) timeout -s 9 2 ../source/replace.exe '%@[[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B]' 'a&'  < ../inputs/temp-test/2269.inp.961.5 > ../outputs/t346
    if diff ../outputs/t346 ../originals/t346 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p347) timeout -s 9 2 ../source/replace.exe '%@d' 'fg~4[LmRA3o6:cW<[RU@3H*M;Z:.;y'\'',gC?= VPAFmAF'\'':1)z3<<'  < ../inputs/input/ruin.377 > ../outputs/t347
    if diff ../outputs/t347 ../originals/t347 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p348) timeout -s 9 2 ../source/replace.exe '%@n' '`'  < ../inputs/input/ruin.1158 > ../outputs/t348
    if diff ../outputs/t348 ../originals/t348 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p349) timeout -s 9 2 ../source/replace.exe '%@n' 'l|'  < ../inputs/input/ruin.1775 > ../outputs/t349
    if diff ../outputs/t349 ../originals/t349 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p350) timeout -s 9 2 ../source/replace.exe '%@n' 'v'  < ../inputs/input/ruin.1561 > ../outputs/t350
    if diff ../outputs/t350 ../originals/t350 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p351) timeout -s 9 2 ../source/replace.exe '%@n'  < ../inputs/input/ruin.1158 > ../outputs/t351
    if diff ../outputs/t351 ../originals/t351 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p352) timeout -s 9 2 ../source/replace.exe '%@n?' ''  < ../inputs/input/ruin.1860 > ../outputs/t352
    if diff ../outputs/t352 ../originals/t352 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p353) timeout -s 9 2 ../source/replace.exe '%@t$' '\_'  < ../inputs/input/ruin.1586 > ../outputs/t353
    if diff ../outputs/t353 ../originals/t353 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p354) timeout -s 9 2 ../source/replace.exe '%@t*' '@'  < ../inputs/input/ruin.1787 > ../outputs/t354
    if diff ../outputs/t354 ../originals/t354 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p355) timeout -s 9 2 ../source/replace.exe '%A' ':45s3M%Yaoud%{~QFrbA`:&NwJ9(nw}Qy=?D['  < ../inputs/input/ruin.1115 > ../outputs/t355
    if diff ../outputs/t355 ../originals/t355 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p356) timeout -s 9 2 ../source/replace.exe '%A*$' ':45s3M%Yaoud%{~QFrbA`:&NwJ9(nw}Qy=?D['  < ../inputs/input/ruin.1115 > ../outputs/t356
    if diff ../outputs/t356 ../originals/t356 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p357) timeout -s 9 2 ../source/replace.exe '%A*[^0-9]*$' '@%@&'  < ../inputs/temp-test/36.inp.15.10 > ../outputs/t357
    if diff ../outputs/t357 ../originals/t357 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p358) timeout -s 9 2 ../source/replace.exe '%A[0-9]?@**[a-c][^0-9]$' '@%&a'  < ../inputs/temp-test/672.inp.292.11 > ../outputs/t358
    if diff ../outputs/t358 ../originals/t358 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p359) timeout -s 9 2 ../source/replace.exe '%E$' 'I'  < ../inputs/input/ruin.1790 > ../outputs/t359
    if diff ../outputs/t359 ../originals/t359 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p360) timeout -s 9 2 ../source/replace.exe '%E' 'E'  < ../inputs/input/ruin.1184 > ../outputs/t360
    if diff ../outputs/t360 ../originals/t360 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p361) timeout -s 9 2 ../source/replace.exe '%E?' 'h'  < ../inputs/input/ruin.903 > ../outputs/t361
    if diff ../outputs/t361 ../originals/t361 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p362) timeout -s 9 2 ../source/replace.exe '%O$' '\'  < ../inputs/input/ruin.683 > ../outputs/t362
    if diff ../outputs/t362 ../originals/t362 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p363) timeout -s 9 2 ../source/replace.exe '%P$' 'dLQ('  < ../inputs/input/ruin.1532 > ../outputs/t363
    if diff ../outputs/t363 ../originals/t363 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p364) timeout -s 9 2 ../source/replace.exe '%S' ' P'  < ../inputs/input/ruin.1601 > ../outputs/t364
    if diff ../outputs/t364 ../originals/t364 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p365) timeout -s 9 2 ../source/replace.exe '%S?*' ' P'  < ../inputs/input/ruin.1601 > ../outputs/t365
    if diff ../outputs/t365 ../originals/t365 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p366) timeout -s 9 2 ../source/replace.exe '%U' 'N+2rHDje[,A_^!$*}]k`e2{1lp*{^'  < ../inputs/input/ruin.15 > ../outputs/t366
    if diff ../outputs/t366 ../originals/t366 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p367) timeout -s 9 2 ../source/replace.exe '%U' 'h<z?cC=|(I]>/deslsGqiEdmY'  < ../inputs/input/ruin.1760 > ../outputs/t367
    if diff ../outputs/t367 ../originals/t367 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p368) timeout -s 9 2 ../source/replace.exe '%V' '`wtFDA"\YWV{x=qMe@$iJ&LgdV'  < ../inputs/input/ruin.757 > ../outputs/t368
    if diff ../outputs/t368 ../originals/t368 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p369) timeout -s 9 2 ../source/replace.exe '%V' 'd'  < ../inputs/input/ruin.1707 > ../outputs/t369
    if diff ../outputs/t369 ../originals/t369 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p370) timeout -s 9 2 ../source/replace.exe '%WQtcc@n' '( $V0B&16|L'  < ../inputs/input/ruin.270 > ../outputs/t370
    if diff ../outputs/t370 ../originals/t370 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p371) timeout -s 9 2 ../source/replace.exe '%[-z][^9-B]?--[^9-B]-[^9-B][^9-B]-?@%[-z][^9-B]?--[^9-B]-[^9-B][^9-B]-?@[[%[-z][^9-B]?--[^9-B]-[^9-B][^9-B]-?@[%[-z][^9-B]?--[^9-B]-[^9-B][^9-B]-?@[%[-z][^9-B]?--[^9-B]-[^9-B][^9-B]-?@[' '@n'  < ../inputs/temp-test/2096.inp.888.5 > ../outputs/t371
    if diff ../outputs/t371 ../originals/t371 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p372) timeout -s 9 2 ../source/replace.exe '%[-z][^9-B]?--[^9-B]-[^9-B][^9-B]-?@[' '@n'  < ../inputs/temp-test/2096.inp.888.5 > ../outputs/t372
    if diff ../outputs/t372 ../originals/t372 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p373) timeout -s 9 2 ../source/replace.exe '%[0-4-1]' '-1'  < ../inputs/moni/f7.inp > ../outputs/t373
    if diff ../outputs/t373 ../originals/t373 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p374) timeout -s 9 2 ../source/replace.exe '%[0-9H]$' 'l*>nm)BOulbBc1&N6A'  < ../inputs/input/ruin.549 > ../outputs/t374
    if diff ../outputs/t374 ../originals/t374 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p375) timeout -s 9 2 ../source/replace.exe '%[0-9]' 'l'  < ../inputs/input/ruin.1572 > ../outputs/t375
    if diff ../outputs/t375 ../originals/t375 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p376) timeout -s 9 2 ../source/replace.exe '%[0-9]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t376
    if diff ../outputs/t376 ../originals/t376 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p377) timeout -s 9 2 ../source/replace.exe '%[0-9]-[9-B]?-[9-B]^-]?$' 'NEW'  < ../inputs/temp-test/1672.inp.712.10 > ../outputs/t377
    if diff ../outputs/t377 ../originals/t377 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p378) timeout -s 9 2 ../source/replace.exe '%[0-9]?' '@t'  < ../inputs/temp-test/1048.inp.451.5 > ../outputs/t378
    if diff ../outputs/t378 ../originals/t378 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p379) timeout -s 9 2 ../source/replace.exe '%[0-9]@@' '@%&a'  < ../inputs/temp-test/1696.inp.723.5 > ../outputs/t379
    if diff ../outputs/t379 ../originals/t379 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p380) timeout -s 9 2 ../source/replace.exe '%[0-9]@[*' '@n'  < ../inputs/temp-test/844.inp.362.5 > ../outputs/t380
    if diff ../outputs/t380 ../originals/t380 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p381) timeout -s 9 2 ../source/replace.exe '%[0-9][^9-B][@t][^a-c]' '@%&a'  < ../inputs/temp-test/1040.inp.447.5 > ../outputs/t381
    if diff ../outputs/t381 ../originals/t381 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p382) timeout -s 9 2 ../source/replace.exe '%[1]*@@' '@YLmg{>yPr b&3<TkY4-a|k+L63(J^$~xY:n\b6%fo3[-n, =}@e'  < ../inputs/input/ruin.626 > ../outputs/t382
    if diff ../outputs/t382 ../originals/t382 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p383) timeout -s 9 2 ../source/replace.exe '%[9-B]' '&'  < ../inputs/temp-test/2307.inp.979.7 > ../outputs/t383
    if diff ../outputs/t383 ../originals/t383 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p384) timeout -s 9 2 ../source/replace.exe '%[9-B]-$' 'NEW'  < ../inputs/temp-test/1455.inp.623.10 > ../outputs/t384
    if diff ../outputs/t384 ../originals/t384 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p385) timeout -s 9 2 ../source/replace.exe '%[9-B]?$' '&a@%'  < ../inputs/temp-test/2045.inp.867.10 > ../outputs/t385
    if diff ../outputs/t385 ../originals/t385 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p386) timeout -s 9 2 ../source/replace.exe '%[9-B]?' '@%&a'  < ../inputs/temp-test/801.inp.344.5 > ../outputs/t386
    if diff ../outputs/t386 ../originals/t386 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p387) timeout -s 9 2 ../source/replace.exe '%[9-B]?-@[*[^9-B]-@tc*a-]' '@n'  < ../inputs/temp-test/1536.inp.657.7 > ../outputs/t387
    if diff ../outputs/t387 ../originals/t387 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p388) timeout -s 9 2 ../source/replace.exe '%[9-B][^a--]' 'a@nb@tc'  < ../inputs/temp-test/1355.inp.581.5 > ../outputs/t388
    if diff ../outputs/t388 ../originals/t388 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p389) timeout -s 9 2 ../source/replace.exe '%[9-B]c*?@[*-? $' '&'  < ../inputs/temp-test/436.inp.191.10 > ../outputs/t389
    if diff ../outputs/t389 ../originals/t389 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p390) timeout -s 9 2 ../source/replace.exe '%[>-AA-G>-A]' '%'  < ../inputs/input/ruin.801 > ../outputs/t390
    if diff ../outputs/t390 ../originals/t390 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p391) timeout -s 9 2 ../source/replace.exe '%[>-A]$' 'Rob"FQFK`\,mU`gzl<R<1`Ns4W.g'  < ../inputs/input/ruin.371 > ../outputs/t391
    if diff ../outputs/t391 ../originals/t391 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p392) timeout -s 9 2 ../source/replace.exe '%[@t]- [^0-9][^a-^?@n?$' 'a&'  < ../inputs/temp-test/2252.inp.954.10 > ../outputs/t392
    if diff ../outputs/t392 ../originals/t392 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p393) timeout -s 9 2 ../source/replace.exe '%[@t]@*?[^-[9-B]-' 'b@t'  < ../inputs/temp-test/1732.inp.736.5 > ../outputs/t393
    if diff ../outputs/t393 ../originals/t393 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p394) timeout -s 9 2 ../source/replace.exe '%[A-G0-9]' 'aKzJRRKf,'\''We6;r+n+]pU-`P}I'  < ../inputs/input/ruin.988 > ../outputs/t394
    if diff ../outputs/t394 ../originals/t394 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p395) timeout -s 9 2 ../source/replace.exe '%[A-G]' 'P'  < ../inputs/input/ruin.730 > ../outputs/t395
    if diff ../outputs/t395 ../originals/t395 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p396) timeout -s 9 2 ../source/replace.exe '%[A-G]' 'xeD;,?BG|~6y8P D&x*"3r^Ej5VL$'  < ../inputs/input/ruin.1081 > ../outputs/t396
    if diff ../outputs/t396 ../originals/t396 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p397) timeout -s 9 2 ../source/replace.exe '%[I]'   < ../inputs/input/ruin.1156 > ../outputs/t397
    if diff ../outputs/t397 ../originals/t397 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p398) timeout -s 9 2 ../source/replace.exe '%[I]' 'r?alRkSvq6'  < ../inputs/input/ruin.1156 > ../outputs/t398
    if diff ../outputs/t398 ../originals/t398 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p399) timeout -s 9 2 ../source/replace.exe '%[R]$' 'f&<'  < ../inputs/input/ruin.9 > ../outputs/t399
    if diff ../outputs/t399 ../originals/t399 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p400) timeout -s 9 2 ../source/replace.exe '%[Z-a]^_`a]$' 'easgtgK\'\''\*W LdSez|/"f'  < ../inputs/input/ruin.76 > ../outputs/t400
    if diff ../outputs/t400 ../originals/t400 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p401) timeout -s 9 2 ../source/replace.exe '%[]? ' 'a@nb@tc'  < ../inputs/temp-test/218.inp.97.5 > ../outputs/t401
    if diff ../outputs/t401 ../originals/t401 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p402) timeout -s 9 2 ../source/replace.exe '%[][^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/527.inp.228.5 > ../outputs/t402
    if diff ../outputs/t402 ../originals/t402 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p403) timeout -s 9 2 ../source/replace.exe '%[^-z] ' 'NEW'  < ../inputs/temp-test/248.inp.110.5 > ../outputs/t403
    if diff ../outputs/t403 ../originals/t403 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p404) timeout -s 9 2 ../source/replace.exe '%[^0-9] [^9-B]--[0-9]??[a-c]?-' ''  < ../inputs/temp-test/568.inp.244.5 > ../outputs/t404
    if diff ../outputs/t404 ../originals/t404 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p405) timeout -s 9 2 ../source/replace.exe '%[^0-9]' '&'  < ../inputs/temp-test/665.inp.289.5 > ../outputs/t405
    if diff ../outputs/t405 ../originals/t405 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p406) timeout -s 9 2 ../source/replace.exe '%[^0-9]' '@%@&'  < ../inputs/temp-test/2005.inp.851.5 > ../outputs/t406
    if diff ../outputs/t406 ../originals/t406 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p407) timeout -s 9 2 ../source/replace.exe '%[^0-9]*$' '@t'  < ../inputs/temp-test/527.inp.228.5 > ../outputs/t407
    if diff ../outputs/t407 ../originals/t407 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p408) timeout -s 9 2 ../source/replace.exe '%[^0-9]*' '@t'  < ../inputs/temp-test/527.inp.228.5 > ../outputs/t408
    if diff ../outputs/t408 ../originals/t408 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p409) timeout -s 9 2 ../source/replace.exe '%[^0-9]-' '@%&a'  < ../inputs/temp-test/1570.inp.670.5 > ../outputs/t409
    if diff ../outputs/t409 ../originals/t409 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p410) timeout -s 9 2 ../source/replace.exe '%[^0-9]-?[9-B]?-[9-B]?'   < ../inputs/temp-test/527.inp.228.5 > ../outputs/t410
    if diff ../outputs/t410 ../originals/t410 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p411) timeout -s 9 2 ../source/replace.exe '%[^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/527.inp.228.5 > ../outputs/t411
    if diff ../outputs/t411 ../originals/t411 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p412) timeout -s 9 2 ../source/replace.exe '%[^0-9]?' '@%@&'  < ../inputs/temp-test/942.inp.404.5 > ../outputs/t412
    if diff ../outputs/t412 ../originals/t412 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p413) timeout -s 9 2 ../source/replace.exe '%[^0-9]?*' '@t'  < ../inputs/temp-test/527.inp.228.5 > ../outputs/t413
    if diff ../outputs/t413 ../originals/t413 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p414) timeout -s 9 2 ../source/replace.exe '%[^0-9]@t*' '&a@%'  < ../inputs/temp-test/461.inp.202.5 > ../outputs/t414
    if diff ../outputs/t414 ../originals/t414 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p415) timeout -s 9 2 ../source/replace.exe '%[^0-9]A?' '@n'  < ../inputs/temp-test/1835.inp.780.7 > ../outputs/t415
    if diff ../outputs/t415 ../originals/t415 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p416) timeout -s 9 2 ../source/replace.exe '%[^0-9][^0-9][^9-B]' '@n'  < ../inputs/temp-test/1955.inp.829.5 > ../outputs/t416
    if diff ../outputs/t416 ../originals/t416 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p417) timeout -s 9 2 ../source/replace.exe '%[^0-9][a--][^9-B][^-z]$' 'a@nb@tc'  < ../inputs/temp-test/2256.inp.956.10 > ../outputs/t417
    if diff ../outputs/t417 ../originals/t417 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p418) timeout -s 9 2 ../source/replace.exe '%[^0-9][a-]$' ''  < ../inputs/temp-test/151.inp.68.10 > ../outputs/t418
    if diff ../outputs/t418 ../originals/t418 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p419) timeout -s 9 2 ../source/replace.exe '%[^0-9][a-c]$' ''  < ../inputs/temp-test/728.inp.313.10 > ../outputs/t419
    if diff ../outputs/t419 ../originals/t419 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p420) timeout -s 9 2 ../source/replace.exe '%[^9-B]$' 'a&'  < ../inputs/temp-test/1539.inp.658.10 > ../outputs/t420
    if diff ../outputs/t420 ../originals/t420 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p421) timeout -s 9 2 ../source/replace.exe '%[^9-B]-' '@%&a'  < ../inputs/temp-test/2131.inp.902.5 > ../outputs/t421
    if diff ../outputs/t421 ../originals/t421 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p422) timeout -s 9 2 ../source/replace.exe '%[^9-B]?' '&'  < ../inputs/temp-test/2161.inp.914.5 > ../outputs/t422
    if diff ../outputs/t422 ../originals/t422 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p423) timeout -s 9 2 ../source/replace.exe '%[^9-B]?' '@%@&'  < ../inputs/temp-test/1555.inp.665.5 > ../outputs/t423
    if diff ../outputs/t423 ../originals/t423 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p424) timeout -s 9 2 ../source/replace.exe '%[^9-B]?-[^9-B]-*-[^9-B][^0-9]-*-[^0-9]$' '@%&a'  < ../inputs/temp-test/1083.inp.466.10 > ../outputs/t424
    if diff ../outputs/t424 ../originals/t424 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p425) timeout -s 9 2 ../source/replace.exe '%[^9-B]?[a-c-?a-][^a-]-?-[9-B][0-9][^a-c*[0-9][^0-9]@[[9-B][^a-c]$' ''  < ../inputs/temp-test/1224.inp.525.10 > ../outputs/t425
    if diff ../outputs/t425 ../originals/t425 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p426) timeout -s 9 2 ../source/replace.exe '%[^9-B][9-B]-*?[^@@]-a-]-' '@%&a'  < ../inputs/temp-test/2143.inp.907.5 > ../outputs/t426
    if diff ../outputs/t426 ../originals/t426 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p427) timeout -s 9 2 ../source/replace.exe '%[^9-B][a-c]$' '@%&a'  < ../inputs/temp-test/1306.inp.561.10 > ../outputs/t427
    if diff ../outputs/t427 ../originals/t427 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p428) timeout -s 9 2 ../source/replace.exe '%[^>-A]' 'm})h'  < ../inputs/input/ruin.816 > ../outputs/t428
    if diff ../outputs/t428 ../originals/t428 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p429) timeout -s 9 2 ../source/replace.exe '%[^>-A]' 'rw`h-v1P5_?OU7NRz`:a9HNb]H="9cjwym["lqG<!&sYJc^dbfdN7N2ms3E ZS&g'  < ../inputs/input/ruin.666 > ../outputs/t429
    if diff ../outputs/t429 ../originals/t429 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p430) timeout -s 9 2 ../source/replace.exe '%[^>-A]' 'w'  < ../inputs/input/ruin.1698 > ../outputs/t430
    if diff ../outputs/t430 ../originals/t430 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p431) timeout -s 9 2 ../source/replace.exe '%[^?z-}>-A0-9A-GZ-a]^_`a-c-ac-a]' 'NA'  < ../inputs/input/ruin.293 > ../outputs/t431
    if diff ../outputs/t431 ../originals/t431 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p432) timeout -s 9 2 ../source/replace.exe '%[^?z-}>-A0-9A-GZ-a]^_`a-c-ac-a]@n' 'N&A'  < ../inputs/input/ruin.293 > ../outputs/t432
    if diff ../outputs/t432 ../originals/t432 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p433) timeout -s 9 2 ../source/replace.exe '%[^A-G]$' 'Pb'  < ../inputs/input/ruin.1111 > ../outputs/t433
    if diff ../outputs/t433 ../originals/t433 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p434) timeout -s 9 2 ../source/replace.exe '%[^A-G]' '(Qk '  < ../inputs/input/ruin.1205 > ../outputs/t434
    if diff ../outputs/t434 ../originals/t434 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p435) timeout -s 9 2 ../source/replace.exe '%[^B]' 'o'  < ../inputs/input/ruin.733 > ../outputs/t435
    if diff ../outputs/t435 ../originals/t435 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p436) timeout -s 9 2 ../source/replace.exe '%[^Z-a]^_`a]' 'J=iYas^_]iYPHxV5eUw(z'  < ../inputs/input/ruin.1660 > ../outputs/t436
    if diff ../outputs/t436 ../originals/t436 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p437) timeout -s 9 2 ../source/replace.exe '%[^]? ' 'a@nb@tc'  < ../inputs/temp-test/218.inp.97.5 > ../outputs/t437
    if diff ../outputs/t437 ../originals/t437 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p438) timeout -s 9 2 ../source/replace.exe '%[^][^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/527.inp.228.5 > ../outputs/t438
    if diff ../outputs/t438 ../originals/t438 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p439) timeout -s 9 2 ../source/replace.exe '%[^a-' '&'  < ../inputs/temp-test/2316.inp.982.7 > ../outputs/t439
    if diff ../outputs/t439 ../originals/t439 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p440) timeout -s 9 2 ../source/replace.exe '%[^a-?[a-]?-?-]' '&'  < ../inputs/temp-test/49.inp.20.7 > ../outputs/t440
    if diff ../outputs/t440 ../originals/t440 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p441) timeout -s 9 2 ../source/replace.exe '%[^a-c]' '@%@&'  < ../inputs/temp-test/2282.inp.966.7 > ../outputs/t441
    if diff ../outputs/t441 ../originals/t441 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p442) timeout -s 9 2 ../source/replace.exe '%[^a-c]???@*?[^a-c][a-c[^9-B]$' 'NEW'  < ../inputs/temp-test/484.inp.211.10 > ../outputs/t442
    if diff ../outputs/t442 ../originals/t442 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p443) timeout -s 9 2 ../source/replace.exe '%[^a-c]?[^0-9]a-c][9-B]c*?[^0-9]$' ''  < ../inputs/temp-test/1295.inp.555.10 > ../outputs/t443
    if diff ../outputs/t443 ../originals/t443 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p444) timeout -s 9 2 ../source/replace.exe '%[^a-c]?[^0-9]a-c][9-B]c*?[^0-9]' ''  < ../inputs/temp-test/1294.inp.555.7 > ../outputs/t444
    if diff ../outputs/t444 ../originals/t444 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p445) timeout -s 9 2 ../source/replace.exe '%[^a-c]@t*$' '@t'  < ../inputs/temp-test/1191.inp.512.10 > ../outputs/t445
    if diff ../outputs/t445 ../originals/t445 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p446) timeout -s 9 2 ../source/replace.exe '%[^a-c]@t*' '@t'  < ../inputs/temp-test/1190.inp.512.7 > ../outputs/t446
    if diff ../outputs/t446 ../originals/t446 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p447) timeout -s 9 2 ../source/replace.exe '%[^a-c][0-9]' 'a&'  < ../inputs/temp-test/1784.inp.759.5 > ../outputs/t447
    if diff ../outputs/t447 ../originals/t447 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p448) timeout -s 9 2 ../source/replace.exe '%[^a-c][9-B]$' '@%@&'  < ../inputs/temp-test/1644.inp.700.10 > ../outputs/t448
    if diff ../outputs/t448 ../originals/t448 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p449) timeout -s 9 2 ../source/replace.exe '%[^a-c]^*' '@%@&'  < ../inputs/temp-test/2300.inp.976.5 > ../outputs/t449
    if diff ../outputs/t449 ../originals/t449 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p450) timeout -s 9 2 ../source/replace.exe '%[^c-a>-A]' 'q\)&urQRC6v%ZLu%T%'  < ../inputs/input/ruin.1358 > ../outputs/t450
    if diff ../outputs/t450 ../originals/t450 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p451) timeout -s 9 2 ../source/replace.exe '%[^~>-A<]' 'W'  < ../inputs/input/ruin.1816 > ../outputs/t451
    if diff ../outputs/t451 ../originals/t451 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p452) timeout -s 9 2 ../source/replace.exe '%[_-z]-' '@n'  < ../inputs/temp-test/811.inp.348.7 > ../outputs/t452
    if diff ../outputs/t452 ../originals/t452 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p453) timeout -s 9 2 ../source/replace.exe '%[a-?$' 'NEW'  < ../inputs/temp-test/737.inp.316.11 > ../outputs/t453
    if diff ../outputs/t453 ../originals/t453 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p454) timeout -s 9 2 ../source/replace.exe '%[a-]-*[a-c][^a--]-$' '@t'  < ../inputs/temp-test/1091.inp.470.10 > ../outputs/t454
    if diff ../outputs/t454 ../originals/t454 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p455) timeout -s 9 2 ../source/replace.exe '%[a-b]?**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t455
    if diff ../outputs/t455 ../originals/t455 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p456) timeout -s 9 2 ../source/replace.exe '%[a-c-@@[0-9][^a-]?a-c]--c*$' '@%@&'  < ../inputs/temp-test/1976.inp.839.10 > ../outputs/t456
    if diff ../outputs/t456 ../originals/t456 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p457) timeout -s 9 2 ../source/replace.exe '%[a-c[^9-B]' '@%@&'  < ../inputs/temp-test/1431.inp.614.7 > ../outputs/t457
    if diff ../outputs/t457 ../originals/t457 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p458) timeout -s 9 2 ../source/replace.exe '%[a-c]$' 'a@nb@tc'  < ../inputs/temp-test/1342.inp.576.11 > ../outputs/t458
    if diff ../outputs/t458 ../originals/t458 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p459) timeout -s 9 2 ../source/replace.exe '%[a-c]-$' 'a@nb@tc'  < ../inputs/temp-test/1632.inp.694.10 > ../outputs/t459
    if diff ../outputs/t459 ../originals/t459 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p460) timeout -s 9 2 ../source/replace.exe '%[a-c]?[^9-B][9-B][^a--b][0-9]-@@*' '@%&a'  < ../inputs/temp-test/490.inp.214.7 > ../outputs/t460
    if diff ../outputs/t460 ../originals/t460 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p461) timeout -s 9 2 ../source/replace.exe '%[a-c]?[^9-B][9-B][^a--b][0-9]-@@*@' '@%&a'  < ../inputs/temp-test/490.inp.214.7 > ../outputs/t461
    if diff ../outputs/t461 ../originals/t461 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p462) timeout -s 9 2 ../source/replace.exe '%[a-c][^0-9]*[a-c]' '&@n'  < ../inputs/temp-test/693.inp.300.5 > ../outputs/t462
    if diff ../outputs/t462 ../originals/t462 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p463) timeout -s 9 2 ../source/replace.exe '%[a-c][^0-9]*[a-c]' '&@nmohaw'  < ../inputs/temp-test/693.inp.300.5 > ../outputs/t463
    if diff ../outputs/t463 ../originals/t463 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p464) timeout -s 9 2 ../source/replace.exe '%[a-c][^0-9]-*-[a-c]-' '@n'  < ../inputs/temp-test/693.inp.300.5 > ../outputs/t464
    if diff ../outputs/t464 ../originals/t464 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p465) timeout -s 9 2 ../source/replace.exe '%[c-az-}z-}>-AA-Gz-}z-}c-a]r' '%'  < ../inputs/input/ruin.1529 > ../outputs/t465
    if diff ../outputs/t465 ../originals/t465 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p466) timeout -s 9 2 ../source/replace.exe '%[g]' 'JR]VaH^{mV&/1Ta}4.dF0WCLpBLR8AShG"$St'  < ../inputs/input/ruin.1432 > ../outputs/t466
    if diff ../outputs/t466 ../originals/t466 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p467) timeout -s 9 2 ../source/replace.exe '%[k]' 'T'  < ../inputs/input/ruin.475 > ../outputs/t467
    if diff ../outputs/t467 ../originals/t467 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p468) timeout -s 9 2 ../source/replace.exe '%[q0-9]' '.^u>`Y~4'\''!d;?[6eMR*)X+D>xU%AUWv8y$.jdQ@jBn='\''(J8f,KIL4L'  < ../inputs/input/ruin.285 > ../outputs/t468
    if diff ../outputs/t468 ../originals/t468 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p469) timeout -s 9 2 ../source/replace.exe '%[z-}Z-a]^_`a->-A>-A-c-ac-a-A-GABCDEFGl-A-GABCDEFG~-A-GABCDEFG-z-}z-}!-A-GABCDEFG]' '=h'  < ../inputs/input/ruin.770 > ../outputs/t469
    if diff ../outputs/t469 ../originals/t469 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p470) timeout -s 9 2 ../source/replace.exe '%[z-}]$' 'h'  < ../inputs/input/ruin.898 > ../outputs/t470
    if diff ../outputs/t470 ../originals/t470 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p471) timeout -s 9 2 ../source/replace.exe '%^' 'x'  < ../inputs/input/ruin.1600 > ../outputs/t471
    if diff ../outputs/t471 ../originals/t471 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p472) timeout -s 9 2 ../source/replace.exe '%^*??-$' '@%@&'  < ../inputs/temp-test/2242.inp.950.10 > ../outputs/t472
    if diff ../outputs/t472 ../originals/t472 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p473) timeout -s 9 2 ../source/replace.exe '%^*[^@@]-?^a-][a--][^@@]?-[0-9]' '@%@&'  < ../inputs/temp-test/1684.inp.717.5 > ../outputs/t473
    if diff ../outputs/t473 ../originals/t473 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p474) timeout -s 9 2 ../source/replace.exe '%^*[^a--]$' 'a&'  < ../inputs/temp-test/257.inp.113.10 > ../outputs/t474
    if diff ../outputs/t474 ../originals/t474 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p475) timeout -s 9 2 ../source/replace.exe '%^*a-c]' '@%&a'  < ../inputs/temp-test/2247.inp.952.7 > ../outputs/t475
    if diff ../outputs/t475 ../originals/t475 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p476) timeout -s 9 2 ../source/replace.exe '%^-$' '&'  < ../inputs/temp-test/875.inp.375.11 > ../outputs/t476
    if diff ../outputs/t476 ../originals/t476 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p477) timeout -s 9 2 ../source/replace.exe '%^-]?' '&'  < ../inputs/temp-test/1768.inp.752.5 > ../outputs/t477
    if diff ../outputs/t477 ../originals/t477 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p478) timeout -s 9 2 ../source/replace.exe '%^-]@**' 'b@t'  < ../inputs/temp-test/743.inp.318.5 > ../outputs/t478
    if diff ../outputs/t478 ../originals/t478 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p479) timeout -s 9 2 ../source/replace.exe '%^?*' 'x'  < ../inputs/input/ruin.1600 > ../outputs/t479
    if diff ../outputs/t479 ../originals/t479 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p480) timeout -s 9 2 ../source/replace.exe '%^a-]?a-][^a-]' ''  < ../inputs/temp-test/449.inp.196.7 > ../outputs/t480
    if diff ../outputs/t480 ../originals/t480 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p481) timeout -s 9 2 ../source/replace.exe '%^a-][9-B][^--z]??@[*?$' 'a&'  < ../inputs/temp-test/2154.inp.911.10 > ../outputs/t481
    if diff ../outputs/t481 ../originals/t481 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p482) timeout -s 9 2 ../source/replace.exe '%^a-c]-' 'NEW'  < ../inputs/temp-test/194.inp.87.7 > ../outputs/t482
    if diff ../outputs/t482 ../originals/t482 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p483) timeout -s 9 2 ../source/replace.exe '%^a-c]?*' 'NEW'  < ../inputs/temp-test/194.inp.87.7 > ../outputs/t483
    if diff ../outputs/t483 ../originals/t483 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p484) timeout -s 9 2 ../source/replace.exe '%^a-c][a-c]$' 'b@t'  < ../inputs/temp-test/1059.inp.455.10 > ../outputs/t484
    if diff ../outputs/t484 ../originals/t484 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p485) timeout -s 9 2 ../source/replace.exe '%a' kkkkkkkkkkkkk  < ../inputs/moni/f7.inp > ../outputs/t485
    if diff ../outputs/t485 ../originals/t485 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p486) timeout -s 9 2 ../source/replace.exe '%a' kkkkkkkkkkkkk$  < ../inputs/moni/f7.inp > ../outputs/t486
    if diff ../outputs/t486 ../originals/t486 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p487) timeout -s 9 2 ../source/replace.exe '%a-]-*?c[^--z]a-][^a-][a--b]?' 'a&'  < ../inputs/temp-test/1327.inp.569.5 > ../outputs/t487
    if diff ../outputs/t487 ../originals/t487 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p488) timeout -s 9 2 ../source/replace.exe '%a-]@@*$' 'NEW'  < ../inputs/temp-test/1204.inp.516.10 > ../outputs/t488
    if diff ../outputs/t488 ../originals/t488 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p489) timeout -s 9 2 ../source/replace.exe '%a-c]-[0-9]@t*@*?$' '@%@&'  < ../inputs/temp-test/993.inp.427.10 > ../outputs/t489
    if diff ../outputs/t489 ../originals/t489 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p490) timeout -s 9 2 ../source/replace.exe '%a-c][^@@]' '@t'  < ../inputs/temp-test/1515.inp.648.7 > ../outputs/t490
    if diff ../outputs/t490 ../originals/t490 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p491) timeout -s 9 2 ../source/replace.exe '%a[ ]*' '&@t'  < ../inputs/moni/f8.inp > ../outputs/t491
    if diff ../outputs/t491 ../originals/t491 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p492) timeout -s 9 2 ../source/replace.exe '%a[ ]*[ ]c$' '&@n'  < ../inputs/moni/f8.inp > ../outputs/t492
    if diff ../outputs/t492 ../originals/t492 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p493) timeout -s 9 2 ../source/replace.exe '%c' '&a@%'  < ../inputs/temp-test/312.inp.139.7 > ../outputs/t493
    if diff ../outputs/t493 ../originals/t493 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p494) timeout -s 9 2 ../source/replace.exe '%c*' '&a@%'  < ../inputs/temp-test/2088.inp.884.5 > ../outputs/t494
    if diff ../outputs/t494 ../originals/t494 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p495) timeout -s 9 2 ../source/replace.exe '%dB' 'P'  < ../inputs/input/ruin.517 > ../outputs/t495
    if diff ../outputs/t495 ../originals/t495 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p496) timeout -s 9 2 ../source/replace.exe '%e@n[^>-A/]$' '98&)4@z=|'\''-xLsL|#?_(vf/fhZ'  < ../inputs/input/ruin.201 > ../outputs/t496
    if diff ../outputs/t496 ../originals/t496 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p497) timeout -s 9 2 ../source/replace.exe '%f' '\'  < ../inputs/input/ruin.1034 > ../outputs/t497
    if diff ../outputs/t497 ../originals/t497 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p498) timeout -s 9 2 ../source/replace.exe '%f' '\KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@'  < ../inputs/input/ruin.1034 > ../outputs/t498
    if diff ../outputs/t498 ../originals/t498 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p499) timeout -s 9 2 ../source/replace.exe '[^a-c]?$' 'a@n'  < ../inputs/temp-test/70.inp.30.9 > ../outputs/t499
    if diff ../outputs/t499 ../originals/t499 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p500) timeout -s 9 2 ../source/replace.exe '[^a-c]?' '&a@%'  < ../inputs/temp-test/2031.inp.862.1 > ../outputs/t500
    if diff ../outputs/t500 ../originals/t500 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p501) timeout -s 9 2 ../source/replace.exe '[^a-c]?' '&a@%'  < ../inputs/temp-test/2032.inp.862.2 > ../outputs/t501
    if diff ../outputs/t501 ../originals/t501 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p502) timeout -s 9 2 ../source/replace.exe '[^a-c]?' '&a@%'  < ../inputs/temp-test/2033.inp.862.3 > ../outputs/t502
    if diff ../outputs/t502 ../originals/t502 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p503) timeout -s 9 2 ../source/replace.exe '[^a-c]?' ''  < ../inputs/temp-test/1148.inp.494.1 > ../outputs/t503
    if diff ../outputs/t503 ../originals/t503 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p504) timeout -s 9 2 ../source/replace.exe '[^a-c]?' ''  < ../inputs/temp-test/1149.inp.494.3 > ../outputs/t504
    if diff ../outputs/t504 ../originals/t504 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p505) timeout -s 9 2 ../source/replace.exe '[^a-c]?' 'a@n'  < ../inputs/temp-test/69.inp.30.1 > ../outputs/t505
    if diff ../outputs/t505 ../originals/t505 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p506) timeout -s 9 2 ../source/replace.exe '[^a-c]???@*?[^a-c][a-c[^9-B]' 'NEW'  < ../inputs/temp-test/482.inp.211.1 > ../outputs/t506
    if diff ../outputs/t506 ../originals/t506 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p507) timeout -s 9 2 ../source/replace.exe '[^a-c]???@*?[^a-c][a-c[^9-B]' 'NEW'  < ../inputs/temp-test/483.inp.211.4 > ../outputs/t507
    if diff ../outputs/t507 ../originals/t507 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p508) timeout -s 9 2 ../source/replace.exe '[^a-c]?[^0-9]a-c][9-B]c*?[^0-9]' ''  < ../inputs/temp-test/1293.inp.555.1 > ../outputs/t508
    if diff ../outputs/t508 ../originals/t508 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p509) timeout -s 9 2 ../source/replace.exe '[^a-c]@*' ''  < ../inputs/temp-test/827.inp.356.1 > ../outputs/t509
    if diff ../outputs/t509 ../originals/t509 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p510) timeout -s 9 2 ../source/replace.exe '[^a-c]@** *? [0-9]-?@**-' 'b@t'  < ../inputs/temp-test/396.inp.173.1 > ../outputs/t510
    if diff ../outputs/t510 ../originals/t510 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p511) timeout -s 9 2 ../source/replace.exe '[^a-c]@** *? [0-9]-?@**-' 'b@t'  < ../inputs/temp-test/397.inp.173.3 > ../outputs/t511
    if diff ../outputs/t511 ../originals/t511 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p512) timeout -s 9 2 ../source/replace.exe '[^a-c]@t*' '@t'  < ../inputs/temp-test/1187.inp.512.1 > ../outputs/t512
    if diff ../outputs/t512 ../originals/t512 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p513) timeout -s 9 2 ../source/replace.exe '[^a-c]@t*' '@t'  < ../inputs/temp-test/1188.inp.512.2 > ../outputs/t513
    if diff ../outputs/t513 ../originals/t513 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p514) timeout -s 9 2 ../source/replace.exe '[^a-c]@t*' '@t'  < ../inputs/temp-test/1189.inp.512.4 > ../outputs/t514
    if diff ../outputs/t514 ../originals/t514 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p515) timeout -s 9 2 ../source/replace.exe '[^a-c]A*' '@t'  < ../inputs/temp-test/1481.inp.636.1 > ../outputs/t515
    if diff ../outputs/t515 ../originals/t515 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p516) timeout -s 9 2 ../source/replace.exe '[^a-c]A*' '@t'  < ../inputs/temp-test/1482.inp.636.2 > ../outputs/t516
    if diff ../outputs/t516 ../originals/t516 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p517) timeout -s 9 2 ../source/replace.exe '[^a-c]A*' '@t'  < ../inputs/temp-test/1483.inp.636.3 > ../outputs/t517
    if diff ../outputs/t517 ../originals/t517 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p518) timeout -s 9 2 ../source/replace.exe '[^a-c][0-9]' 'a&'  < ../inputs/temp-test/1781.inp.759.1 > ../outputs/t518
    if diff ../outputs/t518 ../originals/t518 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p519) timeout -s 9 2 ../source/replace.exe '[^a-c][0-9]' 'a&'  < ../inputs/temp-test/1782.inp.759.2 > ../outputs/t519
    if diff ../outputs/t519 ../originals/t519 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p520) timeout -s 9 2 ../source/replace.exe '[^a-c][0-9]' 'a&'  < ../inputs/temp-test/1783.inp.759.3 > ../outputs/t520
    if diff ../outputs/t520 ../originals/t520 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p521) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]$' '&a@%'  < ../inputs/temp-test/1980.inp.840.6 > ../outputs/t521
    if diff ../outputs/t521 ../originals/t521 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p522) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]'   < ../inputs/temp-test/223.inp.99.3 > ../outputs/t522
    if diff ../outputs/t522 ../originals/t522 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p523) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' '&a@%'  < ../inputs/temp-test/1977.inp.840.1 > ../outputs/t523
    if diff ../outputs/t523 ../originals/t523 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p524) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' '&a@%'  < ../inputs/temp-test/1978.inp.840.3 > ../outputs/t524
    if diff ../outputs/t524 ../originals/t524 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p525) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' '&a@%'  < ../inputs/temp-test/1979.inp.840.4 > ../outputs/t525
    if diff ../outputs/t525 ../originals/t525 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p526) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' ''  < ../inputs/temp-test/1851.inp.786.1 > ../outputs/t526
    if diff ../outputs/t526 ../originals/t526 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p527) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' '@%&a'  < ../inputs/temp-test/222.inp.99.1 > ../outputs/t527
    if diff ../outputs/t527 ../originals/t527 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p528) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' '@%&a'  < ../inputs/temp-test/223.inp.99.3 > ../outputs/t528
    if diff ../outputs/t528 ../originals/t528 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p529) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' '@%@&'  < ../inputs/temp-test/1641.inp.700.1 > ../outputs/t529
    if diff ../outputs/t529 ../originals/t529 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p530) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' '@%@&'  < ../inputs/temp-test/1642.inp.700.2 > ../outputs/t530
    if diff ../outputs/t530 ../originals/t530 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p531) timeout -s 9 2 ../source/replace.exe '[^a-c][9-B]' '@%@&'  < ../inputs/temp-test/1643.inp.700.3 > ../outputs/t531
    if diff ../outputs/t531 ../originals/t531 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p532) timeout -s 9 2 ../source/replace.exe '[^a-c][][9-B]' '@%&a'  < ../inputs/temp-test/222.inp.99.1 > ../outputs/t532
    if diff ../outputs/t532 ../originals/t532 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p533) timeout -s 9 2 ../source/replace.exe '[^a-c][]a-]' 'NEW'  < ../inputs/temp-test/211.inp.94.1 > ../outputs/t533
    if diff ../outputs/t533 ../originals/t533 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p534) timeout -s 9 2 ../source/replace.exe '[^a-c][^][9-B]' '@%&a'  < ../inputs/temp-test/222.inp.99.1 > ../outputs/t534
    if diff ../outputs/t534 ../originals/t534 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p535) timeout -s 9 2 ../source/replace.exe '[^a-c][^]a-]' 'NEW'  < ../inputs/temp-test/211.inp.94.1 > ../outputs/t535
    if diff ../outputs/t535 ../originals/t535 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p536) timeout -s 9 2 ../source/replace.exe '[^a-c][a--b]' 'a@n'  < ../inputs/temp-test/789.inp.340.1 > ../outputs/t536
    if diff ../outputs/t536 ../originals/t536 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p537) timeout -s 9 2 ../source/replace.exe '[^a-c][a--b]' 'a@n'  < ../inputs/temp-test/790.inp.340.3 > ../outputs/t537
    if diff ../outputs/t537 ../originals/t537 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p538) timeout -s 9 2 ../source/replace.exe '[^a-c]^*' '@%@&'  < ../inputs/temp-test/2299.inp.976.1 > ../outputs/t538
    if diff ../outputs/t538 ../originals/t538 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p539) timeout -s 9 2 ../source/replace.exe '[^a-c]^*' 'NEW'  < ../inputs/temp-test/43.inp.18.1 > ../outputs/t539
    if diff ../outputs/t539 ../originals/t539 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p540) timeout -s 9 2 ../source/replace.exe '[^a-c]^*?---[a-c' 'a@nb@tc'  < ../inputs/temp-test/1446.inp.620.1 > ../outputs/t540
    if diff ../outputs/t540 ../originals/t540 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p541) timeout -s 9 2 ../source/replace.exe '[^a-c]^*?---[a-c' 'a@nb@tc'  < ../inputs/temp-test/1447.inp.620.2 > ../outputs/t541
    if diff ../outputs/t541 ../originals/t541 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p542) timeout -s 9 2 ../source/replace.exe '[^a-c]^*?---[a-c' 'a@nb@tc'  < ../inputs/temp-test/1448.inp.620.3 > ../outputs/t542
    if diff ../outputs/t542 ../originals/t542 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p543) timeout -s 9 2 ../source/replace.exe '[^a-c]a-]'   < ../inputs/temp-test/211.inp.94.1 > ../outputs/t543
    if diff ../outputs/t543 ../originals/t543 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p544) timeout -s 9 2 ../source/replace.exe '[^a-c]a-]' '&@n'  < ../inputs/temp-test/211.inp.94.1 > ../outputs/t544
    if diff ../outputs/t544 ../originals/t544 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p545) timeout -s 9 2 ../source/replace.exe '[^a-c]a-]' '@%&a'  < ../inputs/temp-test/599.inp.258.1 > ../outputs/t545
    if diff ../outputs/t545 ../originals/t545 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p546) timeout -s 9 2 ../source/replace.exe '[^a-c]a-]' '@%&a'  < ../inputs/temp-test/600.inp.258.3 > ../outputs/t546
    if diff ../outputs/t546 ../originals/t546 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p547) timeout -s 9 2 ../source/replace.exe '[^a-c]a-]' 'NEW'  < ../inputs/temp-test/211.inp.94.1 > ../outputs/t547
    if diff ../outputs/t547 ../originals/t547 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p548) timeout -s 9 2 ../source/replace.exe '[^a-c]a-][^0-9][9-B]^$' 'a@nb@tc'  < ../inputs/temp-test/678.inp.294.9 > ../outputs/t548
    if diff ../outputs/t548 ../originals/t548 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p549) timeout -s 9 2 ../source/replace.exe '[^a-c]a-][^0-9][9-B]^' 'a@nb@tc'  < ../inputs/temp-test/676.inp.294.1 > ../outputs/t549
    if diff ../outputs/t549 ../originals/t549 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p550) timeout -s 9 2 ../source/replace.exe '[^a-c]a-][^0-9][9-B]^' 'a@nb@tc'  < ../inputs/temp-test/677.inp.294.3 > ../outputs/t550
    if diff ../outputs/t550 ../originals/t550 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p551) timeout -s 9 2 ../source/replace.exe '[^a-c]a-c]' 'a@n'  < ../inputs/temp-test/581.inp.250.1 > ../outputs/t551
    if diff ../outputs/t551 ../originals/t551 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p552) timeout -s 9 2 ../source/replace.exe '[^a-c]a-c]' 'a@n'  < ../inputs/temp-test/582.inp.250.2 > ../outputs/t552
    if diff ../outputs/t552 ../originals/t552 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p553) timeout -s 9 2 ../source/replace.exe '[^a-c]a-c]@*-[^a--]-]-]-' 'a&'  < ../inputs/temp-test/1994.inp.847.1 > ../outputs/t553
    if diff ../outputs/t553 ../originals/t553 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p554) timeout -s 9 2 ../source/replace.exe '[^a-c]a-c]@*-[^a--]-]-]-' 'a&'  < ../inputs/temp-test/1995.inp.847.2 > ../outputs/t554
    if diff ../outputs/t554 ../originals/t554 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p555) timeout -s 9 2 ../source/replace.exe '[^a-c]a-c]@*-[^a--]-]-]-' 'a&'  < ../inputs/temp-test/1996.inp.847.3 > ../outputs/t555
    if diff ../outputs/t555 ../originals/t555 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p556) timeout -s 9 2 ../source/replace.exe '[^a-c]c*' 'b@t'  < ../inputs/temp-test/1558.inp.667.1 > ../outputs/t556
    if diff ../outputs/t556 ../originals/t556 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p557) timeout -s 9 2 ../source/replace.exe '[^a-c]c*' 'b@t'  < ../inputs/temp-test/1559.inp.667.2 > ../outputs/t557
    if diff ../outputs/t557 ../originals/t557 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p558) timeout -s 9 2 ../source/replace.exe '[^a-c]c*' 'b@t'  < ../inputs/temp-test/1560.inp.667.3 > ../outputs/t558
    if diff ../outputs/t558 ../originals/t558 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p559) timeout -s 9 2 ../source/replace.exe '[^a-c]c*' 'b@t'  < ../inputs/temp-test/1561.inp.667.4 > ../outputs/t559
    if diff ../outputs/t559 ../originals/t559 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p560) timeout -s 9 2 ../source/replace.exe '[^c-aA-GA-G]' '`D)'\''CsjN5-8Dcm%JYz!iFF'  < ../inputs/input/ruin.1351 > ../outputs/t560
    if diff ../outputs/t560 ../originals/t560 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p561) timeout -s 9 2 ../source/replace.exe '[^c-aA-GA]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY-G]' '`D)'\''CsjN5-8Dcm%JYz!iFF'  < ../inputs/input/ruin.1351 > ../outputs/t561
    if diff ../outputs/t561 ../originals/t561 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p562) timeout -s 9 2 ../source/replace.exe '[^c-aA-GA]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY-G]-*?* *[a' '`D)'\''CsjN5-8Dcm%JYz!iFF'  < ../inputs/input/ruin.1351 > ../outputs/t562
    if diff ../outputs/t562 ../originals/t562 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p563) timeout -s 9 2 ../source/replace.exe '[^c-aA-G]' '\.'  < ../inputs/input/ruin.1420 > ../outputs/t563
    if diff ../outputs/t563 ../originals/t563 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p564) timeout -s 9 2 ../source/replace.exe '[^c-a]$' '( $Pn*#>~&BsFeg_'  < ../inputs/input/ruin.368 > ../outputs/t564
    if diff ../outputs/t564 ../originals/t564 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p565) timeout -s 9 2 ../source/replace.exe '[^c-a]' '!'  < ../inputs/input/ruin.469 > ../outputs/t565
    if diff ../outputs/t565 ../originals/t565 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p566) timeout -s 9 2 ../source/replace.exe '[^c-a]' ''\''n52Glpp'  < ../inputs/input/ruin.1535 > ../outputs/t566
    if diff ../outputs/t566 ../originals/t566 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p567) timeout -s 9 2 ../source/replace.exe '[^c-a]' '*K2l6A0)5";'  < ../inputs/input/ruin.731 > ../outputs/t567
    if diff ../outputs/t567 ../originals/t567 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p568) timeout -s 9 2 ../source/replace.exe '[^c-a]' 'Cd'\''V/"FE%-roxA3znMH"Vj/iEO{Tr]'  < ../inputs/input/ruin.690 > ../outputs/t568
    if diff ../outputs/t568 ../originals/t568 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p569) timeout -s 9 2 ../source/replace.exe '[^c-a]' 'L=&XW&%JwE}YEQ"vBljIYg}l'  < ../inputs/input/ruin.494 > ../outputs/t569
    if diff ../outputs/t569 ../originals/t569 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p570) timeout -s 9 2 ../source/replace.exe '[^c-a]' 'Vy^EeJ{O/i]=ys,]tXg]?;,,<g;AU*QZSavRY*4'  < ../inputs/input/ruin.25 > ../outputs/t570
    if diff ../outputs/t570 ../originals/t570 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p571) timeout -s 9 2 ../source/replace.exe '[^c-a]' 'X'  < ../inputs/input/ruin.1887 > ../outputs/t571
    if diff ../outputs/t571 ../originals/t571 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p572) timeout -s 9 2 ../source/replace.exe '[^c-a]' ']dcgBzE@$fo!1~q~Mu'  < ../inputs/input/ruin.79 > ../outputs/t572
    if diff ../outputs/t572 ../originals/t572 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p573) timeout -s 9 2 ../source/replace.exe '[^c-a]' 'ai*J&OD~k5g{d%7nKT}yCFPq=tEUJEYc@Hon$lyR+t2\Cv=k&Z4'  < ../inputs/input/ruin.1818 > ../outputs/t573
    if diff ../outputs/t573 ../originals/t573 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p574) timeout -s 9 2 ../source/replace.exe '[^c-a]' 'x'  < ../inputs/input/ruin.884 > ../outputs/t574
    if diff ../outputs/t574 ../originals/t574 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p575) timeout -s 9 2 ../source/replace.exe '[^c-a]'\''' '1H}ZQ7/sx)W='  < ../inputs/input/ruin.173 > ../outputs/t575
    if diff ../outputs/t575 ../originals/t575 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p576) timeout -s 9 2 ../source/replace.exe '[^c-a]@n' 'L=&XW&%JwE}YEQ"vBljIYg}l'  < ../inputs/input/ruin.494 > ../outputs/t576
    if diff ../outputs/t576 ../originals/t576 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p577) timeout -s 9 2 ../source/replace.exe '[^c-ad]\8w[^c-ad]' '&4H~Nda9*ew0ux1#*F"*X3"/;[UiC=(Z@O-w6XEYiKkbBX-ZL%DtJ1dxHklBV\SP:C'  < ../inputs/input/ruin.1557 > ../outputs/t577
    if diff ../outputs/t577 ../originals/t577 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p578) timeout -s 9 2 ../source/replace.exe '[^ec-a]' 'T}UP?R=Z[T|IG=mM'  < ../inputs/input/ruin.166 > ../outputs/t578
    if diff ../outputs/t578 ../originals/t578 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p579) timeout -s 9 2 ../source/replace.exe '[^i]' 'aG:]y;Zm{7<\33O~hG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_J_Jp4?/`+iR&LbrJ},3'  < ../inputs/input/ruin.1040 > ../outputs/t579
    if diff ../outputs/t579 ../originals/t579 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p580) timeout -s 9 2 ../source/replace.exe '[^i]' 'aG:]y;Zm{7<\33O~h_Jp4?/`+iR&LbrJ},3'  < ../inputs/input/ruin.1040 > ../outputs/t580
    if diff ../outputs/t580 ../originals/t580 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p581) timeout -s 9 2 ../source/replace.exe '[^j]' '^'  < ../inputs/input/ruin.268 > ../outputs/t581
    if diff ../outputs/t581 ../originals/t581 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p582) timeout -s 9 2 ../source/replace.exe '[^p&y=3[ZYp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIIgTBkz-}Z-a]^_`a-z-}z-}]' 'v5xI27<*qtgs#`vmdnC IH['  < ../inputs/input/ruin.1333 > ../outputs/t582
    if diff ../outputs/t582 ../originals/t582 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p583) timeout -s 9 2 ../source/replace.exe '[^t]' '3A'  < ../inputs/input/ruin.1679 > ../outputs/t583
    if diff ../outputs/t583 ../originals/t583 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p584) timeout -s 9 2 ../source/replace.exe '[^t]\jGt|Bd' '&IOTC3<-BYFp<SrAfdt]'  < ../inputs/input/ruin.1317 > ../outputs/t584
    if diff ../outputs/t584 ../originals/t584 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p585) timeout -s 9 2 ../source/replace.exe '[^y]' 'Tc2k|h=&-k2k|h=&-kA{I^m)l>oO{GA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{Ge'  < ../inputs/input/ruin.1030 > ../outputs/t585
    if diff ../outputs/t585 ../originals/t585 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p586) timeout -s 9 2 ../source/replace.exe '[^y]' 'Tce'  < ../inputs/input/ruin.1030 > ../outputs/t586
    if diff ../outputs/t586 ../originals/t586 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p587) timeout -s 9 2 ../source/replace.exe '[^z-}0-9Z-a]^_`a]' 'U'  < ../inputs/input/ruin.1611 > ../outputs/t587
    if diff ../outputs/t587 ../originals/t587 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p588) timeout -s 9 2 ../source/replace.exe '[^z-}0-9]' '-Z&:|zzG_EZcTV.:M*0"c^'  < ../inputs/input/ruin.1843 > ../outputs/t588
    if diff ../outputs/t588 ../originals/t588 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p589) timeout -s 9 2 ../source/replace.exe '[^z-}>-A0-9A-G>-A0-9]' '7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpX'  < ../inputs/input/ruin.1054 > ../outputs/t589
    if diff ../outputs/t589 ../originals/t589 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p590) timeout -s 9 2 ../source/replace.exe '[^z-}>-A0-9A-G>-A0-9]' 'X'  < ../inputs/input/ruin.1054 > ../outputs/t590
    if diff ../outputs/t590 ../originals/t590 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p591) timeout -s 9 2 ../source/replace.exe '[^z-}>-A]' 'H'  < ../inputs/input/ruin.1933 > ../outputs/t591
    if diff ../outputs/t591 ../originals/t591 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p592) timeout -s 9 2 ../source/replace.exe '[^z-}A-Gc-ad?]' '&r)ZKX29[^e-9$'  < ../inputs/input/ruin.745 > ../outputs/t592
    if diff ../outputs/t592 ../originals/t592 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p593) timeout -s 9 2 ../source/replace.exe '[^z-}Z-a]^_`a-z-}z-}]' 'v5xI27<*qtgs#`vmdnC IH['  < ../inputs/input/ruin.1333 > ../outputs/t593
    if diff ../outputs/t593 ../originals/t593 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p594) timeout -s 9 2 ../source/replace.exe '[^z-}Z-a]^_`a-z-}z-}]' 'v5xz-}Z-a]^_`a-z-}z-}]z-}Z-a]^_`a-z-}z-}]z-}Z-a]^_`a-z-}z-}]z-}Z-a]^_`a-z-}z-}]z-}Z-a]^_`a-z-}z-}]z-}Z-a]^_`a-z-}z-}]z-}Z-a]^_`a-z-}z-}]z-}Z-a]^_`a-z-}z-}]I27<*qtgs#`vmdnC IH[0-9]*[3-4]'  < ../inputs/input/ruin.1333 > ../outputs/t594
    if diff ../outputs/t594 ../originals/t594 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p595) timeout -s 9 2 ../source/replace.exe '[^z-}Z-a]^_`a]' '&'  < ../inputs/input/ruin.96 > ../outputs/t595
    if diff ../outputs/t595 ../originals/t595 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p596) timeout -s 9 2 ../source/replace.exe '[^z-}]' '!tYvZIshp/O-, z$MMuM0D0Wl[w'  < ../inputs/input/ruin.1369 > ../outputs/t596
    if diff ../outputs/t596 ../originals/t596 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p597) timeout -s 9 2 ../source/replace.exe '[^z-}]' '#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO(B='  < ../inputs/input/ruin.1197 > ../outputs/t597
    if diff ../outputs/t597 ../originals/t597 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p598) timeout -s 9 2 ../source/replace.exe '[^z-}]' '(]E[? g0RJ5hr+k^RH|*q0V^1p#/qQFY%l3_{n[6PFv_frgx[p&G<^#K2Hfw6'  < ../inputs/input/ruin.178 > ../outputs/t598
    if diff ../outputs/t598 ../originals/t598 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p599) timeout -s 9 2 ../source/replace.exe '[^z-}]' '*C0e+YNj4(j?V|i|z,[YlSNT[z-DW(7.ByKgI2|4h16!)>y Jn)V(0wVfe'  < ../inputs/input/ruin.746 > ../outputs/t599
    if diff ../outputs/t599 ../originals/t599 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p600) timeout -s 9 2 ../source/replace.exe '[^z-}]' '1gF=n$u]g/C}w8N6'  < ../inputs/input/ruin.1207 > ../outputs/t600
    if diff ../outputs/t600 ../originals/t600 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p601) timeout -s 9 2 ../source/replace.exe '[^z-}]' '9[u+JB/|waE*e&|<.eSjw]z2%O#}`XSA%F3R['  < ../inputs/input/ruin.132 > ../outputs/t601
    if diff ../outputs/t601 ../originals/t601 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p602) timeout -s 9 2 ../source/replace.exe '[^z-}]' '>WbZbdg'\''c'  < ../inputs/input/ruin.653 > ../outputs/t602
    if diff ../outputs/t602 ../originals/t602 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p603) timeout -s 9 2 ../source/replace.exe '[^z-}]' '@NH|fHRf5]'\''w5; %%Q'\''Ft=st0eg6j\)j}H'  < ../inputs/input/ruin.1975 > ../outputs/t603
    if diff ../outputs/t603 ../originals/t603 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p604) timeout -s 9 2 ../source/replace.exe '[^z-}]' 'B\qm8SPL=zX>(KLz.kURG ?bDPFy8~p+5;Q'  < ../inputs/input/ruin.1381 > ../outputs/t604
    if diff ../outputs/t604 ../originals/t604 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p605) timeout -s 9 2 ../source/replace.exe '[^z-}]' 'G'  < ../inputs/input/ruin.796 > ../outputs/t605
    if diff ../outputs/t605 ../originals/t605 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p606) timeout -s 9 2 ../source/replace.exe '[^z-}]' 'R'  < ../inputs/input/ruin.1664 > ../outputs/t606
    if diff ../outputs/t606 ../originals/t606 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p607) timeout -s 9 2 ../source/replace.exe '[^z-}]' '_&z-.p"MapF'  < ../inputs/input/ruin.843 > ../outputs/t607
    if diff ../outputs/t607 ../originals/t607 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p608) timeout -s 9 2 ../source/replace.exe '[^z-}]*?' ' '  < ../inputs/input/ruin.1192 > ../outputs/t608
    if diff ../outputs/t608 ../originals/t608 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p609) timeout -s 9 2 ../source/replace.exe '[^z-}][^z-}]' ' fO?sCGL)h$78e5TolWx>y1s v]'  < ../inputs/input/ruin.1705 > ../outputs/t609
    if diff ../outputs/t609 ../originals/t609 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p610) timeout -s 9 2 ../source/replace.exe '[^z-}c-a]' 'h'  < ../inputs/input/ruin.1221 > ../outputs/t610
    if diff ../outputs/t610 ../originals/t610 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p611) timeout -s 9 2 ../source/replace.exe '[^z-}c-a]@n' 'h&[0-9]'  < ../inputs/input/ruin.1221 > ../outputs/t611
    if diff ../outputs/t611 ../originals/t611 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p612) timeout -s 9 2 ../source/replace.exe '[^z-}z-}*c-a]' 'L'  < ../inputs/input/ruin.1838 > ../outputs/t612
    if diff ../outputs/t612 ../originals/t612 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p613) timeout -s 9 2 ../source/replace.exe '[^{]' 'V>m9RW"i6a==?f&}(9'  < ../inputs/input/ruin.1798 > ../outputs/t613
    if diff ../outputs/t613 ../originals/t613 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p614) timeout -s 9 2 ../source/replace.exe '[^|]' '>'  < ../inputs/input/ruin.1301 > ../outputs/t614
    if diff ../outputs/t614 ../originals/t614 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p615) timeout -s 9 2 ../source/replace.exe '[_-z]' 'NEW'  < ../inputs/temp-test/1645.inp.701.1 > ../outputs/t615
    if diff ../outputs/t615 ../originals/t615 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p616) timeout -s 9 2 ../source/replace.exe '[_-z]' 'NEW'  < ../inputs/temp-test/1646.inp.701.3 > ../outputs/t616
    if diff ../outputs/t616 ../originals/t616 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p617) timeout -s 9 2 ../source/replace.exe '[_-z]-' '@n'  < ../inputs/temp-test/809.inp.348.1 > ../outputs/t617
    if diff ../outputs/t617 ../originals/t617 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p618) timeout -s 9 2 ../source/replace.exe '[_-z]-' '@n'  < ../inputs/temp-test/810.inp.348.2 > ../outputs/t618
    if diff ../outputs/t618 ../originals/t618 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p619) timeout -s 9 2 ../source/replace.exe '[_-z]-[0-9]^-] ^a-c]-??@*' 'b@t'  < ../inputs/temp-test/1420.inp.610.1 > ../outputs/t619
    if diff ../outputs/t619 ../originals/t619 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p620) timeout -s 9 2 ../source/replace.exe '[_-z]-^ [^0-9][^a-][a-c]-[^9-B]-?[^9-B]?@**[a-c@t*?' 'a@nb@tc'  < ../inputs/temp-test/1757.inp.747.1 > ../outputs/t620
    if diff ../outputs/t620 ../originals/t620 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p621) timeout -s 9 2 ../source/replace.exe '[_-z]-^ [^0-9][^a-][a-c]-[^9-B]-?[^9-B]?@**[a-c@t*?' 'a@nb@tc'  < ../inputs/temp-test/1758.inp.747.3 > ../outputs/t621
    if diff ../outputs/t621 ../originals/t621 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p622) timeout -s 9 2 ../source/replace.exe '[_-z]?' ''  < ../inputs/temp-test/169.inp.76.1 > ../outputs/t622
    if diff ../outputs/t622 ../originals/t622 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p623) timeout -s 9 2 ../source/replace.exe '[_-z]?' ''  < ../inputs/temp-test/170.inp.76.2 > ../outputs/t623
    if diff ../outputs/t623 ../originals/t623 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p624) timeout -s 9 2 ../source/replace.exe '[_-z]?' 'a@n'  < ../inputs/temp-test/308.inp.138.1 > ../outputs/t624
    if diff ../outputs/t624 ../originals/t624 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p625) timeout -s 9 2 ../source/replace.exe '[_-z]?' 'a@n'  < ../inputs/temp-test/309.inp.138.2 > ../outputs/t625
    if diff ../outputs/t625 ../originals/t625 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p626) timeout -s 9 2 ../source/replace.exe '[_-z]?' 'a@nb@tc'  < ../inputs/temp-test/1027.inp.442.1 > ../outputs/t626
    if diff ../outputs/t626 ../originals/t626 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p627) timeout -s 9 2 ../source/replace.exe '[_-z]?' 'a@nb@tc'  < ../inputs/temp-test/1028.inp.442.3 > ../outputs/t627
    if diff ../outputs/t627 ../originals/t627 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p628) timeout -s 9 2 ../source/replace.exe '[_-z]?' 'b@t'  < ../inputs/temp-test/2182.inp.923.1 > ../outputs/t628
    if diff ../outputs/t628 ../originals/t628 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p629) timeout -s 9 2 ../source/replace.exe '[_-z]@*A' '&'  < ../inputs/temp-test/1480.inp.635.1 > ../outputs/t629
    if diff ../outputs/t629 ../originals/t629 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p630) timeout -s 9 2 ../source/replace.exe '[_-z][^0-9]' '@%@&'  < ../inputs/temp-test/1380.inp.592.1 > ../outputs/t630
    if diff ../outputs/t630 ../originals/t630 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p631) timeout -s 9 2 ../source/replace.exe '[_-z][^0-9]' '@%@&'  < ../inputs/temp-test/1381.inp.592.2 > ../outputs/t631
    if diff ../outputs/t631 ../originals/t631 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p632) timeout -s 9 2 ../source/replace.exe '[_-z][^0-9]' '@%@&'  < ../inputs/temp-test/1382.inp.592.3 > ../outputs/t632
    if diff ../outputs/t632 ../originals/t632 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p633) timeout -s 9 2 ../source/replace.exe '[_-z][^a-c' '@%&a'  < ../inputs/temp-test/344.inp.151.1 > ../outputs/t633
    if diff ../outputs/t633 ../originals/t633 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p634) timeout -s 9 2 ../source/replace.exe '[_-z][^a-c' '@%&a'  < ../inputs/temp-test/345.inp.151.2 > ../outputs/t634
    if diff ../outputs/t634 ../originals/t634 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p635) timeout -s 9 2 ../source/replace.exe '[_-z][^a-c' '@%&a@'  < ../inputs/temp-test/345.inp.151.2 > ../outputs/t635
    if diff ../outputs/t635 ../originals/t635 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p636) timeout -s 9 2 ../source/replace.exe '[_-z][^a-c@' '@%&a@'  < ../inputs/temp-test/344.inp.151.1 > ../outputs/t636
    if diff ../outputs/t636 ../originals/t636 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p637) timeout -s 9 2 ../source/replace.exe '[_-z]^' '&a@%'  < ../inputs/temp-test/100.inp.45.1 > ../outputs/t637
    if diff ../outputs/t637 ../originals/t637 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p638) timeout -s 9 2 ../source/replace.exe '[_-z]^' '&a@%'  < ../inputs/temp-test/101.inp.45.3 > ../outputs/t638
    if diff ../outputs/t638 ../originals/t638 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p639) timeout -s 9 2 ../source/replace.exe '[a--' 'b@t'  < ../inputs/temp-test/2093.inp.887.1 > ../outputs/t639
    if diff ../outputs/t639 ../originals/t639 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p640) timeout -s 9 2 ../source/replace.exe '[a--' 'b@t'  < ../inputs/temp-test/2094.inp.887.3 > ../outputs/t640
    if diff ../outputs/t640 ../originals/t640 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p641) timeout -s 9 2 ../source/replace.exe '[a---*-' 'a@n'  < ../inputs/temp-test/1877.inp.796.1 > ../outputs/t641
    if diff ../outputs/t641 ../originals/t641 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p642) timeout -s 9 2 ../source/replace.exe '[a---*-' 'a@n'  < ../inputs/temp-test/1878.inp.796.3 > ../outputs/t642
    if diff ../outputs/t642 ../originals/t642 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p643) timeout -s 9 2 ../source/replace.exe '[a---*-' 'a@n'  < ../inputs/temp-test/1879.inp.796.4 > ../outputs/t643
    if diff ../outputs/t643 ../originals/t643 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p644) timeout -s 9 2 ../source/replace.exe '[a---?-a-][^0-9]^' '@%@&'  < ../inputs/temp-test/1922.inp.817.1 > ../outputs/t644
    if diff ../outputs/t644 ../originals/t644 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p645) timeout -s 9 2 ../source/replace.exe '[a---?-a-][^0-9]^' '@%@&'  < ../inputs/temp-test/1923.inp.817.3 > ../outputs/t645
    if diff ../outputs/t645 ../originals/t645 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p646) timeout -s 9 2 ../source/replace.exe '[a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9]' '@%&a'  < ../inputs/temp-test/496.inp.217.1 > ../outputs/t646
    if diff ../outputs/t646 ../originals/t646 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p647) timeout -s 9 2 ../source/replace.exe '[a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9]' '@%&a'  < ../inputs/temp-test/497.inp.217.3 > ../outputs/t647
    if diff ../outputs/t647 ../originals/t647 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p648) timeout -s 9 2 ../source/replace.exe '[a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9][a--] *^a-c]?-[0-9]?--a-]@t*?@[[^0-9]' '@%&a'  < ../inputs/temp-test/496.inp.217.1 > ../outputs/t648
    if diff ../outputs/t648 ../originals/t648 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p649) timeout -s 9 2 ../source/replace.exe '[a--]?-?@[[^a-c]' '&a@%'  < ../inputs/temp-test/109.inp.50.1 > ../outputs/t649
    if diff ../outputs/t649 ../originals/t649 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p650) timeout -s 9 2 ../source/replace.exe '[a--]?-?@[[^a-c]' '&a@%'  < ../inputs/temp-test/110.inp.50.2 > ../outputs/t650
    if diff ../outputs/t650 ../originals/t650 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p651) timeout -s 9 2 ../source/replace.exe '[a--]?-?@[[^a-c]' '&a@%'  < ../inputs/temp-test/111.inp.50.3 > ../outputs/t651
    if diff ../outputs/t651 ../originals/t651 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p652) timeout -s 9 2 ../source/replace.exe '[a--]?[a--]-@n*-[^@@][a--]-' ''  < ../inputs/temp-test/108.inp.49.1 > ../outputs/t652
    if diff ../outputs/t652 ../originals/t652 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p653) timeout -s 9 2 ../source/replace.exe '[a--]@@*^-]?-[9-B][^@@]-' 'a@nb@tc'  < ../inputs/temp-test/718.inp.310.1 > ../outputs/t653
    if diff ../outputs/t653 ../originals/t653 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p654) timeout -s 9 2 ../source/replace.exe '[a--]@@*^-]?-[9-B][^@@]-' 'a@nb@tc'  < ../inputs/temp-test/719.inp.310.2 > ../outputs/t654
    if diff ../outputs/t654 ../originals/t654 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p655) timeout -s 9 2 ../source/replace.exe '[a--][^a-c]' '@n'  < ../inputs/temp-test/914.inp.394.1 > ../outputs/t655
    if diff ../outputs/t655 ../originals/t655 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p656) timeout -s 9 2 ../source/replace.exe '[a--][^a-c]' '@n'  < ../inputs/temp-test/915.inp.394.4 > ../outputs/t656
    if diff ../outputs/t656 ../originals/t656 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p657) timeout -s 9 2 ../source/replace.exe '[a--b] *' 'b@t'  < ../inputs/temp-test/301.inp.135.2 > ../outputs/t657
    if diff ../outputs/t657 ../originals/t657 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p658) timeout -s 9 2 ../source/replace.exe '[a--b]$' '&a@%'  < ../inputs/temp-test/1422.inp.611.9 > ../outputs/t658
    if diff ../outputs/t658 ../originals/t658 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p659) timeout -s 9 2 ../source/replace.exe '[a--b]' '&a@%'  < ../inputs/temp-test/1421.inp.611.2 > ../outputs/t659
    if diff ../outputs/t659 ../originals/t659 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p660) timeout -s 9 2 ../source/replace.exe '[a--b]?$' 'b@t'  < ../inputs/temp-test/2111.inp.894.8 > ../outputs/t660
    if diff ../outputs/t660 ../originals/t660 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p661) timeout -s 9 2 ../source/replace.exe '[a--b]?' 'b@t'  < ../inputs/temp-test/2109.inp.894.1 > ../outputs/t661
    if diff ../outputs/t661 ../originals/t661 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p662) timeout -s 9 2 ../source/replace.exe '[a--b]?' 'b@t'  < ../inputs/temp-test/2110.inp.894.2 > ../outputs/t662
    if diff ../outputs/t662 ../originals/t662 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p663) timeout -s 9 2 ../source/replace.exe '[a--b]?[9-B]' '@%&a'  < ../inputs/temp-test/1237.inp.531.1 > ../outputs/t663
    if diff ../outputs/t663 ../originals/t663 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p664) timeout -s 9 2 ../source/replace.exe '[a--b]?[9-B]' '@%&a'  < ../inputs/temp-test/1238.inp.531.2 > ../outputs/t664
    if diff ../outputs/t664 ../originals/t664 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p665) timeout -s 9 2 ../source/replace.exe '[a--b]@*[^a-c] *-[^0-9]-' 'a@nb@tc'  < ../inputs/temp-test/1962.inp.833.1 > ../outputs/t665
    if diff ../outputs/t665 ../originals/t665 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p666) timeout -s 9 2 ../source/replace.exe '[a--b]@*[^a-c] *-[^0-9]-' 'a@nb@tc'  < ../inputs/temp-test/1963.inp.833.4 > ../outputs/t666
    if diff ../outputs/t666 ../originals/t666 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p667) timeout -s 9 2 ../source/replace.exe '[a--b][-z][^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]' ''  < ../inputs/temp-test/833.inp.359.1 > ../outputs/t667
    if diff ../outputs/t667 ../originals/t667 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p668) timeout -s 9 2 ../source/replace.exe '[a--b][-z][^9-B]@t*[^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]' ''  < ../inputs/temp-test/833.inp.359.1 > ../outputs/t668
    if diff ../outputs/t668 ../originals/t668 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p669) timeout -s 9 2 ../source/replace.exe '[a--b]c$' 'NEW'  < ../inputs/temp-test/711.inp.307.9 > ../outputs/t669
    if diff ../outputs/t669 ../originals/t669 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p670) timeout -s 9 2 ../source/replace.exe '[a--b]c' 'NEW'  < ../inputs/temp-test/708.inp.307.1 > ../outputs/t670
    if diff ../outputs/t670 ../originals/t670 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p671) timeout -s 9 2 ../source/replace.exe '[a--b]c' 'NEW'  < ../inputs/temp-test/709.inp.307.2 > ../outputs/t671
    if diff ../outputs/t671 ../originals/t671 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p672) timeout -s 9 2 ../source/replace.exe '[a--b]c' 'NEW'  < ../inputs/temp-test/710.inp.307.3 > ../outputs/t672
    if diff ../outputs/t672 ../originals/t672 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p673) timeout -s 9 2 ../source/replace.exe '[a-?' 'NEW'  < ../inputs/temp-test/734.inp.316.1 > ../outputs/t673
    if diff ../outputs/t673 ../originals/t673 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p674) timeout -s 9 2 ../source/replace.exe '[a-?' 'NEW'  < ../inputs/temp-test/735.inp.316.2 > ../outputs/t674
    if diff ../outputs/t674 ../originals/t674 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p675) timeout -s 9 2 ../source/replace.exe '[a-?' 'NEW'  < ../inputs/temp-test/736.inp.316.3 > ../outputs/t675
    if diff ../outputs/t675 ../originals/t675 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p676) timeout -s 9 2 ../source/replace.exe '[a-@[*' 'NEW'  < ../inputs/temp-test/860.inp.370.1 > ../outputs/t676
    if diff ../outputs/t676 ../originals/t676 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p677) timeout -s 9 2 ../source/replace.exe '[a-@[*' 'NEW'  < ../inputs/temp-test/861.inp.370.2 > ../outputs/t677
    if diff ../outputs/t677 ../originals/t677 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p678) timeout -s 9 2 ../source/replace.exe '[a-[^0-9] *-]' 'a@nb@tc'  < ../inputs/temp-test/1777.inp.757.1 > ../outputs/t678
    if diff ../outputs/t678 ../originals/t678 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p679) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]' ''  < ../inputs/temp-test/839.inp.361.1 > ../outputs/t679
    if diff ../outputs/t679 ../originals/t679 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p680) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]' ''  < ../inputs/temp-test/840.inp.361.2 > ../outputs/t680
    if diff ../outputs/t680 ../originals/t680 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p681) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]' ''  < ../inputs/temp-test/841.inp.361.3 > ../outputs/t681
    if diff ../outputs/t681 ../originals/t681 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p682) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]' ''  < ../inputs/temp-test/842.inp.361.4 > ../outputs/t682
    if diff ../outputs/t682 ../originals/t682 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p683) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]' '@t'  < ../inputs/temp-test/1111.inp.478.1 > ../outputs/t683
    if diff ../outputs/t683 ../originals/t683 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p684) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]' '@t'  < ../inputs/temp-test/1112.inp.478.2 > ../outputs/t684
    if diff ../outputs/t684 ../originals/t684 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p685) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]' '@t'  < ../inputs/temp-test/1113.inp.478.4 > ../outputs/t685
    if diff ../outputs/t685 ../originals/t685 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p686) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]A*[^9-B][^a-c[^a-c@[-?[^-[0-9]?[^a-c]' 'a@nb@tc'  < ../inputs/temp-test/97.inp.44.1 > ../outputs/t686
    if diff ../outputs/t686 ../originals/t686 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p687) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]A*[^9-B][^a-c[^a-c@[-?[^-[0-9]?[^a-c]' 'a@nb@tc'  < ../inputs/temp-test/98.inp.44.2 > ../outputs/t687
    if diff ../outputs/t687 ../originals/t687 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p688) timeout -s 9 2 ../source/replace.exe '[a-[^0-9]A*[^9-B][^a-c[^a-c@[-?[^-[0-9]?[^a-c]' 'a@nb@tc'  < ../inputs/temp-test/99.inp.44.3 > ../outputs/t688
    if diff ../outputs/t688 ../originals/t688 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p689) timeout -s 9 2 ../source/replace.exe '[a-]' '&@n!4'  < ../inputs/temp-test/641.inp.277.1 > ../outputs/t689
    if diff ../outputs/t689 ../originals/t689 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p690) timeout -s 9 2 ../source/replace.exe '[a-]' '&@n'  < ../inputs/temp-test/641.inp.277.1 > ../outputs/t690
    if diff ../outputs/t690 ../originals/t690 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p691) timeout -s 9 2 ../source/replace.exe '[a-]' '&@n'  < ../inputs/temp-test/642.inp.277.3 > ../outputs/t691
    if diff ../outputs/t691 ../originals/t691 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p692) timeout -s 9 2 ../source/replace.exe '[a-]' '@%@&'  < ../inputs/temp-test/1259.inp.541.1 > ../outputs/t692
    if diff ../outputs/t692 ../originals/t692 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p693) timeout -s 9 2 ../source/replace.exe '[a-]' '@%@&'  < ../inputs/temp-test/1260.inp.541.2 > ../outputs/t693
    if diff ../outputs/t693 ../originals/t693 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p694) timeout -s 9 2 ../source/replace.exe '[a-]' '@%@&'  < ../inputs/temp-test/1261.inp.541.3 > ../outputs/t694
    if diff ../outputs/t694 ../originals/t694 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p695) timeout -s 9 2 ../source/replace.exe '[a-]' 'a@nb@tc'  < ../inputs/temp-test/1543.inp.661.1 > ../outputs/t695
    if diff ../outputs/t695 ../originals/t695 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p696) timeout -s 9 2 ../source/replace.exe '[a-]' 'a@nb@tc'  < ../inputs/temp-test/1544.inp.661.2 > ../outputs/t696
    if diff ../outputs/t696 ../originals/t696 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p697) timeout -s 9 2 ../source/replace.exe '[a-]' 'a@nb@tc'  < ../inputs/temp-test/1545.inp.661.3 > ../outputs/t697
    if diff ../outputs/t697 ../originals/t697 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p698) timeout -s 9 2 ../source/replace.exe '[a-]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t698
    if diff ../outputs/t698 ../originals/t698 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p699) timeout -s 9 2 ../source/replace.exe '[a-]- -^a-c]?[^-?' 'NEW'  < ../inputs/temp-test/1449.inp.621.1 > ../outputs/t699
    if diff ../outputs/t699 ../originals/t699 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p700) timeout -s 9 2 ../source/replace.exe '[a-]-' '@n'  < ../inputs/temp-test/641.inp.277.1 > ../outputs/t700
    if diff ../outputs/t700 ../originals/t700 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p701) timeout -s 9 2 ../source/replace.exe '[a-]-' '@n'  < ../inputs/temp-test/642.inp.277.3 > ../outputs/t701
    if diff ../outputs/t701 ../originals/t701 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p702) timeout -s 9 2 ../source/replace.exe '[a-]-' 'NEW'  < ../inputs/temp-test/1250.inp.536.1 > ../outputs/t702
    if diff ../outputs/t702 ../originals/t702 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p703) timeout -s 9 2 ../source/replace.exe '[a-]-' 'NEW'  < ../inputs/temp-test/1251.inp.536.2 > ../outputs/t703
    if diff ../outputs/t703 ../originals/t703 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p704) timeout -s 9 2 ../source/replace.exe '[a-]-*[a-c][^a--]-' '@t'  < ../inputs/temp-test/1090.inp.470.1 > ../outputs/t704
    if diff ../outputs/t704 ../originals/t704 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p705) timeout -s 9 2 ../source/replace.exe '[a-][^9-B]?[0-9][^a-c]-?@[-?[^0-9]' '@%&a'  < ../inputs/temp-test/2317.inp.983.1 > ../outputs/t705
    if diff ../outputs/t705 ../originals/t705 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p706) timeout -s 9 2 ../source/replace.exe '[a-][^a-c]-?' '&'  < ../inputs/temp-test/745.inp.319.1 > ../outputs/t706
    if diff ../outputs/t706 ../originals/t706 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p707) timeout -s 9 2 ../source/replace.exe '[a-][^a-c]-?' '&'  < ../inputs/temp-test/746.inp.319.2 > ../outputs/t707
    if diff ../outputs/t707 ../originals/t707 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p708) timeout -s 9 2 ../source/replace.exe '[a-]^-[a-c]' 'a@n'  < ../inputs/temp-test/1556.inp.666.1 > ../outputs/t708
    if diff ../outputs/t708 ../originals/t708 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p709) timeout -s 9 2 ../source/replace.exe '[a-]^-[a-c]' 'a@n'  < ../inputs/temp-test/1557.inp.666.3 > ../outputs/t709
    if diff ../outputs/t709 ../originals/t709 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p710) timeout -s 9 2 ../source/replace.exe '[a-]c' 'NEW'  < ../inputs/temp-test/2137.inp.905.1 > ../outputs/t710
    if diff ../outputs/t710 ../originals/t710 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p711) timeout -s 9 2 ../source/replace.exe '[a-]c' 'NEW'  < ../inputs/temp-test/2138.inp.905.3 > ../outputs/t711
    if diff ../outputs/t711 ../originals/t711 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p712) timeout -s 9 2 ../source/replace.exe '[a-c%[9-B]c*^-[0-9]-^*?@[-[^a-c]?' 'b@t'  < ../inputs/temp-test/2344.inp.996.1 > ../outputs/t712
    if diff ../outputs/t712 ../originals/t712 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p713) timeout -s 9 2 ../source/replace.exe '[a-c' '&a@%'  < ../inputs/temp-test/1914.inp.813.1 > ../outputs/t713
    if diff ../outputs/t713 ../originals/t713 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p714) timeout -s 9 2 ../source/replace.exe '[a-c' '&a@%'  < ../inputs/temp-test/1915.inp.813.3 > ../outputs/t714
    if diff ../outputs/t714 ../originals/t714 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p715) timeout -s 9 2 ../source/replace.exe '[a-c' '@%@&'  < ../inputs/temp-test/1969.inp.837.2 > ../outputs/t715
    if diff ../outputs/t715 ../originals/t715 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p716) timeout -s 9 2 ../source/replace.exe '[a-c' '@%@&'  < ../inputs/temp-test/1970.inp.837.3 > ../outputs/t716
    if diff ../outputs/t716 ../originals/t716 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p717) timeout -s 9 2 ../source/replace.exe '[a-c' '@%@&'  < ../inputs/temp-test/1971.inp.837.4 > ../outputs/t717
    if diff ../outputs/t717 ../originals/t717 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p718) timeout -s 9 2 ../source/replace.exe '[a-c-@@[0-9][^a-]?a-c]--c*' '@%@&'  < ../inputs/temp-test/1975.inp.839.1 > ../outputs/t718
    if diff ../outputs/t718 ../originals/t718 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p719) timeout -s 9 2 ../source/replace.exe '[a-c?$'   < ../inputs/temp-test/520.inp.225.8 > ../outputs/t719
    if diff ../outputs/t719 ../originals/t719 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p720) timeout -s 9 2 ../source/replace.exe '[a-c?$' 'a&'  < ../inputs/temp-test/520.inp.225.8 > ../outputs/t720
    if diff ../outputs/t720 ../originals/t720 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p721) timeout -s 9 2 ../source/replace.exe '[a-c?'   < ../inputs/temp-test/517.inp.225.2 > ../outputs/t721
    if diff ../outputs/t721 ../originals/t721 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p722) timeout -s 9 2 ../source/replace.exe '[a-c?'   < ../inputs/temp-test/518.inp.225.3 > ../outputs/t722
    if diff ../outputs/t722 ../originals/t722 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p723) timeout -s 9 2 ../source/replace.exe '[a-c?' 'a&'  < ../inputs/temp-test/516.inp.225.1 > ../outputs/t723
    if diff ../outputs/t723 ../originals/t723 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p724) timeout -s 9 2 ../source/replace.exe '[a-c?' 'a&'  < ../inputs/temp-test/517.inp.225.2 > ../outputs/t724
    if diff ../outputs/t724 ../originals/t724 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p725) timeout -s 9 2 ../source/replace.exe '[a-c?' 'a&'  < ../inputs/temp-test/518.inp.225.3 > ../outputs/t725
    if diff ../outputs/t725 ../originals/t725 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p726) timeout -s 9 2 ../source/replace.exe '[a-c?' 'a&'  < ../inputs/temp-test/519.inp.225.4 > ../outputs/t726
    if diff ../outputs/t726 ../originals/t726 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p727) timeout -s 9 2 ../source/replace.exe '[a-c?*$' 'a&'  < ../inputs/temp-test/520.inp.225.8 > ../outputs/t727
    if diff ../outputs/t727 ../originals/t727 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p728) timeout -s 9 2 ../source/replace.exe '[a-c?*' 'a&'  < ../inputs/temp-test/517.inp.225.2 > ../outputs/t728
    if diff ../outputs/t728 ../originals/t728 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p729) timeout -s 9 2 ../source/replace.exe '[a-c?*' 'a&'  < ../inputs/temp-test/518.inp.225.3 > ../outputs/t729
    if diff ../outputs/t729 ../originals/t729 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p730) timeout -s 9 2 ../source/replace.exe '[a-c?*' 'a&'  < ../inputs/temp-test/519.inp.225.4 > ../outputs/t730
    if diff ../outputs/t730 ../originals/t730 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p731) timeout -s 9 2 ../source/replace.exe '[a-c?-?-[9-B]' '@%&a'  < ../inputs/temp-test/1989.inp.845.1 > ../outputs/t731
    if diff ../outputs/t731 ../originals/t731 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p732) timeout -s 9 2 ../source/replace.exe '[a-c?-?-[9-B]' '@%&a'  < ../inputs/temp-test/1990.inp.845.3 > ../outputs/t732
    if diff ../outputs/t732 ../originals/t732 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p733) timeout -s 9 2 ../source/replace.exe '[a-c[9-B]c*^-[0-9]-^*?@[-%[^a-c]?' 'b@t'  < ../inputs/temp-test/2346.inp.996.3 > ../outputs/t733
    if diff ../outputs/t733 ../originals/t733 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p734) timeout -s 9 2 ../source/replace.exe '[a-c[9-B]c*^-[0-9]-^*?@[-[^a-c]?' 'b@t'  < ../inputs/temp-test/2344.inp.996.1 > ../outputs/t734
    if diff ../outputs/t734 ../originals/t734 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p735) timeout -s 9 2 ../source/replace.exe '[a-c[9-B]c*^-[0-9]-^*?@[-[^a-c]?' 'b@t'  < ../inputs/temp-test/2345.inp.996.2 > ../outputs/t735
    if diff ../outputs/t735 ../originals/t735 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p736) timeout -s 9 2 ../source/replace.exe '[a-c[9-B]c*^-[0-9]-^*?@[-[^a-c]?' 'b@t'  < ../inputs/temp-test/2346.inp.996.3 > ../outputs/t736
    if diff ../outputs/t736 ../originals/t736 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p737) timeout -s 9 2 ../source/replace.exe '[a-c[^-' 'a&'  < ../inputs/temp-test/1135.inp.488.1 > ../outputs/t737
    if diff ../outputs/t737 ../originals/t737 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p738) timeout -s 9 2 ../source/replace.exe '[a-c[^9-B]' '@%@&'  < ../inputs/temp-test/1429.inp.614.1 > ../outputs/t738
    if diff ../outputs/t738 ../originals/t738 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p739) timeout -s 9 2 ../source/replace.exe '[a-c[^9-B]' '@%@&'  < ../inputs/temp-test/1430.inp.614.2 > ../outputs/t739
    if diff ../outputs/t739 ../originals/t739 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p740) timeout -s 9 2 ../source/replace.exe '[a-c] *' 'a@nb@tc'  < ../inputs/temp-test/2106.inp.893.1 > ../outputs/t740
    if diff ../outputs/t740 ../originals/t740 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p741) timeout -s 9 2 ../source/replace.exe '[a-c] *' 'a@nb@tc'  < ../inputs/temp-test/2107.inp.893.2 > ../outputs/t741
    if diff ../outputs/t741 ../originals/t741 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p742) timeout -s 9 2 ../source/replace.exe '[a-c] *' 'a@nb@tc'  < ../inputs/temp-test/2108.inp.893.3 > ../outputs/t742
    if diff ../outputs/t742 ../originals/t742 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p743) timeout -s 9 2 ../source/replace.exe '[a-c]%[^9-B]' 'NEW'  < ../inputs/temp-test/2332.inp.989.1 > ../outputs/t743
    if diff ../outputs/t743 ../originals/t743 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p744) timeout -s 9 2 ../source/replace.exe '[a-c]%[^9-B]' 'NEW'  < ../inputs/temp-test/2333.inp.989.2 > ../outputs/t744
    if diff ../outputs/t744 ../originals/t744 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p745) timeout -s 9 2 ../source/replace.exe '[a-c]' '&'  < ../inputs/temp-test/944.inp.406.1 > ../outputs/t745
    if diff ../outputs/t745 ../originals/t745 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p746) timeout -s 9 2 ../source/replace.exe '[a-c]' '&'  < ../inputs/temp-test/945.inp.406.2 > ../outputs/t746
    if diff ../outputs/t746 ../originals/t746 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p747) timeout -s 9 2 ../source/replace.exe '[a-c]' '@%@&'  < ../inputs/temp-test/1207.inp.518.1 > ../outputs/t747
    if diff ../outputs/t747 ../originals/t747 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p748) timeout -s 9 2 ../source/replace.exe '[a-c]' '@%@&'  < ../inputs/temp-test/1208.inp.518.4 > ../outputs/t748
    if diff ../outputs/t748 ../originals/t748 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p749) timeout -s 9 2 ../source/replace.exe '[a-c]' 'NEW'  < ../inputs/temp-test/1772.inp.755.1 > ../outputs/t749
    if diff ../outputs/t749 ../originals/t749 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p750) timeout -s 9 2 ../source/replace.exe '[a-c]' 'NEW'  < ../inputs/temp-test/1773.inp.755.2 > ../outputs/t750
    if diff ../outputs/t750 ../originals/t750 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p751) timeout -s 9 2 ../source/replace.exe '[a-c]' 'a@n'  < ../inputs/temp-test/819.inp.353.1 > ../outputs/t751
    if diff ../outputs/t751 ../originals/t751 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p752) timeout -s 9 2 ../source/replace.exe '[a-c]' 'a@n'  < ../inputs/temp-test/820.inp.353.2 > ../outputs/t752
    if diff ../outputs/t752 ../originals/t752 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p753) timeout -s 9 2 ../source/replace.exe '[a-c]' 'a@nb@tc'  < ../inputs/temp-test/1340.inp.576.1 > ../outputs/t753
    if diff ../outputs/t753 ../originals/t753 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p754) timeout -s 9 2 ../source/replace.exe '[a-c]' 'a@nb@tc'  < ../inputs/temp-test/1341.inp.576.2 > ../outputs/t754
    if diff ../outputs/t754 ../originals/t754 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p755) timeout -s 9 2 ../source/replace.exe '[a-c]*' '@%&a'  < ../inputs/temp-test/83.inp.37.1 > ../outputs/t755
    if diff ../outputs/t755 ../originals/t755 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p756) timeout -s 9 2 ../source/replace.exe '[a-c]*-' 'NEW'  < ../inputs/temp-test/44.inp.19.1 > ../outputs/t756
    if diff ../outputs/t756 ../originals/t756 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p757) timeout -s 9 2 ../source/replace.exe '[a-c]*-' 'NEW'  < ../inputs/temp-test/45.inp.19.3 > ../outputs/t757
    if diff ../outputs/t757 ../originals/t757 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p758) timeout -s 9 2 ../source/replace.exe '[a-c]*??[a-c]' '@%@&'  < ../inputs/temp-test/369.inp.161.1 > ../outputs/t758
    if diff ../outputs/t758 ../originals/t758 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p759) timeout -s 9 2 ../source/replace.exe '[a-c]*??[a-c]' '@%@&'  < ../inputs/temp-test/370.inp.161.2 > ../outputs/t759
    if diff ../outputs/t759 ../originals/t759 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p760) timeout -s 9 2 ../source/replace.exe '[a-c]*??[a-c]' '@%@&'  < ../inputs/temp-test/371.inp.161.3 > ../outputs/t760
    if diff ../outputs/t760 ../originals/t760 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p761) timeout -s 9 2 ../source/replace.exe '[a-c]-' '@%&a'  < ../inputs/temp-test/1846.inp.784.1 > ../outputs/t761
    if diff ../outputs/t761 ../originals/t761 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p762) timeout -s 9 2 ../source/replace.exe '[a-c]-' '@%&a'  < ../inputs/temp-test/1847.inp.784.2 > ../outputs/t762
    if diff ../outputs/t762 ../originals/t762 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p763) timeout -s 9 2 ../source/replace.exe '[a-c]-' '@%&a'  < ../inputs/temp-test/1848.inp.784.3 > ../outputs/t763
    if diff ../outputs/t763 ../originals/t763 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p764) timeout -s 9 2 ../source/replace.exe '[a-c]-' '@%@&'  < ../inputs/temp-test/117.inp.54.1 > ../outputs/t764
    if diff ../outputs/t764 ../originals/t764 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p765) timeout -s 9 2 ../source/replace.exe '[a-c]-' 'a@nb@tc'  < ../inputs/temp-test/1630.inp.694.1 > ../outputs/t765
    if diff ../outputs/t765 ../originals/t765 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p766) timeout -s 9 2 ../source/replace.exe '[a-c]-' 'a@nb@tc'  < ../inputs/temp-test/1631.inp.694.3 > ../outputs/t766
    if diff ../outputs/t766 ../originals/t766 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p767) timeout -s 9 2 ../source/replace.exe '[a-c]?' '&@n'  < ../inputs/temp-test/644.inp.279.1 > ../outputs/t767
    if diff ../outputs/t767 ../originals/t767 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p768) timeout -s 9 2 ../source/replace.exe '[a-c]?' '&@naaaa'  < ../inputs/temp-test/644.inp.279.1 > ../outputs/t768
    if diff ../outputs/t768 ../originals/t768 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p769) timeout -s 9 2 ../source/replace.exe '[a-c]?' '@t'  < ../inputs/temp-test/1843.inp.783.1 > ../outputs/t769
    if diff ../outputs/t769 ../originals/t769 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p770) timeout -s 9 2 ../source/replace.exe '[a-c]?' '@t'  < ../inputs/temp-test/1844.inp.783.2 > ../outputs/t770
    if diff ../outputs/t770 ../originals/t770 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p771) timeout -s 9 2 ../source/replace.exe '[a-c]?' '@t'  < ../inputs/temp-test/1845.inp.783.3 > ../outputs/t771
    if diff ../outputs/t771 ../originals/t771 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p772) timeout -s 9 2 ../source/replace.exe '[a-c]?' '@t'  < ../inputs/temp-test/644.inp.279.1 > ../outputs/t772
    if diff ../outputs/t772 ../originals/t772 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p773) timeout -s 9 2 ../source/replace.exe '[a-c]?' '@t'  < ../inputs/temp-test/645.inp.279.2 > ../outputs/t773
    if diff ../outputs/t773 ../originals/t773 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p774) timeout -s 9 2 ../source/replace.exe '[a-c]?' 'NEW'  < ../inputs/temp-test/750.inp.322.1 > ../outputs/t774
    if diff ../outputs/t774 ../originals/t774 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p775) timeout -s 9 2 ../source/replace.exe '[a-c]?' 'NEW'  < ../inputs/temp-test/751.inp.322.3 > ../outputs/t775
    if diff ../outputs/t775 ../originals/t775 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p776) timeout -s 9 2 ../source/replace.exe '[a-c]??@n[^9-B]??-' '@t'  < ../inputs/temp-test/1278.inp.549.1 > ../outputs/t776
    if diff ../outputs/t776 ../originals/t776 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p777) timeout -s 9 2 ../source/replace.exe '[a-c]??@n[^9-B]??-' '@t'  < ../inputs/temp-test/1279.inp.549.2 > ../outputs/t777
    if diff ../outputs/t777 ../originals/t777 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p778) timeout -s 9 2 ../source/replace.exe '[a-c]??@n[^9-B]??-' '@t'  < ../inputs/temp-test/1280.inp.549.3 > ../outputs/t778
    if diff ../outputs/t778 ../originals/t778 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p779) timeout -s 9 2 ../source/replace.exe '[a-c]?[0-9]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t779
    if diff ../outputs/t779 ../originals/t779 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p780) timeout -s 9 2 ../source/replace.exe '[a-c]?[0-9]^*' 'NEW'  < ../inputs/temp-test/1822.inp.775.1 > ../outputs/t780
    if diff ../outputs/t780 ../originals/t780 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p781) timeout -s 9 2 ../source/replace.exe '[a-c]?[0-9]^*' 'NEW'  < ../inputs/temp-test/1823.inp.775.3 > ../outputs/t781
    if diff ../outputs/t781 ../originals/t781 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p782) timeout -s 9 2 ../source/replace.exe '[a-c]?[^9-B][9-B][^a--b][0-9]-@@*' '@%&a'  < ../inputs/temp-test/489.inp.214.1 > ../outputs/t782
    if diff ../outputs/t782 ../originals/t782 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p783) timeout -s 9 2 ../source/replace.exe '[a-c]?[^9-B][9-B][^a--b][0-9]-@@*@' '@%&a'  < ../inputs/temp-test/489.inp.214.1 > ../outputs/t783
    if diff ../outputs/t783 ../originals/t783 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p784) timeout -s 9 2 ../source/replace.exe '[a-c]?a-]??-@*^a-c][9-B]' 'a@nb@tc'  < ../inputs/temp-test/1471.inp.631.1 > ../outputs/t784
    if diff ../outputs/t784 ../originals/t784 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p785) timeout -s 9 2 ../source/replace.exe '[a-c]?a-]??-@*^a-c][9-B]' 'a@nb@tc'  < ../inputs/temp-test/1472.inp.631.3 > ../outputs/t785
    if diff ../outputs/t785 ../originals/t785 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p786) timeout -s 9 2 ../source/replace.exe '[a-c]@t' '&'  < ../inputs/temp-test/1389.inp.596.1 > ../outputs/t786
    if diff ../outputs/t786 ../originals/t786 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p787) timeout -s 9 2 ../source/replace.exe '[a-c]@t' '&'  < ../inputs/temp-test/1390.inp.596.3 > ../outputs/t787
    if diff ../outputs/t787 ../originals/t787 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p788) timeout -s 9 2 ../source/replace.exe '[a-c]@t' ''  < ../inputs/temp-test/1986.inp.844.1 > ../outputs/t788
    if diff ../outputs/t788 ../originals/t788 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p789) timeout -s 9 2 ../source/replace.exe '[a-c]@t' ''  < ../inputs/temp-test/1987.inp.844.2 > ../outputs/t789
    if diff ../outputs/t789 ../originals/t789 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p790) timeout -s 9 2 ../source/replace.exe '[a-c]@t' ''  < ../inputs/temp-test/1988.inp.844.3 > ../outputs/t790
    if diff ../outputs/t790 ../originals/t790 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p791) timeout -s 9 2 ../source/replace.exe '[a-c]A' '&'  < ../inputs/temp-test/922.inp.398.1 > ../outputs/t791
    if diff ../outputs/t791 ../originals/t791 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p792) timeout -s 9 2 ../source/replace.exe '[a-c]A' '&'  < ../inputs/temp-test/923.inp.398.2 > ../outputs/t792
    if diff ../outputs/t792 ../originals/t792 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p793) timeout -s 9 2 ../source/replace.exe '[a-c]A' '&'  < ../inputs/temp-test/924.inp.398.3 > ../outputs/t793
    if diff ../outputs/t793 ../originals/t793 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p794) timeout -s 9 2 ../source/replace.exe '[a-c][--' '&a@%'  < ../inputs/temp-test/1598.inp.680.1 > ../outputs/t794
    if diff ../outputs/t794 ../originals/t794 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p795) timeout -s 9 2 ../source/replace.exe '[a-c][--' '&a@%'  < ../inputs/temp-test/1599.inp.680.2 > ../outputs/t795
    if diff ../outputs/t795 ../originals/t795 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p796) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]' '&@n'  < ../inputs/temp-test/694.inp.300.9 > ../outputs/t796
    if diff ../outputs/t796 ../originals/t796 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p797) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]' '&@n[0-9]'  < ../inputs/temp-test/694.inp.300.9 > ../outputs/t797
    if diff ../outputs/t797 ../originals/t797 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p798) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]' '@%@&'  < ../inputs/temp-test/535.inp.232.1 > ../outputs/t798
    if diff ../outputs/t798 ../originals/t798 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p799) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]' '@%@&'  < ../inputs/temp-test/536.inp.232.2 > ../outputs/t799
    if diff ../outputs/t799 ../originals/t799 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p800) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]' '@%@&'  < ../inputs/temp-test/537.inp.232.3 > ../outputs/t800
    if diff ../outputs/t800 ../originals/t800 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p801) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]*[a-c]' '&@n&t'  < ../inputs/temp-test/690.inp.300.1 > ../outputs/t801
    if diff ../outputs/t801 ../originals/t801 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p802) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]*[a-c]' '&@n'  < ../inputs/temp-test/690.inp.300.1 > ../outputs/t802
    if diff ../outputs/t802 ../originals/t802 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p803) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]*[a-c]' '&@n'  < ../inputs/temp-test/691.inp.300.2 > ../outputs/t803
    if diff ../outputs/t803 ../originals/t803 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p804) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]*[a-c]' '&@n'  < ../inputs/temp-test/692.inp.300.3 > ../outputs/t804
    if diff ../outputs/t804 ../originals/t804 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p805) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]*[a-c]' '&@na@t@t'  < ../inputs/temp-test/691.inp.300.2 > ../outputs/t805
    if diff ../outputs/t805 ../originals/t805 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p806) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]-*-[a-c]-$' '@n'  < ../inputs/temp-test/694.inp.300.9 > ../outputs/t806
    if diff ../outputs/t806 ../originals/t806 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p807) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]-*-[a-c]-' '@n'  < ../inputs/temp-test/690.inp.300.1 > ../outputs/t807
    if diff ../outputs/t807 ../originals/t807 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p808) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]-*-[a-c]-' '@n'  < ../inputs/temp-test/691.inp.300.2 > ../outputs/t808
    if diff ../outputs/t808 ../originals/t808 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p809) timeout -s 9 2 ../source/replace.exe '[a-c][^0-9]-*-[a-c]-' '@n'  < ../inputs/temp-test/692.inp.300.3 > ../outputs/t809
    if diff ../outputs/t809 ../originals/t809 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p810) timeout -s 9 2 ../source/replace.exe '[a-c][^9-B]' 'NEW'  < ../inputs/temp-test/2332.inp.989.1 > ../outputs/t810
    if diff ../outputs/t810 ../originals/t810 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p811) timeout -s 9 2 ../source/replace.exe '[a-c][^9-B]' 'NEW'  < ../inputs/temp-test/2333.inp.989.2 > ../outputs/t811
    if diff ../outputs/t811 ../originals/t811 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p812) timeout -s 9 2 ../source/replace.exe '[a-c][^@n]-[^a-c' '@%@&'  < ../inputs/temp-test/64.inp.28.1 > ../outputs/t812
    if diff ../outputs/t812 ../originals/t812 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p813) timeout -s 9 2 ../source/replace.exe '[a-c][^@n]-[^a-c' '@%@&'  < ../inputs/temp-test/65.inp.28.2 > ../outputs/t813
    if diff ../outputs/t813 ../originals/t813 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p814) timeout -s 9 2 ../source/replace.exe '[a-c][^a-c]' 'a&'  < ../inputs/temp-test/1685.inp.718.1 > ../outputs/t814
    if diff ../outputs/t814 ../originals/t814 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p815) timeout -s 9 2 ../source/replace.exe '[a-c][^a-c]' 'a&'  < ../inputs/temp-test/1686.inp.718.3 > ../outputs/t815
    if diff ../outputs/t815 ../originals/t815 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p816) timeout -s 9 2 ../source/replace.exe '[a-c]^-]' 'NEW'  < ../inputs/temp-test/1956.inp.830.1 > ../outputs/t816
    if diff ../outputs/t816 ../originals/t816 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p817) timeout -s 9 2 ../source/replace.exe '[a-c]^-]' 'NEW'  < ../inputs/temp-test/1957.inp.830.2 > ../outputs/t817
    if diff ../outputs/t817 ../originals/t817 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p818) timeout -s 9 2 ../source/replace.exe '[a-c]^-]' 'NEW'  < ../inputs/temp-test/1958.inp.830.3 > ../outputs/t818
    if diff ../outputs/t818 ../originals/t818 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p819) timeout -s 9 2 ../source/replace.exe '[a-cc*' 'a@n'  < ../inputs/temp-test/925.inp.399.1 > ../outputs/t819
    if diff ../outputs/t819 ../originals/t819 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p820) timeout -s 9 2 ../source/replace.exe '[a-cc*' 'a@n'  < ../inputs/temp-test/926.inp.399.2 > ../outputs/t820
    if diff ../outputs/t820 ../originals/t820 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p821) timeout -s 9 2 ../source/replace.exe '[a-cc*' 'a@n'  < ../inputs/temp-test/927.inp.399.3 > ../outputs/t821
    if diff ../outputs/t821 ../originals/t821 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p822) timeout -s 9 2 ../source/replace.exe '[a-d]' '&@n'  < ../inputs/moni/f8.inp > ../outputs/t822
    if diff ../outputs/t822 ../originals/t822 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p823) timeout -s 9 2 ../source/replace.exe '[a-z0-9]@n' '?&<N#N4zMu+/?$@,"oa`nt=1CL!g3y*(k((w!.4aPc>wSP2w2'  < ../inputs/input/ruin.487 > ../outputs/t823
    if diff ../outputs/t823 ../originals/t823 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p824) timeout -s 9 2 ../source/replace.exe '[a-z]$' 6666666  < ../inputs/moni/f6.inp > ../outputs/t824
    if diff ../outputs/t824 ../originals/t824 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p825) timeout -s 9 2 ../source/replace.exe '[a-z]*' 'c'  < ../inputs/moni/f7.inp > ../outputs/t825
    if diff ../outputs/t825 ../originals/t825 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p826) timeout -s 9 2 ../source/replace.exe '[a-z]@n' ';S&=:zD+0/]VKClfA;8d-(~bTN"m'  < ../inputs/input/ruin.1086 > ../outputs/t826
    if diff ../outputs/t826 ../originals/t826 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p827) timeout -s 9 2 ../source/replace.exe '[a-z]@n' 'P&p'  < ../inputs/input/ruin.276 > ../outputs/t827
    if diff ../outputs/t827 ../originals/t827 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p828) timeout -s 9 2 ../source/replace.exe '[a-z]@n' 'y&8sdW9T'  < ../inputs/input/ruin.1065 > ../outputs/t828
    if diff ../outputs/t828 ../originals/t828 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p829) timeout -s 9 2 ../source/replace.exe '[c-a>-AZ-a]^_`a->-A>-A-c-ac-a-A-GABCDEFG-z-}z-}]' '/pWrCGn $(=Vs1rb~eI-_'  < ../inputs/input/ruin.243 > ../outputs/t829
    if diff ../outputs/t829 ../originals/t829 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p830) timeout -s 9 2 ../source/replace.exe '[c-a>-A]' 'Mc\}+8d\*7-pc Iw4hhz;o>M0T q:ct)|%} 5R\x8a|3y@A\-`$e'  < ../inputs/input/ruin.56 > ../outputs/t830
    if diff ../outputs/t830 ../originals/t830 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p831) timeout -s 9 2 ../source/replace.exe '[c-aA-GA-G]' '~'  < ../inputs/input/ruin.1769 > ../outputs/t831
    if diff ../outputs/t831 ../originals/t831 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p832) timeout -s 9 2 ../source/replace.exe '[c-aA-GZ-a]^_`a]@@?' 'I8-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_DDe(Gk8G'  < ../inputs/input/ruin.1050 > ../outputs/t832
    if diff ../outputs/t832 ../originals/t832 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p833) timeout -s 9 2 ../source/replace.exe '[c-aA-GZ-a]^_`a]@@?' 'I8DDe(Gk8G'  < ../inputs/input/ruin.1050 > ../outputs/t833
    if diff ../outputs/t833 ../originals/t833 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p834) timeout -s 9 2 ../source/replace.exe '[c-aA-G]' '.8bt`e.7uXtI;mb)w4,*v%}s=:<?cQ6 k=#@zJHd'  < ../inputs/input/ruin.1017 > ../outputs/t834
    if diff ../outputs/t834 ../originals/t834 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p835) timeout -s 9 2 ../source/replace.exe '[c-aA-G]@@@@' '.kBod&JKL>8L6M2SZY`We5?e BEyk?<_wc7Y(M9N='  < ../inputs/input/ruin.692 > ../outputs/t835
    if diff ../outputs/t835 ../originals/t835 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p836) timeout -s 9 2 ../source/replace.exe '[c-aCZ-a]^_`a->-A>-A]' 'MN6)$<V>G9kmDmReuQ&W%@sP%7!mP'  < ../inputs/input/ruin.1003 > ../outputs/t836
    if diff ../outputs/t836 ../originals/t836 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p837) timeout -s 9 2 ../source/replace.exe '[c-aZ-a]^_`a-A-GABCDEFG]' 'X'  < ../inputs/input/ruin.497 > ../outputs/t837
    if diff ../outputs/t837 ../originals/t837 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p838) timeout -s 9 2 ../source/replace.exe '[c-aZ-a]^_`a]' 'F'  < ../inputs/input/ruin.468 > ../outputs/t838
    if diff ../outputs/t838 ../originals/t838 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p839) timeout -s 9 2 ../source/replace.exe '[c-aZ-a]^_`a]' 'dt|NbM\.:;'\''5E]m\6;l!?&g4ikE^yZ+P{]q++Ke\6|bYujj"[\l'  < ../inputs/input/ruin.1099 > ../outputs/t839
    if diff ../outputs/t839 ../originals/t839 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p840) timeout -s 9 2 ../source/replace.exe '[c-a]$' '>'  < ../inputs/input/ruin.1635 > ../outputs/t840
    if diff ../outputs/t840 ../originals/t840 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p841) timeout -s 9 2 ../source/replace.exe '[c-a]'   < ../inputs/input/ruin.1163 > ../outputs/t841
    if diff ../outputs/t841 ../originals/t841 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p842) timeout -s 9 2 ../source/replace.exe '[c-a]' ''  < ../inputs/input/ruin.529 > ../outputs/t842
    if diff ../outputs/t842 ../originals/t842 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p843) timeout -s 9 2 ../source/replace.exe '[c-a]' '('  < ../inputs/input/ruin.1862 > ../outputs/t843
    if diff ../outputs/t843 ../originals/t843 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p844) timeout -s 9 2 ../source/replace.exe '[c-a]' '*=Ia,P2&C['  < ../inputs/input/ruin.906 > ../outputs/t844
    if diff ../outputs/t844 ../originals/t844 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p845) timeout -s 9 2 ../source/replace.exe '[c-a]' '<-'\''p@+\*cH#a!.5:5`a'  < ../inputs/input/ruin.1163 > ../outputs/t845
    if diff ../outputs/t845 ../originals/t845 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p846) timeout -s 9 2 ../source/replace.exe '[c-a]' 'M^Cj&~4#,,`zk.j6n5wIVUMC#A^32{jG//Raz[SCLQ'  < ../inputs/input/ruin.187 > ../outputs/t846
    if diff ../outputs/t846 ../originals/t846 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p847) timeout -s 9 2 ../source/replace.exe '[c-a]' 'N'  < ../inputs/input/ruin.1225 > ../outputs/t847
    if diff ../outputs/t847 ../originals/t847 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p848) timeout -s 9 2 ../source/replace.exe '[c-a]' 'Rc}U{^ dhC_9!75dFF'  < ../inputs/input/ruin.756 > ../outputs/t848
    if diff ../outputs/t848 ../originals/t848 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p849) timeout -s 9 2 ../source/replace.exe '[c-a]' 'WvfXw!)GQ;wfqA==_$'\'';jL^X}LS)ZRG#01|zqwb4Z&E{uTWowB6'  < ../inputs/input/ruin.1918 > ../outputs/t849
    if diff ../outputs/t849 ../originals/t849 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p850) timeout -s 9 2 ../source/replace.exe '[c-a]' 'g'  < ../inputs/input/ruin.288 > ../outputs/t850
    if diff ../outputs/t850 ../originals/t850 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p851) timeout -s 9 2 ../source/replace.exe '[c-a]' 'j*,aNncxD\LU/Iefe#fadF0tSa[ta$7K+i l$o>;iO>x.mhhXeutrdDfm/ 9gV?%sMY(vOdQKW^*f[5T'  < ../inputs/input/ruin.862 > ../outputs/t851
    if diff ../outputs/t851 ../originals/t851 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p852) timeout -s 9 2 ../source/replace.exe '[c-a]' 's'  < ../inputs/input/ruin.1424 > ../outputs/t852
    if diff ../outputs/t852 ../originals/t852 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p853) timeout -s 9 2 ../source/replace.exe '[c-a]' 'x'  < ../inputs/input/ruin.1599 > ../outputs/t853
    if diff ../outputs/t853 ../originals/t853 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p854) timeout -s 9 2 ../source/replace.exe '[c-a]'\''Th4oD' 'F!d~`tL_DBH) [K-oW'  < ../inputs/input/ruin.681 > ../outputs/t854
    if diff ../outputs/t854 ../originals/t854 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p855) timeout -s 9 2 ../source/replace.exe '[c-a]?*' 'x'  < ../inputs/input/ruin.1599 > ../outputs/t855
    if diff ../outputs/t855 ../originals/t855 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p856) timeout -s 9 2 ../source/replace.exe '[c-a]@@?$' 'I>'  < ../inputs/input/ruin.29 > ../outputs/t856
    if diff ../outputs/t856 ../originals/t856 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p857) timeout -s 9 2 ../source/replace.exe '[c-a]@n' 'g&h'  < ../inputs/input/ruin.288 > ../outputs/t857
    if diff ../outputs/t857 ../originals/t857 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p858) timeout -s 9 2 ../source/replace.exe '[c-a][c-a]' '?'  < ../inputs/input/ruin.703 > ../outputs/t858
    if diff ../outputs/t858 ../originals/t858 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p859) timeout -s 9 2 ../source/replace.exe '[c-a][c-a]' 'uSD-'  < ../inputs/input/ruin.1990 > ../outputs/t859
    if diff ../outputs/t859 ../originals/t859 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p860) timeout -s 9 2 ../source/replace.exe '[c-a]\$?!I' 'C5"Ugs7z;#[m'  < ../inputs/input/ruin.1075 > ../outputs/t860
    if diff ../outputs/t860 ../originals/t860 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p861) timeout -s 9 2 ../source/replace.exe '[c-a`]' 'TxfCZ,ncl`!85cZi#F6f>B[=2xb1rZXXah,}F?O2+9xtAeyi[3h9Al$KjK7.Km?K4YU~ '\'''  < ../inputs/input/ruin.434 > ../outputs/t861
    if diff ../outputs/t861 ../originals/t861 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p862) timeout -s 9 2 ../source/replace.exe '[c-at]' 'AQ'  < ../inputs/input/ruin.253 > ../outputs/t862
    if diff ../outputs/t862 ../originals/t862 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p863) timeout -s 9 2 ../source/replace.exe '[mA-G]' '}n/rz%ZQ%Z3Z+jQI'  < ../inputs/input/ruin.1927 > ../outputs/t863
    if diff ../outputs/t863 ../originals/t863 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p864) timeout -s 9 2 ../source/replace.exe '[m]*' '=>q4/4W{xj^&B|w@/f1KHWBb#R/=43XWDWT)K'  < ../inputs/input/ruin.1454 > ../outputs/t864
    if diff ../outputs/t864 ../originals/t864 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p865) timeout -s 9 2 ../source/replace.exe '[o]' '&'  < ../inputs/input/ruin.837 > ../outputs/t865
    if diff ../outputs/t865 ../originals/t865 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p866) timeout -s 9 2 ../source/replace.exe '[p]' 'qPv3t,hM>u^_Q739Rf[^O=PY^v@Sd<vR<D=(7y5Y'  < ../inputs/input/ruin.1471 > ../outputs/t866
    if diff ../outputs/t866 ../originals/t866 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p867) timeout -s 9 2 ../source/replace.exe '[q0-9]@n' '.^&u>`Y~4'\''!d;?[6eMR*)X+D>xU%AUWv8y$.jdQ@jBn='\''(J8f,KIL4L'  < ../inputs/input/ruin.285 > ../outputs/t867
    if diff ../outputs/t867 ../originals/t867 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p868) timeout -s 9 2 ../source/replace.exe '[q]' '*'  < ../inputs/input/ruin.395 > ../outputs/t868
    if diff ../outputs/t868 ../originals/t868 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p869) timeout -s 9 2 ../source/replace.exe '[s]' 'SWCmkAgq0?ml-.(QE"<D(s5YN'  < ../inputs/input/ruin.501 > ../outputs/t869
    if diff ../outputs/t869 ../originals/t869 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p870) timeout -s 9 2 ../source/replace.exe '[z-}0-9]' ')^'  < ../inputs/input/ruin.191 > ../outputs/t870
    if diff ../outputs/t870 ../originals/t870 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p871) timeout -s 9 2 ../source/replace.exe '[z-}0-9z-}Z-a]^_`a-c-ac-a-0-90123456789->-A>-A]' 'b\Uny"%(>W]TD'\''B!T#}.".bsJjH[Q\%'  < ../inputs/input/ruin.1731 > ../outputs/t871
    if diff ../outputs/t871 ../originals/t871 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p872) timeout -s 9 2 ../source/replace.exe '[z-}]$' 'x<W#6\5oQ+{Kh2/kx#w6k`0;nznycd:QlGcd,'  < ../inputs/input/ruin.1253 > ../outputs/t872
    if diff ../outputs/t872 ../originals/t872 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p873) timeout -s 9 2 ../source/replace.exe '[z-}]'   < ../inputs/input/ruin.1164 > ../outputs/t873
    if diff ../outputs/t873 ../originals/t873 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p874) timeout -s 9 2 ../source/replace.exe '[z-}]' ' <oZI`e4Og*@]nAfBB=i%[o> ?~/z5>FDJ)"'  < ../inputs/input/ruin.356 > ../outputs/t874
    if diff ../outputs/t874 ../originals/t874 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p875) timeout -s 9 2 ../source/replace.exe '[z-}]' ''  < ../inputs/input/ruin.1055 > ../outputs/t875
    if diff ../outputs/t875 ../originals/t875 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p876) timeout -s 9 2 ../source/replace.exe '[z-}]' '5S5stRu.W%X4J'  < ../inputs/input/ruin.503 > ../outputs/t876
    if diff ../outputs/t876 ../originals/t876 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p877) timeout -s 9 2 ../source/replace.exe '[z-}]' '7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp'  < ../inputs/input/ruin.1055 > ../outputs/t877
    if diff ../outputs/t877 ../originals/t877 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p878) timeout -s 9 2 ../source/replace.exe '[z-}]' ':!OthH~kXWn'  < ../inputs/input/ruin.894 > ../outputs/t878
    if diff ../outputs/t878 ../originals/t878 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p879) timeout -s 9 2 ../source/replace.exe '[z-}]' 'P'  < ../inputs/input/ruin.217 > ../outputs/t879
    if diff ../outputs/t879 ../originals/t879 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p880) timeout -s 9 2 ../source/replace.exe '[z-}]' 'Vu'  < ../inputs/input/ruin.1883 > ../outputs/t880
    if diff ../outputs/t880 ../originals/t880 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p881) timeout -s 9 2 ../source/replace.exe '[z-}]' 'f'  < ../inputs/input/ruin.872 > ../outputs/t881
    if diff ../outputs/t881 ../originals/t881 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p882) timeout -s 9 2 ../source/replace.exe '[z-}]' 'g|9'  < ../inputs/input/ruin.1164 > ../outputs/t882
    if diff ../outputs/t882 ../originals/t882 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p883) timeout -s 9 2 ../source/replace.exe '[z-}]*$' 'x<W#6\5oQ+{Kh2/kx#w6k`0;nznycd:QlGcd,'  < ../inputs/input/ruin.1253 > ../outputs/t883
    if diff ../outputs/t883 ../originals/t883 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p884) timeout -s 9 2 ../source/replace.exe '[z-}]@t' '1O'  < ../inputs/input/ruin.47 > ../outputs/t884
    if diff ../outputs/t884 ../originals/t884 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p885) timeout -s 9 2 ../source/replace.exe '[z-}c-a]' '-MPvM'\''v'  < ../inputs/input/ruin.244 > ../outputs/t885
    if diff ../outputs/t885 ../originals/t885 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p886) timeout -s 9 2 ../source/replace.exe '[{]' '=zZZTW>^oIXf'  < ../inputs/input/ruin.71 > ../outputs/t886
    if diff ../outputs/t886 ../originals/t886 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p887) timeout -s 9 2 ../source/replace.exe '[|Z-a]^_`a]' 'C'  < ../inputs/input/ruin.1090 > ../outputs/t887
    if diff ../outputs/t887 ../originals/t887 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p888) timeout -s 9 2 ../source/replace.exe '\"Q %?' 'a'  < ../inputs/input/ruin.982 > ../outputs/t888
    if diff ../outputs/t888 ../originals/t888 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p889) timeout -s 9 2 ../source/replace.exe '\' '<'  < ../inputs/input/ruin.1395 > ../outputs/t889
    if diff ../outputs/t889 ../originals/t889 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p890) timeout -s 9 2 ../source/replace.exe '\' 'YEb bc%%["wg_QT&UFt:ir*4ne~Bh*oK?f1u3)0}uzx_+!IeT+'\''/M[Yj'  < ../inputs/input/ruin.1786 > ../outputs/t890
    if diff ../outputs/t890 ../originals/t890 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p891) timeout -s 9 2 ../source/replace.exe '\*' 'g!dZjV4QD8X5M%6e((5C]ZJ/mJ$P0N~8'  < ../inputs/input/ruin.1391 > ../outputs/t891
    if diff ../outputs/t891 ../originals/t891 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p892) timeout -s 9 2 ../source/replace.exe '\7L' 'OYei+V4`(LC05cWs)XsG(6]gdF'  < ../inputs/input/ruin.1725 > ../outputs/t892
    if diff ../outputs/t892 ../originals/t892 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p893) timeout -s 9 2 ../source/replace.exe '\8V41?' 'ee8HNWCf2?*3$ft8$/6D'  < ../inputs/input/ruin.1888 > ../outputs/t893
    if diff ../outputs/t893 ../originals/t893 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p894) timeout -s 9 2 ../source/replace.exe '\<@^@@' '&*pa1X1"X@\UX>IdCGEO|f'  < ../inputs/input/ruin.901 > ../outputs/t894
    if diff ../outputs/t894 ../originals/t894 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p895) timeout -s 9 2 ../source/replace.exe '\?' '$:Kr*#&N} g}5E6ztAOMT!}qoV,Fb\h7p5Jrvqa'  < ../inputs/input/ruin.159 > ../outputs/t895
    if diff ../outputs/t895 ../originals/t895 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p896) timeout -s 9 2 ../source/replace.exe '\@@'   < ../inputs/input/ruin.1165 > ../outputs/t896
    if diff ../outputs/t896 ../originals/t896 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p897) timeout -s 9 2 ../source/replace.exe '\@@' '('\''mg>,gajn*qm-_6So|`!\UG(w,@.$=2g]>RA'  < ../inputs/input/ruin.1995 > ../outputs/t897
    if diff ../outputs/t897 ../originals/t897 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p898) timeout -s 9 2 ../source/replace.exe '\@@' 'f'  < ../inputs/input/ruin.1165 > ../outputs/t898
    if diff ../outputs/t898 ../originals/t898 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p899) timeout -s 9 2 ../source/replace.exe '\@@*$' '('\''mg>,gajn*qm-_6So|`!\UG(w,@.$=2g]>RA'  < ../inputs/input/ruin.1995 > ../outputs/t899
    if diff ../outputs/t899 ../originals/t899 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p900) timeout -s 9 2 ../source/replace.exe '\T[v*' '8-=O.xe7b;<s`,{cP`y=:>K-=B=~q/.'  < ../inputs/input/ruin.1898 > ../outputs/t900
    if diff ../outputs/t900 ../originals/t900 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p901) timeout -s 9 2 ../source/replace.exe '\VSx"Um@@' '|'  < ../inputs/input/ruin.1643 > ../outputs/t901
    if diff ../outputs/t901 ../originals/t901 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p902) timeout -s 9 2 ../source/replace.exe '\Y!%aK@@' 'G'  < ../inputs/input/ruin.142 > ../outputs/t902
    if diff ../outputs/t902 ../originals/t902 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p903) timeout -s 9 2 ../source/replace.exe '\\v<}h]' ':"f$Nb}3DcX'  < ../inputs/input/ruin.1386 > ../outputs/t903
    if diff ../outputs/t903 ../originals/t903 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p904) timeout -s 9 2 ../source/replace.exe '\a8*' 'r'  < ../inputs/input/ruin.305 > ../outputs/t904
    if diff ../outputs/t904 ../originals/t904 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p905) timeout -s 9 2 ../source/replace.exe '\l]#+wVDo{!?' 'Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8[0-9]*z$?\aq<W4'  < ../inputs/input/ruin.1347 > ../outputs/t905
    if diff ../outputs/t905 ../originals/t905 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p906) timeout -s 9 2 ../source/replace.exe '\l]#+wVDo{!?' 'Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?\aq<W4'  < ../inputs/input/ruin.1347 > ../outputs/t906
    if diff ../outputs/t906 ../originals/t906 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p907) timeout -s 9 2 ../source/replace.exe '\l]#+wVDo{!?@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}[0-9]*' 'Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?\aq<W4'  < ../inputs/input/ruin.1347 > ../outputs/t907
    if diff ../outputs/t907 ../originals/t907 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p908) timeout -s 9 2 ../source/replace.exe '\u=vvW~U' '2'  < ../inputs/input/ruin.949 > ../outputs/t908
    if diff ../outputs/t908 ../originals/t908 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p909) timeout -s 9 2 ../source/replace.exe '\xn[^>-A]' 'o'  < ../inputs/input/ruin.1871 > ../outputs/t909
    if diff ../outputs/t909 ../originals/t909 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p910) timeout -s 9 2 ../source/replace.exe '\x|' '?'  < ../inputs/input/ruin.924 > ../outputs/t910
    if diff ../outputs/t910 ../originals/t910 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p911) timeout -s 9 2 ../source/replace.exe '\}Os*$' 'y'  < ../inputs/input/ruin.364 > ../outputs/t911
    if diff ../outputs/t911 ../originals/t911 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p912) timeout -s 9 2 ../source/replace.exe ']' '$'  < ../inputs/input/ruin.1809 > ../outputs/t912
    if diff ../outputs/t912 ../originals/t912 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p913) timeout -s 9 2 ../source/replace.exe ']' '=x3%"'  < ../inputs/input/ruin.203 > ../outputs/t913
    if diff ../outputs/t913 ../originals/t913 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p914) timeout -s 9 2 ../source/replace.exe ']' 'IGeVt0Z[JX~d];kXZc?D4${Q c5&'\''#u}/3LoWR#uj'  < ../inputs/input/ruin.237 > ../outputs/t914
    if diff ../outputs/t914 ../originals/t914 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p915) timeout -s 9 2 ../source/replace.exe ']' 'S'  < ../inputs/input/ruin.1619 > ../outputs/t915
    if diff ../outputs/t915 ../originals/t915 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p916) timeout -s 9 2 ../source/replace.exe ']' 'a'  < ../inputs/input/ruin.684 > ../outputs/t916
    if diff ../outputs/t916 ../originals/t916 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p917) timeout -s 9 2 ../source/replace.exe ']' 'd7t3xoKq,7NtyV+.x5<Q?H`Sa2j'  < ../inputs/input/ruin.812 > ../outputs/t917
    if diff ../outputs/t917 ../originals/t917 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p918) timeout -s 9 2 ../source/replace.exe ']' 'qu!E@^n@92)^Kms}mC/G>>0qc.q'  < ../inputs/input/ruin.1827 > ../outputs/t918
    if diff ../outputs/t918 ../originals/t918 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p919) timeout -s 9 2 ../source/replace.exe ']?*' 'S'  < ../inputs/input/ruin.1619 > ../outputs/t919
    if diff ../outputs/t919 ../originals/t919 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p920) timeout -s 9 2 ../source/replace.exe ']@n' '=&lk'  < ../inputs/input/ruin.277 > ../outputs/t920
    if diff ../outputs/t920 ../originals/t920 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p921) timeout -s 9 2 ../source/replace.exe '^$**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t921
    if diff ../outputs/t921 ../originals/t921 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p922) timeout -s 9 2 ../source/replace.exe '^%a-c]-' '@%@&'  < ../inputs/temp-test/25.inp.11.2 > ../outputs/t922
    if diff ../outputs/t922 ../originals/t922 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p923) timeout -s 9 2 ../source/replace.exe '^' ')J&ym12(Um?ZG6'  < ../inputs/input/ruin.1718 > ../outputs/t923
    if diff ../outputs/t923 ../originals/t923 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p924) timeout -s 9 2 ../source/replace.exe '^' '/=VXw>%)rWz0.ROqC>THDqQ^Hr+jB~x]S(cp}#'  < ../inputs/input/ruin.1204 > ../outputs/t924
    if diff ../outputs/t924 ../originals/t924 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p925) timeout -s 9 2 ../source/replace.exe '^' '>'  < ../inputs/input/ruin.630 > ../outputs/t925
    if diff ../outputs/t925 ../originals/t925 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p926) timeout -s 9 2 ../source/replace.exe '^' 'RJ"uId4{]]FL|-)/'  < ../inputs/input/ruin.1789 > ../outputs/t926
    if diff ../outputs/t926 ../originals/t926 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p927) timeout -s 9 2 ../source/replace.exe '^' 'Sy]U)vS+Ig:nzR;}B#I}p0@nOb"@Yqv.A`?PuhL g0{svG=S'  < ../inputs/input/ruin.1093 > ../outputs/t927
    if diff ../outputs/t927 ../originals/t927 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p928) timeout -s 9 2 ../source/replace.exe '^' 'b@t'  < ../inputs/temp-test/124.inp.58.1 > ../outputs/t928
    if diff ../outputs/t928 ../originals/t928 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p929) timeout -s 9 2 ../source/replace.exe '^' 'b@t'  < ../inputs/temp-test/125.inp.58.3 > ../outputs/t929
    if diff ../outputs/t929 ../originals/t929 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p930) timeout -s 9 2 ../source/replace.exe '^' 'e'  < ../inputs/input/ruin.1661 > ../outputs/t930
    if diff ../outputs/t930 ../originals/t930 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p931) timeout -s 9 2 ../source/replace.exe '^' 'o:d;LeM"ts3$SRInwYpZ;bC1@HdnY?I(lB'  < ../inputs/input/ruin.1944 > ../outputs/t931
    if diff ../outputs/t931 ../originals/t931 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p932) timeout -s 9 2 ../source/replace.exe '^*%^*?-[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[?' '@%&a'  < ../inputs/temp-test/15.inp.7.1 > ../outputs/t932
    if diff ../outputs/t932 ../originals/t932 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p933) timeout -s 9 2 ../source/replace.exe '^*%^*?-[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[?' '@%&a'  < ../inputs/temp-test/16.inp.7.3 > ../outputs/t933
    if diff ../outputs/t933 ../originals/t933 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p934) timeout -s 9 2 ../source/replace.exe '^**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t934
    if diff ../outputs/t934 ../originals/t934 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p935) timeout -s 9 2 ../source/replace.exe '^*-' '&'  < ../inputs/temp-test/183.inp.82.1 > ../outputs/t935
    if diff ../outputs/t935 ../originals/t935 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p936) timeout -s 9 2 ../source/replace.exe '^*-' '&'  < ../inputs/temp-test/184.inp.82.3 > ../outputs/t936
    if diff ../outputs/t936 ../originals/t936 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p937) timeout -s 9 2 ../source/replace.exe '^*-' '&a@%'  < ../inputs/temp-test/1932.inp.821.1 > ../outputs/t937
    if diff ../outputs/t937 ../originals/t937 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p938) timeout -s 9 2 ../source/replace.exe '^*-[a-]-[^@t]' 'a@n'  < ../inputs/temp-test/1265.inp.543.1 > ../outputs/t938
    if diff ../outputs/t938 ../originals/t938 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p939) timeout -s 9 2 ../source/replace.exe '^*-[a-]-[^@t]' 'a@n'  < ../inputs/temp-test/1266.inp.543.2 > ../outputs/t939
    if diff ../outputs/t939 ../originals/t939 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p940) timeout -s 9 2 ../source/replace.exe '^*-[a-]-[^@t]' 'a@n'  < ../inputs/temp-test/1267.inp.543.3 > ../outputs/t940
    if diff ../outputs/t940 ../originals/t940 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p941) timeout -s 9 2 ../source/replace.exe '^*?' '&a@%'  < ../inputs/temp-test/1540.inp.659.1 > ../outputs/t941
    if diff ../outputs/t941 ../originals/t941 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p942) timeout -s 9 2 ../source/replace.exe '^*??-' '@%@&'  < ../inputs/temp-test/2240.inp.950.1 > ../outputs/t942
    if diff ../outputs/t942 ../originals/t942 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p943) timeout -s 9 2 ../source/replace.exe '^*??-' '@%@&'  < ../inputs/temp-test/2241.inp.950.2 > ../outputs/t943
    if diff ../outputs/t943 ../originals/t943 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p944) timeout -s 9 2 ../source/replace.exe '^*[9-B]?' '&'  < ../inputs/temp-test/1012.inp.435.1 > ../outputs/t944
    if diff ../outputs/t944 ../originals/t944 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p945) timeout -s 9 2 ../source/replace.exe '^*[9-B]?' '&'  < ../inputs/temp-test/1013.inp.435.3 > ../outputs/t945
    if diff ../outputs/t945 ../originals/t945 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p946) timeout -s 9 2 ../source/replace.exe '^*[^-z]' '@t'  < ../inputs/temp-test/102.inp.46.1 > ../outputs/t946
    if diff ../outputs/t946 ../originals/t946 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p947) timeout -s 9 2 ../source/replace.exe '^*[^-z]' '@t'  < ../inputs/temp-test/103.inp.46.2 > ../outputs/t947
    if diff ../outputs/t947 ../originals/t947 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p948) timeout -s 9 2 ../source/replace.exe '^*[^@@]-?^a-][a--][^@@]?-[0-9]' '@%@&'  < ../inputs/temp-test/1683.inp.717.1 > ../outputs/t948
    if diff ../outputs/t948 ../originals/t948 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p949) timeout -s 9 2 ../source/replace.exe '^*[^a--]$' 'a&'  < ../inputs/temp-test/256.inp.113.8 > ../outputs/t949
    if diff ../outputs/t949 ../originals/t949 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p950) timeout -s 9 2 ../source/replace.exe '^*[^a--]' 'a&'  < ../inputs/temp-test/254.inp.113.1 > ../outputs/t950
    if diff ../outputs/t950 ../originals/t950 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p951) timeout -s 9 2 ../source/replace.exe '^*[^a--]' 'a&'  < ../inputs/temp-test/255.inp.113.2 > ../outputs/t951
    if diff ../outputs/t951 ../originals/t951 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p952) timeout -s 9 2 ../source/replace.exe '^*[^a-[a-c][0-9]?-*-?? ' ''  < ../inputs/temp-test/1933.inp.822.1 > ../outputs/t952
    if diff ../outputs/t952 ../originals/t952 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p953) timeout -s 9 2 ../source/replace.exe '^*[^a-[a-c][0-9]?-*-?? ' ''  < ../inputs/temp-test/1934.inp.822.3 > ../outputs/t953
    if diff ../outputs/t953 ../originals/t953 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p954) timeout -s 9 2 ../source/replace.exe '^*[_-z]' 'a@nb@tc'  < ../inputs/temp-test/653.inp.284.1 > ../outputs/t954
    if diff ../outputs/t954 ../originals/t954 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p955) timeout -s 9 2 ../source/replace.exe '^*[_-z]' 'a@nb@tc'  < ../inputs/temp-test/654.inp.284.2 > ../outputs/t955
    if diff ../outputs/t955 ../originals/t955 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p956) timeout -s 9 2 ../source/replace.exe '^*[_-z]' 'a@nb@tc'  < ../inputs/temp-test/655.inp.284.3 > ../outputs/t956
    if diff ../outputs/t956 ../originals/t956 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p957) timeout -s 9 2 ../source/replace.exe '^*[a--]' ''  < ../inputs/temp-test/1395.inp.598.1 > ../outputs/t957
    if diff ../outputs/t957 ../originals/t957 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p958) timeout -s 9 2 ../source/replace.exe '^*[a-c[9-B]?' 'a&'  < ../inputs/temp-test/1297.inp.557.1 > ../outputs/t958
    if diff ../outputs/t958 ../originals/t958 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p959) timeout -s 9 2 ../source/replace.exe '^*[a-c[9-B]?' 'a&'  < ../inputs/temp-test/1298.inp.557.2 > ../outputs/t959
    if diff ../outputs/t959 ../originals/t959 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p960) timeout -s 9 2 ../source/replace.exe '^*^*?-[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[?' '@%&a'  < ../inputs/temp-test/15.inp.7.1 > ../outputs/t960
    if diff ../outputs/t960 ../originals/t960 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p961) timeout -s 9 2 ../source/replace.exe '^*^*?-[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[?' '@%&a'  < ../inputs/temp-test/16.inp.7.3 > ../outputs/t961
    if diff ../outputs/t961 ../originals/t961 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p962) timeout -s 9 2 ../source/replace.exe '^*a-c]' '@%&a'  < ../inputs/temp-test/2244.inp.952.1 > ../outputs/t962
    if diff ../outputs/t962 ../originals/t962 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p963) timeout -s 9 2 ../source/replace.exe '^*a-c]' '@%&a'  < ../inputs/temp-test/2245.inp.952.2 > ../outputs/t963
    if diff ../outputs/t963 ../originals/t963 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p964) timeout -s 9 2 ../source/replace.exe '^*a-c]' '@%&a'  < ../inputs/temp-test/2246.inp.952.3 > ../outputs/t964
    if diff ../outputs/t964 ../originals/t964 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p965) timeout -s 9 2 ../source/replace.exe '^-' '&'  < ../inputs/temp-test/873.inp.375.1 > ../outputs/t965
    if diff ../outputs/t965 ../originals/t965 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p966) timeout -s 9 2 ../source/replace.exe '^-' '&'  < ../inputs/temp-test/874.inp.375.2 > ../outputs/t966
    if diff ../outputs/t966 ../originals/t966 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p967) timeout -s 9 2 ../source/replace.exe '^-' '@t'  < ../inputs/temp-test/429.inp.189.1 > ../outputs/t967
    if diff ../outputs/t967 ../originals/t967 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p968) timeout -s 9 2 ../source/replace.exe '^-' '@t'  < ../inputs/temp-test/430.inp.189.2 > ../outputs/t968
    if diff ../outputs/t968 ../originals/t968 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p969) timeout -s 9 2 ../source/replace.exe '^-' '@t'  < ../inputs/temp-test/431.inp.189.3 > ../outputs/t969
    if diff ../outputs/t969 ../originals/t969 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p970) timeout -s 9 2 ../source/replace.exe '^-?[][^9-B]' 'a@n'  < ../inputs/temp-test/510.inp.222.4 > ../outputs/t970
    if diff ../outputs/t970 ../originals/t970 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p971) timeout -s 9 2 ../source/replace.exe '^-?[^9-B]'   < ../inputs/temp-test/510.inp.222.4 > ../outputs/t971
    if diff ../outputs/t971 ../originals/t971 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p972) timeout -s 9 2 ../source/replace.exe '^-?[^9-B]' 'a@n'  < ../inputs/temp-test/509.inp.222.1 > ../outputs/t972
    if diff ../outputs/t972 ../originals/t972 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p973) timeout -s 9 2 ../source/replace.exe '^-?[^9-B]' 'a@n'  < ../inputs/temp-test/510.inp.222.4 > ../outputs/t973
    if diff ../outputs/t973 ../originals/t973 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p974) timeout -s 9 2 ../source/replace.exe '^-?[^9-B]*$' 'a@n'  < ../inputs/temp-test/510.inp.222.4 > ../outputs/t974
    if diff ../outputs/t974 ../originals/t974 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p975) timeout -s 9 2 ../source/replace.exe '^-?[^9-B]*' 'a@n'  < ../inputs/temp-test/510.inp.222.4 > ../outputs/t975
    if diff ../outputs/t975 ../originals/t975 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p976) timeout -s 9 2 ../source/replace.exe '^-?[^][^9-B]' 'a@n'  < ../inputs/temp-test/510.inp.222.4 > ../outputs/t976
    if diff ../outputs/t976 ../originals/t976 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p977) timeout -s 9 2 ../source/replace.exe '^-?[a-c]' '@%@&'  < ../inputs/temp-test/881.inp.378.1 > ../outputs/t977
    if diff ../outputs/t977 ../originals/t977 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p978) timeout -s 9 2 ../source/replace.exe '^-]-[9-B]' '@%&a'  < ../inputs/temp-test/1666.inp.711.1 > ../outputs/t978
    if diff ../outputs/t978 ../originals/t978 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p979) timeout -s 9 2 ../source/replace.exe '^-]-[9-B]' '@%&a'  < ../inputs/temp-test/1667.inp.711.3 > ../outputs/t979
    if diff ../outputs/t979 ../originals/t979 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p980) timeout -s 9 2 ../source/replace.exe '^-]-[9-B]' '@%&a'  < ../inputs/temp-test/1668.inp.711.4 > ../outputs/t980
    if diff ../outputs/t980 ../originals/t980 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p981) timeout -s 9 2 ../source/replace.exe '^-]?' '&'  < ../inputs/temp-test/1766.inp.752.1 > ../outputs/t981
    if diff ../outputs/t981 ../originals/t981 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p982) timeout -s 9 2 ../source/replace.exe '^-]?' '&'  < ../inputs/temp-test/1767.inp.752.2 > ../outputs/t982
    if diff ../outputs/t982 ../originals/t982 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p983) timeout -s 9 2 ../source/replace.exe '^-]@**$' 'b@t'  < ../inputs/temp-test/744.inp.318.8 > ../outputs/t983
    if diff ../outputs/t983 ../originals/t983 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p984) timeout -s 9 2 ../source/replace.exe '^-]@**' 'b@t'  < ../inputs/temp-test/741.inp.318.1 > ../outputs/t984
    if diff ../outputs/t984 ../originals/t984 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p985) timeout -s 9 2 ../source/replace.exe '^-]@**' 'b@t'  < ../inputs/temp-test/742.inp.318.2 > ../outputs/t985
    if diff ../outputs/t985 ../originals/t985 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p986) timeout -s 9 2 ../source/replace.exe '^-][0-9]' 'NEW'  < ../inputs/temp-test/667.inp.291.1 > ../outputs/t986
    if diff ../outputs/t986 ../originals/t986 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p987) timeout -s 9 2 ../source/replace.exe '^-][0-9]' 'NEW'  < ../inputs/temp-test/668.inp.291.2 > ../outputs/t987
    if diff ../outputs/t987 ../originals/t987 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p988) timeout -s 9 2 ../source/replace.exe '^?$' '@%@&'  < ../inputs/temp-test/339.inp.148.6 > ../outputs/t988
    if diff ../outputs/t988 ../originals/t988 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p989) timeout -s 9 2 ../source/replace.exe '^?' '@%@&'  < ../inputs/temp-test/336.inp.148.1 > ../outputs/t989
    if diff ../outputs/t989 ../originals/t989 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p990) timeout -s 9 2 ../source/replace.exe '^?' '@%@&'  < ../inputs/temp-test/337.inp.148.2 > ../outputs/t990
    if diff ../outputs/t990 ../originals/t990 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p991) timeout -s 9 2 ../source/replace.exe '^?' '@%@&'  < ../inputs/temp-test/338.inp.148.3 > ../outputs/t991
    if diff ../outputs/t991 ../originals/t991 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p992) timeout -s 9 2 ../source/replace.exe '^?' 'a&'  < ../inputs/temp-test/401.inp.175.1 > ../outputs/t992
    if diff ../outputs/t992 ../originals/t992 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p993) timeout -s 9 2 ../source/replace.exe '^?' 'a&'  < ../inputs/temp-test/402.inp.175.4 > ../outputs/t993
    if diff ../outputs/t993 ../originals/t993 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p994) timeout -s 9 2 ../source/replace.exe '^?[^0-9][a--b]-@[' '&'  < ../inputs/temp-test/907.inp.391.1 > ../outputs/t994
    if diff ../outputs/t994 ../originals/t994 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p995) timeout -s 9 2 ../source/replace.exe '^?[^0-9][a--b]-@[' '&'  < ../inputs/temp-test/908.inp.391.2 > ../outputs/t995
    if diff ../outputs/t995 ../originals/t995 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p996) timeout -s 9 2 ../source/replace.exe '^@@\?[^c-a]$' 'bSRy3i[Ff.nx{B>V$n/JFtqSP6s7do)BW%F=xS_&{a'  < ../inputs/input/ruin.1580 > ../outputs/t996
    if diff ../outputs/t996 ../originals/t996 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p997) timeout -s 9 2 ../source/replace.exe '^[9-B]' '@%@&'  < ../inputs/temp-test/1967.inp.836.1 > ../outputs/t997
    if diff ../outputs/t997 ../originals/t997 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p998) timeout -s 9 2 ../source/replace.exe '^[9-B]' '@%@&'  < ../inputs/temp-test/1968.inp.836.4 > ../outputs/t998
    if diff ../outputs/t998 ../originals/t998 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p999) timeout -s 9 2 ../source/replace.exe '^[9-B]^a-]-@[^a-c]$' 'a&'  < ../inputs/temp-test/779.inp.335.6 > ../outputs/t999
    if diff ../outputs/t999 ../originals/t999 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1000) timeout -s 9 2 ../source/replace.exe '^[9-B]^a-]-@[^a-c]' 'a&'  < ../inputs/temp-test/778.inp.335.1 > ../outputs/t1000
    if diff ../outputs/t1000 ../originals/t1000 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1001) timeout -s 9 2 ../source/replace.exe '^[^9-B]' 'a&'  < ../inputs/temp-test/80.inp.35.1 > ../outputs/t1001
    if diff ../outputs/t1001 ../originals/t1001 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1002) timeout -s 9 2 ../source/replace.exe '^[^9-B]?' 'a&'  < ../inputs/temp-test/657.inp.286.1 > ../outputs/t1002
    if diff ../outputs/t1002 ../originals/t1002 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1003) timeout -s 9 2 ../source/replace.exe '^[^9-B]?' 'a&'  < ../inputs/temp-test/658.inp.286.2 > ../outputs/t1003
    if diff ../outputs/t1003 ../originals/t1003 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1004) timeout -s 9 2 ../source/replace.exe '^[^9-B]?' 'a&'  < ../inputs/temp-test/659.inp.286.4 > ../outputs/t1004
    if diff ../outputs/t1004 ../originals/t1004 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1005) timeout -s 9 2 ../source/replace.exe '^[^@t]' '&a@%'  < ../inputs/temp-test/1639.inp.699.1 > ../outputs/t1005
    if diff ../outputs/t1005 ../originals/t1005 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1006) timeout -s 9 2 ../source/replace.exe '^[^@t]' '&a@%'  < ../inputs/temp-test/1640.inp.699.3 > ../outputs/t1006
    if diff ../outputs/t1006 ../originals/t1006 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1007) timeout -s 9 2 ../source/replace.exe '^[a--]' '&a@%'  < ../inputs/temp-test/984.inp.424.1 > ../outputs/t1007
    if diff ../outputs/t1007 ../originals/t1007 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1008) timeout -s 9 2 ../source/replace.exe '^a%-]@[*^a-]^' '&'  < ../inputs/temp-test/13.inp.6.2 > ../outputs/t1008
    if diff ../outputs/t1008 ../originals/t1008 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1009) timeout -s 9 2 ../source/replace.exe '^a-%]@[*^a-]^' '&'  < ../inputs/temp-test/12.inp.6.1 > ../outputs/t1009
    if diff ../outputs/t1009 ../originals/t1009 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1010) timeout -s 9 2 ../source/replace.exe '^a-%c]-' '@%@&'  < ../inputs/temp-test/24.inp.11.1 > ../outputs/t1010
    if diff ../outputs/t1010 ../originals/t1010 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1011) timeout -s 9 2 ../source/replace.exe '^a-%c]-' '@%@&'  < ../inputs/temp-test/26.inp.11.3 > ../outputs/t1011
    if diff ../outputs/t1011 ../originals/t1011 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1012) timeout -s 9 2 ../source/replace.exe '^a-]-*$' 'NEW'  < ../inputs/temp-test/559.inp.241.6 > ../outputs/t1012
    if diff ../outputs/t1012 ../originals/t1012 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1013) timeout -s 9 2 ../source/replace.exe '^a-]-*$' 'NEW'  < ../inputs/temp-test/560.inp.241.8 > ../outputs/t1013
    if diff ../outputs/t1013 ../originals/t1013 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1014) timeout -s 9 2 ../source/replace.exe '^a-]-*' 'NEW'  < ../inputs/temp-test/557.inp.241.1 > ../outputs/t1014
    if diff ../outputs/t1014 ../originals/t1014 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1015) timeout -s 9 2 ../source/replace.exe '^a-]-*' 'NEW'  < ../inputs/temp-test/558.inp.241.3 > ../outputs/t1015
    if diff ../outputs/t1015 ../originals/t1015 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1016) timeout -s 9 2 ../source/replace.exe '^a-]?' 'a@nb@tc'  < ../inputs/temp-test/138.inp.64.1 > ../outputs/t1016
    if diff ../outputs/t1016 ../originals/t1016 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1017) timeout -s 9 2 ../source/replace.exe '^a-]?a-][^a-]' ''  < ../inputs/temp-test/447.inp.196.1 > ../outputs/t1017
    if diff ../outputs/t1017 ../originals/t1017 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1018) timeout -s 9 2 ../source/replace.exe '^a-]?a-][^a-]' ''  < ../inputs/temp-test/448.inp.196.3 > ../outputs/t1018
    if diff ../outputs/t1018 ../originals/t1018 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1019) timeout -s 9 2 ../source/replace.exe '^a-]@[*^a-]%^' '&'  < ../inputs/temp-test/14.inp.6.4 > ../outputs/t1019
    if diff ../outputs/t1019 ../originals/t1019 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1020) timeout -s 9 2 ../source/replace.exe '^a-]@[*^a-]^' '&'  < ../inputs/temp-test/12.inp.6.1 > ../outputs/t1020
    if diff ../outputs/t1020 ../originals/t1020 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1021) timeout -s 9 2 ../source/replace.exe '^a-]@[*^a-]^' '&'  < ../inputs/temp-test/13.inp.6.2 > ../outputs/t1021
    if diff ../outputs/t1021 ../originals/t1021 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1022) timeout -s 9 2 ../source/replace.exe '^a-]@[*^a-]^' '&'  < ../inputs/temp-test/14.inp.6.4 > ../outputs/t1022
    if diff ../outputs/t1022 ../originals/t1022 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1023) timeout -s 9 2 ../source/replace.exe '^a-]@n*' '@%&a'  < ../inputs/temp-test/1516.inp.649.1 > ../outputs/t1023
    if diff ../outputs/t1023 ../originals/t1023 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1024) timeout -s 9 2 ../source/replace.exe '^a-]@n*' '@%&a'  < ../inputs/temp-test/1517.inp.649.3 > ../outputs/t1024
    if diff ../outputs/t1024 ../originals/t1024 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1025) timeout -s 9 2 ../source/replace.exe '^a-][9-B][^--z]??@[*?' 'a&'  < ../inputs/temp-test/2151.inp.911.1 > ../outputs/t1025
    if diff ../outputs/t1025 ../originals/t1025 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1026) timeout -s 9 2 ../source/replace.exe '^a-][9-B][^--z]??@[*?' 'a&'  < ../inputs/temp-test/2152.inp.911.2 > ../outputs/t1026
    if diff ../outputs/t1026 ../originals/t1026 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1027) timeout -s 9 2 ../source/replace.exe '^a-][9-B][^--z]??@[*?' 'a&'  < ../inputs/temp-test/2153.inp.911.3 > ../outputs/t1027
    if diff ../outputs/t1027 ../originals/t1027 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1028) timeout -s 9 2 ../source/replace.exe '^a-][a--b]$' '@%&a'  < ../inputs/temp-test/2065.inp.875.6 > ../outputs/t1028
    if diff ../outputs/t1028 ../originals/t1028 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1029) timeout -s 9 2 ../source/replace.exe '^a-][a--b]' '@%&a'  < ../inputs/temp-test/2064.inp.875.1 > ../outputs/t1029
    if diff ../outputs/t1029 ../originals/t1029 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1030) timeout -s 9 2 ../source/replace.exe '^a-c?*' 'NEW'  < ../inputs/temp-test/193.inp.87.3 > ../outputs/t1030
    if diff ../outputs/t1030 ../originals/t1030 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1031) timeout -s 9 2 ../source/replace.exe '^a-c]' '&a@%'  < ../inputs/temp-test/2072.inp.878.1 > ../outputs/t1031
    if diff ../outputs/t1031 ../originals/t1031 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1032) timeout -s 9 2 ../source/replace.exe '^a-c]' '&a@%'  < ../inputs/temp-test/2073.inp.878.3 > ../outputs/t1032
    if diff ../outputs/t1032 ../originals/t1032 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1033) timeout -s 9 2 ../source/replace.exe '^a-c]' 'a&'  < ../inputs/temp-test/626.inp.270.1 > ../outputs/t1033
    if diff ../outputs/t1033 ../originals/t1033 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1034) timeout -s 9 2 ../source/replace.exe '^a-c]' 'a&'  < ../inputs/temp-test/627.inp.270.4 > ../outputs/t1034
    if diff ../outputs/t1034 ../originals/t1034 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1035) timeout -s 9 2 ../source/replace.exe '^a-c]-' '@%@&'  < ../inputs/temp-test/24.inp.11.1 > ../outputs/t1035
    if diff ../outputs/t1035 ../originals/t1035 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1036) timeout -s 9 2 ../source/replace.exe '^a-c]-' '@%@&'  < ../inputs/temp-test/25.inp.11.2 > ../outputs/t1036
    if diff ../outputs/t1036 ../originals/t1036 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1037) timeout -s 9 2 ../source/replace.exe '^a-c]-' '@%@&'  < ../inputs/temp-test/26.inp.11.3 > ../outputs/t1037
    if diff ../outputs/t1037 ../originals/t1037 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1038) timeout -s 9 2 ../source/replace.exe '^a-c]-' 'NEW'  < ../inputs/temp-test/191.inp.87.1 > ../outputs/t1038
    if diff ../outputs/t1038 ../originals/t1038 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1039) timeout -s 9 2 ../source/replace.exe '^a-c]-' 'NEW'  < ../inputs/temp-test/192.inp.87.2 > ../outputs/t1039
    if diff ../outputs/t1039 ../originals/t1039 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1040) timeout -s 9 2 ../source/replace.exe '^a-c]-' 'NEW'  < ../inputs/temp-test/193.inp.87.3 > ../outputs/t1040
    if diff ../outputs/t1040 ../originals/t1040 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1041) timeout -s 9 2 ../source/replace.exe '^a-c]-?*' 'NEW'  < ../inputs/temp-test/191.inp.87.1 > ../outputs/t1041
    if diff ../outputs/t1041 ../originals/t1041 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1042) timeout -s 9 2 ../source/replace.exe '^a-c]?' ''  < ../inputs/temp-test/2196.inp.931.1 > ../outputs/t1042
    if diff ../outputs/t1042 ../originals/t1042 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1043) timeout -s 9 2 ../source/replace.exe '^a-c]?' ''  < ../inputs/temp-test/2197.inp.931.3 > ../outputs/t1043
    if diff ../outputs/t1043 ../originals/t1043 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1044) timeout -s 9 2 ../source/replace.exe '^a-c]?' 'a&'  < ../inputs/temp-test/961.inp.414.1 > ../outputs/t1044
    if diff ../outputs/t1044 ../originals/t1044 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1045) timeout -s 9 2 ../source/replace.exe '^a-c]?' 'a&'  < ../inputs/temp-test/962.inp.414.3 > ../outputs/t1045
    if diff ../outputs/t1045 ../originals/t1045 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1046) timeout -s 9 2 ../source/replace.exe '^a-c]?*' 'NEW'  < ../inputs/temp-test/192.inp.87.2 > ../outputs/t1046
    if diff ../outputs/t1046 ../originals/t1046 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1047) timeout -s 9 2 ../source/replace.exe '^a-c][a-c]' 'b@t'  < ../inputs/temp-test/1057.inp.455.1 > ../outputs/t1047
    if diff ../outputs/t1047 ../originals/t1047 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1048) timeout -s 9 2 ../source/replace.exe '^a-c][a-c]' 'b@t'  < ../inputs/temp-test/1058.inp.455.3 > ../outputs/t1048
    if diff ../outputs/t1048 ../originals/t1048 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1049) timeout -s 9 2 ../source/replace.exe '^a-c]a-c] [9-B]??-' '@n'  < ../inputs/temp-test/230.inp.103.1 > ../outputs/t1049
    if diff ../outputs/t1049 ../originals/t1049 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1050) timeout -s 9 2 ../source/replace.exe '^a-c]a-c] [9-B]??-' '@n'  < ../inputs/temp-test/231.inp.103.3 > ../outputs/t1050
    if diff ../outputs/t1050 ../originals/t1050 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1051) timeout -s 9 2 ../source/replace.exe '^d' f  < ../inputs/moni/f4.inp > ../outputs/t1051
    if diff ../outputs/t1051 ../originals/t1051 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1052) timeout -s 9 2 ../source/replace.exe '_' '9}* bi8K(A-oQ<`>X6{_]~x)/2?ka!kso='  < ../inputs/input/ruin.22 > ../outputs/t1052
    if diff ../outputs/t1052 ../originals/t1052 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1053) timeout -s 9 2 ../source/replace.exe '_' 'd '\''Ts/gEB(0=$(}A.AVje3x'  < ../inputs/input/ruin.1202 > ../outputs/t1053
    if diff ../outputs/t1053 ../originals/t1053 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1054) timeout -s 9 2 ../source/replace.exe '_'\''w' ''  < ../inputs/input/ruin.1220 > ../outputs/t1054
    if diff ../outputs/t1054 ../originals/t1054 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1055) timeout -s 9 2 ../source/replace.exe '_K' '2$-2ws/Lk;]a=k~'  < ../inputs/input/ruin.1227 > ../outputs/t1055
    if diff ../outputs/t1055 ../originals/t1055 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1056) timeout -s 9 2 ../source/replace.exe '`' '[VP/8]e\R?;WE$d6'  < ../inputs/input/ruin.1473 > ../outputs/t1056
    if diff ../outputs/t1056 ../originals/t1056 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1057) timeout -s 9 2 ../source/replace.exe '`a-A-GABCDEFG]:@n' '-[&b0:'  < ../inputs/input/ruin.1020 > ../outputs/t1057
    if diff ../outputs/t1057 ../originals/t1057 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1058) timeout -s 9 2 ../source/replace.exe '`a-c-ac-a]@n' 'N&A'  < ../inputs/input/ruin.293 > ../outputs/t1058
    if diff ../outputs/t1058 ../originals/t1058 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1059) timeout -s 9 2 ../source/replace.exe 'a$' '{:Kvg4Y@Go<Iyg"ZP5a'\''O>)9@XxZ1a/{Y'  < ../inputs/input/ruin.1503 > ../outputs/t1059
    if diff ../outputs/t1059 ../originals/t1059 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1060) timeout -s 9 2 ../source/replace.exe 'a' '& #2@@@-'  < ../inputs/moni/f7.inp > ../outputs/t1060
    if diff ../outputs/t1060 ../originals/t1060 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1061) timeout -s 9 2 ../source/replace.exe 'a' '&'  < ../inputs/moni/f7.inp > ../outputs/t1061
    if diff ../outputs/t1061 ../originals/t1061 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1062) timeout -s 9 2 ../source/replace.exe 'a' '&@n'  < ../inputs/moni/f7.inp > ../outputs/t1062
    if diff ../outputs/t1062 ../originals/t1062 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1063) timeout -s 9 2 ../source/replace.exe 'a' ''  < ../inputs/moni/f7.inp > ../outputs/t1063
    if diff ../outputs/t1063 ../originals/t1063 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1064) timeout -s 9 2 ../source/replace.exe 'a' ')zLIH{N+2AGC>Gf5'  < ../inputs/input/ruin.172 > ../outputs/t1064
    if diff ../outputs/t1064 ../originals/t1064 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1065) timeout -s 9 2 ../source/replace.exe 'a' '12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890'  < ../inputs/moni/f7.inp > ../outputs/t1065
    if diff ../outputs/t1065 ../originals/t1065 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1066) timeout -s 9 2 ../source/replace.exe 'a' 'Ot<f]|MW(_V*YV'\''<8N?BrfOM-IG-}b#U5KSs0gIf$F\#!n_Ll.*k@e2CjOJ<^T`'  < ../inputs/input/ruin.700 > ../outputs/t1066
    if diff ../outputs/t1066 ../originals/t1066 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1067) timeout -s 9 2 ../source/replace.exe 'a' '_,wpFpZ@r`UP}ZE)'  < ../inputs/input/ruin.1703 > ../outputs/t1067
    if diff ../outputs/t1067 ../originals/t1067 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1068) timeout -s 9 2 ../source/replace.exe 'a*' 'c-1'  < ../inputs/moni/f7.inp > ../outputs/t1068
    if diff ../outputs/t1068 ../originals/t1068 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1069) timeout -s 9 2 ../source/replace.exe 'a-**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t1069
    if diff ../outputs/t1069 ../originals/t1069 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1070) timeout -s 9 2 ../source/replace.exe 'a-]' '@%@&'  < ../inputs/temp-test/2288.inp.969.2 > ../outputs/t1070
    if diff ../outputs/t1070 ../originals/t1070 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1071) timeout -s 9 2 ../source/replace.exe 'a-]' '@%@&'  < ../inputs/temp-test/2289.inp.969.3 > ../outputs/t1071
    if diff ../outputs/t1071 ../originals/t1071 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1072) timeout -s 9 2 ../source/replace.exe 'a-]' 'a@nb@tc'  < ../inputs/temp-test/410.inp.180.2 > ../outputs/t1072
    if diff ../outputs/t1072 ../originals/t1072 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1073) timeout -s 9 2 ../source/replace.exe 'a-]' 'a@nb@tc'  < ../inputs/temp-test/411.inp.180.3 > ../outputs/t1073
    if diff ../outputs/t1073 ../originals/t1073 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1074) timeout -s 9 2 ../source/replace.exe 'a-]-*?c[^--z]a-][^a-][a--b]?' 'a&'  < ../inputs/temp-test/1325.inp.569.1 > ../outputs/t1074
    if diff ../outputs/t1074 ../originals/t1074 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1075) timeout -s 9 2 ../source/replace.exe 'a-]-*?c[^--z]a-][^a-][a--b]?' 'a&'  < ../inputs/temp-test/1326.inp.569.2 > ../outputs/t1075
    if diff ../outputs/t1075 ../originals/t1075 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1076) timeout -s 9 2 ../source/replace.exe 'a-]?-?^-]-[^a-^[^0-9]$' '&a@%'  < ../inputs/temp-test/2195.inp.930.9 > ../outputs/t1076
    if diff ../outputs/t1076 ../originals/t1076 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1077) timeout -s 9 2 ../source/replace.exe 'a-]?-?^-]-[^a-^[^0-9]' '&a@%'  < ../inputs/temp-test/2193.inp.930.1 > ../outputs/t1077
    if diff ../outputs/t1077 ../originals/t1077 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1078) timeout -s 9 2 ../source/replace.exe 'a-]?-?^-]-[^a-^[^0-9]' '&a@%'  < ../inputs/temp-test/2194.inp.930.2 > ../outputs/t1078
    if diff ../outputs/t1078 ../originals/t1078 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1079) timeout -s 9 2 ../source/replace.exe 'a-]?[^0-9]?[^a--][a-c]@[*[^0-9]a-c][^a-c' '@n'  < ../inputs/temp-test/612.inp.264.1 > ../outputs/t1079
    if diff ../outputs/t1079 ../originals/t1079 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1080) timeout -s 9 2 ../source/replace.exe 'a-]?[^0-9]?[^a--][a-c]@[*[^0-9]a-c][^a-c' '@n'  < ../inputs/temp-test/613.inp.264.3 > ../outputs/t1080
    if diff ../outputs/t1080 ../originals/t1080 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1081) timeout -s 9 2 ../source/replace.exe 'a-]@@*' 'NEW'  < ../inputs/temp-test/1202.inp.516.1 > ../outputs/t1081
    if diff ../outputs/t1081 ../originals/t1081 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1082) timeout -s 9 2 ../source/replace.exe 'a-]@@*' 'NEW'  < ../inputs/temp-test/1203.inp.516.3 > ../outputs/t1082
    if diff ../outputs/t1082 ../originals/t1082 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1083) timeout -s 9 2 ../source/replace.exe 'a-]A*[^0-9][a-c]' '@%&a'  < ../inputs/temp-test/1951.inp.828.1 > ../outputs/t1083
    if diff ../outputs/t1083 ../originals/t1083 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1084) timeout -s 9 2 ../source/replace.exe 'a-][^0-9]' '&'  < ../inputs/temp-test/729.inp.314.1 > ../outputs/t1084
    if diff ../outputs/t1084 ../originals/t1084 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1085) timeout -s 9 2 ../source/replace.exe 'a-][^0-9]' '&'  < ../inputs/temp-test/730.inp.314.2 > ../outputs/t1085
    if diff ../outputs/t1085 ../originals/t1085 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1086) timeout -s 9 2 ../source/replace.exe 'a-][^0-9]' '&'  < ../inputs/temp-test/731.inp.314.3 > ../outputs/t1086
    if diff ../outputs/t1086 ../originals/t1086 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1087) timeout -s 9 2 ../source/replace.exe 'a-][^9-B]' '@%&a'  < ../inputs/temp-test/662.inp.288.1 > ../outputs/t1087
    if diff ../outputs/t1087 ../originals/t1087 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1088) timeout -s 9 2 ../source/replace.exe 'a-][^9-B]' '@%&a'  < ../inputs/temp-test/663.inp.288.2 > ../outputs/t1088
    if diff ../outputs/t1088 ../originals/t1088 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1089) timeout -s 9 2 ../source/replace.exe 'a-][a-c' ''  < ../inputs/temp-test/555.inp.240.2 > ../outputs/t1089
    if diff ../outputs/t1089 ../originals/t1089 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1090) timeout -s 9 2 ../source/replace.exe 'a-][a-c' ''  < ../inputs/temp-test/556.inp.240.4 > ../outputs/t1090
    if diff ../outputs/t1090 ../originals/t1090 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1091) timeout -s 9 2 ../source/replace.exe 'a-]^*-?-@@*@n-[^0-9]-' 'a&'  < ../inputs/temp-test/272.inp.122.1 > ../outputs/t1091
    if diff ../outputs/t1091 ../originals/t1091 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1092) timeout -s 9 2 ../source/replace.exe 'a-]^*-?-@@*@n-[^0-9]-' 'a&'  < ../inputs/temp-test/273.inp.122.3 > ../outputs/t1092
    if diff ../outputs/t1092 ../originals/t1092 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1093) timeout -s 9 2 ../source/replace.exe 'a-c]-' 'a&'  < ../inputs/temp-test/1910.inp.811.1 > ../outputs/t1093
    if diff ../outputs/t1093 ../originals/t1093 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1094) timeout -s 9 2 ../source/replace.exe 'a-c]-' 'a&'  < ../inputs/temp-test/1911.inp.811.3 > ../outputs/t1094
    if diff ../outputs/t1094 ../originals/t1094 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1095) timeout -s 9 2 ../source/replace.exe 'a-c]-[0-9]@t*@*?' '@%@&'  < ../inputs/temp-test/991.inp.427.1 > ../outputs/t1095
    if diff ../outputs/t1095 ../originals/t1095 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1096) timeout -s 9 2 ../source/replace.exe 'a-c]-[0-9]@t*@*?' '@%@&'  < ../inputs/temp-test/992.inp.427.3 > ../outputs/t1096
    if diff ../outputs/t1096 ../originals/t1096 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1097) timeout -s 9 2 ../source/replace.exe 'a-c]@*[0-9]?*A-' 'NEW'  < ../inputs/temp-test/3.inp.2.1 > ../outputs/t1097
    if diff ../outputs/t1097 ../originals/t1097 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1098) timeout -s 9 2 ../source/replace.exe 'a-c]@*[0-9]?*A-' 'NEW'  < ../inputs/temp-test/4.inp.2.3 > ../outputs/t1098
    if diff ../outputs/t1098 ../originals/t1098 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1099) timeout -s 9 2 ../source/replace.exe 'a-c]@*[0-9]?*A-' 'NEW'  < ../inputs/temp-test/5.inp.2.4 > ../outputs/t1099
    if diff ../outputs/t1099 ../originals/t1099 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1100) timeout -s 9 2 ../source/replace.exe 'a-c][^@@]' '@t'  < ../inputs/temp-test/1514.inp.648.1 > ../outputs/t1100
    if diff ../outputs/t1100 ../originals/t1100 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1101) timeout -s 9 2 ../source/replace.exe 'ab?p**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t1101
    if diff ../outputs/t1101 ../originals/t1101 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1102) timeout -s 9 2 ../source/replace.exe 'abc$%**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t1102
    if diff ../outputs/t1102 ../originals/t1102 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1103) timeout -s 9 2 ../source/replace.exe 'b' '-HM{Qv|H1pLYv2Eb1x5)'  < ../inputs/input/ruin.589 > ../outputs/t1103
    if diff ../outputs/t1103 ../originals/t1103 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1104) timeout -s 9 2 ../source/replace.exe 'b' 'UK4N.tls!-g6_D0+`!hP:rH8$|5'\''xGr?'  < ../inputs/input/ruin.1633 > ../outputs/t1104
    if diff ../outputs/t1104 ../originals/t1104 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1105) timeout -s 9 2 ../source/replace.exe 'b' 'v+AfoGgD^s"3R2jL|'  < ../inputs/input/ruin.747 > ../outputs/t1105
    if diff ../outputs/t1105 ../originals/t1105 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1106) timeout -s 9 2 ../source/replace.exe 'c' '&a@%'  < ../inputs/temp-test/310.inp.139.1 > ../outputs/t1106
    if diff ../outputs/t1106 ../originals/t1106 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1107) timeout -s 9 2 ../source/replace.exe 'c' '&a@%'  < ../inputs/temp-test/311.inp.139.3 > ../outputs/t1107
    if diff ../outputs/t1107 ../originals/t1107 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1108) timeout -s 9 2 ../source/replace.exe 'c' '|-rnI[>\$@wV'  < ../inputs/input/ruin.1493 > ../outputs/t1108
    if diff ../outputs/t1108 ../originals/t1108 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1109) timeout -s 9 2 ../source/replace.exe 'c*' '&a@%'  < ../inputs/temp-test/2087.inp.884.1 > ../outputs/t1109
    if diff ../outputs/t1109 ../originals/t1109 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1110) timeout -s 9 2 ../source/replace.exe 'c*' 'a&'  < ../inputs/temp-test/1408.inp.604.1 > ../outputs/t1110
    if diff ../outputs/t1110 ../originals/t1110 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1111) timeout -s 9 2 ../source/replace.exe 'c*' 'a&'  < ../inputs/temp-test/1409.inp.604.3 > ../outputs/t1111
    if diff ../outputs/t1111 ../originals/t1111 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1112) timeout -s 9 2 ../source/replace.exe 'c*-[^--z]-?' 'a@nb@tc'  < ../inputs/temp-test/2275.inp.964.1 > ../outputs/t1112
    if diff ../outputs/t1112 ../originals/t1112 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1113) timeout -s 9 2 ../source/replace.exe 'c*?$' 'a@nb@tc'  < ../inputs/temp-test/805.inp.345.9 > ../outputs/t1113
    if diff ../outputs/t1113 ../originals/t1113 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1114) timeout -s 9 2 ../source/replace.exe 'c*?' '&'  < ../inputs/temp-test/340.inp.149.1 > ../outputs/t1114
    if diff ../outputs/t1114 ../originals/t1114 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1115) timeout -s 9 2 ../source/replace.exe 'c*?' '&'  < ../inputs/temp-test/341.inp.149.4 > ../outputs/t1115
    if diff ../outputs/t1115 ../originals/t1115 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1116) timeout -s 9 2 ../source/replace.exe 'c*?' '@%&a'  < ../inputs/temp-test/354.inp.155.1 > ../outputs/t1116
    if diff ../outputs/t1116 ../originals/t1116 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1117) timeout -s 9 2 ../source/replace.exe 'c*?' '@%&a'  < ../inputs/temp-test/355.inp.155.2 > ../outputs/t1117
    if diff ../outputs/t1117 ../originals/t1117 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1118) timeout -s 9 2 ../source/replace.exe 'c*?' '@%&a@'  < ../inputs/temp-test/354.inp.155.1 > ../outputs/t1118
    if diff ../outputs/t1118 ../originals/t1118 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1119) timeout -s 9 2 ../source/replace.exe 'c*?' '@%&a@'  < ../inputs/temp-test/355.inp.155.2 > ../outputs/t1119
    if diff ../outputs/t1119 ../originals/t1119 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1120) timeout -s 9 2 ../source/replace.exe 'c*?' 'a@nb@tc'  < ../inputs/temp-test/802.inp.345.1 > ../outputs/t1120
    if diff ../outputs/t1120 ../originals/t1120 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1121) timeout -s 9 2 ../source/replace.exe 'c*?' 'a@nb@tc'  < ../inputs/temp-test/803.inp.345.2 > ../outputs/t1121
    if diff ../outputs/t1121 ../originals/t1121 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1122) timeout -s 9 2 ../source/replace.exe 'c*?' 'a@nb@tc'  < ../inputs/temp-test/804.inp.345.3 > ../outputs/t1122
    if diff ../outputs/t1122 ../originals/t1122 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1123) timeout -s 9 2 ../source/replace.exe 'c*?[a--][^9-B][9-B][a-[a-c@@*[^-?' '@%@&'  < ../inputs/temp-test/785.inp.338.1 > ../outputs/t1123
    if diff ../outputs/t1123 ../originals/t1123 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1124) timeout -s 9 2 ../source/replace.exe 'c*?[a--][^9-B][9-B][a-[a-c@@*[^-?' '@%@&'  < ../inputs/temp-test/786.inp.338.2 > ../outputs/t1124
    if diff ../outputs/t1124 ../originals/t1124 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1125) timeout -s 9 2 ../source/replace.exe 'c*[9-B][9-B]-*-[^0-9]' 'a&'  < ../inputs/temp-test/1880.inp.797.1 > ../outputs/t1125
    if diff ../outputs/t1125 ../originals/t1125 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1126) timeout -s 9 2 ../source/replace.exe 'c*[9-B][9-B]-*-[^0-9]' 'a&'  < ../inputs/temp-test/1881.inp.797.3 > ../outputs/t1126
    if diff ../outputs/t1126 ../originals/t1126 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1127) timeout -s 9 2 ../source/replace.exe 'c*[][^a-' 'a@nb@tc'  < ../inputs/temp-test/514.inp.224.1 > ../outputs/t1127
    if diff ../outputs/t1127 ../originals/t1127 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1128) timeout -s 9 2 ../source/replace.exe 'c*[^][^a-' 'a@nb@tc'  < ../inputs/temp-test/514.inp.224.1 > ../outputs/t1128
    if diff ../outputs/t1128 ../originals/t1128 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1129) timeout -s 9 2 ../source/replace.exe 'c*[^a-'   < ../inputs/temp-test/515.inp.224.3 > ../outputs/t1129
    if diff ../outputs/t1129 ../originals/t1129 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1130) timeout -s 9 2 ../source/replace.exe 'c*[^a-' 'a@nb@tc'  < ../inputs/temp-test/514.inp.224.1 > ../outputs/t1130
    if diff ../outputs/t1130 ../originals/t1130 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1131) timeout -s 9 2 ../source/replace.exe 'c*[^a-' 'a@nb@tc'  < ../inputs/temp-test/515.inp.224.3 > ../outputs/t1131
    if diff ../outputs/t1131 ../originals/t1131 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1132) timeout -s 9 2 ../source/replace.exe 'c*^a-c]' ''  < ../inputs/temp-test/313.inp.140.1 > ../outputs/t1132
    if diff ../outputs/t1132 ../originals/t1132 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1133) timeout -s 9 2 ../source/replace.exe 'c*^a-c]' ''  < ../inputs/temp-test/314.inp.140.2 > ../outputs/t1133
    if diff ../outputs/t1133 ../originals/t1133 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1134) timeout -s 9 2 ../source/replace.exe 'c*^a-c]' ''  < ../inputs/temp-test/315.inp.140.3 > ../outputs/t1134
    if diff ../outputs/t1134 ../originals/t1134 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1135) timeout -s 9 2 ../source/replace.exe 'c*^a-c]' 'a@nb@tc'  < ../inputs/temp-test/2056.inp.872.1 > ../outputs/t1135
    if diff ../outputs/t1135 ../originals/t1135 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1136) timeout -s 9 2 ../source/replace.exe 'c*^a-c]' 'a@nb@tc'  < ../inputs/temp-test/2057.inp.872.3 > ../outputs/t1136
    if diff ../outputs/t1136 ../originals/t1136 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1137) timeout -s 9 2 ../source/replace.exe 'c-$' '@%@&'  < ../inputs/temp-test/1747.inp.742.8 > ../outputs/t1137
    if diff ../outputs/t1137 ../originals/t1137 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1138) timeout -s 9 2 ../source/replace.exe 'c-' ''  < ../inputs/temp-test/387.inp.169.1 > ../outputs/t1138
    if diff ../outputs/t1138 ../originals/t1138 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1139) timeout -s 9 2 ../source/replace.exe 'c-' ''  < ../inputs/temp-test/388.inp.169.2 > ../outputs/t1139
    if diff ../outputs/t1139 ../originals/t1139 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1140) timeout -s 9 2 ../source/replace.exe 'c-' ''  < ../inputs/temp-test/389.inp.169.3 > ../outputs/t1140
    if diff ../outputs/t1140 ../originals/t1140 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1141) timeout -s 9 2 ../source/replace.exe 'c-' '@%@&'  < ../inputs/temp-test/1744.inp.742.1 > ../outputs/t1141
    if diff ../outputs/t1141 ../originals/t1141 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1142) timeout -s 9 2 ../source/replace.exe 'c-' '@%@&'  < ../inputs/temp-test/1745.inp.742.2 > ../outputs/t1142
    if diff ../outputs/t1142 ../originals/t1142 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1143) timeout -s 9 2 ../source/replace.exe 'c-' '@%@&'  < ../inputs/temp-test/1746.inp.742.3 > ../outputs/t1143
    if diff ../outputs/t1143 ../originals/t1143 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1144) timeout -s 9 2 ../source/replace.exe 'c-[0-9][^a-c@**-' '@t'  < ../inputs/temp-test/167.inp.75.1 > ../outputs/t1144
    if diff ../outputs/t1144 ../originals/t1144 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1145) timeout -s 9 2 ../source/replace.exe 'c-[0-9][^a-c@**-' '@t'  < ../inputs/temp-test/168.inp.75.2 > ../outputs/t1145
    if diff ../outputs/t1145 ../originals/t1145 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1146) timeout -s 9 2 ../source/replace.exe 'c-^a-]?a-]-][a-c]-' '&a@%'  < ../inputs/temp-test/112.inp.51.1 > ../outputs/t1146
    if diff ../outputs/t1146 ../originals/t1146 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1147) timeout -s 9 2 ../source/replace.exe 'c-^a-]?a-]-][a-c]-' '&a@%'  < ../inputs/temp-test/113.inp.51.2 > ../outputs/t1147
    if diff ../outputs/t1147 ../originals/t1147 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1148) timeout -s 9 2 ../source/replace.exe 'c-^a-]?a-]-][a-c]-' '&a@%'  < ../inputs/temp-test/114.inp.51.3 > ../outputs/t1148
    if diff ../outputs/t1148 ../originals/t1148 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1149) timeout -s 9 2 ../source/replace.exe 'c?$' '@n'  < ../inputs/temp-test/1738.inp.739.8 > ../outputs/t1149
    if diff ../outputs/t1149 ../originals/t1149 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1150) timeout -s 9 2 ../source/replace.exe 'c?' '@%@&'  < ../inputs/temp-test/1168.inp.503.1 > ../outputs/t1150
    if diff ../outputs/t1150 ../originals/t1150 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1151) timeout -s 9 2 ../source/replace.exe 'c?' '@%@&'  < ../inputs/temp-test/1169.inp.503.2 > ../outputs/t1151
    if diff ../outputs/t1151 ../originals/t1151 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1152) timeout -s 9 2 ../source/replace.exe 'c?' '@n'  < ../inputs/temp-test/1737.inp.739.1 > ../outputs/t1152
    if diff ../outputs/t1152 ../originals/t1152 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1153) timeout -s 9 2 ../source/replace.exe 'c?*' ''  < ../inputs/temp-test/387.inp.169.1 > ../outputs/t1153
    if diff ../outputs/t1153 ../originals/t1153 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1154) timeout -s 9 2 ../source/replace.exe 'c?*' ''  < ../inputs/temp-test/388.inp.169.2 > ../outputs/t1154
    if diff ../outputs/t1154 ../originals/t1154 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1155) timeout -s 9 2 ../source/replace.exe 'c?*' ''  < ../inputs/temp-test/389.inp.169.3 > ../outputs/t1155
    if diff ../outputs/t1155 ../originals/t1155 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1156) timeout -s 9 2 ../source/replace.exe 'c?-@t?$' 'a@nb@tc'  < ../inputs/temp-test/1787.inp.760.6 > ../outputs/t1156
    if diff ../outputs/t1156 ../originals/t1156 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1157) timeout -s 9 2 ../source/replace.exe 'c?-@t?' 'a@nb@tc'  < ../inputs/temp-test/1785.inp.760.1 > ../outputs/t1157
    if diff ../outputs/t1157 ../originals/t1157 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1158) timeout -s 9 2 ../source/replace.exe 'c?-@t?' 'a@nb@tc'  < ../inputs/temp-test/1786.inp.760.4 > ../outputs/t1158
    if diff ../outputs/t1158 ../originals/t1158 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1159) timeout -s 9 2 ../source/replace.exe 'c[]*[^a-' 'a@nb@tc'  < ../inputs/temp-test/515.inp.224.3 > ../outputs/t1159
    if diff ../outputs/t1159 ../originals/t1159 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1160) timeout -s 9 2 ../source/replace.exe 'c[^0-9]'   < ../inputs/temp-test/212.inp.95.1 > ../outputs/t1160
    if diff ../outputs/t1160 ../originals/t1160 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1161) timeout -s 9 2 ../source/replace.exe 'c[^0-9]' '&@n'  < ../inputs/temp-test/212.inp.95.1 > ../outputs/t1161
    if diff ../outputs/t1161 ../originals/t1161 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1162) timeout -s 9 2 ../source/replace.exe 'c[^0-9]' '&a@%'  < ../inputs/temp-test/212.inp.95.1 > ../outputs/t1162
    if diff ../outputs/t1162 ../originals/t1162 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1163) timeout -s 9 2 ../source/replace.exe 'c[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/1307.inp.562.1 > ../outputs/t1163
    if diff ../outputs/t1163 ../originals/t1163 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1164) timeout -s 9 2 ../source/replace.exe 'c[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/1308.inp.562.3 > ../outputs/t1164
    if diff ../outputs/t1164 ../originals/t1164 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1165) timeout -s 9 2 ../source/replace.exe 'c[^0-9]*$' '&a@%'  < ../inputs/temp-test/212.inp.95.1 > ../outputs/t1165
    if diff ../outputs/t1165 ../originals/t1165 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1166) timeout -s 9 2 ../source/replace.exe 'c[^0-9]*' '&a@%'  < ../inputs/temp-test/212.inp.95.1 > ../outputs/t1166
    if diff ../outputs/t1166 ../originals/t1166 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1167) timeout -s 9 2 ../source/replace.exe 'c[^0-9][9-B]-' '@%@&'  < ../inputs/temp-test/1884.inp.799.1 > ../outputs/t1167
    if diff ../outputs/t1167 ../originals/t1167 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1168) timeout -s 9 2 ../source/replace.exe 'c[^0-9][9-B]-' '@%@&'  < ../inputs/temp-test/1885.inp.799.3 > ../outputs/t1168
    if diff ../outputs/t1168 ../originals/t1168 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1169) timeout -s 9 2 ../source/replace.exe 'c[^0-9][]' '&a@%'  < ../inputs/temp-test/212.inp.95.1 > ../outputs/t1169
    if diff ../outputs/t1169 ../originals/t1169 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1170) timeout -s 9 2 ../source/replace.exe 'c[^0-9][^]' '&a@%'  < ../inputs/temp-test/212.inp.95.1 > ../outputs/t1170
    if diff ../outputs/t1170 ../originals/t1170 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1171) timeout -s 9 2 ../source/replace.exe 'c[^9-B][^9-B]c*?[9-B]c-'   < ../inputs/temp-test/530.inp.230.1 > ../outputs/t1171
    if diff ../outputs/t1171 ../originals/t1171 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1172) timeout -s 9 2 ../source/replace.exe 'c[^9-B][^9-B]c*?[9-B]c-'   < ../inputs/temp-test/531.inp.230.4 > ../outputs/t1172
    if diff ../outputs/t1172 ../originals/t1172 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1173) timeout -s 9 2 ../source/replace.exe 'c[^9-B][^9-B]c*?[9-B]c-' '&@n'  < ../inputs/temp-test/530.inp.230.1 > ../outputs/t1173
    if diff ../outputs/t1173 ../originals/t1173 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1174) timeout -s 9 2 ../source/replace.exe 'c[^9-B][^9-B]c*?[9-B]c-' '&@n'  < ../inputs/temp-test/531.inp.230.4 > ../outputs/t1174
    if diff ../outputs/t1174 ../originals/t1174 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1175) timeout -s 9 2 ../source/replace.exe 'c[^]*[^a-' 'a@nb@tc'  < ../inputs/temp-test/515.inp.224.3 > ../outputs/t1175
    if diff ../outputs/t1175 ../originals/t1175 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1176) timeout -s 9 2 ../source/replace.exe 'c[^a--]-' '&'  < ../inputs/temp-test/316.inp.141.1 > ../outputs/t1176
    if diff ../outputs/t1176 ../originals/t1176 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1177) timeout -s 9 2 ../source/replace.exe 'c[^a--]-' '&'  < ../inputs/temp-test/317.inp.141.2 > ../outputs/t1177
    if diff ../outputs/t1177 ../originals/t1177 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1178) timeout -s 9 2 ../source/replace.exe 'c[^a--]-' '&'  < ../inputs/temp-test/318.inp.141.3 > ../outputs/t1178
    if diff ../outputs/t1178 ../originals/t1178 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1179) timeout -s 9 2 ../source/replace.exe 'd' 'MmG]j}^kC1v9&)@IDYiz'\'';OSYD&k}crmPG^5g?/'  < ../inputs/input/ruin.955 > ../outputs/t1179
    if diff ../outputs/t1179 ../originals/t1179 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1180) timeout -s 9 2 ../source/replace.exe 'd' 'W5QeouQGFKI&'\''2),,O1<HEyR)\#6$~\h/z#&u_Uj'  < ../inputs/input/ruin.414 > ../outputs/t1180
    if diff ../outputs/t1180 ../originals/t1180 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1181) timeout -s 9 2 ../source/replace.exe 'd' 'o'  < ../inputs/input/ruin.1837 > ../outputs/t1181
    if diff ../outputs/t1181 ../originals/t1181 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1182) timeout -s 9 2 ../source/replace.exe 'd' 'z>'  < ../inputs/input/ruin.1414 > ../outputs/t1182
    if diff ../outputs/t1182 ../originals/t1182 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1183) timeout -s 9 2 ../source/replace.exe 'e' '@,tDXi*;qGHNFVV$d#hd'  < ../inputs/input/ruin.736 > ../outputs/t1183
    if diff ../outputs/t1183 ../originals/t1183 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1184) timeout -s 9 2 ../source/replace.exe 'e' 'h'  < ../inputs/input/ruin.1833 > ../outputs/t1184
    if diff ../outputs/t1184 ../originals/t1184 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1185) timeout -s 9 2 ../source/replace.exe 'f' 'f \RbTgbc"N]M>?p2'\''g'\''\v'  < ../inputs/input/ruin.44 > ../outputs/t1185
    if diff ../outputs/t1185 ../originals/t1185 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1186) timeout -s 9 2 ../source/replace.exe 'g' 'A'  < ../inputs/input/ruin.127 > ../outputs/t1186
    if diff ../outputs/t1186 ../originals/t1186 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1187) timeout -s 9 2 ../source/replace.exe 'g' 'G*7D:6^_h`8n@*deLn'  < ../inputs/input/ruin.1859 > ../outputs/t1187
    if diff ../outputs/t1187 ../originals/t1187 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1188) timeout -s 9 2 ../source/replace.exe 'g' 'O>w-xOn _^8DDez8}PX=$`~'  < ../inputs/input/ruin.624 > ../outputs/t1188
    if diff ../outputs/t1188 ../originals/t1188 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1189) timeout -s 9 2 ../source/replace.exe 'h' '6'  < ../inputs/input/ruin.629 > ../outputs/t1189
    if diff ../outputs/t1189 ../originals/t1189 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1190) timeout -s 9 2 ../source/replace.exe 'h' 'C'  < ../inputs/input/ruin.1885 > ../outputs/t1190
    if diff ../outputs/t1190 ../originals/t1190 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1191) timeout -s 9 2 ../source/replace.exe 'i' '+-$GSJR|61O"bXEf~l@G#'  < ../inputs/input/ruin.1912 > ../outputs/t1191
    if diff ../outputs/t1191 ../originals/t1191 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1192) timeout -s 9 2 ../source/replace.exe 'i' '6'  < ../inputs/input/ruin.1031 > ../outputs/t1192
    if diff ../outputs/t1192 ../originals/t1192 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1193) timeout -s 9 2 ../source/replace.exe 'i' '62k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G'  < ../inputs/input/ruin.1031 > ../outputs/t1193
    if diff ../outputs/t1193 ../originals/t1193 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1194) timeout -s 9 2 ../source/replace.exe 'i' ';!{5}'  < ../inputs/input/ruin.115 > ../outputs/t1194
    if diff ../outputs/t1194 ../originals/t1194 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1195) timeout -s 9 2 ../source/replace.exe 'i' '<.'\''F=YB?N(u5L;RCvxh5pg/6B3Ma`Yy^~+2/S}'  < ../inputs/input/ruin.1938 > ../outputs/t1195
    if diff ../outputs/t1195 ../originals/t1195 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1196) timeout -s 9 2 ../source/replace.exe 'i' 't!8ey$58#h'  < ../inputs/input/ruin.78 > ../outputs/t1196
    if diff ../outputs/t1196 ../originals/t1196 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1197) timeout -s 9 2 ../source/replace.exe 'j' 'wa>o$un8[j}CvDtO'  < ../inputs/input/ruin.108 > ../outputs/t1197
    if diff ../outputs/t1197 ../originals/t1197 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1198) timeout -s 9 2 ../source/replace.exe 'l' 'f'  < ../inputs/input/ruin.946 > ../outputs/t1198
    if diff ../outputs/t1198 ../originals/t1198 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1199) timeout -s 9 2 ../source/replace.exe 'l' 'va~y^kcfJ^dEk~7R&7i`_HBl=+ccP_Sm]30txxupfl'\''{C#'  < ../inputs/input/ruin.1984 > ../outputs/t1199
    if diff ../outputs/t1199 ../originals/t1199 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1200) timeout -s 9 2 ../source/replace.exe 'm' '/'  < ../inputs/input/ruin.1114 > ../outputs/t1200
    if diff ../outputs/t1200 ../originals/t1200 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1201) timeout -s 9 2 ../source/replace.exe 'm' '0'  < ../inputs/input/ruin.879 > ../outputs/t1201
    if diff ../outputs/t1201 ../originals/t1201 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1202) timeout -s 9 2 ../source/replace.exe 'm' 'B9Fb'  < ../inputs/input/ruin.167 > ../outputs/t1202
    if diff ../outputs/t1202 ../originals/t1202 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1203) timeout -s 9 2 ../source/replace.exe 'm' 'Ml'  < ../inputs/input/ruin.1996 > ../outputs/t1203
    if diff ../outputs/t1203 ../originals/t1203 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1204) timeout -s 9 2 ../source/replace.exe 'm' 'X'  < ../inputs/input/ruin.459 > ../outputs/t1204
    if diff ../outputs/t1204 ../originals/t1204 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1205) timeout -s 9 2 ../source/replace.exe 'm*$' '/'  < ../inputs/input/ruin.1114 > ../outputs/t1205
    if diff ../outputs/t1205 ../originals/t1205 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1206) timeout -s 9 2 ../source/replace.exe 'm*$' 'Ml'  < ../inputs/input/ruin.1996 > ../outputs/t1206
    if diff ../outputs/t1206 ../originals/t1206 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1207) timeout -s 9 2 ../source/replace.exe 'm@n$' '7"py31%VhaB9=x'  < ../inputs/input/ruin.394 > ../outputs/t1207
    if diff ../outputs/t1207 ../originals/t1207 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1208) timeout -s 9 2 ../source/replace.exe 'n' '/T'  < ../inputs/input/ruin.594 > ../outputs/t1208
    if diff ../outputs/t1208 ../originals/t1208 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1209) timeout -s 9 2 ../source/replace.exe 'o' 'GX,Cu(WNj'  < ../inputs/input/ruin.1749 > ../outputs/t1209
    if diff ../outputs/t1209 ../originals/t1209 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1210) timeout -s 9 2 ../source/replace.exe 'o' ']'  < ../inputs/input/ruin.1577 > ../outputs/t1210
    if diff ../outputs/t1210 ../originals/t1210 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1211) timeout -s 9 2 ../source/replace.exe 'o'\''-' 'e'  < ../inputs/input/ruin.1907 > ../outputs/t1211
    if diff ../outputs/t1211 ../originals/t1211 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1212) timeout -s 9 2 ../source/replace.exe 'o@@' '+'  < ../inputs/input/ruin.568 > ../outputs/t1212
    if diff ../outputs/t1212 ../originals/t1212 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1213) timeout -s 9 2 ../source/replace.exe 'p' 'I'  < ../inputs/input/ruin.413 > ../outputs/t1213
    if diff ../outputs/t1213 ../originals/t1213 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1214) timeout -s 9 2 ../source/replace.exe 'p*' '"WJ +9!ApjK'  < ../inputs/input/ruin.1399 > ../outputs/t1214
    if diff ../outputs/t1214 ../originals/t1214 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1215) timeout -s 9 2 ../source/replace.exe 'p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<A[^a-c][0-9]@[*' '&a@%'  < ../inputs/temp-test/589.inp.253.1 > ../outputs/t1215
    if diff ../outputs/t1215 ../originals/t1215 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1216) timeout -s 9 2 ../source/replace.exe 'p@n' 'a&L'  < ../inputs/input/ruin.274 > ../outputs/t1216
    if diff ../outputs/t1216 ../originals/t1216 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1217) timeout -s 9 2 ../source/replace.exe 'q' 'E'  < ../inputs/input/ruin.1057 > ../outputs/t1217
    if diff ../outputs/t1217 ../originals/t1217 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1218) timeout -s 9 2 ../source/replace.exe 'q' 'E7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp'  < ../inputs/input/ruin.1057 > ../outputs/t1218
    if diff ../outputs/t1218 ../originals/t1218 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1219) timeout -s 9 2 ../source/replace.exe 'q' 'IirRPe>0iIjW%K:~^H{21R'  < ../inputs/input/ruin.1552 > ../outputs/t1219
    if diff ../outputs/t1219 ../originals/t1219 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1220) timeout -s 9 2 ../source/replace.exe 'q' 'cC4(j6a>IX1EH2r{.d V<%s]2X'  < ../inputs/input/ruin.1589 > ../outputs/t1220
    if diff ../outputs/t1220 ../originals/t1220 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1221) timeout -s 9 2 ../source/replace.exe 'q' 'wt5(~7ozr>3'\''R6}}$ro{9ghx'\''5eBz~[SZ4aw98rWZ8pN;p}dh{awT!'  < ../inputs/input/ruin.521 > ../outputs/t1221
    if diff ../outputs/t1221 ../originals/t1221 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1222) timeout -s 9 2 ../source/replace.exe 'q'\''Ck;oR7' 'jGU}XIi?]qLF"YtOv~~lB;!5+a):Y'  < ../inputs/input/ruin.1348 > ../outputs/t1222
    if diff ../outputs/t1222 ../originals/t1222 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1223) timeout -s 9 2 ../source/replace.exe 'qz' 'm'  < ../inputs/input/ruin.1357 > ../outputs/t1223
    if diff ../outputs/t1223 ../originals/t1223 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1224) timeout -s 9 2 ../source/replace.exe 'r' 'P wrT^[v'  < ../inputs/input/ruin.1889 > ../outputs/t1224
    if diff ../outputs/t1224 ../originals/t1224 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1225) timeout -s 9 2 ../source/replace.exe 'r' '['  < ../inputs/input/ruin.478 > ../outputs/t1225
    if diff ../outputs/t1225 ../originals/t1225 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1226) timeout -s 9 2 ../source/replace.exe 's$' '4'  < ../inputs/input/ruin.847 > ../outputs/t1226
    if diff ../outputs/t1226 ../originals/t1226 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1227) timeout -s 9 2 ../source/replace.exe 's' '*idnvvLz)]37D7^a'  < ../inputs/input/ruin.769 > ../outputs/t1227
    if diff ../outputs/t1227 ../originals/t1227 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1228) timeout -s 9 2 ../source/replace.exe 's' 'S'  < ../inputs/input/ruin.1649 > ../outputs/t1228
    if diff ../outputs/t1228 ../originals/t1228 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1229) timeout -s 9 2 ../source/replace.exe 's' '`o8oL$^vE P()\:5;1af!&IGg~yDx>RB6h0.,WNAuM%[x;Y'\''xp$2DN'  < ../inputs/input/ruin.860 > ../outputs/t1229
    if diff ../outputs/t1229 ../originals/t1229 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1230) timeout -s 9 2 ../source/replace.exe 's' 'ke_A{j'\''5'  < ../inputs/input/ruin.1648 > ../outputs/t1230
    if diff ../outputs/t1230 ../originals/t1230 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1231) timeout -s 9 2 ../source/replace.exe 't$' 'H'  < ../inputs/input/ruin.1464 > ../outputs/t1231
    if diff ../outputs/t1231 ../originals/t1231 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1232) timeout -s 9 2 ../source/replace.exe 't' '-gf@/{AfvdzFO'  < ../inputs/input/ruin.1870 > ../outputs/t1232
    if diff ../outputs/t1232 ../originals/t1232 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1233) timeout -s 9 2 ../source/replace.exe 't' '@~jUa){1S?_^6GN)8I|&~"/L_(iq#'  < ../inputs/input/ruin.671 > ../outputs/t1233
    if diff ../outputs/t1233 ../originals/t1233 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1234) timeout -s 9 2 ../source/replace.exe 't' 'h'  < ../inputs/input/ruin.1416 > ../outputs/t1234
    if diff ../outputs/t1234 ../originals/t1234 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1235) timeout -s 9 2 ../source/replace.exe 'u' 'DCN4"{FW^I%=M8,i]G '\''FcEpuH'\''~c2^L3Bj35$J0LOJvv}q\z]'  < ../inputs/input/ruin.510 > ../outputs/t1235
    if diff ../outputs/t1235 ../originals/t1235 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1236) timeout -s 9 2 ../source/replace.exe 'u' 'In1%L5k:Ru\3H# ]-QF'  < ../inputs/input/ruin.1874 > ../outputs/t1236
    if diff ../outputs/t1236 ../originals/t1236 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1237) timeout -s 9 2 ../source/replace.exe 'u' 'T'  < ../inputs/input/ruin.466 > ../outputs/t1237
    if diff ../outputs/t1237 ../originals/t1237 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1238) timeout -s 9 2 ../source/replace.exe 'u' '[8$F_eY'  < ../inputs/input/ruin.1145 > ../outputs/t1238
    if diff ../outputs/t1238 ../originals/t1238 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1239) timeout -s 9 2 ../source/replace.exe 'u' 't'  < ../inputs/input/ruin.1124 > ../outputs/t1239
    if diff ../outputs/t1239 ../originals/t1239 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1240) timeout -s 9 2 ../source/replace.exe 'u' '}'  < ../inputs/input/ruin.1382 > ../outputs/t1240
    if diff ../outputs/t1240 ../originals/t1240 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1241) timeout -s 9 2 ../source/replace.exe 'u*$' 'NgW3k~nFJWW0d%"'  < ../inputs/input/ruin.1110 > ../outputs/t1241
    if diff ../outputs/t1241 ../originals/t1241 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1242) timeout -s 9 2 ../source/replace.exe 'v' 'c'  < ../inputs/input/ruin.729 > ../outputs/t1242
    if diff ../outputs/t1242 ../originals/t1242 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1243) timeout -s 9 2 ../source/replace.exe 'v' 'riSuHLH;6ksnxf-y2vuU^'  < ../inputs/input/ruin.1077 > ../outputs/t1243
    if diff ../outputs/t1243 ../originals/t1243 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1244) timeout -s 9 2 ../source/replace.exe 'v' 'w[(s3{cZZ~mUbU2(A$UX@ KoJ4[7oA qu?_|WJ GU OQxSx"j_l[Ws#!,Z4'\''9uk\B5>"[/<P%0gb>ExJ-"97v'  < ../inputs/input/ruin.499 > ../outputs/t1244
    if diff ../outputs/t1244 ../originals/t1244 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1245) timeout -s 9 2 ../source/replace.exe 'v' '{ndD U;N<EuDv3]risr=A?dbryA^dbz'  < ../inputs/input/ruin.985 > ../outputs/t1245
    if diff ../outputs/t1245 ../originals/t1245 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1246) timeout -s 9 2 ../source/replace.exe 'v?[0-9Z-a]^_`a]' ''  < ../inputs/input/ruin.83 > ../outputs/t1246
    if diff ../outputs/t1246 ../originals/t1246 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1247) timeout -s 9 2 ../source/replace.exe 'w$' 'es=b1R:cvVwr[0nH'\''uMteaL<TR6oIeq'  < ../inputs/input/ruin.1701 > ../outputs/t1247
    if diff ../outputs/t1247 ../originals/t1247 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1248) timeout -s 9 2 ../source/replace.exe 'w' '%.:s|HwIZ`s.lwvoiM&7g$TlM%Pgcz5^x LSK@J>YVY]'  < ../inputs/input/ruin.1550 > ../outputs/t1248
    if diff ../outputs/t1248 ../originals/t1248 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1249) timeout -s 9 2 ../source/replace.exe 'w' '5b'  < ../inputs/input/ruin.918 > ../outputs/t1249
    if diff ../outputs/t1249 ../originals/t1249 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1250) timeout -s 9 2 ../source/replace.exe 'w' 'U'  < ../inputs/input/ruin.1551 > ../outputs/t1250
    if diff ../outputs/t1250 ../originals/t1250 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1251) timeout -s 9 2 ../source/replace.exe 'x' '!TZ_|!54C3*^$['  < ../inputs/input/ruin.1025 > ../outputs/t1251
    if diff ../outputs/t1251 ../originals/t1251 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1252) timeout -s 9 2 ../source/replace.exe 'x' 'Q>P#tF'  < ../inputs/input/ruin.598 > ../outputs/t1252
    if diff ../outputs/t1252 ../originals/t1252 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1253) timeout -s 9 2 ../source/replace.exe 'x' 'vif#21aJuxd&,I1PPnf{b,On|j&db8)b<`\|'  < ../inputs/input/ruin.334 > ../outputs/t1253
    if diff ../outputs/t1253 ../originals/t1253 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1254) timeout -s 9 2 ../source/replace.exe 'y' '$'  < ../inputs/input/ruin.1699 > ../outputs/t1254
    if diff ../outputs/t1254 ../originals/t1254 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1255) timeout -s 9 2 ../source/replace.exe 'y/' 'G'  < ../inputs/input/ruin.1713 > ../outputs/t1255
    if diff ../outputs/t1255 ../originals/t1255 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1256) timeout -s 9 2 ../source/replace.exe 'z' '7N?!wFKF+nl$JG]\l|P\}]'\'''  < ../inputs/input/ruin.198 > ../outputs/t1256
    if diff ../outputs/t1256 ../originals/t1256 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1257) timeout -s 9 2 ../source/replace.exe 'z' 'RquQ5Vxh[sU1'  < ../inputs/input/ruin.479 > ../outputs/t1257
    if diff ../outputs/t1257 ../originals/t1257 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1258) timeout -s 9 2 ../source/replace.exe 'z' '|!]P(D3RiY#b#z'\''7|UAr}'  < ../inputs/input/ruin.1002 > ../outputs/t1258
    if diff ../outputs/t1258 ../originals/t1258 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1259) timeout -s 9 2 ../source/replace.exe '{' '+*99`cWbDE]&LL%\!=ocKQ'\''O+.[_4C@]'\''8'  < ../inputs/input/ruin.688 > ../outputs/t1259
    if diff ../outputs/t1259 ../originals/t1259 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1260) timeout -s 9 2 ../source/replace.exe '{' 'Q'  < ../inputs/input/ruin.1832 > ../outputs/t1260
    if diff ../outputs/t1260 ../originals/t1260 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1261) timeout -s 9 2 ../source/replace.exe '{' 'Y'  < ../inputs/input/ruin.1448 > ../outputs/t1261
    if diff ../outputs/t1261 ../originals/t1261 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1262) timeout -s 9 2 ../source/replace.exe '{' 'hn3sgyo$9.^y`X";72$qC'\'')fKf!'\''B'  < ../inputs/input/ruin.719 > ../outputs/t1262
    if diff ../outputs/t1262 ../originals/t1262 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1263) timeout -s 9 2 ../source/replace.exe '{\uX+2-' 'R'  < ../inputs/input/ruin.316 > ../outputs/t1263
    if diff ../outputs/t1263 ../originals/t1263 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1264) timeout -s 9 2 ../source/replace.exe '|$' 'HfDW/Zd09jY~nUga6}A4YUa,Dqr3xYQE>t,EZ'  < ../inputs/input/ruin.715 > ../outputs/t1264
    if diff ../outputs/t1264 ../originals/t1264 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1265) timeout -s 9 2 ../source/replace.exe '|' '$YCh^I\Wj>ja*r1dJ<FtZj&?HW}wua}`udW[vu_T}W;'  < ../inputs/input/ruin.974 > ../outputs/t1265
    if diff ../outputs/t1265 ../originals/t1265 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1266) timeout -s 9 2 ../source/replace.exe '|' 'GwiK'\'']%o:MKot-V@"WY.'  < ../inputs/input/ruin.1445 > ../outputs/t1266
    if diff ../outputs/t1266 ../originals/t1266 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1267) timeout -s 9 2 ../source/replace.exe '|' '[zw'\''0!G]!FE'  < ../inputs/input/ruin.453 > ../outputs/t1267
    if diff ../outputs/t1267 ../originals/t1267 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1268) timeout -s 9 2 ../source/replace.exe '|?' 'E%+OB.\-JIJ"MhV]wdPWqi`t?QTW5`'  < ../inputs/input/ruin.555 > ../outputs/t1268
    if diff ../outputs/t1268 ../originals/t1268 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1269) timeout -s 9 2 ../source/replace.exe '}' ''  < ../inputs/input/ruin.824 > ../outputs/t1269
    if diff ../outputs/t1269 ../originals/t1269 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1270) timeout -s 9 2 ../source/replace.exe '}' 'r3pd3Trb.w]o@'  < ../inputs/input/ruin.1952 > ../outputs/t1270
    if diff ../outputs/t1270 ../originals/t1270 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1271) timeout -s 9 2 ../source/replace.exe '})0J&Y6XsPqpxC53aKh3HTW9ITsk@m9aFOys4{Ym@&Eg1[G|ntmx;o|2xwF})0J&Y6XsPqpxC53aKh3HTW9ITsk@m9aFOys4{Ym@&Eg1[G|ntmx;o|2xwF})0J&Y6XsPqpxC53aKh3HTW9ITsk@m9aFOys4{Ym@&Eg1[G|ntmx;o|2xwF[Z-a]^_[Z-a]^_*[Z-a]^_*' 'a'   < ../inputs/input/ruin.1616 > ../outputs/t1271
    if diff ../outputs/t1271 ../originals/t1271 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1272) timeout -s 9 2 ../source/replace.exe '~$' 'AD1^,&FOIyq7KTrQu^vZ]v\X&>^(W#CM^K@\|+;bEf2X?RkW'  < ../inputs/input/ruin.443 > ../outputs/t1272
    if diff ../outputs/t1272 ../originals/t1272 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1273) timeout -s 9 2 ../source/replace.exe '~' '8hxxn}h2[n]KY)mM?MnZ6t|h##e\}GBn}39c'  < ../inputs/input/ruin.1847 > ../outputs/t1273
    if diff ../outputs/t1273 ../originals/t1273 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1274) timeout -s 9 2 ../source/replace.exe '~' ':7WZ2'  < ../inputs/input/ruin.1295 > ../outputs/t1274
    if diff ../outputs/t1274 ../originals/t1274 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1275) timeout -s 9 2 ../source/replace.exe '~' 'M'  < ../inputs/input/ruin.39 > ../outputs/t1275
    if diff ../outputs/t1275 ../originals/t1275 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1276) timeout -s 9 2 ../source/replace.exe '~@@' 'ah'  < ../inputs/input/ruin.1313 > ../outputs/t1276
    if diff ../outputs/t1276 ../originals/t1276 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1277) timeout -s 9 2 ../source/replace.exe *4 5   < ../inputs/moni/f1.inp > ../outputs/t1277
    if diff ../outputs/t1277 ../originals/t1277 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1278) timeout -s 9 2 ../source/replace.exe *[a-z]? 4  < ../inputs/moni/f2.inp > ../outputs/t1278
    if diff ../outputs/t1278 ../originals/t1278 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1279) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1011 > ../outputs/t1279
    if diff ../outputs/t1279 ../originals/t1279 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1280) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1056 > ../outputs/t1280
    if diff ../outputs/t1280 ../originals/t1280 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1281) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1280 > ../outputs/t1281
    if diff ../outputs/t1281 ../originals/t1281 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1282) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1401 > ../outputs/t1282
    if diff ../outputs/t1282 ../originals/t1282 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1283) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1480 > ../outputs/t1283
    if diff ../outputs/t1283 ../originals/t1283 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1284) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1581 > ../outputs/t1284
    if diff ../outputs/t1284 ../originals/t1284 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1285) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1590 > ../outputs/t1285
    if diff ../outputs/t1285 ../originals/t1285 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1286) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1592 > ../outputs/t1286
    if diff ../outputs/t1286 ../originals/t1286 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1287) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1595 > ../outputs/t1287
    if diff ../outputs/t1287 ../originals/t1287 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1288) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1778 > ../outputs/t1288
    if diff ../outputs/t1288 ../originals/t1288 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1289) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1788 > ../outputs/t1289
    if diff ../outputs/t1289 ../originals/t1289 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1290) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.1814 > ../outputs/t1290
    if diff ../outputs/t1290 ../originals/t1290 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1291) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.2 > ../outputs/t1291
    if diff ../outputs/t1291 ../originals/t1291 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1292) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.266 > ../outputs/t1292
    if diff ../outputs/t1292 ../originals/t1292 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1293) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.271 > ../outputs/t1293
    if diff ../outputs/t1293 ../originals/t1293 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1294) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.363 > ../outputs/t1294
    if diff ../outputs/t1294 ../originals/t1294 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1295) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.400 > ../outputs/t1295
    if diff ../outputs/t1295 ../originals/t1295 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1296) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.43 > ../outputs/t1296
    if diff ../outputs/t1296 ../originals/t1296 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1297) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.622 > ../outputs/t1297
    if diff ../outputs/t1297 ../originals/t1297 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1298) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.792 > ../outputs/t1298
    if diff ../outputs/t1298 ../originals/t1298 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1299) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.957 > ../outputs/t1299
    if diff ../outputs/t1299 ../originals/t1299 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1300) timeout -s 9 2 ../source/replace.exe  < ../inputs/input/ruin.990 > ../outputs/t1300
    if diff ../outputs/t1300 ../originals/t1300 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1301) timeout -s 9 2 ../source/replace.exe '%jh[3-9]@f**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t1301
    if diff ../outputs/t1301 ../originals/t1301 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1302) timeout -s 9 2 ../source/replace.exe '%q' 'd'  < ../inputs/input/ruin.1813 > ../outputs/t1302
    if diff ../outputs/t1302 ../originals/t1302 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1303) timeout -s 9 2 ../source/replace.exe '%x' 'm~bsLkd.o0:yq^yMu$f*\Yc<'  < ../inputs/input/ruin.226 > ../outputs/t1303
    if diff ../outputs/t1303 ../originals/t1303 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1304) timeout -s 9 2 ../source/replace.exe '%yw,0+8@n' 'a&`'  < ../inputs/input/ruin.1158 > ../outputs/t1304
    if diff ../outputs/t1304 ../originals/t1304 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1305) timeout -s 9 2 ../source/replace.exe '%z$' '*'  < ../inputs/input/ruin.1693 > ../outputs/t1305
    if diff ../outputs/t1305 ../originals/t1305 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1306) timeout -s 9 2 ../source/replace.exe '%|$' 'j'  < ../inputs/input/ruin.944 > ../outputs/t1306
    if diff ../outputs/t1306 ../originals/t1306 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1307) timeout -s 9 2 ../source/replace.exe '&$ab**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t1307
    if diff ../outputs/t1307 ../originals/t1307 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1308) timeout -s 9 2 ../source/replace.exe '&' 'II|-#'  < ../inputs/input/ruin.673 > ../outputs/t1308
    if diff ../outputs/t1308 ../originals/t1308 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1309) timeout -s 9 2 ../source/replace.exe '&' 'e&R7H2HKc,  kd7Q<uPE<Zx+ ah'  < ../inputs/input/ruin.1422 > ../outputs/t1309
    if diff ../outputs/t1309 ../originals/t1309 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1310) timeout -s 9 2 ../source/replace.exe '&' 'e'  < ../inputs/input/ruin.1537 > ../outputs/t1310
    if diff ../outputs/t1310 ../originals/t1310 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1311) timeout -s 9 2 ../source/replace.exe '&' 'pg'  < ../inputs/input/ruin.124 > ../outputs/t1311
    if diff ../outputs/t1311 ../originals/t1311 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1312) timeout -s 9 2 ../source/replace.exe '&6 **' 'a'  < ../inputs/moni/f7.inp > ../outputs/t1312
    if diff ../outputs/t1312 ../originals/t1312 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1313) timeout -s 9 2 ../source/replace.exe '' ' '  < ../inputs/input/ruin.452 > ../outputs/t1313
    if diff ../outputs/t1313 ../originals/t1313 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1314) timeout -s 9 2 ../source/replace.exe '' '!'  < ../inputs/input/ruin.922 > ../outputs/t1314
    if diff ../outputs/t1314 ../originals/t1314 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1315) timeout -s 9 2 ../source/replace.exe '' '"'  < ../inputs/input/ruin.1728 > ../outputs/t1315
    if diff ../outputs/t1315 ../originals/t1315 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1316) timeout -s 9 2 ../source/replace.exe '' '$'  < ../inputs/input/ruin.1750 > ../outputs/t1316
    if diff ../outputs/t1316 ../originals/t1316 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1317) timeout -s 9 2 ../source/replace.exe '' ''\''Z y<j$`3-b6{hC,KW4dJZ\tWkm'  < ../inputs/input/ruin.1104 > ../outputs/t1317
    if diff ../outputs/t1317 ../originals/t1317 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1318) timeout -s 9 2 ../source/replace.exe '' '(,t{kot~t4%]~"i|?`&\Qrhl6SO&4rT\Y[].'  < ../inputs/input/ruin.1822 > ../outputs/t1318
    if diff ../outputs/t1318 ../originals/t1318 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1319) timeout -s 9 2 ../source/replace.exe '' '(h.--"zy)?N*:eh'  < ../inputs/input/ruin.1899 > ../outputs/t1319
    if diff ../outputs/t1319 ../originals/t1319 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1320) timeout -s 9 2 ../source/replace.exe '' ').EgV46YLA|t(jN!%1'\''AO,A_{pP_'  < ../inputs/input/ruin.1835 > ../outputs/t1320
    if diff ../outputs/t1320 ../originals/t1320 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1321) timeout -s 9 2 ../source/replace.exe '' '-'  < ../inputs/input/ruin.373 > ../outputs/t1321
    if diff ../outputs/t1321 ../originals/t1321 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1322) timeout -s 9 2 ../source/replace.exe '' '-'  < ../inputs/input/ruin.705 > ../outputs/t1322
    if diff ../outputs/t1322 ../originals/t1322 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1323) timeout -s 9 2 ../source/replace.exe '' '-,i3&R}<-W[ItMRB{.b2mI]T1UZKpg'  < ../inputs/input/ruin.772 > ../outputs/t1323
    if diff ../outputs/t1323 ../originals/t1323 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1324) timeout -s 9 2 ../source/replace.exe '' '1'  < ../inputs/input/ruin.227 > ../outputs/t1324
    if diff ../outputs/t1324 ../originals/t1324 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1325) timeout -s 9 2 ../source/replace.exe '' '2'  < ../inputs/input/ruin.236 > ../outputs/t1325
    if diff ../outputs/t1325 ../originals/t1325 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1326) timeout -s 9 2 ../source/replace.exe '' '4k2I3Sx/L.0lMc,Ct<O91xn!N!6XD)Za'  < ../inputs/input/ruin.440 > ../outputs/t1326
    if diff ../outputs/t1326 ../originals/t1326 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1327) timeout -s 9 2 ../source/replace.exe '' '9'  < ../inputs/input/ruin.1064 > ../outputs/t1327
    if diff ../outputs/t1327 ../originals/t1327 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1328) timeout -s 9 2 ../source/replace.exe '' ';C5Q#+!5V<oSjIW"k3~oP *vIBN'  < ../inputs/input/ruin.257 > ../outputs/t1328
    if diff ../outputs/t1328 ../originals/t1328 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1329) timeout -s 9 2 ../source/replace.exe '' '>'  < ../inputs/input/ruin.628 > ../outputs/t1329
    if diff ../outputs/t1329 ../originals/t1329 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1330) timeout -s 9 2 ../source/replace.exe '' '@g5fQ|ruR,ZAD+Q/'  < ../inputs/input/ruin.19 > ../outputs/t1330
    if diff ../outputs/t1330 ../originals/t1330 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1331) timeout -s 9 2 ../source/replace.exe '' 'BTKzQX[0{Fdkhsx%lQ<KOmjPx{RO4%y?I<*;>77`@akb|!'\''B~Awc]Rw*Jg;joAvfHhyE_e3'  < ../inputs/input/ruin.861 > ../outputs/t1331
    if diff ../outputs/t1331 ../originals/t1331 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1332) timeout -s 9 2 ../source/replace.exe '' 'E4\70!JDTfF[Z}ggd'  < ../inputs/input/ruin.880 > ../outputs/t1332
    if diff ../outputs/t1332 ../originals/t1332 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1333) timeout -s 9 2 ../source/replace.exe '' 'G'  < ../inputs/input/ruin.1466 > ../outputs/t1333
    if diff ../outputs/t1333 ../originals/t1333 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1334) timeout -s 9 2 ../source/replace.exe '' 'G'  < ../inputs/input/ruin.1563 > ../outputs/t1334
    if diff ../outputs/t1334 ../originals/t1334 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1335) timeout -s 9 2 ../source/replace.exe '' 'K'  < ../inputs/input/ruin.1852 > ../outputs/t1335
    if diff ../outputs/t1335 ../originals/t1335 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1336) timeout -s 9 2 ../source/replace.exe '' 'K'  < ../inputs/input/ruin.259 > ../outputs/t1336
    if diff ../outputs/t1336 ../originals/t1336 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1337) timeout -s 9 2 ../source/replace.exe '' 'K'  < ../inputs/input/ruin.859 > ../outputs/t1337
    if diff ../outputs/t1337 ../originals/t1337 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1338) timeout -s 9 2 ../source/replace.exe '' 'L/FLz+< y/Ch49G5.NnZ7s2<*w+Vf,L2'  < ../inputs/input/ruin.134 > ../outputs/t1338
    if diff ../outputs/t1338 ../originals/t1338 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1339) timeout -s 9 2 ../source/replace.exe '' 'M8|(B=(H(T{P 1$~klg'  < ../inputs/input/ruin.114 > ../outputs/t1339
    if diff ../outputs/t1339 ../originals/t1339 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1340) timeout -s 9 2 ../source/replace.exe '' 'M\?#!~.)L* N'\''8%*?\DH&Kn+Kb$@&?H! '\''b<+~(8QgW'\''k('  < ../inputs/input/ruin.1652 > ../outputs/t1340
    if diff ../outputs/t1340 ../originals/t1340 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1341) timeout -s 9 2 ../source/replace.exe '' 'Pd#(tEJLie`_i@Qb,]e66XCMVy8%p9<>%Z[P'  < ../inputs/input/ruin.221 > ../outputs/t1341
    if diff ../outputs/t1341 ../originals/t1341 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1342) timeout -s 9 2 ../source/replace.exe '' 'T'  < ../inputs/input/ruin.1744 > ../outputs/t1342
    if diff ../outputs/t1342 ../originals/t1342 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1343) timeout -s 9 2 ../source/replace.exe '' 'T'  < ../inputs/input/ruin.1755 > ../outputs/t1343
    if diff ../outputs/t1343 ../originals/t1343 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1344) timeout -s 9 2 ../source/replace.exe '' 'U@DbH]&>ZR('  < ../inputs/input/ruin.1839 > ../outputs/t1344
    if diff ../outputs/t1344 ../originals/t1344 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1345) timeout -s 9 2 ../source/replace.exe '' 'VcA~!1&(Sea@k2P2'  < ../inputs/input/ruin.1776 > ../outputs/t1345
    if diff ../outputs/t1345 ../originals/t1345 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1346) timeout -s 9 2 ../source/replace.exe '' 'Y!ME~#'  < ../inputs/input/ruin.1170 > ../outputs/t1346
    if diff ../outputs/t1346 ../originals/t1346 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1347) timeout -s 9 2 ../source/replace.exe '' '^TA6q#%uc@pEv0e!Gk8Z?vyYdyRhx~|6\ BY7fs}+:K7S'  < ../inputs/input/ruin.1437 > ../outputs/t1347
    if diff ../outputs/t1347 ../originals/t1347 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1348) timeout -s 9 2 ../source/replace.exe '' '_'  < ../inputs/input/ruin.1427 > ../outputs/t1348
    if diff ../outputs/t1348 ../originals/t1348 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1349) timeout -s 9 2 ../source/replace.exe '' 'a'  < ../inputs/input/ruin.696 > ../outputs/t1349
    if diff ../outputs/t1349 ../originals/t1349 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1350) timeout -s 9 2 ../source/replace.exe '' 'c'  < ../inputs/input/ruin.1135 > ../outputs/t1350
    if diff ../outputs/t1350 ../originals/t1350 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1351) timeout -s 9 2 ../source/replace.exe '' 'd'  < ../inputs/input/ruin.584 > ../outputs/t1351
    if diff ../outputs/t1351 ../originals/t1351 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1352) timeout -s 9 2 ../source/replace.exe '' 'dV\?Qb7f]GZ:YV(22%ESH;?$'  < ../inputs/input/ruin.1160 > ../outputs/t1352
    if diff ../outputs/t1352 ../originals/t1352 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1353) timeout -s 9 2 ../source/replace.exe '' 'f'  < ../inputs/input/ruin.557 > ../outputs/t1353
    if diff ../outputs/t1353 ../originals/t1353 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1354) timeout -s 9 2 ../source/replace.exe '' 'h'  < ../inputs/input/ruin.1966 > ../outputs/t1354
    if diff ../outputs/t1354 ../originals/t1354 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1355) timeout -s 9 2 ../source/replace.exe '' 'j'  < ../inputs/input/ruin.1735 > ../outputs/t1355
    if diff ../outputs/t1355 ../originals/t1355 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1356) timeout -s 9 2 ../source/replace.exe '' 'j@+'  < ../inputs/input/ruin.339 > ../outputs/t1356
    if diff ../outputs/t1356 ../originals/t1356 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1357) timeout -s 9 2 ../source/replace.exe '' 'kGv'\''@V.cj'  < ../inputs/input/ruin.1518 > ../outputs/t1357
    if diff ../outputs/t1357 ../originals/t1357 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1358) timeout -s 9 2 ../source/replace.exe '' 'l[*U(0T7mn'  < ../inputs/input/ruin.1352 > ../outputs/t1358
    if diff ../outputs/t1358 ../originals/t1358 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1359) timeout -s 9 2 ../source/replace.exe '' 'n'  < ../inputs/input/ruin.724 > ../outputs/t1359
    if diff ../outputs/t1359 ../originals/t1359 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1360) timeout -s 9 2 ../source/replace.exe '' 'oB'  < ../inputs/input/ruin.220 > ../outputs/t1360
    if diff ../outputs/t1360 ../originals/t1360 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1361) timeout -s 9 2 ../source/replace.exe '' 'ua1CB[Gc%"D/ ~h[ifc{.'\'''  < ../inputs/input/ruin.375 > ../outputs/t1361
    if diff ../outputs/t1361 ../originals/t1361 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1362) timeout -s 9 2 ../source/replace.exe '' 'v'  < ../inputs/input/ruin.1429 > ../outputs/t1362
    if diff ../outputs/t1362 ../originals/t1362 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1363) timeout -s 9 2 ../source/replace.exe '' 'x'  < ../inputs/input/ruin.886 > ../outputs/t1363
    if diff ../outputs/t1363 ../originals/t1363 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1364) timeout -s 9 2 ../source/replace.exe '' 'x|g=Y,'  < ../inputs/input/ruin.1880 > ../outputs/t1364
    if diff ../outputs/t1364 ../originals/t1364 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1365) timeout -s 9 2 ../source/replace.exe '' '{#umxUXsQww[=tD`2X'  < ../inputs/input/ruin.211 > ../outputs/t1365
    if diff ../outputs/t1365 ../originals/t1365 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1366) timeout -s 9 2 ../source/replace.exe '' '{'  < ../inputs/input/ruin.1255 > ../outputs/t1366
    if diff ../outputs/t1366 ../originals/t1366 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1367) timeout -s 9 2 ../source/replace.exe '' '|,'  < ../inputs/input/ruin.1173 > ../outputs/t1367
    if diff ../outputs/t1367 ../originals/t1367 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1368) timeout -s 9 2 ../source/replace.exe '' '|g4|;Y<)c'\''5\IC5utpVH'  < ../inputs/input/ruin.784 > ../outputs/t1368
    if diff ../outputs/t1368 ../originals/t1368 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1369) timeout -s 9 2 ../source/replace.exe '' '}'  < ../inputs/input/ruin.1066 > ../outputs/t1369
    if diff ../outputs/t1369 ../originals/t1369 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1370) timeout -s 9 2 ../source/replace.exe '' '~]/'  < ../inputs/input/ruin.1237 > ../outputs/t1370
    if diff ../outputs/t1370 ../originals/t1370 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1371) timeout -s 9 2 ../source/replace.exe '' '~]/*$'  < ../inputs/input/ruin.1237 > ../outputs/t1371
    if diff ../outputs/t1371 ../originals/t1371 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1372) timeout -s 9 2 ../source/replace.exe '' op  < ../inputs/moni/f7.inp > ../outputs/t1372
    if diff ../outputs/t1372 ../originals/t1372 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1373) timeout -s 9 2 ../source/replace.exe ''\'' nKE'\''?' '(/>AguC9He H1#DQ$_\3z;giEd'  < ../inputs/input/ruin.869 > ../outputs/t1373
    if diff ../outputs/t1373 ../originals/t1373 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1374) timeout -s 9 2 ../source/replace.exe ''\''$' '%'  < ../inputs/input/ruin.783 > ../outputs/t1374
    if diff ../outputs/t1374 ../originals/t1374 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1375) timeout -s 9 2 ../source/replace.exe ''\''' 'm%NN3G5'  < ../inputs/input/ruin.92 > ../outputs/t1375
    if diff ../outputs/t1375 ../originals/t1375 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1376) timeout -s 9 2 ../source/replace.exe ''\''0i[^>]' 'f%JGn8F(1'\''2X1w#F4X@ `bKu'\''z5>%"1xr,|i^;H0+u)A]'  < ../inputs/input/ruin.698 > ../outputs/t1376
    if diff ../outputs/t1376 ../originals/t1376 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1377) timeout -s 9 2 ../source/replace.exe ''\''3*' '!5'  < ../inputs/input/ruin.1359 > ../outputs/t1377
    if diff ../outputs/t1377 ../originals/t1377 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1378) timeout -s 9 2 ../source/replace.exe ''\''3fR]'\''f!t@@' 'h3'  < ../inputs/input/ruin.1757 > ../outputs/t1378
    if diff ../outputs/t1378 ../originals/t1378 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1379) timeout -s 9 2 ../source/replace.exe ''\''5@=' 'Zi8'  < ../inputs/input/ruin.1978 > ../outputs/t1379
    if diff ../outputs/t1379 ../originals/t1379 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1380) timeout -s 9 2 ../source/replace.exe ''\''<"7y7*' '$6B1-CefGQQf]dVO#lukP'  < ../inputs/input/ruin.183 > ../outputs/t1380
    if diff ../outputs/t1380 ../originals/t1380 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1381) timeout -s 9 2 ../source/replace.exe ''\''=,bX!+@@[y]' 'cC'  < ../inputs/input/ruin.706 > ../outputs/t1381
    if diff ../outputs/t1381 ../originals/t1381 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1382) timeout -s 9 2 ../source/replace.exe ''\''?*@n' 'R$W\g?~KtfT Z7}t^C<isN=sCXIezpz-\C8xg)"zcmNP'  < ../inputs/input/ruin.722 > ../outputs/t1382
    if diff ../outputs/t1382 ../originals/t1382 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1383) timeout -s 9 2 ../source/replace.exe ''\''A@@D' '0'  < ../inputs/input/ruin.890 > ../outputs/t1383
    if diff ../outputs/t1383 ../originals/t1383 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1384) timeout -s 9 2 ../source/replace.exe ''\''Hs$' 'vvG{[/ZzAySoM$[X*ij4,vM1}^Xs2$L"^/ XIb_'  < ../inputs/input/ruin.718 > ../outputs/t1384
    if diff ../outputs/t1384 ../originals/t1384 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1385) timeout -s 9 2 ../source/replace.exe ''\''\m' '+6DCv5ol)/q7p'  < ../inputs/input/ruin.1639 > ../outputs/t1385
    if diff ../outputs/t1385 ../originals/t1385 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1386) timeout -s 9 2 ../source/replace.exe ''\''`2ZFWK[^0-9A-G]' '^U7*jCT2uSAbKD0d,m2|1|q ]|'  < ../inputs/input/ruin.1624 > ../outputs/t1386
    if diff ../outputs/t1386 ../originals/t1386 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1387) timeout -s 9 2 ../source/replace.exe ''\''`2ZFWK[^0-9A-G]?*' '^U7*jCT2uSAbKD0d,m2|1|q ]|'  < ../inputs/input/ruin.1624 > ../outputs/t1387
    if diff ../outputs/t1387 ../originals/t1387 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1388) timeout -s 9 2 ../source/replace.exe ''\''ae[d_$T?' 'i'  < ../inputs/input/ruin.838 > ../outputs/t1388
    if diff ../outputs/t1388 ../originals/t1388 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1389) timeout -s 9 2 ../source/replace.exe ''\''dwM?' '!'  < ../inputs/input/ruin.87 > ../outputs/t1389
    if diff ../outputs/t1389 ../originals/t1389 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1390) timeout -s 9 2 ../source/replace.exe ''\''i,Zl' 'JocZqS0rv$$&knoDor[tO8v }wC!q.H:B~)^t^zXX)@hl%'  < ../inputs/input/ruin.348 > ../outputs/t1390
    if diff ../outputs/t1390 ../originals/t1390 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1391) timeout -s 9 2 ../source/replace.exe ''\''vb(#?' 'E[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur'  < ../inputs/input/ruin.1328 > ../outputs/t1391
    if diff ../outputs/t1391 ../originals/t1391 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1392) timeout -s 9 2 ../source/replace.exe ''\''vb(#?' 'E[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\'[a-z]*[0-9]*'+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur'  < ../inputs/input/ruin.1328 > ../outputs/t1392
    if diff ../outputs/t1392 ../originals/t1392 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1393) timeout -s 9 2 ../source/replace.exe ')' '%QdHuGpf=?qy 3~3QQ_2yf8K<@XUjm78_'  < ../inputs/input/ruin.42 > ../outputs/t1393
    if diff ../outputs/t1393 ../originals/t1393 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1394) timeout -s 9 2 ../source/replace.exe ')' 'G(:jQg6w{T Va1#rG@ Oh{y=E`8'  < ../inputs/input/ruin.1685 > ../outputs/t1394
    if diff ../outputs/t1394 ../originals/t1394 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1395) timeout -s 9 2 ../source/replace.exe ')' 'bj:]m@p4*VSsQ[P&I)~5Q'  < ../inputs/input/ruin.410 > ../outputs/t1395
    if diff ../outputs/t1395 ../originals/t1395 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1396) timeout -s 9 2 ../source/replace.exe ')[^~]' 'HnY<{aYd91.NgWAZ'  < ../inputs/input/ruin.1831 > ../outputs/t1396
    if diff ../outputs/t1396 ../originals/t1396 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1397) timeout -s 9 2 ../source/replace.exe '*$' '2'  < ../inputs/input/ruin.849 > ../outputs/t1397
    if diff ../outputs/t1397 ../originals/t1397 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1398) timeout -s 9 2 ../source/replace.exe '*$' '4'  < ../inputs/input/ruin.476 > ../outputs/t1398
    if diff ../outputs/t1398 ../originals/t1398 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1399) timeout -s 9 2 ../source/replace.exe '*$' '9Yd(bzS<c l?GhI'  < ../inputs/input/ruin.100 > ../outputs/t1399
    if diff ../outputs/t1399 ../originals/t1399 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1400) timeout -s 9 2 ../source/replace.exe '*$' 'D'  < ../inputs/input/ruin.1998 > ../outputs/t1400
    if diff ../outputs/t1400 ../originals/t1400 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1401) timeout -s 9 2 ../source/replace.exe '*$' 'L'  < ../inputs/input/ruin.432 > ../outputs/t1401
    if diff ../outputs/t1401 ../originals/t1401 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1402) timeout -s 9 2 ../source/replace.exe '*$' '`'  < ../inputs/input/ruin.1249 > ../outputs/t1402
    if diff ../outputs/t1402 ../originals/t1402 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1403) timeout -s 9 2 ../source/replace.exe '*$' 'ap[D!P=9JT#e4"ii]*DCP)_yR'  < ../inputs/input/ruin.1956 > ../outputs/t1403
    if diff ../outputs/t1403 ../originals/t1403 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1404) timeout -s 9 2 ../source/replace.exe '*$' 'f'  < ../inputs/input/ruin.1108 > ../outputs/t1404
    if diff ../outputs/t1404 ../originals/t1404 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1405) timeout -s 9 2 ../source/replace.exe '*$' 'l'  < ../inputs/input/ruin.1251 > ../outputs/t1405
    if diff ../outputs/t1405 ../originals/t1405 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1406) timeout -s 9 2 ../source/replace.exe '*$' 'nDf38_|G_<?#50:)+jM'  < ../inputs/input/ruin.1242 > ../outputs/t1406
    if diff ../outputs/t1406 ../originals/t1406 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1407) timeout -s 9 2 ../source/replace.exe '*$' 'w'  < ../inputs/input/ruin.1436 > ../outputs/t1407
    if diff ../outputs/t1407 ../originals/t1407 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1408) timeout -s 9 2 ../source/replace.exe '*$' '{'  < ../inputs/input/ruin.1255 > ../outputs/t1408
    if diff ../outputs/t1408 ../originals/t1408 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1409) timeout -s 9 2 ../source/replace.exe '*&\:H@@Y\' '7'  < ../inputs/input/ruin.1704 > ../outputs/t1409
    if diff ../outputs/t1409 ../originals/t1409 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1410) timeout -s 9 2 ../source/replace.exe '*'   < ../inputs/input/ruin.1162 > ../outputs/t1410
    if diff ../outputs/t1410 ../originals/t1410 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1411) timeout -s 9 2 ../source/replace.exe '*'   < ../inputs/input/ruin.1269 > ../outputs/t1411
    if diff ../outputs/t1411 ../originals/t1411 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1412) timeout -s 9 2 ../source/replace.exe '*'   < ../inputs/temp-test/532.inp.231.1 > ../outputs/t1412
    if diff ../outputs/t1412 ../originals/t1412 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1413) timeout -s 9 2 ../source/replace.exe '*' ' '  < ../inputs/input/ruin.1283 > ../outputs/t1413
    if diff ../outputs/t1413 ../originals/t1413 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1414) timeout -s 9 2 ../source/replace.exe '*' ' '  < ../inputs/input/ruin.486 > ../outputs/t1414
    if diff ../outputs/t1414 ../originals/t1414 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1415) timeout -s 9 2 ../source/replace.exe '*' ' iUr?ERqn:&}P0'  < ../inputs/input/ruin.582 > ../outputs/t1415
    if diff ../outputs/t1415 ../originals/t1415 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1416) timeout -s 9 2 ../source/replace.exe '*' ' vf6BS n\'\''3;^AX<~{)[+<ucX8fJ%lTq*f>$x;$K(G\Dx(x5daSW'\''ig%-P<``YCp1awN5jBMe!a{ehg6AAG9%P;+G[o_d6:'  < ../inputs/input/ruin.762 > ../outputs/t1416
    if diff ../outputs/t1416 ../originals/t1416 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1417) timeout -s 9 2 ../source/replace.exe '*' '!'  < ../inputs/input/ruin.471 > ../outputs/t1417
    if diff ../outputs/t1417 ../originals/t1417 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1418) timeout -s 9 2 ../source/replace.exe '*' '!'  < ../inputs/input/ruin.659 > ../outputs/t1418
    if diff ../outputs/t1418 ../originals/t1418 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1419) timeout -s 9 2 ../source/replace.exe '*' '#'  < ../inputs/input/ruin.1622 > ../outputs/t1419
    if diff ../outputs/t1419 ../originals/t1419 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1420) timeout -s 9 2 ../source/replace.exe '*' '#'  < ../inputs/input/ruin.866 > ../outputs/t1420
    if diff ../outputs/t1420 ../originals/t1420 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1421) timeout -s 9 2 ../source/replace.exe '*' '$'  < ../inputs/input/ruin.1528 > ../outputs/t1421
    if diff ../outputs/t1421 ../originals/t1421 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1422) timeout -s 9 2 ../source/replace.exe '*' '$QoC!xsIeF,A!nqn4vnEyMHomb8wt~}yL(:1p.(ks|;anN_?6/|L'  < ../inputs/input/ruin.809 > ../outputs/t1422
    if diff ../outputs/t1422 ../originals/t1422 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1423) timeout -s 9 2 ../source/replace.exe '*' '$U`XG#S'  < ../inputs/input/ruin.1319 > ../outputs/t1423
    if diff ../outputs/t1423 ../originals/t1423 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1424) timeout -s 9 2 ../source/replace.exe '*' '%'  < ../inputs/input/ruin.1122 > ../outputs/t1424
    if diff ../outputs/t1424 ../originals/t1424 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1425) timeout -s 9 2 ../source/replace.exe '*' '%2 ]TOV!zB)ez~h;W'\''Rv|F"FjKHB7'  < ../inputs/input/ruin.1720 > ../outputs/t1425
    if diff ../outputs/t1425 ../originals/t1425 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1426) timeout -s 9 2 ../source/replace.exe '*' '%Z}!'  < ../inputs/input/ruin.740 > ../outputs/t1426
    if diff ../outputs/t1426 ../originals/t1426 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1427) timeout -s 9 2 ../source/replace.exe '*' '&#tvW5KHbWqppCxb#?ETu@O!uhsxBI)E%Bx6E9Db>;g[q'\''1'  < ../inputs/input/ruin.1533 > ../outputs/t1427
    if diff ../outputs/t1427 ../originals/t1427 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1428) timeout -s 9 2 ../source/replace.exe '*' '&'  < ../inputs/input/ruin.1071 > ../outputs/t1428
    if diff ../outputs/t1428 ../originals/t1428 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1429) timeout -s 9 2 ../source/replace.exe '*' '&'  < ../inputs/input/ruin.378 > ../outputs/t1429
    if diff ../outputs/t1429 ../originals/t1429 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1430) timeout -s 9 2 ../source/replace.exe '*' '&-EO<`uTW\}@>'  < ../inputs/input/ruin.415 > ../outputs/t1430
    if diff ../outputs/t1430 ../originals/t1430 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1431) timeout -s 9 2 ../source/replace.exe '*' '&@n'  < ../inputs/temp-test/532.inp.231.1 > ../outputs/t1431
    if diff ../outputs/t1431 ../originals/t1431 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1432) timeout -s 9 2 ../source/replace.exe '*' '&tm#n4gz=9'  < ../inputs/input/ruin.1949 > ../outputs/t1432
    if diff ../outputs/t1432 ../originals/t1432 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1433) timeout -s 9 2 ../source/replace.exe '*' ''  < ../inputs/input/ruin.993 > ../outputs/t1433
    if diff ../outputs/t1433 ../originals/t1433 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1434) timeout -s 9 2 ../source/replace.exe '*' ''\''$ia|e*5g"jk"'\''6'  < ../inputs/input/ruin.516 > ../outputs/t1434
    if diff ../outputs/t1434 ../originals/t1434 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1435) timeout -s 9 2 ../source/replace.exe '*' ''\'''  < ../inputs/input/ruin.1968 > ../outputs/t1435
    if diff ../outputs/t1435 ../originals/t1435 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1436) timeout -s 9 2 ../source/replace.exe '*' ''\'',_{05yQ>]e2Ll},e5b]TTt}JwWxDfD`%\uKmF&L5CRcou0vj/m'  < ../inputs/input/ruin.1142 > ../outputs/t1436
    if diff ../outputs/t1436 ../originals/t1436 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1437) timeout -s 9 2 ../source/replace.exe '*' '(!('  < ../inputs/input/ruin.520 > ../outputs/t1437
    if diff ../outputs/t1437 ../originals/t1437 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1438) timeout -s 9 2 ../source/replace.exe '*' '*@czJB%'\''p!{sw~#<3`jZj&,nBHTJ/,[iy#['  < ../inputs/input/ruin.1272 > ../outputs/t1438
    if diff ../outputs/t1438 ../originals/t1438 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1439) timeout -s 9 2 ../source/replace.exe '*' '*eb47-Z1(o?{cRs3'\''-Z6a+{mK<8:Jtzs2<'  < ../inputs/input/ruin.171 > ../outputs/t1439
    if diff ../outputs/t1439 ../originals/t1439 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1440) timeout -s 9 2 ../source/replace.exe '*' '+'  < ../inputs/input/ruin.1137 > ../outputs/t1440
    if diff ../outputs/t1440 ../originals/t1440 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1441) timeout -s 9 2 ../source/replace.exe '*' '+m8CH#~??9k3<a6'  < ../inputs/input/ruin.408 > ../outputs/t1441
    if diff ../outputs/t1441 ../originals/t1441 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1442) timeout -s 9 2 ../source/replace.exe '*' ','  < ../inputs/input/ruin.1353 > ../outputs/t1442
    if diff ../outputs/t1442 ../originals/t1442 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1443) timeout -s 9 2 ../source/replace.exe '*' '-'  < ../inputs/input/ruin.1210 > ../outputs/t1443
    if diff ../outputs/t1443 ../originals/t1443 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1444) timeout -s 9 2 ../source/replace.exe '*' '-'  < ../inputs/input/ruin.241 > ../outputs/t1444
    if diff ../outputs/t1444 ../originals/t1444 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1445) timeout -s 9 2 ../source/replace.exe '*' '-4>'  < ../inputs/input/ruin.1834 > ../outputs/t1445
    if diff ../outputs/t1445 ../originals/t1445 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1446) timeout -s 9 2 ../source/replace.exe '*' '-D0?|{_vP-|TX(X=iq'  < ../inputs/input/ruin.1134 > ../outputs/t1446
    if diff ../outputs/t1446 ../originals/t1446 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1447) timeout -s 9 2 ../source/replace.exe '*' '-Sao&~r'\'':~.S]#LZyv}n8e.'  < ../inputs/input/ruin.458 > ../outputs/t1447
    if diff ../outputs/t1447 ../originals/t1447 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1448) timeout -s 9 2 ../source/replace.exe '*' '.'  < ../inputs/input/ruin.1675 > ../outputs/t1448
    if diff ../outputs/t1448 ../originals/t1448 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1449) timeout -s 9 2 ../source/replace.exe '*' '.H[:am)]H.Eaz0xd\*+'\''@~q>B~N<'\''W'  < ../inputs/input/ruin.881 > ../outputs/t1449
    if diff ../outputs/t1449 ../originals/t1449 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1450) timeout -s 9 2 ../source/replace.exe '*' '.L'  < ../inputs/input/ruin.17 > ../outputs/t1450
    if diff ../outputs/t1450 ../originals/t1450 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1451) timeout -s 9 2 ../source/replace.exe '*' '.f/!.,_~+OWno#EPEePE'\''`.sN#uxti:ia9h##A?$NO'  < ../inputs/input/ruin.59 > ../outputs/t1451
    if diff ../outputs/t1451 ../originals/t1451 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1452) timeout -s 9 2 ../source/replace.exe '*' '/'  < ../inputs/input/ruin.1605 > ../outputs/t1452
    if diff ../outputs/t1452 ../originals/t1452 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1453) timeout -s 9 2 ../source/replace.exe '*' '/'  < ../inputs/input/ruin.336 > ../outputs/t1453
    if diff ../outputs/t1453 ../originals/t1453 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1454) timeout -s 9 2 ../source/replace.exe '*' '0'  < ../inputs/input/ruin.1951 > ../outputs/t1454
    if diff ../outputs/t1454 ../originals/t1454 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1455) timeout -s 9 2 ../source/replace.exe '*' '1'  < ../inputs/input/ruin.1468 > ../outputs/t1455
    if diff ../outputs/t1455 ../originals/t1455 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1456) timeout -s 9 2 ../source/replace.exe '*' '2b;'\''An'  < ../inputs/input/ruin.923 > ../outputs/t1456
    if diff ../outputs/t1456 ../originals/t1456 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1457) timeout -s 9 2 ../source/replace.exe '*' '3'  < ../inputs/input/ruin.738 > ../outputs/t1457
    if diff ../outputs/t1457 ../originals/t1457 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1458) timeout -s 9 2 ../source/replace.exe '*' '3_a9tyP_K'  < ../inputs/input/ruin.224 > ../outputs/t1458
    if diff ../outputs/t1458 ../originals/t1458 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1459) timeout -s 9 2 ../source/replace.exe '*' '3iSUKlIcJY@zzKt\o}E]o[Nt}2@,!\FR +S:,^u'  < ../inputs/input/ruin.1795 > ../outputs/t1459
    if diff ../outputs/t1459 ../originals/t1459 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1460) timeout -s 9 2 ../source/replace.exe '*' '3ntGq*:GgM74d~I<l'  < ../inputs/input/ruin.104 > ../outputs/t1460
    if diff ../outputs/t1460 ../originals/t1460 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1461) timeout -s 9 2 ../source/replace.exe '*' '4j'  < ../inputs/input/ruin.1715 > ../outputs/t1461
    if diff ../outputs/t1461 ../originals/t1461 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1462) timeout -s 9 2 ../source/replace.exe '*' '5'  < ../inputs/input/ruin.651 > ../outputs/t1462
    if diff ../outputs/t1462 ../originals/t1462 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1463) timeout -s 9 2 ../source/replace.exe '*' '5'  < ../inputs/input/ruin.931 > ../outputs/t1463
    if diff ../outputs/t1463 ../originals/t1463 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1464) timeout -s 9 2 ../source/replace.exe '*' '5.'  < ../inputs/input/ruin.1186 > ../outputs/t1464
    if diff ../outputs/t1464 ../originals/t1464 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1465) timeout -s 9 2 ../source/replace.exe '*' '5UQx)=#p,UFSk#_5dkspr'  < ../inputs/input/ruin.449 > ../outputs/t1465
    if diff ../outputs/t1465 ../originals/t1465 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1466) timeout -s 9 2 ../source/replace.exe '*' '5_edflj&5h8_DCEi.gTlx*L#a)htiLD2@W$74Vc.L'  < ../inputs/input/ruin.325 > ../outputs/t1466
    if diff ../outputs/t1466 ../originals/t1466 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1467) timeout -s 9 2 ../source/replace.exe '*' '6'  < ../inputs/input/ruin.554 > ../outputs/t1467
    if diff ../outputs/t1467 ../originals/t1467 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1468) timeout -s 9 2 ../source/replace.exe '*' '7%;n!0;'  < ../inputs/input/ruin.817 > ../outputs/t1468
    if diff ../outputs/t1468 ../originals/t1468 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1469) timeout -s 9 2 ../source/replace.exe '*' '7'  < ../inputs/input/ruin.1442 > ../outputs/t1469
    if diff ../outputs/t1469 ../originals/t1469 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1470) timeout -s 9 2 ../source/replace.exe '*' '7'  < ../inputs/input/ruin.1983 > ../outputs/t1470
    if diff ../outputs/t1470 ../originals/t1470 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1471) timeout -s 9 2 ../source/replace.exe '*' '8'  < ../inputs/input/ruin.1052 > ../outputs/t1471
    if diff ../outputs/t1471 ../originals/t1471 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1472) timeout -s 9 2 ../source/replace.exe '*' '8'  < ../inputs/input/ruin.947 > ../outputs/t1472
    if diff ../outputs/t1472 ../originals/t1472 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1473) timeout -s 9 2 ../source/replace.exe '*' '8pAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7m'  < ../inputs/input/ruin.1052 > ../outputs/t1473
    if diff ../outputs/t1473 ../originals/t1473 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1474) timeout -s 9 2 ../source/replace.exe '*' '9y}x\e/hlao4-J,5Brx*UDmoT |WPY biu:":Vt'\''b?)#uE}Fft%rk;(wUa8r'  < ../inputs/input/ruin.1569 > ../outputs/t1474
    if diff ../outputs/t1474 ../originals/t1474 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1475) timeout -s 9 2 ../source/replace.exe '*' ': 4`?Kz] u"eMDvLqtSl$_5S"|{_5'  < ../inputs/input/ruin.788 > ../outputs/t1475
    if diff ../outputs/t1475 ../originals/t1475 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1476) timeout -s 9 2 ../source/replace.exe '*' ':'  < ../inputs/input/ruin.1308 > ../outputs/t1476
    if diff ../outputs/t1476 ../originals/t1476 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1477) timeout -s 9 2 ../source/replace.exe '*' ':'  < ../inputs/input/ruin.1967 > ../outputs/t1477
    if diff ../outputs/t1477 ../originals/t1477 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1478) timeout -s 9 2 ../source/replace.exe '*' ':'  < ../inputs/input/ruin.905 > ../outputs/t1478
    if diff ../outputs/t1478 ../originals/t1478 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1479) timeout -s 9 2 ../source/replace.exe '*' ':J->WYooGp*:r1[?,ZWzKCBB'  < ../inputs/input/ruin.640 > ../outputs/t1479
    if diff ../outputs/t1479 ../originals/t1479 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1480) timeout -s 9 2 ../source/replace.exe '*' ';<'\''v`iDr8;#lj`gFV{L1E`F>Wn'\''ZeP'\''LY7t6)T'  < ../inputs/input/ruin.1507 > ../outputs/t1480
    if diff ../outputs/t1480 ../originals/t1480 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1481) timeout -s 9 2 ../source/replace.exe '*' ';vzFr_%VsZj81=`|r?_&t6Pcx5x(hTheq0yE75]Z'  < ../inputs/input/ruin.815 > ../outputs/t1481
    if diff ../outputs/t1481 ../originals/t1481 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1482) timeout -s 9 2 ../source/replace.exe '*' '<.!=Ljt]D4[&K:%i/`t%;>'  < ../inputs/input/ruin.758 > ../outputs/t1482
    if diff ../outputs/t1482 ../originals/t1482 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1483) timeout -s 9 2 ../source/replace.exe '*' '<26no'\''uHp_tNoqJ*[!mGwAfC<bg#fVUjsVhF_U_k:[qge8m2A%!'  < ../inputs/input/ruin.1216 > ../outputs/t1483
    if diff ../outputs/t1483 ../originals/t1483 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1484) timeout -s 9 2 ../source/replace.exe '*' '<[IB@lD7)<VIn-|{+ijt<n}oz'\''p0w0!k]U/~],98q&^,HLc9:nJD!S k-gi]}g/m'  < ../inputs/input/ruin.1269 > ../outputs/t1484
    if diff ../outputs/t1484 ../originals/t1484 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1485) timeout -s 9 2 ../source/replace.exe '*' '='  < ../inputs/input/ruin.1162 > ../outputs/t1485
    if diff ../outputs/t1485 ../originals/t1485 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1486) timeout -s 9 2 ../source/replace.exe '*' '='  < ../inputs/input/ruin.1676 > ../outputs/t1486
    if diff ../outputs/t1486 ../originals/t1486 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1487) timeout -s 9 2 ../source/replace.exe '*' '>'  < ../inputs/input/ruin.1417 > ../outputs/t1487
    if diff ../outputs/t1487 ../originals/t1487 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1488) timeout -s 9 2 ../source/replace.exe '*' '>'  < ../inputs/input/ruin.536 > ../outputs/t1488
    if diff ../outputs/t1488 ../originals/t1488 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1489) timeout -s 9 2 ../source/replace.exe '*' '?'  < ../inputs/input/ruin.439 > ../outputs/t1489
    if diff ../outputs/t1489 ../originals/t1489 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1490) timeout -s 9 2 ../source/replace.exe '*' '?1#YUPSP}y'  < ../inputs/input/ruin.810 > ../outputs/t1490
    if diff ../outputs/t1490 ../originals/t1490 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1491) timeout -s 9 2 ../source/replace.exe '*' '?MXR'\''>)$r(Yfiq~ eO66s=VLR;[T'  < ../inputs/input/ruin.1800 > ../outputs/t1491
    if diff ../outputs/t1491 ../originals/t1491 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1492) timeout -s 9 2 ../source/replace.exe '*' '?{+v!^lJqvUd,&s,5{=7vA'  < ../inputs/input/ruin.420 > ../outputs/t1492
    if diff ../outputs/t1492 ../originals/t1492 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1493) timeout -s 9 2 ../source/replace.exe '*' '@'  < ../inputs/input/ruin.1262 > ../outputs/t1493
    if diff ../outputs/t1493 ../originals/t1493 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1494) timeout -s 9 2 ../source/replace.exe '*' '@'  < ../inputs/input/ruin.878 > ../outputs/t1494
    if diff ../outputs/t1494 ../originals/t1494 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1495) timeout -s 9 2 ../source/replace.exe '*' 'A8@$#5>kr^SZP|_Cg|q`l3R].uI*'  < ../inputs/input/ruin.1758 > ../outputs/t1495
    if diff ../outputs/t1495 ../originals/t1495 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1496) timeout -s 9 2 ../source/replace.exe '*' 'Ayxg=po%]]@lhZe,xFP.{F:@m}I)|?,Wlw>ppLMMd[{R'  < ../inputs/input/ruin.512 > ../outputs/t1496
    if diff ../outputs/t1496 ../originals/t1496 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1497) timeout -s 9 2 ../source/replace.exe '*' 'B'  < ../inputs/input/ruin.1219 > ../outputs/t1497
    if diff ../outputs/t1497 ../originals/t1497 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1498) timeout -s 9 2 ../source/replace.exe '*' 'B'  < ../inputs/input/ruin.502 > ../outputs/t1498
    if diff ../outputs/t1498 ../originals/t1498 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1499) timeout -s 9 2 ../source/replace.exe '*' 'BIH%mo6 M)u#WKgz[L!G}2t%[6!AE1C:jV9'  < ../inputs/input/ruin.426 > ../outputs/t1499
    if diff ../outputs/t1499 ../originals/t1499 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1500) timeout -s 9 2 ../source/replace.exe '*' 'C@-U'  < ../inputs/input/ruin.576 > ../outputs/t1500
    if diff ../outputs/t1500 ../originals/t1500 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1501) timeout -s 9 2 ../source/replace.exe '*' 'CkXBvnICbdWao|!`=Pm+@9I5TWu'  < ../inputs/input/ruin.1310 > ../outputs/t1501
    if diff ../outputs/t1501 ../originals/t1501 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1502) timeout -s 9 2 ../source/replace.exe '*' 'D'  < ../inputs/input/ruin.1998 > ../outputs/t1502
    if diff ../outputs/t1502 ../originals/t1502 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1503) timeout -s 9 2 ../source/replace.exe '*' 'D'  < ../inputs/input/ruin.88 > ../outputs/t1503
    if diff ../outputs/t1503 ../originals/t1503 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1504) timeout -s 9 2 ../source/replace.exe '*' 'D>gwriB0<V^6qti|/%?0C)#MA8+AZ&'  < ../inputs/input/ruin.704 > ../outputs/t1504
    if diff ../outputs/t1504 ../originals/t1504 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1505) timeout -s 9 2 ../source/replace.exe '*' 'DVM*w<2(OU&\_HGSyM6o2TxiF3]v37y.opwBH/&y2'\''-V4^vk?H'\''5HuognF[}F&n@V'  < ../inputs/input/ruin.1733 > ../outputs/t1505
    if diff ../outputs/t1505 ../originals/t1505 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1506) timeout -s 9 2 ../source/replace.exe '*' 'EzQo'\''9xwbhkZ:|Y)F,jmC}rWN$1^*3AXp\yo:rrvFH#UO#7$>_0ibL;x)G=@uxqR=0o|dZD|zN):dC'  < ../inputs/input/ruin.1910 > ../outputs/t1506
    if diff ../outputs/t1506 ../originals/t1506 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1507) timeout -s 9 2 ../source/replace.exe '*' 'F- 5tmxsbhUa<v*Mh)mZ{*^\$!10qKy6k>5S [5tI04mu&{.bpKg?g%,UdYLMhG&]z'  < ../inputs/input/ruin.976 > ../outputs/t1507
    if diff ../outputs/t1507 ../originals/t1507 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1508) timeout -s 9 2 ../source/replace.exe '*' 'GvQA5d6`7{`G3X{D9:+:'\''4^ZW$MP%0GpyOHhdXF+\dDLkTp'  < ../inputs/input/ruin.899 > ../outputs/t1508
    if diff ../outputs/t1508 ../originals/t1508 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1509) timeout -s 9 2 ../source/replace.exe '*' 'H'  < ../inputs/input/ruin.1945 > ../outputs/t1509
    if diff ../outputs/t1509 ../originals/t1509 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1510) timeout -s 9 2 ../source/replace.exe '*' 'H'  < ../inputs/input/ruin.485 > ../outputs/t1510
    if diff ../outputs/t1510 ../originals/t1510 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1511) timeout -s 9 2 ../source/replace.exe '*' 'H4{}`[,(g4eKdkV-$X;D32HgE %[Qrg"nm&,iYO"EGYFqntnujmPVm<T=X'  < ../inputs/input/ruin.75 > ../outputs/t1511
    if diff ../outputs/t1511 ../originals/t1511 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1512) timeout -s 9 2 ../source/replace.exe '*' 'H4{}`[,(g4eKdkV-$X;D32HgE %[Qrg"nm&,iYO"EGYFqntnujmPVm<T=X[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n[Z-a]^_`a]*@n'  < ../inputs/input/ruin.75 > ../outputs/t1512
    if diff ../outputs/t1512 ../originals/t1512 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1513) timeout -s 9 2 ../source/replace.exe '*' 'H5d'  < ../inputs/input/ruin.1452 > ../outputs/t1513
    if diff ../outputs/t1513 ../originals/t1513 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1514) timeout -s 9 2 ../source/replace.exe '*' 'Hg:(OEg%`74JT=z=z'\''MGGx7ocG$N'  < ../inputs/input/ruin.752 > ../outputs/t1514
    if diff ../outputs/t1514 ../originals/t1514 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1515) timeout -s 9 2 ../source/replace.exe '*' 'I&i'\'''  < ../inputs/input/ruin.1404 > ../outputs/t1515
    if diff ../outputs/t1515 ../originals/t1515 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1516) timeout -s 9 2 ../source/replace.exe '*' 'I'  < ../inputs/input/ruin.1727 > ../outputs/t1516
    if diff ../outputs/t1516 ../originals/t1516 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1517) timeout -s 9 2 ../source/replace.exe '*' 'J'  < ../inputs/input/ruin.357 > ../outputs/t1517
    if diff ../outputs/t1517 ../originals/t1517 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1518) timeout -s 9 2 ../source/replace.exe '*' 'J'  < ../inputs/input/ruin.742 > ../outputs/t1518
    if diff ../outputs/t1518 ../originals/t1518 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1519) timeout -s 9 2 ../source/replace.exe '*' 'J;!rYgPGr|p,NR53Q55E`:ERqiKWg,iCq3t!'  < ../inputs/input/ruin.398 > ../outputs/t1519
    if diff ../outputs/t1519 ../originals/t1519 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1520) timeout -s 9 2 ../source/replace.exe '*' 'JG,;t-g_\pm0Y:}<mw$;B@%pVy"`g7Y[C2m(SpRFcb|w'  < ../inputs/input/ruin.118 > ../outputs/t1520
    if diff ../outputs/t1520 ../originals/t1520 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1521) timeout -s 9 2 ../source/replace.exe '*' 'L'  < ../inputs/input/ruin.1987 > ../outputs/t1521
    if diff ../outputs/t1521 ../originals/t1521 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1522) timeout -s 9 2 ../source/replace.exe '*' 'L'  < ../inputs/input/ruin.274 > ../outputs/t1522
    if diff ../outputs/t1522 ../originals/t1522 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1523) timeout -s 9 2 ../source/replace.exe '*' 'LPChM#M/":OzI UXX_Jv'\''7]M!CB'  < ../inputs/input/ruin.1521 > ../outputs/t1523
    if diff ../outputs/t1523 ../originals/t1523 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1524) timeout -s 9 2 ../source/replace.exe '*' 'LRg'  < ../inputs/input/ruin.1960 > ../outputs/t1524
    if diff ../outputs/t1524 ../originals/t1524 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1525) timeout -s 9 2 ../source/replace.exe '*' 'M'  < ../inputs/input/ruin.1185 > ../outputs/t1525
    if diff ../outputs/t1525 ../originals/t1525 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1526) timeout -s 9 2 ../source/replace.exe '*' 'M'  < ../inputs/input/ruin.636 > ../outputs/t1526
    if diff ../outputs/t1526 ../originals/t1526 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1527) timeout -s 9 2 ../source/replace.exe '*' 'M'  < ../inputs/input/ruin.645 > ../outputs/t1527
    if diff ../outputs/t1527 ../originals/t1527 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1528) timeout -s 9 2 ../source/replace.exe '*' 'M'  < ../inputs/input/ruin.825 > ../outputs/t1528
    if diff ../outputs/t1528 ../originals/t1528 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1529) timeout -s 9 2 ../source/replace.exe '*' 'MPKwD.47](#W/L3Yj'  < ../inputs/input/ruin.286 > ../outputs/t1529
    if diff ../outputs/t1529 ../originals/t1529 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1530) timeout -s 9 2 ../source/replace.exe '*' 'MXM`j+WFd5g=e}7'  < ../inputs/input/ruin.411 > ../outputs/t1530
    if diff ../outputs/t1530 ../originals/t1530 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1531) timeout -s 9 2 ../source/replace.exe '*' 'N'  < ../inputs/input/ruin.1737 > ../outputs/t1531
    if diff ../outputs/t1531 ../originals/t1531 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1532) timeout -s 9 2 ../source/replace.exe '*' 'N'  < ../inputs/input/ruin.1954 > ../outputs/t1532
    if diff ../outputs/t1532 ../originals/t1532 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1533) timeout -s 9 2 ../source/replace.exe '*' 'N'  < ../inputs/input/ruin.401 > ../outputs/t1533
    if diff ../outputs/t1533 ../originals/t1533 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1534) timeout -s 9 2 ../source/replace.exe '*' 'NgjG8_`kVg5[D5RE6nU5#"1'  < ../inputs/input/ruin.350 > ../outputs/t1534
    if diff ../outputs/t1534 ../originals/t1534 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1535) timeout -s 9 2 ../source/replace.exe '*' 'O'  < ../inputs/input/ruin.229 > ../outputs/t1535
    if diff ../outputs/t1535 ../originals/t1535 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1536) timeout -s 9 2 ../source/replace.exe '*' 'P'  < ../inputs/input/ruin.841 > ../outputs/t1536
    if diff ../outputs/t1536 ../originals/t1536 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1537) timeout -s 9 2 ../source/replace.exe '*' 'P54;@=_4xdN:$7^We'  < ../inputs/input/ruin.1620 > ../outputs/t1537
    if diff ../outputs/t1537 ../originals/t1537 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1538) timeout -s 9 2 ../source/replace.exe '*' 'P\ea4(T~AiIC=5Aj'\''`~lPq'  < ../inputs/input/ruin.1446 > ../outputs/t1538
    if diff ../outputs/t1538 ../originals/t1538 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1539) timeout -s 9 2 ../source/replace.exe '*' 'Pd?g(>Fc8M$8'  < ../inputs/input/ruin.435 > ../outputs/t1539
    if diff ../outputs/t1539 ../originals/t1539 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1540) timeout -s 9 2 ../source/replace.exe '*' 'Pq6$0Uv>*<O%B7'  < ../inputs/input/ruin.588 > ../outputs/t1540
    if diff ../outputs/t1540 ../originals/t1540 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1541) timeout -s 9 2 ../source/replace.exe '*' 'Q?]'  < ../inputs/input/ruin.1864 > ../outputs/t1541
    if diff ../outputs/t1541 ../originals/t1541 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1542) timeout -s 9 2 ../source/replace.exe '*' 'QCW =vT/1H-P(;wWsdk8,N.{|a <'  < ../inputs/input/ruin.473 > ../outputs/t1542
    if diff ../outputs/t1542 ../originals/t1542 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1543) timeout -s 9 2 ../source/replace.exe '*' 'QNaHbxy4*gJ7qH&xy:k#(fN84]]raEtv9Q}'  < ../inputs/input/ruin.418 > ../outputs/t1543
    if diff ../outputs/t1543 ../originals/t1543 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1544) timeout -s 9 2 ../source/replace.exe '*' 'R'  < ../inputs/input/ruin.1631 > ../outputs/t1544
    if diff ../outputs/t1544 ../originals/t1544 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1545) timeout -s 9 2 ../source/replace.exe '*' 'R'  < ../inputs/input/ruin.299 > ../outputs/t1545
    if diff ../outputs/t1545 ../originals/t1545 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1546) timeout -s 9 2 ../source/replace.exe '*' 'S'  < ../inputs/input/ruin.1398 > ../outputs/t1546
    if diff ../outputs/t1546 ../originals/t1546 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1547) timeout -s 9 2 ../source/replace.exe '*' 'Sm'  < ../inputs/input/ruin.60 > ../outputs/t1547
    if diff ../outputs/t1547 ../originals/t1547 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1548) timeout -s 9 2 ../source/replace.exe '*' 'T6PKI@&0O#B1Lh^{h]k6b|.%dFTDX2_5Hk{?}iSqsk"BO)2*{p{K<y$&)'\'''  < ../inputs/input/ruin.749 > ../outputs/t1548
    if diff ../outputs/t1548 ../originals/t1548 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1549) timeout -s 9 2 ../source/replace.exe '*' 'UE'\''%ko!Oi)bgbC-$;2(E\Z>n'  < ../inputs/input/ruin.1365 > ../outputs/t1549
    if diff ../outputs/t1549 ../originals/t1549 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1550) timeout -s 9 2 ../source/replace.exe '*' 'V'  < ../inputs/input/ruin.888 > ../outputs/t1550
    if diff ../outputs/t1550 ../originals/t1550 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1551) timeout -s 9 2 ../source/replace.exe '*' 'VLS~rJO,!qeNNS`W"Lej?|^?u*ao2Cc\oAXv3BifHHbA.'  < ../inputs/input/ruin.592 > ../outputs/t1551
    if diff ../outputs/t1551 ../originals/t1551 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1552) timeout -s 9 2 ../source/replace.exe '*' 'W[Ckn0Vg.DBF0Pcjo#(vLE}v?9^%([{x6'  < ../inputs/input/ruin.1126 > ../outputs/t1552
    if diff ../outputs/t1552 ../originals/t1552 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1553) timeout -s 9 2 ../source/replace.exe '*' 'X'  < ../inputs/input/ruin.765 > ../outputs/t1553
    if diff ../outputs/t1553 ../originals/t1553 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1554) timeout -s 9 2 ../source/replace.exe '*' 'Y'  < ../inputs/input/ruin.1136 > ../outputs/t1554
    if diff ../outputs/t1554 ../originals/t1554 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1555) timeout -s 9 2 ../source/replace.exe '*' 'Y'  < ../inputs/input/ruin.1902 > ../outputs/t1555
    if diff ../outputs/t1555 ../originals/t1555 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1556) timeout -s 9 2 ../source/replace.exe '*' 'Yv*l,JBe9^%Hb^*^GD pqO~_{'  < ../inputs/input/ruin.932 > ../outputs/t1556
    if diff ../outputs/t1556 ../originals/t1556 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1557) timeout -s 9 2 ../source/replace.exe '*' '['  < ../inputs/input/ruin.1312 > ../outputs/t1557
    if diff ../outputs/t1557 ../originals/t1557 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1558) timeout -s 9 2 ../source/replace.exe '*' '['  < ../inputs/input/ruin.611 > ../outputs/t1558
    if diff ../outputs/t1558 ../originals/t1558 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1559) timeout -s 9 2 ../source/replace.exe '*' '\'  < ../inputs/input/ruin.623 > ../outputs/t1559
    if diff ../outputs/t1559 ../originals/t1559 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1560) timeout -s 9 2 ../source/replace.exe '*' '\IA>XW?'\''N,gjA$j)'  < ../inputs/input/ruin.735 > ../outputs/t1560
    if diff ../outputs/t1560 ../originals/t1560 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1561) timeout -s 9 2 ../source/replace.exe '*' ']'  < ../inputs/input/ruin.858 > ../outputs/t1561
    if diff ../outputs/t1561 ../originals/t1561 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1562) timeout -s 9 2 ../source/replace.exe '*' ']nh3$maLj{=]f`6K5>fdDES`#&1Z*mW?lp{'  < ../inputs/input/ruin.1914 > ../outputs/t1562
    if diff ../outputs/t1562 ../originals/t1562 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1563) timeout -s 9 2 ../source/replace.exe '*' '^5i w+3P~!nu. d<Gv%'  < ../inputs/input/ruin.580 > ../outputs/t1563
    if diff ../outputs/t1563 ../originals/t1563 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1564) timeout -s 9 2 ../source/replace.exe '*' '_ZWn.!dHH9c^%X"vFT<2: '\''-YSnDcUFe%XPj"H8HfAhTvkxw'\''m'  < ../inputs/input/ruin.811 > ../outputs/t1564
    if diff ../outputs/t1564 ../originals/t1564 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1565) timeout -s 9 2 ../source/replace.exe '*' '`'  < ../inputs/input/ruin.138 > ../outputs/t1565
    if diff ../outputs/t1565 ../originals/t1565 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1566) timeout -s 9 2 ../source/replace.exe '*' '`bhi>$;X'  < ../inputs/input/ruin.1632 > ../outputs/t1566
    if diff ../outputs/t1566 ../originals/t1566 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1567) timeout -s 9 2 ../source/replace.exe '*' '`~lB<%:Nz?4&h442N'  < ../inputs/input/ruin.1486 > ../outputs/t1567
    if diff ../outputs/t1567 ../originals/t1567 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1568) timeout -s 9 2 ../source/replace.exe '*' 'a33iv(a|>Z(Ol1~oyl9@+q /1T,&KV%PJ@}]Jo?2BuXAg'  < ../inputs/input/ruin.1396 > ../outputs/t1568
    if diff ../outputs/t1568 ../originals/t1568 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1569) timeout -s 9 2 ../source/replace.exe '*' 'aE7jUPO'\''dYm{VX"Mit;I#WmSAh}7LXL4dYC8WM|1SUzIC^=xTXQ*Ewea'  < ../inputs/input/ruin.607 > ../outputs/t1569
    if diff ../outputs/t1569 ../originals/t1569 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1570) timeout -s 9 2 ../source/replace.exe '*' 'b$M]}'  < ../inputs/input/ruin.1334 > ../outputs/t1570
    if diff ../outputs/t1570 ../originals/t1570 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1571) timeout -s 9 2 ../source/replace.exe '*' 'b$MbJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<]}*[0-9]*[a-z]'  < ../inputs/input/ruin.1334 > ../outputs/t1571
    if diff ../outputs/t1571 ../originals/t1571 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1572) timeout -s 9 2 ../source/replace.exe '*' 'b'  < ../inputs/input/ruin.1926 > ../outputs/t1572
    if diff ../outputs/t1572 ../originals/t1572 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1573) timeout -s 9 2 ../source/replace.exe '*' 'b'  < ../inputs/input/ruin.289 > ../outputs/t1573
    if diff ../outputs/t1573 ../originals/t1573 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1574) timeout -s 9 2 ../source/replace.exe '*' 'b'  < ../inputs/input/ruin.396 > ../outputs/t1574
    if diff ../outputs/t1574 ../originals/t1574 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1575) timeout -s 9 2 ../source/replace.exe '*' 'b.j<'  < ../inputs/input/ruin.340 > ../outputs/t1575
    if diff ../outputs/t1575 ../originals/t1575 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1576) timeout -s 9 2 ../source/replace.exe '*' 'bLE@:(bDn~LPO3(w6HCZ[@47udWt,'\''-r\CT]_(9~('  < ../inputs/input/ruin.1231 > ../outputs/t1576
    if diff ../outputs/t1576 ../originals/t1576 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1577) timeout -s 9 2 ../source/replace.exe '*' 'bfA]{~U1GD+4 nhtf,jNx+DWX{d'  < ../inputs/input/ruin.447 > ../outputs/t1577
    if diff ../outputs/t1577 ../originals/t1577 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1578) timeout -s 9 2 ../source/replace.exe '*' 'cg'  < ../inputs/input/ruin.1013 > ../outputs/t1578
    if diff ../outputs/t1578 ../originals/t1578 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1579) timeout -s 9 2 ../source/replace.exe '*' 'cw!~'\''*5>*Nk]<ECo#CO,4"\7^74-'  < ../inputs/input/ruin.306 > ../outputs/t1579
    if diff ../outputs/t1579 ../originals/t1579 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1580) timeout -s 9 2 ../source/replace.exe '*' 'dfn~zcSQ=]etkUCr'  < ../inputs/input/ruin.1915 > ../outputs/t1580
    if diff ../outputs/t1580 ../originals/t1580 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1581) timeout -s 9 2 ../source/replace.exe '*' 'eT)'  < ../inputs/input/ruin.794 > ../outputs/t1581
    if diff ../outputs/t1581 ../originals/t1581 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1582) timeout -s 9 2 ../source/replace.exe '*' 'f'  < ../inputs/input/ruin.1108 > ../outputs/t1582
    if diff ../outputs/t1582 ../originals/t1582 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1583) timeout -s 9 2 ../source/replace.exe '*' 'f4'  < ../inputs/input/ruin.1785 > ../outputs/t1583
    if diff ../outputs/t1583 ../originals/t1583 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1584) timeout -s 9 2 ../source/replace.exe '*' 'fz8_]H+3t\.]f'  < ../inputs/input/ruin.697 > ../outputs/t1584
    if diff ../outputs/t1584 ../originals/t1584 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1585) timeout -s 9 2 ../source/replace.exe '*' 'h.4IrxEv=BU'\'')d0,04S7*xFvN//5VOKA('  < ../inputs/input/ruin.1498 > ../outputs/t1585
    if diff ../outputs/t1585 ../originals/t1585 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1586) timeout -s 9 2 ../source/replace.exe '*' 'h.TSi}6|%YSU&8M.i|jIUqv!h'  < ../inputs/input/ruin.1100 > ../outputs/t1586
    if diff ../outputs/t1586 ../originals/t1586 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1587) timeout -s 9 2 ../source/replace.exe '*' 'i'  < ../inputs/input/ruin.1587 > ../outputs/t1587
    if diff ../outputs/t1587 ../originals/t1587 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1588) timeout -s 9 2 ../source/replace.exe '*' 'jVtxSiz~whG5Bsg$Yy*S]e*_ g)vm"MOL..JBLrCfn.gL,_!El'  < ../inputs/input/ruin.1098 > ../outputs/t1588
    if diff ../outputs/t1588 ../originals/t1588 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1589) timeout -s 9 2 ../source/replace.exe '*' 'j^b+ EL'\''jFvDb.4t'\''C]yiF`GoLQ=kEowbH"jNZOe o3*L,>2`eNn0'  < ../inputs/input/ruin.317 > ../outputs/t1589
    if diff ../outputs/t1589 ../originals/t1589 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1590) timeout -s 9 2 ../source/replace.exe '*' 'k +/-CZfd?F4d8]ILL9J['  < ../inputs/input/ruin.1472 > ../outputs/t1590
    if diff ../outputs/t1590 ../originals/t1590 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1591) timeout -s 9 2 ../source/replace.exe '*' 'k'  < ../inputs/input/ruin.493 > ../outputs/t1591
    if diff ../outputs/t1591 ../originals/t1591 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1592) timeout -s 9 2 ../source/replace.exe '*' 'kL'  < ../inputs/input/ruin.563 > ../outputs/t1592
    if diff ../outputs/t1592 ../originals/t1592 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1593) timeout -s 9 2 ../source/replace.exe '*' 'kw'  < ../inputs/input/ruin.1696 > ../outputs/t1593
    if diff ../outputs/t1593 ../originals/t1593 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1594) timeout -s 9 2 ../source/replace.exe '*' 'l'  < ../inputs/input/ruin.1251 > ../outputs/t1594
    if diff ../outputs/t1594 ../originals/t1594 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1595) timeout -s 9 2 ../source/replace.exe '*' 'le8z7y>M>6ay71HYppSuKQ5\kn*fc:XX;T+3SL#jB&[q,BTV8o'  < ../inputs/input/ruin.702 > ../outputs/t1595
    if diff ../outputs/t1595 ../originals/t1595 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1596) timeout -s 9 2 ../source/replace.exe '*' 'm'  < ../inputs/input/ruin.1015 > ../outputs/t1596
    if diff ../outputs/t1596 ../originals/t1596 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1597) timeout -s 9 2 ../source/replace.exe '*' 'mx0sD,3u'\''aUVn)!`w;[(,]ua'  < ../inputs/input/ruin.481 > ../outputs/t1597
    if diff ../outputs/t1597 ../originals/t1597 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1598) timeout -s 9 2 ../source/replace.exe '*' 'n"7<:4 FFMm)2fT'\''@KR!ni>(k,g'  < ../inputs/input/ruin.638 > ../outputs/t1598
    if diff ../outputs/t1598 ../originals/t1598 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1599) timeout -s 9 2 ../source/replace.exe '*' 'nDf38_|G_<?#50:)+jM'  < ../inputs/input/ruin.1242 > ../outputs/t1599
    if diff ../outputs/t1599 ../originals/t1599 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1600) timeout -s 9 2 ../source/replace.exe '*' 'o'  < ../inputs/input/ruin.1069 > ../outputs/t1600
    if diff ../outputs/t1600 ../originals/t1600 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1601) timeout -s 9 2 ../source/replace.exe '*' 'o'  < ../inputs/input/ruin.67 > ../outputs/t1601
    if diff ../outputs/t1601 ../originals/t1601 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1602) timeout -s 9 2 ../source/replace.exe '*' 'o.[m&W'\''8`'  < ../inputs/input/ruin.1458 > ../outputs/t1602
    if diff ../outputs/t1602 ../originals/t1602 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1603) timeout -s 9 2 ../source/replace.exe '*' 'o`'  < ../inputs/input/ruin.561 > ../outputs/t1603
    if diff ../outputs/t1603 ../originals/t1603 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1604) timeout -s 9 2 ../source/replace.exe '*' 'ofUr<QH^?2i;bS"E?b7eFTRXE\s<)S"0v>7v\N,z@3+^T4X'  < ../inputs/input/ruin.1783 > ../outputs/t1604
    if diff ../outputs/t1604 ../originals/t1604 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1605) timeout -s 9 2 ../source/replace.exe '*' 'p'  < ../inputs/input/ruin.900 > ../outputs/t1605
    if diff ../outputs/t1605 ../originals/t1605 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1606) timeout -s 9 2 ../source/replace.exe '*' 'p7vM1c-~m$]<e#{^ 62"j[IyS@N2dV5Hecaiot%1'  < ../inputs/input/ruin.1072 > ../outputs/t1606
    if diff ../outputs/t1606 ../originals/t1606 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1607) timeout -s 9 2 ../source/replace.exe '*' 'pGZzvW$G(JB1Y]5.>I/9<"@rfHP'  < ../inputs/input/ruin.1326 > ../outputs/t1607
    if diff ../outputs/t1607 ../originals/t1607 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1608) timeout -s 9 2 ../source/replace.exe '*' 'q'  < ../inputs/input/ruin.1298 > ../outputs/t1608
    if diff ../outputs/t1608 ../originals/t1608 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1609) timeout -s 9 2 ../source/replace.exe '*' 'q'  < ../inputs/input/ruin.1932 > ../outputs/t1609
    if diff ../outputs/t1609 ../originals/t1609 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1610) timeout -s 9 2 ../source/replace.exe '*' 'q;E%){t-m!*a!rdD+2u,A0&_l'  < ../inputs/input/ruin.1709 > ../outputs/t1610
    if diff ../outputs/t1610 ../originals/t1610 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1611) timeout -s 9 2 ../source/replace.exe '*' 'r"'  < ../inputs/input/ruin.1393 > ../outputs/t1611
    if diff ../outputs/t1611 ../originals/t1611 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1612) timeout -s 9 2 ../source/replace.exe '*' 'r'  < ../inputs/input/ruin.648 > ../outputs/t1612
    if diff ../outputs/t1612 ../originals/t1612 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1613) timeout -s 9 2 ../source/replace.exe '*' 'r5fa/J@lY+PAM.8bQT#kQ/%L*##X3vqVARWNU_@.lDfO+1Y1h1G)/cedT7J![!7@g@"?+*5\k{6i={'  < ../inputs/input/ruin.1791 > ../outputs/t1613
    if diff ../outputs/t1613 ../originals/t1613 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1614) timeout -s 9 2 ../source/replace.exe '*' 's'  < ../inputs/input/ruin.1627 > ../outputs/t1614
    if diff ../outputs/t1614 ../originals/t1614 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1615) timeout -s 9 2 ../source/replace.exe '*' 't[WFHbt0G| J*7:o?A,)&7:~TI#z1{ga'\''Z>FLu'\''pYw>]=kZG^O=8I86z+V6H}d\HLd%]^{P(16(+L<)1J'  < ../inputs/input/ruin.119 > ../outputs/t1615
    if diff ../outputs/t1615 ../originals/t1615 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1616) timeout -s 9 2 ../source/replace.exe '*' 't{'  < ../inputs/input/ruin.1815 > ../outputs/t1616
    if diff ../outputs/t1616 ../originals/t1616 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1617) timeout -s 9 2 ../source/replace.exe '*' 'u'  < ../inputs/input/ruin.392 > ../outputs/t1617
    if diff ../outputs/t1617 ../originals/t1617 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1618) timeout -s 9 2 ../source/replace.exe '*' 'u'  < ../inputs/input/ruin.406 > ../outputs/t1618
    if diff ../outputs/t1618 ../originals/t1618 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1619) timeout -s 9 2 ../source/replace.exe '*' 'vB|CqDQNo,Fg|RTv5;bkJFE.twyj39J13'\''TcKY1sb&G<g]|ZaPL`0=8`YdR,'  < ../inputs/input/ruin.1614 > ../outputs/t1619
    if diff ../outputs/t1619 ../originals/t1619 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1620) timeout -s 9 2 ../source/replace.exe '*' 'vDu6FZh%!TOgp@!'\''b}>.}c^?R-'  < ../inputs/input/ruin.934 > ../outputs/t1620
    if diff ../outputs/t1620 ../originals/t1620 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1621) timeout -s 9 2 ../source/replace.exe '*' 'vV{&u2QCx+'  < ../inputs/input/ruin.1911 > ../outputs/t1621
    if diff ../outputs/t1621 ../originals/t1621 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1622) timeout -s 9 2 ../source/replace.exe '*' 'w'  < ../inputs/input/ruin.1610 > ../outputs/t1622
    if diff ../outputs/t1622 ../originals/t1622 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1623) timeout -s 9 2 ../source/replace.exe '*' 'w.h:AS*N<PuJ'\''%,%YHyLui~e5i"jjK@cNS; :R,W'  < ../inputs/input/ruin.462 > ../outputs/t1623
    if diff ../outputs/t1623 ../originals/t1623 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1624) timeout -s 9 2 ../source/replace.exe '*' 'x'  < ../inputs/input/ruin.1591 > ../outputs/t1624
    if diff ../outputs/t1624 ../originals/t1624 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1625) timeout -s 9 2 ../source/replace.exe '*' 'x+Q;z@RN/2%ew9=boU'\''N5^^>GYbLS:u^`|hk.y4+RSYe'  < ../inputs/input/ruin.1140 > ../outputs/t1625
    if diff ../outputs/t1625 ../originals/t1625 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1626) timeout -s 9 2 ../source/replace.exe '*' 'xv'\''%;99C.L6GYG|5'\''B4JA{:,!;i0:/n+[q}2g+Q+T[#; `w&%3:]~,5M]m.'  < ../inputs/input/ruin.1118 > ../outputs/t1626
    if diff ../outputs/t1626 ../originals/t1626 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1627) timeout -s 9 2 ../source/replace.exe '*' 'y!~#e7LEp?9]*iTkr1HrHG0Zu}RTi[q'  < ../inputs/input/ruin.531 > ../outputs/t1627
    if diff ../outputs/t1627 ../originals/t1627 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1628) timeout -s 9 2 ../source/replace.exe '*' 'y'  < ../inputs/input/ruin.1962 > ../outputs/t1628
    if diff ../outputs/t1628 ../originals/t1628 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1629) timeout -s 9 2 ../source/replace.exe '*' 'yEyj6*dR|$%NuXL^E`WEDg^@cc^?"+?a^?/x#'  < ../inputs/input/ruin.393 > ../outputs/t1629
    if diff ../outputs/t1629 ../originals/t1629 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1630) timeout -s 9 2 ../source/replace.exe '*' 'yJ!rEL|Xd02,<c X[+fSSek&#=SQ%VOTJY}T) H'  < ../inputs/input/ruin.741 > ../outputs/t1630
    if diff ../outputs/t1630 ../originals/t1630 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1631) timeout -s 9 2 ../source/replace.exe '*' '{'  < ../inputs/input/ruin.1403 > ../outputs/t1631
    if diff ../outputs/t1631 ../originals/t1631 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1632) timeout -s 9 2 ../source/replace.exe '*' '{q+631T.^ oN4+;vL0W[1Rcn%`iyF7Xs71[ l"lp'  < ../inputs/input/ruin.1780 > ../outputs/t1632
    if diff ../outputs/t1632 ../originals/t1632 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1633) timeout -s 9 2 ../source/replace.exe '*' '{zSL3h[z%C\T6 L?'  < ../inputs/input/ruin.372 > ../outputs/t1633
    if diff ../outputs/t1633 ../originals/t1633 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1634) timeout -s 9 2 ../source/replace.exe '*' '|GZy1Ki'\''I'  < ../inputs/input/ruin.1360 > ../outputs/t1634
    if diff ../outputs/t1634 ../originals/t1634 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1635) timeout -s 9 2 ../source/replace.exe '*' '|O'  < ../inputs/input/ruin.766 > ../outputs/t1635
    if diff ../outputs/t1635 ../originals/t1635 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1636) timeout -s 9 2 ../source/replace.exe '*' '|m{'  < ../inputs/input/ruin.335 > ../outputs/t1636
    if diff ../outputs/t1636 ../originals/t1636 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1637) timeout -s 9 2 ../source/replace.exe '*' '|zYQ /?~i1Ja\,"BRs(Y)-'\''Q3-)FlvxFPXZ/SuIC'\'''  < ../inputs/input/ruin.987 > ../outputs/t1637
    if diff ../outputs/t1637 ../originals/t1637 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1638) timeout -s 9 2 ../source/replace.exe '*' '}  = M3kL`Z&XdB~=2f6(qC%NFD1yTO_Zn}'  < ../inputs/input/ruin.330 > ../outputs/t1638
    if diff ../outputs/t1638 ../originals/t1638 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1639) timeout -s 9 2 ../source/replace.exe '*' '}'  < ../inputs/input/ruin.105 > ../outputs/t1639
    if diff ../outputs/t1639 ../originals/t1639 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1640) timeout -s 9 2 ../source/replace.exe '*' '}k]s&Qlf:sCd-<z'\''8oc,P~Jty8k'\''CS'\''WE'  < ../inputs/input/ruin.136 > ../outputs/t1640
    if diff ../outputs/t1640 ../originals/t1640 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1641) timeout -s 9 2 ../source/replace.exe '*'  < ../inputs/input/ruin.1262 > ../outputs/t1641
    if diff ../outputs/t1641 ../originals/t1641 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1642) timeout -s 9 2 ../source/replace.exe '*'\''' '&'  < ../inputs/input/ruin.1172 > ../outputs/t1642
    if diff ../outputs/t1642 ../originals/t1642 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1643) timeout -s 9 2 ../source/replace.exe '*'\''-(je' 'GZ7c.-_;Miyl1L5/A'  < ../inputs/input/ruin.1955 > ../outputs/t1643
    if diff ../outputs/t1643 ../originals/t1643 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1644) timeout -s 9 2 ../source/replace.exe '*'\''[^H]' ':Q|SA%e$'  < ../inputs/input/ruin.74 > ../outputs/t1644
    if diff ../outputs/t1644 ../originals/t1644 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1645) timeout -s 9 2 ../source/replace.exe '**' '8/r]'  < ../inputs/input/ruin.574 > ../outputs/t1645
    if diff ../outputs/t1645 ../originals/t1645 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1646) timeout -s 9 2 ../source/replace.exe '**' '`'  < ../inputs/input/ruin.1249 > ../outputs/t1646
    if diff ../outputs/t1646 ../originals/t1646 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1647) timeout -s 9 2 ../source/replace.exe '**' 'i'  < ../inputs/input/ruin.753 > ../outputs/t1647
    if diff ../outputs/t1647 ../originals/t1647 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1648) timeout -s 9 2 ../source/replace.exe '**@@' '&,K6#M4J k\$ta='  < ../inputs/input/ruin.95 > ../outputs/t1648
    if diff ../outputs/t1648 ../originals/t1648 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1649) timeout -s 9 2 ../source/replace.exe '**[>-A]' 'O'  < ../inputs/input/ruin.1623 > ../outputs/t1649
    if diff ../outputs/t1649 ../originals/t1649 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1650) timeout -s 9 2 ../source/replace.exe '*-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?' ','  < ../inputs/input/ruin.1353 > ../outputs/t1650
    if diff ../outputs/t1650 ../originals/t1650 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1651) timeout -s 9 2 ../source/replace.exe '*-?'   < ../inputs/temp-test/207.inp.93.1 > ../outputs/t1651
    if diff ../outputs/t1651 ../originals/t1651 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1652) timeout -s 9 2 ../source/replace.exe '*-?'   < ../inputs/temp-test/208.inp.93.2 > ../outputs/t1652
    if diff ../outputs/t1652 ../originals/t1652 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1653) timeout -s 9 2 ../source/replace.exe '*-?'   < ../inputs/temp-test/209.inp.93.3 > ../outputs/t1653
    if diff ../outputs/t1653 ../originals/t1653 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1654) timeout -s 9 2 ../source/replace.exe '*-?' '&@n'  < ../inputs/temp-test/207.inp.93.1 > ../outputs/t1654
    if diff ../outputs/t1654 ../originals/t1654 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1655) timeout -s 9 2 ../source/replace.exe '*-?' '&@n'  < ../inputs/temp-test/208.inp.93.2 > ../outputs/t1655
    if diff ../outputs/t1655 ../originals/t1655 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1656) timeout -s 9 2 ../source/replace.exe '*-?' '&@n'  < ../inputs/temp-test/209.inp.93.3 > ../outputs/t1656
    if diff ../outputs/t1656 ../originals/t1656 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1657) timeout -s 9 2 ../source/replace.exe '*-?[a-c$'   < ../inputs/temp-test/210.inp.93.8 > ../outputs/t1657
    if diff ../outputs/t1657 ../originals/t1657 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1658) timeout -s 9 2 ../source/replace.exe '*-?[a-c$' '&@n'  < ../inputs/temp-test/210.inp.93.8 > ../outputs/t1658
    if diff ../outputs/t1658 ../originals/t1658 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1659) timeout -s 9 2 ../source/replace.exe '*.[Z-a]^_`a-A-GABCDEFG]@n$' '-[&b0:'  < ../inputs/input/ruin.1020 > ../outputs/t1659
    if diff ../outputs/t1659 ../originals/t1659 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1660) timeout -s 9 2 ../source/replace.exe '*.[Z-a]^_`a-A-GABCDEFG]@n$' '-[lu!8lH<2'\''b0:'  < ../inputs/input/ruin.1020 > ../outputs/t1660
    if diff ../outputs/t1660 ../originals/t1660 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1661) timeout -s 9 2 ../source/replace.exe '*7' 'jk$'  < ../inputs/input/ruin.1097 > ../outputs/t1661
    if diff ../outputs/t1661 ../originals/t1661 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1662) timeout -s 9 2 ../source/replace.exe '*?' '#g]ogwHzVu~98e-+FO:{#H5(\{z };KGj5$(z.sX>"u|rv\hwX==$UZh9dSAi+s)*Fw'\''X4*c"J79];P`~rB+*#w%'  < ../inputs/input/ruin.504 > ../outputs/t1662
    if diff ../outputs/t1662 ../originals/t1662 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1663) timeout -s 9 2 ../source/replace.exe '*?' '3g3t=6w'  < ../inputs/input/ruin.163 > ../outputs/t1663
    if diff ../outputs/t1663 ../originals/t1663 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1664) timeout -s 9 2 ../source/replace.exe '*?' 'D'  < ../inputs/input/ruin.782 > ../outputs/t1664
    if diff ../outputs/t1664 ../originals/t1664 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1665) timeout -s 9 2 ../source/replace.exe '*?' 'g*#'  < ../inputs/input/ruin.1869 > ../outputs/t1665
    if diff ../outputs/t1665 ../originals/t1665 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1666) timeout -s 9 2 ../source/replace.exe '*?' 'xkg>el^/j)zWM:uoVRpav3_7LA'\''&o*+G93N^8Po?-z)C+X]XaA\)cgK/=m`AQ-r!+4Drf51/,]+;?Qed>'  < ../inputs/input/ruin.451 > ../outputs/t1666
    if diff ../outputs/t1666 ../originals/t1666 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1667) timeout -s 9 2 ../source/replace.exe '*?*' '/'  < ../inputs/input/ruin.1605 > ../outputs/t1667
    if diff ../outputs/t1667 ../originals/t1667 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1668) timeout -s 9 2 ../source/replace.exe '*?*' 'y'  < ../inputs/input/ruin.425 > ../outputs/t1668
    if diff ../outputs/t1668 ../originals/t1668 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1669) timeout -s 9 2 ../source/replace.exe '*??' 'ke'  < ../inputs/input/ruin.280 > ../outputs/t1669
    if diff ../outputs/t1669 ../originals/t1669 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1670) timeout -s 9 2 ../source/replace.exe '*?[>-A>-Ac-aA-G]' '( $V0B16|L'  < ../inputs/input/ruin.270 > ../outputs/t1670
    if diff ../outputs/t1670 ../originals/t1670 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1671) timeout -s 9 2 ../source/replace.exe '*@@'   < ../inputs/input/ruin.1159 > ../outputs/t1671
    if diff ../outputs/t1671 ../originals/t1671 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1672) timeout -s 9 2 ../source/replace.exe '*@@' ';'  < ../inputs/input/ruin.1415 > ../outputs/t1672
    if diff ../outputs/t1672 ../originals/t1672 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1673) timeout -s 9 2 ../source/replace.exe '*@@' 'H'  < ../inputs/input/ruin.693 > ../outputs/t1673
    if diff ../outputs/t1673 ../originals/t1673 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1674) timeout -s 9 2 ../source/replace.exe '*@@' 'KSssNL3yfIE*o'  < ../inputs/input/ruin.1229 > ../outputs/t1674
    if diff ../outputs/t1674 ../originals/t1674 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1675) timeout -s 9 2 ../source/replace.exe '*@@' 'Stu%'  < ../inputs/input/ruin.1159 > ../outputs/t1675
    if diff ../outputs/t1675 ../originals/t1675 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1676) timeout -s 9 2 ../source/replace.exe '*@@' 'oJ<wB]FP!-F$ jO%'  < ../inputs/input/ruin.349 > ../outputs/t1676
    if diff ../outputs/t1676 ../originals/t1676 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1677) timeout -s 9 2 ../source/replace.exe '*@@*' '98Ge3Ed^R|)7!s<q*mmY4<+<8VfhOfDE}6Goi^\c~i'  < ../inputs/input/ruin.1377 > ../outputs/t1677
    if diff ../outputs/t1677 ../originals/t1677 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1678) timeout -s 9 2 ../source/replace.exe '*@@@@' '>nsYA'  < ../inputs/input/ruin.1873 > ../outputs/t1678
    if diff ../outputs/t1678 ../originals/t1678 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1679) timeout -s 9 2 ../source/replace.exe '*@@G' 'nI'\''+MH'  < ../inputs/input/ruin.743 > ../outputs/t1679
    if diff ../outputs/t1679 ../originals/t1679 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1680) timeout -s 9 2 ../source/replace.exe '*@e' '>'  < ../inputs/input/ruin.1371 > ../outputs/t1680
    if diff ../outputs/t1680 ../originals/t1680 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1681) timeout -s 9 2 ../source/replace.exe '*@n' '0&yd{(t"'\''bw/ i+JO/F,1bSmIlg'  < ../inputs/input/ruin.282 > ../outputs/t1681
    if diff ../outputs/t1681 ../originals/t1681 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1682) timeout -s 9 2 ../source/replace.exe '*@n' '>3tNX^|@zI@;>zg  2%Cd#FNs#U)`U7h#9dYHdo'  < ../inputs/input/ruin.865 > ../outputs/t1682
    if diff ../outputs/t1682 ../originals/t1682 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1683) timeout -s 9 2 ../source/replace.exe '*@n' 'KsxI474&Q(C}u4M|o2T`<`;S^`NUPxX'  < ../inputs/input/ruin.291 > ../outputs/t1683
    if diff ../outputs/t1683 ../originals/t1683 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1684) timeout -s 9 2 ../source/replace.exe '*@n' 'MP&KwD.47](#W/L3Yj'  < ../inputs/input/ruin.286 > ../outputs/t1684
    if diff ../outputs/t1684 ../originals/t1684 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1685) timeout -s 9 2 ../source/replace.exe '*@n' 'X&XXXXXXXXXX'  < ../inputs/input/ruin.321 > ../outputs/t1685
    if diff ../outputs/t1685 ../originals/t1685 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1686) timeout -s 9 2 ../source/replace.exe '*@n' 'b&[0-9]p'  < ../inputs/input/ruin.289 > ../outputs/t1686
    if diff ../outputs/t1686 ../originals/t1686 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1687) timeout -s 9 2 ../source/replace.exe '*@n' 'n&f$BLCD}tiigf@3'  < ../inputs/input/ruin.553 > ../outputs/t1687
    if diff ../outputs/t1687 ../originals/t1687 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1688) timeout -s 9 2 ../source/replace.exe '*@n' 'zCF&lL=IT'  < ../inputs/input/ruin.287 > ../outputs/t1688
    if diff ../outputs/t1688 ../originals/t1688 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1689) timeout -s 9 2 ../source/replace.exe '*@n[^n]*0' 'h1u$*tU$1o;]2xb7CvhE:p@~}PQo+M!UMpJn4Z-zgBh(U'  < ../inputs/input/ruin.983 > ../outputs/t1689
    if diff ../outputs/t1689 ../originals/t1689 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1690) timeout -s 9 2 ../source/replace.exe '*@t' 'F'  < ../inputs/input/ruin.320 > ../outputs/t1690
    if diff ../outputs/t1690 ../originals/t1690 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1691) timeout -s 9 2 ../source/replace.exe '*@t[@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9]' 'F'  < ../inputs/input/ruin.320 > ../outputs/t1691
    if diff ../outputs/t1691 ../originals/t1691 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1692) timeout -s 9 2 ../source/replace.exe '*O' '[SnK:ScY3|gj)p9qF'  < ../inputs/input/ruin.1107 > ../outputs/t1692
    if diff ../outputs/t1692 ../originals/t1692 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1693) timeout -s 9 2 ../source/replace.exe '*R' 'x<\BNOp-x\IfU1 A$8'  < ../inputs/input/ruin.785 > ../outputs/t1693
    if diff ../outputs/t1693 ../originals/t1693 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1694) timeout -s 9 2 ../source/replace.exe '*W@@@@' '~DL\#\S%Frr,MSYXpPBT.^?@ {3sT&TXz"H"$Sf<'  < ../inputs/input/ruin.1476 > ../outputs/t1694
    if diff ../outputs/t1694 ../originals/t1694 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1695) timeout -s 9 2 ../source/replace.exe '*[0-90-9]?' '%'  < ../inputs/input/ruin.830 > ../outputs/t1695
    if diff ../outputs/t1695 ../originals/t1695 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1696) timeout -s 9 2 ../source/replace.exe '*[A-G]?*[A-G]?' '(:,w5(X6)W%qon=YYaq]Q_&nZ~A'  < ../inputs/input/ruin.637 > ../outputs/t1696
    if diff ../outputs/t1696 ../originals/t1696 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1697) timeout -s 9 2 ../source/replace.exe '*[A-G]@t' '=!Gs:fsxv_A58F 5 0YKWB#<UlTQ))[eqI4DwKfd~gZNmB'  < ../inputs/input/ruin.232 > ../outputs/t1697
    if diff ../outputs/t1697 ../originals/t1697 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1698) timeout -s 9 2 ../source/replace.exe '*[Z-a]^_`a]'\''H8WstZ' 'B'  < ../inputs/input/ruin.808 > ../outputs/t1698
    if diff ../outputs/t1698 ../originals/t1698 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1699) timeout -s 9 2 ../source/replace.exe '*[^0-9]@n' 'd`?K#C~VsV'  < ../inputs/input/ruin.10 > ../outputs/t1699
    if diff ../outputs/t1699 ../originals/t1699 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1700) timeout -s 9 2 ../source/replace.exe '*[^M]' 'C;meWLSSV1S!'  < ../inputs/input/ruin.597 > ../outputs/t1700
    if diff ../outputs/t1700 ../originals/t1700 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1701) timeout -s 9 2 ../source/replace.exe '*[^Z-a]^_`a]' 'M'  < ../inputs/input/ruin.804 > ../outputs/t1701
    if diff ../outputs/t1701 ../originals/t1701 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1702) timeout -s 9 2 ../source/replace.exe '*[^z-})]<' 'v'  < ../inputs/input/ruin.616 > ../outputs/t1702
    if diff ../outputs/t1702 ../originals/t1702 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1703) timeout -s 9 2 ../source/replace.exe '*[^z-}]' 'Ud+`L?HbK/{T'  < ../inputs/input/ruin.787 > ../outputs/t1703
    if diff ../outputs/t1703 ../originals/t1703 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1704) timeout -s 9 2 ../source/replace.exe '*\' ''  < ../inputs/input/ruin.1686 > ../outputs/t1704
    if diff ../outputs/t1704 ../originals/t1704 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1705) timeout -s 9 2 ../source/replace.exe '*\' '|'  < ../inputs/input/ruin.1449 > ../outputs/t1705
    if diff ../outputs/t1705 ../originals/t1705 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1706) timeout -s 9 2 ../source/replace.exe '*\tk' 'hkNiPT'  < ../inputs/input/ruin.1886 > ../outputs/t1706
    if diff ../outputs/t1706 ../originals/t1706 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1707) timeout -s 9 2 ../source/replace.exe '*]' '['  < ../inputs/input/ruin.1797 > ../outputs/t1707
    if diff ../outputs/t1707 ../originals/t1707 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1708) timeout -s 9 2 ../source/replace.exe '*f@@' 'E'  < ../inputs/input/ruin.978 > ../outputs/t1708
    if diff ../outputs/t1708 ../originals/t1708 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1709) timeout -s 9 2 ../source/replace.exe '*p&y=3p&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYI[p&y=3[ZYIZYIgTBk' 'b$M]}'  < ../inputs/input/ruin.1334 > ../outputs/t1709
    if diff ../outputs/t1709 ../originals/t1709 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1710) timeout -s 9 2 ../source/replace.exe '+' 'u'  < ../inputs/input/ruin.842 > ../outputs/t1710
    if diff ../outputs/t1710 ../originals/t1710 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1711) timeout -s 9 2 ../source/replace.exe ',$' 'ZCOQ%-V%r?8G'\''%#V'  < ../inputs/input/ruin.930 > ../outputs/t1711
    if diff ../outputs/t1711 ../originals/t1711 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1712) timeout -s 9 2 ../source/replace.exe ',' 'd'  < ../inputs/input/ruin.1082 > ../outputs/t1712
    if diff ../outputs/t1712 ../originals/t1712 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1713) timeout -s 9 2 ../source/replace.exe '- $' 'NEW'  < ../inputs/temp-test/570.inp.245.9 > ../outputs/t1713
    if diff ../outputs/t1713 ../originals/t1713 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1714) timeout -s 9 2 ../source/replace.exe '- '   < ../inputs/temp-test/524.inp.227.1 > ../outputs/t1714
    if diff ../outputs/t1714 ../originals/t1714 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1715) timeout -s 9 2 ../source/replace.exe '- ' '&'  < ../inputs/temp-test/1856.inp.788.1 > ../outputs/t1715
    if diff ../outputs/t1715 ../originals/t1715 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1716) timeout -s 9 2 ../source/replace.exe '- ' '&'  < ../inputs/temp-test/1857.inp.788.2 > ../outputs/t1716
    if diff ../outputs/t1716 ../originals/t1716 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1717) timeout -s 9 2 ../source/replace.exe '- ' '&'  < ../inputs/temp-test/1858.inp.788.3 > ../outputs/t1717
    if diff ../outputs/t1717 ../originals/t1717 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1718) timeout -s 9 2 ../source/replace.exe '- ' '&'  < ../inputs/temp-test/1859.inp.788.4 > ../outputs/t1718
    if diff ../outputs/t1718 ../originals/t1718 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1719) timeout -s 9 2 ../source/replace.exe '- ' '&'  < ../inputs/temp-test/524.inp.227.1 > ../outputs/t1719
    if diff ../outputs/t1719 ../originals/t1719 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1720) timeout -s 9 2 ../source/replace.exe '- ' '@%@&'  < ../inputs/temp-test/2171.inp.918.1 > ../outputs/t1720
    if diff ../outputs/t1720 ../originals/t1720 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1721) timeout -s 9 2 ../source/replace.exe '- ' '@%@&'  < ../inputs/temp-test/2172.inp.918.2 > ../outputs/t1721
    if diff ../outputs/t1721 ../originals/t1721 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1722) timeout -s 9 2 ../source/replace.exe '- ' '@t'  < ../inputs/temp-test/1788.inp.761.1 > ../outputs/t1722
    if diff ../outputs/t1722 ../originals/t1722 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1723) timeout -s 9 2 ../source/replace.exe '- ' '@t'  < ../inputs/temp-test/1789.inp.761.2 > ../outputs/t1723
    if diff ../outputs/t1723 ../originals/t1723 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1724) timeout -s 9 2 ../source/replace.exe '- ' 'NEW'  < ../inputs/temp-test/569.inp.245.1 > ../outputs/t1724
    if diff ../outputs/t1724 ../originals/t1724 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1725) timeout -s 9 2 ../source/replace.exe '- *$' ''  < ../inputs/temp-test/767.inp.328.8 > ../outputs/t1725
    if diff ../outputs/t1725 ../originals/t1725 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1726) timeout -s 9 2 ../source/replace.exe '- *' ''  < ../inputs/temp-test/766.inp.328.1 > ../outputs/t1726
    if diff ../outputs/t1726 ../originals/t1726 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1727) timeout -s 9 2 ../source/replace.exe '- *' 'a@nb@tc'  < ../inputs/temp-test/1373.inp.589.1 > ../outputs/t1727
    if diff ../outputs/t1727 ../originals/t1727 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1728) timeout -s 9 2 ../source/replace.exe '- *' 'b@t'  < ../inputs/temp-test/155.inp.70.1 > ../outputs/t1728
    if diff ../outputs/t1728 ../originals/t1728 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1729) timeout -s 9 2 ../source/replace.exe '- *' 'b@t'  < ../inputs/temp-test/156.inp.70.2 > ../outputs/t1729
    if diff ../outputs/t1729 ../originals/t1729 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1730) timeout -s 9 2 ../source/replace.exe '- *-?' 'a@nb@tc'  < ../inputs/temp-test/1074.inp.462.1 > ../outputs/t1730
    if diff ../outputs/t1730 ../originals/t1730 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1731) timeout -s 9 2 ../source/replace.exe '- [^@n]?[^0-9]?[0-9]?' '@%&a'  < ../inputs/temp-test/162.inp.73.1 > ../outputs/t1731
    if diff ../outputs/t1731 ../originals/t1731 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1732) timeout -s 9 2 ../source/replace.exe '-$' '&@n'  < ../inputs/temp-test/633.inp.273.9 > ../outputs/t1732
    if diff ../outputs/t1732 ../originals/t1732 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1733) timeout -s 9 2 ../source/replace.exe '-$' '*U:an"OMpY#Ei1WdZ>`'  < ../inputs/input/ruin.1277 > ../outputs/t1733
    if diff ../outputs/t1733 ../originals/t1733 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1734) timeout -s 9 2 ../source/replace.exe '-$' '@%@&'  < ../inputs/temp-test/633.inp.273.9 > ../outputs/t1734
    if diff ../outputs/t1734 ../originals/t1734 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1735) timeout -s 9 2 ../source/replace.exe '-%[^a-c' ''  < ../inputs/temp-test/2354.inp.999.2 > ../outputs/t1735
    if diff ../outputs/t1735 ../originals/t1735 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1736) timeout -s 9 2 ../source/replace.exe '-%[^a-c' ''  < ../inputs/temp-test/2355.inp.999.3 > ../outputs/t1736
    if diff ../outputs/t1736 ../originals/t1736 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1737) timeout -s 9 2 ../source/replace.exe '-' '&@n'  < ../inputs/temp-test/631.inp.273.1 > ../outputs/t1737
    if diff ../outputs/t1737 ../originals/t1737 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1738) timeout -s 9 2 ../source/replace.exe '-' '&@n'  < ../inputs/temp-test/632.inp.273.3 > ../outputs/t1738
    if diff ../outputs/t1738 ../originals/t1738 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1739) timeout -s 9 2 ../source/replace.exe '-' '&a@%'  < ../inputs/temp-test/1383.inp.593.1 > ../outputs/t1739
    if diff ../outputs/t1739 ../originals/t1739 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1740) timeout -s 9 2 ../source/replace.exe '-' '&a@%'  < ../inputs/temp-test/2265.inp.960.1 > ../outputs/t1740
    if diff ../outputs/t1740 ../originals/t1740 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1741) timeout -s 9 2 ../source/replace.exe '-' ''  < ../inputs/temp-test/1648.inp.703.1 > ../outputs/t1741
    if diff ../outputs/t1741 ../originals/t1741 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1742) timeout -s 9 2 ../source/replace.exe '-' ''  < ../inputs/temp-test/1649.inp.703.3 > ../outputs/t1742
    if diff ../outputs/t1742 ../originals/t1742 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1743) timeout -s 9 2 ../source/replace.exe '-' ''  < ../inputs/temp-test/258.inp.114.1 > ../outputs/t1743
    if diff ../outputs/t1743 ../originals/t1743 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1744) timeout -s 9 2 ../source/replace.exe '-' ''  < ../inputs/temp-test/259.inp.114.2 > ../outputs/t1744
    if diff ../outputs/t1744 ../originals/t1744 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1745) timeout -s 9 2 ../source/replace.exe '-' ''  < ../inputs/temp-test/706.inp.306.1 > ../outputs/t1745
    if diff ../outputs/t1745 ../originals/t1745 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1746) timeout -s 9 2 ../source/replace.exe '-' ''  < ../inputs/temp-test/707.inp.306.3 > ../outputs/t1746
    if diff ../outputs/t1746 ../originals/t1746 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1747) timeout -s 9 2 ../source/replace.exe '-' '+'  < ../inputs/input/ruin.1488 > ../outputs/t1747
    if diff ../outputs/t1747 ../originals/t1747 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1748) timeout -s 9 2 ../source/replace.exe '-' ';g/&.}:{js8R^#VPXDq2$?H7JEik*Lg_}N\ I(T"'  < ../inputs/input/ruin.1180 > ../outputs/t1748
    if diff ../outputs/t1748 ../originals/t1748 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1749) timeout -s 9 2 ../source/replace.exe '-' '=6F{LtJ|XyCKJD'  < ../inputs/input/ruin.294 > ../outputs/t1749
    if diff ../outputs/t1749 ../originals/t1749 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1750) timeout -s 9 2 ../source/replace.exe '-' '@%&a'  < ../inputs/temp-test/1252.inp.537.1 > ../outputs/t1750
    if diff ../outputs/t1750 ../originals/t1750 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1751) timeout -s 9 2 ../source/replace.exe '-' '@%&a'  < ../inputs/temp-test/1253.inp.537.4 > ../outputs/t1751
    if diff ../outputs/t1751 ../originals/t1751 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1752) timeout -s 9 2 ../source/replace.exe '-' '@%&a'  < ../inputs/temp-test/480.inp.210.1 > ../outputs/t1752
    if diff ../outputs/t1752 ../originals/t1752 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1753) timeout -s 9 2 ../source/replace.exe '-' '@%&a'  < ../inputs/temp-test/481.inp.210.2 > ../outputs/t1753
    if diff ../outputs/t1753 ../originals/t1753 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1754) timeout -s 9 2 ../source/replace.exe '-' '@%@&'  < ../inputs/temp-test/1141.inp.491.1 > ../outputs/t1754
    if diff ../outputs/t1754 ../originals/t1754 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1755) timeout -s 9 2 ../source/replace.exe '-' '@%@&'  < ../inputs/temp-test/631.inp.273.1 > ../outputs/t1755
    if diff ../outputs/t1755 ../originals/t1755 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1756) timeout -s 9 2 ../source/replace.exe '-' '@%@&'  < ../inputs/temp-test/632.inp.273.3 > ../outputs/t1756
    if diff ../outputs/t1756 ../originals/t1756 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1757) timeout -s 9 2 ../source/replace.exe '-' '@n'  < ../inputs/temp-test/2253.inp.955.1 > ../outputs/t1757
    if diff ../outputs/t1757 ../originals/t1757 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1758) timeout -s 9 2 ../source/replace.exe '-' '@n'  < ../inputs/temp-test/994.inp.428.1 > ../outputs/t1758
    if diff ../outputs/t1758 ../originals/t1758 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1759) timeout -s 9 2 ../source/replace.exe '-' '@n'  < ../inputs/temp-test/995.inp.428.2 > ../outputs/t1759
    if diff ../outputs/t1759 ../originals/t1759 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1760) timeout -s 9 2 ../source/replace.exe '-' '@n'  < ../inputs/temp-test/996.inp.428.3 > ../outputs/t1760
    if diff ../outputs/t1760 ../originals/t1760 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1761) timeout -s 9 2 ../source/replace.exe '-' 'NEW'  < ../inputs/temp-test/722.inp.312.1 > ../outputs/t1761
    if diff ../outputs/t1761 ../originals/t1761 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1762) timeout -s 9 2 ../source/replace.exe '-' 'NEW'  < ../inputs/temp-test/723.inp.312.2 > ../outputs/t1762
    if diff ../outputs/t1762 ../originals/t1762 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1763) timeout -s 9 2 ../source/replace.exe '-' 'NEW'  < ../inputs/temp-test/724.inp.312.3 > ../outputs/t1763
    if diff ../outputs/t1763 ../originals/t1763 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1764) timeout -s 9 2 ../source/replace.exe '-' 'T(LYE-ao)s9O(i6'\''Q)yz&A9og__<mtw`8]7CijJ?N#3Q/iGR|RjL$tV_+z6fA:[d'  < ../inputs/input/ruin.1823 > ../outputs/t1764
    if diff ../outputs/t1764 ../originals/t1764 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1765) timeout -s 9 2 ../source/replace.exe '-' 'a&'  < ../inputs/temp-test/1309.inp.563.1 > ../outputs/t1765
    if diff ../outputs/t1765 ../originals/t1765 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1766) timeout -s 9 2 ../source/replace.exe '-' 'a&'  < ../inputs/temp-test/1310.inp.563.2 > ../outputs/t1766
    if diff ../outputs/t1766 ../originals/t1766 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1767) timeout -s 9 2 ../source/replace.exe '-' 'a&'  < ../inputs/temp-test/1311.inp.563.4 > ../outputs/t1767
    if diff ../outputs/t1767 ../originals/t1767 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1768) timeout -s 9 2 ../source/replace.exe '-' 'a@n'  < ../inputs/temp-test/764.inp.327.1 > ../outputs/t1768
    if diff ../outputs/t1768 ../originals/t1768 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1769) timeout -s 9 2 ../source/replace.exe '-' 'a@n'  < ../inputs/temp-test/765.inp.327.3 > ../outputs/t1769
    if diff ../outputs/t1769 ../originals/t1769 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1770) timeout -s 9 2 ../source/replace.exe '-' 'a@nb@tc'  < ../inputs/temp-test/666.inp.290.1 > ../outputs/t1770
    if diff ../outputs/t1770 ../originals/t1770 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1771) timeout -s 9 2 ../source/replace.exe '-' 'a@nb@tc'  < ../inputs/temp-test/876.inp.376.1 > ../outputs/t1771
    if diff ../outputs/t1771 ../originals/t1771 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1772) timeout -s 9 2 ../source/replace.exe '-' 'a@nb@tc'  < ../inputs/temp-test/877.inp.376.3 > ../outputs/t1772
    if diff ../outputs/t1772 ../originals/t1772 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1773) timeout -s 9 2 ../source/replace.exe '-' 'a@nb@tc'  < ../inputs/temp-test/878.inp.376.4 > ../outputs/t1773
    if diff ../outputs/t1773 ../originals/t1773 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1774) timeout -s 9 2 ../source/replace.exe '-' 'c}}1&+CkqDp{"XR613}Oox='\''k&j?itc/lkerG9p]GH'  < ../inputs/input/ruin.1175 > ../outputs/t1774
    if diff ../outputs/t1774 ../originals/t1774 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1775) timeout -s 9 2 ../source/replace.exe '-' 'j_hn&VVQ|;n)#xS;9N.vh@gpT'\''?oF-^_,j_\j[n;{VkW#;EB*C)%(xYY"Oget'\''B!=P7|cKKNU<rkU-GYLmy![G'  < ../inputs/input/ruin.6 > ../outputs/t1775
    if diff ../outputs/t1775 ../originals/t1775 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1776) timeout -s 9 2 ../source/replace.exe '-' 'v'  < ../inputs/input/ruin.1663 > ../outputs/t1776
    if diff ../outputs/t1776 ../originals/t1776 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1777) timeout -s 9 2 ../source/replace.exe '-' '}'  < ../inputs/input/ruin.1734 > ../outputs/t1777
    if diff ../outputs/t1777 ../originals/t1777 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1778) timeout -s 9 2 ../source/replace.exe '-*$'   < ../inputs/temp-test/200.inp.90.1 > ../outputs/t1778
    if diff ../outputs/t1778 ../originals/t1778 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1779) timeout -s 9 2 ../source/replace.exe '-*$'  < ../inputs/temp-test/201.inp.90.3 > ../outputs/t1779
    if diff ../outputs/t1779 ../originals/t1779 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1780) timeout -s 9 2 ../source/replace.exe '-*-' '@n'  < ../inputs/temp-test/2006.inp.852.1 > ../outputs/t1780
    if diff ../outputs/t1780 ../originals/t1780 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1781) timeout -s 9 2 ../source/replace.exe '-*-' '@n'  < ../inputs/temp-test/2007.inp.852.2 > ../outputs/t1781
    if diff ../outputs/t1781 ../originals/t1781 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1782) timeout -s 9 2 ../source/replace.exe '-*-' '@n'  < ../inputs/temp-test/2008.inp.852.3 > ../outputs/t1782
    if diff ../outputs/t1782 ../originals/t1782 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1783) timeout -s 9 2 ../source/replace.exe '-*--' '@t'  < ../inputs/temp-test/286.inp.128.1 > ../outputs/t1783
    if diff ../outputs/t1783 ../originals/t1783 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1784) timeout -s 9 2 ../source/replace.exe '-*?' '&a@%'  < ../inputs/temp-test/1099.inp.474.1 > ../outputs/t1784
    if diff ../outputs/t1784 ../originals/t1784 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1785) timeout -s 9 2 ../source/replace.exe '-*?' '&a@%'  < ../inputs/temp-test/1100.inp.474.2 > ../outputs/t1785
    if diff ../outputs/t1785 ../originals/t1785 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1786) timeout -s 9 2 ../source/replace.exe '-*?' '&a@%'  < ../inputs/temp-test/1101.inp.474.3 > ../outputs/t1786
    if diff ../outputs/t1786 ../originals/t1786 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1787) timeout -s 9 2 ../source/replace.exe '-*?@[?[@@]-' '@%&a'  < ../inputs/temp-test/264.inp.117.1 > ../outputs/t1787
    if diff ../outputs/t1787 ../originals/t1787 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1788) timeout -s 9 2 ../source/replace.exe '-*?@[?[@@]-' '@%&a'  < ../inputs/temp-test/265.inp.117.3 > ../outputs/t1788
    if diff ../outputs/t1788 ../originals/t1788 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1789) timeout -s 9 2 ../source/replace.exe '-*?@t*[^0-9][0-9]' 'b@t'  < ../inputs/temp-test/228.inp.102.1 > ../outputs/t1789
    if diff ../outputs/t1789 ../originals/t1789 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1790) timeout -s 9 2 ../source/replace.exe '-*?@t*[^0-9][0-9]' 'b@t'  < ../inputs/temp-test/229.inp.102.2 > ../outputs/t1790
    if diff ../outputs/t1790 ../originals/t1790 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1791) timeout -s 9 2 ../source/replace.exe '-*[9-B][0-9]@*' '&a@%'  < ../inputs/temp-test/1406.inp.603.1 > ../outputs/t1791
    if diff ../outputs/t1791 ../originals/t1791 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1792) timeout -s 9 2 ../source/replace.exe '-*[9-B][0-9]@*' '&a@%'  < ../inputs/temp-test/1407.inp.603.2 > ../outputs/t1792
    if diff ../outputs/t1792 ../originals/t1792 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1793) timeout -s 9 2 ../source/replace.exe '-*[][^0-9]$' '&'  < ../inputs/temp-test/202.inp.90.6 > ../outputs/t1793
    if diff ../outputs/t1793 ../originals/t1793 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1794) timeout -s 9 2 ../source/replace.exe '-*[^0-9]$'  '&@n' < ../inputs/temp-test/202.inp.90.6 > ../outputs/t1794
    if diff ../outputs/t1794 ../originals/t1794 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1795) timeout -s 9 2 ../source/replace.exe '-*[^0-9]$'   < ../inputs/temp-test/202.inp.90.6 > ../outputs/t1795
    if diff ../outputs/t1795 ../originals/t1795 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1796) timeout -s 9 2 ../source/replace.exe '-*[^0-9]$' '&'  < ../inputs/temp-test/202.inp.90.6 > ../outputs/t1796
    if diff ../outputs/t1796 ../originals/t1796 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1797) timeout -s 9 2 ../source/replace.exe '-*[^0-9]'   < ../inputs/temp-test/200.inp.90.1 > ../outputs/t1797
    if diff ../outputs/t1797 ../originals/t1797 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1798) timeout -s 9 2 ../source/replace.exe '-*[^0-9]'   < ../inputs/temp-test/201.inp.90.3 > ../outputs/t1798
    if diff ../outputs/t1798 ../originals/t1798 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1799) timeout -s 9 2 ../source/replace.exe '-*[^0-9]' '&'  < ../inputs/temp-test/200.inp.90.1 > ../outputs/t1799
    if diff ../outputs/t1799 ../originals/t1799 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1800) timeout -s 9 2 ../source/replace.exe '-*[^0-9]' '&'  < ../inputs/temp-test/201.inp.90.3 > ../outputs/t1800
    if diff ../outputs/t1800 ../originals/t1800 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1801) timeout -s 9 2 ../source/replace.exe '-*[^0-9]' '&@n'  < ../inputs/temp-test/200.inp.90.1 > ../outputs/t1801
    if diff ../outputs/t1801 ../originals/t1801 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1802) timeout -s 9 2 ../source/replace.exe '-*[^0-9]' '@t'  < ../inputs/temp-test/176.inp.79.1 > ../outputs/t1802
    if diff ../outputs/t1802 ../originals/t1802 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1803) timeout -s 9 2 ../source/replace.exe '-*[^0-9]*$' '&'  < ../inputs/temp-test/200.inp.90.1 > ../outputs/t1803
    if diff ../outputs/t1803 ../originals/t1803 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1804) timeout -s 9 2 ../source/replace.exe '-*[^0-9]*$' '&'  < ../inputs/temp-test/201.inp.90.3 > ../outputs/t1804
    if diff ../outputs/t1804 ../originals/t1804 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1805) timeout -s 9 2 ../source/replace.exe '-*[^0-9]*$' '&'  < ../inputs/temp-test/202.inp.90.6 > ../outputs/t1805
    if diff ../outputs/t1805 ../originals/t1805 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1806) timeout -s 9 2 ../source/replace.exe '-*[^0-9]*' '&'  < ../inputs/temp-test/200.inp.90.1 > ../outputs/t1806
    if diff ../outputs/t1806 ../originals/t1806 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1807) timeout -s 9 2 ../source/replace.exe '-*[^0-9]*' '&'  < ../inputs/temp-test/201.inp.90.3 > ../outputs/t1807
    if diff ../outputs/t1807 ../originals/t1807 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1808) timeout -s 9 2 ../source/replace.exe '-*[^0-9]*' '&'  < ../inputs/temp-test/202.inp.90.6 > ../outputs/t1808
    if diff ../outputs/t1808 ../originals/t1808 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1809) timeout -s 9 2 ../source/replace.exe '-*[^9-B]-[a--]' 'a@n'  < ../inputs/temp-test/467.inp.204.1 > ../outputs/t1809
    if diff ../outputs/t1809 ../originals/t1809 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1810) timeout -s 9 2 ../source/replace.exe '-*[^9-B]-[a--]' 'a@n'  < ../inputs/temp-test/468.inp.204.3 > ../outputs/t1810
    if diff ../outputs/t1810 ../originals/t1810 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1811) timeout -s 9 2 ../source/replace.exe '-*[^][^0-9]$' '&'  < ../inputs/temp-test/202.inp.90.6 > ../outputs/t1811
    if diff ../outputs/t1811 ../originals/t1811 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1812) timeout -s 9 2 ../source/replace.exe '-*[^a--b]' '@%&a'  < ../inputs/temp-test/393.inp.172.1 > ../outputs/t1812
    if diff ../outputs/t1812 ../originals/t1812 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1813) timeout -s 9 2 ../source/replace.exe '-*[^a--b]' '@%&a'  < ../inputs/temp-test/394.inp.172.2 > ../outputs/t1813
    if diff ../outputs/t1813 ../originals/t1813 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1814) timeout -s 9 2 ../source/replace.exe '-*[^a--b]' '@%&a'  < ../inputs/temp-test/395.inp.172.3 > ../outputs/t1814
    if diff ../outputs/t1814 ../originals/t1814 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1815) timeout -s 9 2 ../source/replace.exe '-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]-*[^a--b]' '@%&a'  < ../inputs/temp-test/393.inp.172.1 > ../outputs/t1815
    if diff ../outputs/t1815 ../originals/t1815 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1816) timeout -s 9 2 ../source/replace.exe '-*[^a-c]@[[^0-9]-[9-B]' '@n'  < ../inputs/temp-test/1321.inp.567.1 > ../outputs/t1816
    if diff ../outputs/t1816 ../originals/t1816 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1817) timeout -s 9 2 ../source/replace.exe '--%[^9-B][0-9]--[0-9]*-' '@%@&'  < ../inputs/temp-test/17.inp.8.1 > ../outputs/t1817
    if diff ../outputs/t1817 ../originals/t1817 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1818) timeout -s 9 2 ../source/replace.exe '--' ''  < ../inputs/temp-test/1896.inp.804.1 > ../outputs/t1818
    if diff ../outputs/t1818 ../originals/t1818 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1819) timeout -s 9 2 ../source/replace.exe '--' 'a@nb@tc'  < ../inputs/temp-test/951.inp.410.1 > ../outputs/t1819
    if diff ../outputs/t1819 ../originals/t1819 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1820) timeout -s 9 2 ../source/replace.exe '--' 'a@nb@tc'  < ../inputs/temp-test/952.inp.410.2 > ../outputs/t1820
    if diff ../outputs/t1820 ../originals/t1820 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1821) timeout -s 9 2 ../source/replace.exe '--' 'a@nb@tc'  < ../inputs/temp-test/953.inp.410.3 > ../outputs/t1821
    if diff ../outputs/t1821 ../originals/t1821 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1822) timeout -s 9 2 ../source/replace.exe '--*' ''  < ../inputs/temp-test/1282.inp.551.1 > ../outputs/t1822
    if diff ../outputs/t1822 ../originals/t1822 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1823) timeout -s 9 2 ../source/replace.exe '--*' ''  < ../inputs/temp-test/1283.inp.551.2 > ../outputs/t1823
    if diff ../outputs/t1823 ../originals/t1823 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1824) timeout -s 9 2 ../source/replace.exe '--*' ''  < ../inputs/temp-test/1284.inp.551.3 > ../outputs/t1824
    if diff ../outputs/t1824 ../originals/t1824 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1825) timeout -s 9 2 ../source/replace.exe '--*' '@%&a'  < ../inputs/temp-test/807.inp.347.1 > ../outputs/t1825
    if diff ../outputs/t1825 ../originals/t1825 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1826) timeout -s 9 2 ../source/replace.exe '--*' '@%&a'  < ../inputs/temp-test/808.inp.347.3 > ../outputs/t1826
    if diff ../outputs/t1826 ../originals/t1826 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1827) timeout -s 9 2 ../source/replace.exe '--*-A-[0-9]-[^a-c]' 'a@n'  < ../inputs/temp-test/186.inp.84.1 > ../outputs/t1827
    if diff ../outputs/t1827 ../originals/t1827 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1828) timeout -s 9 2 ../source/replace.exe '--*[@t]-' 'b@t'  < ../inputs/temp-test/174.inp.78.1 > ../outputs/t1828
    if diff ../outputs/t1828 ../originals/t1828 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1829) timeout -s 9 2 ../source/replace.exe '--*[@t]-' 'b@t'  < ../inputs/temp-test/175.inp.78.3 > ../outputs/t1829
    if diff ../outputs/t1829 ../originals/t1829 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1830) timeout -s 9 2 ../source/replace.exe '--*[^a-c[0-9]a-c][^0-9][0-9][^0-9]?-' 'NEW'  < ../inputs/temp-test/997.inp.429.1 > ../outputs/t1830
    if diff ../outputs/t1830 ../originals/t1830 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1831) timeout -s 9 2 ../source/replace.exe '--*a-c]?[^0-9]' '@n'  < ../inputs/temp-test/1152.inp.496.1 > ../outputs/t1831
    if diff ../outputs/t1831 ../originals/t1831 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1832) timeout -s 9 2 ../source/replace.exe '--*a-c]?[^0-9]' '@n'  < ../inputs/temp-test/1153.inp.496.2 > ../outputs/t1832
    if diff ../outputs/t1832 ../originals/t1832 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1833) timeout -s 9 2 ../source/replace.exe '--?^[9-B]?' ''  < ../inputs/temp-test/1467.inp.629.1 > ../outputs/t1833
    if diff ../outputs/t1833 ../originals/t1833 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1834) timeout -s 9 2 ../source/replace.exe '--?^[9-B]?' ''  < ../inputs/temp-test/1468.inp.629.2 > ../outputs/t1834
    if diff ../outputs/t1834 ../originals/t1834 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1835) timeout -s 9 2 ../source/replace.exe '--@*-[^-z]-?[^--z][^9-B]?$' '&a@%'  < ../inputs/temp-test/502.inp.219.6 > ../outputs/t1835
    if diff ../outputs/t1835 ../originals/t1835 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1836) timeout -s 9 2 ../source/replace.exe '--@*-[^-z]-?[^--z][^9-B]?' '&a@%'  < ../inputs/temp-test/499.inp.219.1 > ../outputs/t1836
    if diff ../outputs/t1836 ../originals/t1836 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1837) timeout -s 9 2 ../source/replace.exe '--@*-[^-z]-?[^--z][^9-B]?' '&a@%'  < ../inputs/temp-test/500.inp.219.3 > ../outputs/t1837
    if diff ../outputs/t1837 ../originals/t1837 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1838) timeout -s 9 2 ../source/replace.exe '--[0-9]?-?' 'NEW'  < ../inputs/temp-test/2058.inp.873.1 > ../outputs/t1838
    if diff ../outputs/t1838 ../originals/t1838 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1839) timeout -s 9 2 ../source/replace.exe '--[0-9]?-?' 'NEW'  < ../inputs/temp-test/2059.inp.873.2 > ../outputs/t1839
    if diff ../outputs/t1839 ../originals/t1839 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1840) timeout -s 9 2 ../source/replace.exe '--[0-9]?-?' 'NEW'  < ../inputs/temp-test/2060.inp.873.3 > ../outputs/t1840
    if diff ../outputs/t1840 ../originals/t1840 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1841) timeout -s 9 2 ../source/replace.exe '--[^9-B][0-9]--[0-9]*-' '@%@&'  < ../inputs/temp-test/17.inp.8.1 > ../outputs/t1841
    if diff ../outputs/t1841 ../originals/t1841 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1842) timeout -s 9 2 ../source/replace.exe '--]$' '&'  < ../inputs/temp-test/2001.inp.850.6 > ../outputs/t1842
    if diff ../outputs/t1842 ../originals/t1842 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1843) timeout -s 9 2 ../source/replace.exe '--]$' 'NEW'  < ../inputs/temp-test/1940.inp.824.6 > ../outputs/t1843
    if diff ../outputs/t1843 ../originals/t1843 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1844) timeout -s 9 2 ../source/replace.exe '--]$' 'NEW'  < ../inputs/temp-test/1941.inp.824.9 > ../outputs/t1844
    if diff ../outputs/t1844 ../originals/t1844 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1845) timeout -s 9 2 ../source/replace.exe '--]' '&'  < ../inputs/temp-test/2000.inp.850.1 > ../outputs/t1845
    if diff ../outputs/t1845 ../originals/t1845 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1846) timeout -s 9 2 ../source/replace.exe '--]' 'NEW'  < ../inputs/temp-test/1937.inp.824.1 > ../outputs/t1846
    if diff ../outputs/t1846 ../originals/t1846 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1847) timeout -s 9 2 ../source/replace.exe '--]' 'NEW'  < ../inputs/temp-test/1938.inp.824.2 > ../outputs/t1847
    if diff ../outputs/t1847 ../originals/t1847 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1848) timeout -s 9 2 ../source/replace.exe '--]' 'NEW'  < ../inputs/temp-test/1939.inp.824.3 > ../outputs/t1848
    if diff ../outputs/t1848 ../originals/t1848 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1849) timeout -s 9 2 ../source/replace.exe '--][^--z]-' '&a@%'  < ../inputs/temp-test/1271.inp.546.1 > ../outputs/t1849
    if diff ../outputs/t1849 ../originals/t1849 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1850) timeout -s 9 2 ../source/replace.exe '--][^--z]-' '&a@%'  < ../inputs/temp-test/1272.inp.546.2 > ../outputs/t1850
    if diff ../outputs/t1850 ../originals/t1850 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1851) timeout -s 9 2 ../source/replace.exe '--][^--z]-' '&a@%'  < ../inputs/temp-test/1273.inp.546.3 > ../outputs/t1851
    if diff ../outputs/t1851 ../originals/t1851 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1852) timeout -s 9 2 ../source/replace.exe '-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?*[0-9]*' ','  < ../inputs/input/ruin.1353 > ../outputs/t1852
    if diff ../outputs/t1852 ../originals/t1852 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1853) timeout -s 9 2 ../source/replace.exe '-?' '&'  < ../inputs/temp-test/372.inp.162.1 > ../outputs/t1853
    if diff ../outputs/t1853 ../originals/t1853 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1854) timeout -s 9 2 ../source/replace.exe '-?' '&'  < ../inputs/temp-test/373.inp.162.3 > ../outputs/t1854
    if diff ../outputs/t1854 ../originals/t1854 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1855) timeout -s 9 2 ../source/replace.exe '-?' '&'  < ../inputs/temp-test/374.inp.162.4 > ../outputs/t1855
    if diff ../outputs/t1855 ../originals/t1855 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1856) timeout -s 9 2 ../source/replace.exe '-?' '&a@%'  < ../inputs/temp-test/1337.inp.574.1 > ../outputs/t1856
    if diff ../outputs/t1856 ../originals/t1856 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1857) timeout -s 9 2 ../source/replace.exe '-?' ''  < ../inputs/temp-test/1211.inp.520.1 > ../outputs/t1857
    if diff ../outputs/t1857 ../originals/t1857 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1858) timeout -s 9 2 ../source/replace.exe '-?' ''  < ../inputs/temp-test/1577.inp.673.1 > ../outputs/t1858
    if diff ../outputs/t1858 ../originals/t1858 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1859) timeout -s 9 2 ../source/replace.exe '-?' ''  < ../inputs/temp-test/1578.inp.673.2 > ../outputs/t1859
    if diff ../outputs/t1859 ../originals/t1859 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1860) timeout -s 9 2 ../source/replace.exe '-?' ''  < ../inputs/temp-test/1579.inp.673.3 > ../outputs/t1860
    if diff ../outputs/t1860 ../originals/t1860 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1861) timeout -s 9 2 ../source/replace.exe '-?' ''  < ../inputs/temp-test/1580.inp.673.4 > ../outputs/t1861
    if diff ../outputs/t1861 ../originals/t1861 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1862) timeout -s 9 2 ../source/replace.exe '-?' '@%&a'  < ../inputs/temp-test/2052.inp.870.1 > ../outputs/t1862
    if diff ../outputs/t1862 ../originals/t1862 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1863) timeout -s 9 2 ../source/replace.exe '-?' '@%@&'  < ../inputs/temp-test/1764.inp.751.1 > ../outputs/t1863
    if diff ../outputs/t1863 ../originals/t1863 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1864) timeout -s 9 2 ../source/replace.exe '-?' '@%@&'  < ../inputs/temp-test/1765.inp.751.2 > ../outputs/t1864
    if diff ../outputs/t1864 ../originals/t1864 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1865) timeout -s 9 2 ../source/replace.exe '-?' '@%@&'  < ../inputs/temp-test/50.inp.21.1 > ../outputs/t1865
    if diff ../outputs/t1865 ../originals/t1865 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1866) timeout -s 9 2 ../source/replace.exe '-?' '@%@&'  < ../inputs/temp-test/51.inp.21.2 > ../outputs/t1866
    if diff ../outputs/t1866 ../originals/t1866 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1867) timeout -s 9 2 ../source/replace.exe '-?' '@%@&'  < ../inputs/temp-test/52.inp.21.4 > ../outputs/t1867
    if diff ../outputs/t1867 ../originals/t1867 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1868) timeout -s 9 2 ../source/replace.exe '-?' '@n'  < ../inputs/temp-test/2297.inp.974.1 > ../outputs/t1868
    if diff ../outputs/t1868 ../originals/t1868 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1869) timeout -s 9 2 ../source/replace.exe '-?' '@n'  < ../inputs/temp-test/232.inp.104.1 > ../outputs/t1869
    if diff ../outputs/t1869 ../originals/t1869 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1870) timeout -s 9 2 ../source/replace.exe '-?' '@n'  < ../inputs/temp-test/233.inp.104.2 > ../outputs/t1870
    if diff ../outputs/t1870 ../originals/t1870 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1871) timeout -s 9 2 ../source/replace.exe '-?' '@n'  < ../inputs/temp-test/234.inp.104.3 > ../outputs/t1871
    if diff ../outputs/t1871 ../originals/t1871 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1872) timeout -s 9 2 ../source/replace.exe '-?' '@t'  < ../inputs/temp-test/1450.inp.622.1 > ../outputs/t1872
    if diff ../outputs/t1872 ../originals/t1872 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1873) timeout -s 9 2 ../source/replace.exe '-?' '@t'  < ../inputs/temp-test/1451.inp.622.2 > ../outputs/t1873
    if diff ../outputs/t1873 ../originals/t1873 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1874) timeout -s 9 2 ../source/replace.exe '-?' '@t'  < ../inputs/temp-test/306.inp.137.1 > ../outputs/t1874
    if diff ../outputs/t1874 ../originals/t1874 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1875) timeout -s 9 2 ../source/replace.exe '-?' '@t'  < ../inputs/temp-test/307.inp.137.3 > ../outputs/t1875
    if diff ../outputs/t1875 ../originals/t1875 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1876) timeout -s 9 2 ../source/replace.exe '-?' 'NEW'  < ../inputs/temp-test/2066.inp.876.1 > ../outputs/t1876
    if diff ../outputs/t1876 ../originals/t1876 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1877) timeout -s 9 2 ../source/replace.exe '-?' 'NEW'  < ../inputs/temp-test/2067.inp.876.3 > ../outputs/t1877
    if diff ../outputs/t1877 ../originals/t1877 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1878) timeout -s 9 2 ../source/replace.exe '-?' 'a&'  < ../inputs/temp-test/1076.inp.464.1 > ../outputs/t1878
    if diff ../outputs/t1878 ../originals/t1878 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1879) timeout -s 9 2 ../source/replace.exe '-?' 'a&'  < ../inputs/temp-test/1077.inp.464.2 > ../outputs/t1879
    if diff ../outputs/t1879 ../originals/t1879 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1880) timeout -s 9 2 ../source/replace.exe '-?' 'a&'  < ../inputs/temp-test/1078.inp.464.4 > ../outputs/t1880
    if diff ../outputs/t1880 ../originals/t1880 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1881) timeout -s 9 2 ../source/replace.exe '-?' 'a&'  < ../inputs/temp-test/2.inp.1.2 > ../outputs/t1881
    if diff ../outputs/t1881 ../originals/t1881 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1882) timeout -s 9 2 ../source/replace.exe '-?' 'a@n'  < ../inputs/temp-test/61.inp.26.1 > ../outputs/t1882
    if diff ../outputs/t1882 ../originals/t1882 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1883) timeout -s 9 2 ../source/replace.exe '-?' 'a@n'  < ../inputs/temp-test/62.inp.26.3 > ../outputs/t1883
    if diff ../outputs/t1883 ../originals/t1883 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1884) timeout -s 9 2 ../source/replace.exe '-?' 'a@nb@tc'  < ../inputs/temp-test/1142.inp.492.1 > ../outputs/t1884
    if diff ../outputs/t1884 ../originals/t1884 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1885) timeout -s 9 2 ../source/replace.exe '-?' 'a@nb@tc'  < ../inputs/temp-test/1143.inp.492.2 > ../outputs/t1885
    if diff ../outputs/t1885 ../originals/t1885 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1886) timeout -s 9 2 ../source/replace.exe '-?' 'a@nb@tc'  < ../inputs/temp-test/1144.inp.492.3 > ../outputs/t1886
    if diff ../outputs/t1886 ../originals/t1886 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1887) timeout -s 9 2 ../source/replace.exe '-?' 'a@nb@tc'  < ../inputs/temp-test/1145.inp.492.4 > ../outputs/t1887
    if diff ../outputs/t1887 ../originals/t1887 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1888) timeout -s 9 2 ../source/replace.exe '-?*$'   < ../inputs/temp-test/207.inp.93.1 > ../outputs/t1888
    if diff ../outputs/t1888 ../originals/t1888 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1889) timeout -s 9 2 ../source/replace.exe '-?*$'   < ../inputs/temp-test/208.inp.93.2 > ../outputs/t1889
    if diff ../outputs/t1889 ../originals/t1889 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1890) timeout -s 9 2 ../source/replace.exe '-?*$'   < ../inputs/temp-test/209.inp.93.3 > ../outputs/t1890
    if diff ../outputs/t1890 ../originals/t1890 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1891) timeout -s 9 2 ../source/replace.exe '-?*' '&'  < ../inputs/temp-test/524.inp.227.1 > ../outputs/t1891
    if diff ../outputs/t1891 ../originals/t1891 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1892) timeout -s 9 2 ../source/replace.exe '-?-' '@%@&'  < ../inputs/temp-test/943.inp.405.1 > ../outputs/t1892
    if diff ../outputs/t1892 ../originals/t1892 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1893) timeout -s 9 2 ../source/replace.exe '-?-?' 'a@n'  < ../inputs/temp-test/1700.inp.725.1 > ../outputs/t1893
    if diff ../outputs/t1893 ../originals/t1893 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1894) timeout -s 9 2 ../source/replace.exe '-?-?@n[9-B]' '&a@%'  < ../inputs/temp-test/1212.inp.521.1 > ../outputs/t1894
    if diff ../outputs/t1894 ../originals/t1894 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1895) timeout -s 9 2 ../source/replace.exe '-?-?@n[9-B]' '&a@%'  < ../inputs/temp-test/1213.inp.521.2 > ../outputs/t1895
    if diff ../outputs/t1895 ../originals/t1895 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1896) timeout -s 9 2 ../source/replace.exe '-?-?@n[9-B]' '&a@%'  < ../inputs/temp-test/1214.inp.521.3 > ../outputs/t1896
    if diff ../outputs/t1896 ../originals/t1896 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1897) timeout -s 9 2 ../source/replace.exe '-?-@**[^0-9]-' '@%@&'  < ../inputs/temp-test/2076.inp.880.1 > ../outputs/t1897
    if diff ../outputs/t1897 ../originals/t1897 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1898) timeout -s 9 2 ../source/replace.exe '-?-@**[^0-9]-@@*[^9-B]?@n*$' '@%@&'  < ../inputs/temp-test/2078.inp.880.6 > ../outputs/t1898
    if diff ../outputs/t1898 ../originals/t1898 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1899) timeout -s 9 2 ../source/replace.exe '-?-@**[^0-9]-@@*[^9-B]?@n*' '@%@&'  < ../inputs/temp-test/2076.inp.880.1 > ../outputs/t1899
    if diff ../outputs/t1899 ../originals/t1899 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1900) timeout -s 9 2 ../source/replace.exe '-?-@**[^0-9]-@@*[^9-B]?@n*' '@%@&'  < ../inputs/temp-test/2077.inp.880.2 > ../outputs/t1900
    if diff ../outputs/t1900 ../originals/t1900 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1901) timeout -s 9 2 ../source/replace.exe '-?-@n *?' '@%@&'  < ../inputs/temp-test/617.inp.266.1 > ../outputs/t1901
    if diff ../outputs/t1901 ../originals/t1901 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1902) timeout -s 9 2 ../source/replace.exe '-?-@n *?' '@%@&'  < ../inputs/temp-test/618.inp.266.2 > ../outputs/t1902
    if diff ../outputs/t1902 ../originals/t1902 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1903) timeout -s 9 2 ../source/replace.exe '-?-[^-z]' 'NEW'  < ../inputs/temp-test/164.inp.74.1 > ../outputs/t1903
    if diff ../outputs/t1903 ../originals/t1903 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1904) timeout -s 9 2 ../source/replace.exe '-?-[^-z]' 'NEW'  < ../inputs/temp-test/165.inp.74.2 > ../outputs/t1904
    if diff ../outputs/t1904 ../originals/t1904 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1905) timeout -s 9 2 ../source/replace.exe '-?-[^-z]' 'NEW'  < ../inputs/temp-test/166.inp.74.3 > ../outputs/t1905
    if diff ../outputs/t1905 ../originals/t1905 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1906) timeout -s 9 2 ../source/replace.exe '-?-c*[0-9]' 'NEW-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A'  < ../inputs/temp-test/1760.inp.748.3 > ../outputs/t1906
    if diff ../outputs/t1906 ../originals/t1906 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1907) timeout -s 9 2 ../source/replace.exe '-?-c*[0-9][a-c]-?A' 'NEW'  < ../inputs/temp-test/1759.inp.748.1 > ../outputs/t1907
    if diff ../outputs/t1907 ../originals/t1907 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1908) timeout -s 9 2 ../source/replace.exe '-?-c*[0-9][a-c]-?A' 'NEW'  < ../inputs/temp-test/1760.inp.748.3 > ../outputs/t1908
    if diff ../outputs/t1908 ../originals/t1908 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1909) timeout -s 9 2 ../source/replace.exe '-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A' 'NEW'  < ../inputs/temp-test/1760.inp.748.3 > ../outputs/t1909
    if diff ../outputs/t1909 ../originals/t1909 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1910) timeout -s 9 2 ../source/replace.exe '-??[^0-9][9-B][^9-B]' 'a&'  < ../inputs/temp-test/37.inp.16.1 > ../outputs/t1910
    if diff ../outputs/t1910 ../originals/t1910 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1911) timeout -s 9 2 ../source/replace.exe '-??[^0-9][9-B][^9-B]' 'a&'  < ../inputs/temp-test/38.inp.16.2 > ../outputs/t1911
    if diff ../outputs/t1911 ../originals/t1911 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1912) timeout -s 9 2 ../source/replace.exe '-??[a-c]' '@%&a'  < ../inputs/temp-test/1161.inp.500.1 > ../outputs/t1912
    if diff ../outputs/t1912 ../originals/t1912 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1913) timeout -s 9 2 ../source/replace.exe '-??[a-c]' '@%&a'  < ../inputs/temp-test/1162.inp.500.2 > ../outputs/t1913
    if diff ../outputs/t1913 ../originals/t1913 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1914) timeout -s 9 2 ../source/replace.exe '-?@*[^9-B]?' ''  < ../inputs/temp-test/607.inp.261.1 > ../outputs/t1914
    if diff ../outputs/t1914 ../originals/t1914 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1915) timeout -s 9 2 ../source/replace.exe '-?@*[^9-B]?' ''  < ../inputs/temp-test/608.inp.261.3 > ../outputs/t1915
    if diff ../outputs/t1915 ../originals/t1915 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1916) timeout -s 9 2 ../source/replace.exe '-?@@*[_-z][^0-9]' '&'  < ../inputs/temp-test/821.inp.354.1 > ../outputs/t1916
    if diff ../outputs/t1916 ../originals/t1916 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1917) timeout -s 9 2 ../source/replace.exe '-?@@*[_-z][^0-9]' '&'  < ../inputs/temp-test/822.inp.354.4 > ../outputs/t1917
    if diff ../outputs/t1917 ../originals/t1917 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1918) timeout -s 9 2 ../source/replace.exe '-?@[[^9-B]---?' 'a@n'  < ../inputs/temp-test/965.inp.416.1 > ../outputs/t1918
    if diff ../outputs/t1918 ../originals/t1918 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1919) timeout -s 9 2 ../source/replace.exe '-?@[[a-][9-B]- *[a--b]' 'a@n'  < ../inputs/temp-test/1037.inp.446.1 > ../outputs/t1919
    if diff ../outputs/t1919 ../originals/t1919 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1920) timeout -s 9 2 ../source/replace.exe '-?[9-B]--' '&a@%'  < ../inputs/temp-test/1139.inp.490.1 > ../outputs/t1920
    if diff ../outputs/t1920 ../originals/t1920 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1921) timeout -s 9 2 ../source/replace.exe '-?[9-B]--' '&a@%'  < ../inputs/temp-test/1140.inp.490.2 > ../outputs/t1921
    if diff ../outputs/t1921 ../originals/t1921 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1922) timeout -s 9 2 ../source/replace.exe '-?[9-B]@t*$' '@%&a'  < ../inputs/temp-test/816.inp.351.9 > ../outputs/t1922
    if diff ../outputs/t1922 ../originals/t1922 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1923) timeout -s 9 2 ../source/replace.exe '-?[9-B]@t*' '@%&a'  < ../inputs/temp-test/815.inp.351.1 > ../outputs/t1923
    if diff ../outputs/t1923 ../originals/t1923 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1924) timeout -s 9 2 ../source/replace.exe '-?[@n]?[@@][^9-B][0-9]?$' 'NEW'  < ../inputs/temp-test/885.inp.380.6 > ../outputs/t1924
    if diff ../outputs/t1924 ../originals/t1924 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1925) timeout -s 9 2 ../source/replace.exe '-?[@n]?[@@][^9-B][0-9]?' 'NEW'  < ../inputs/temp-test/883.inp.380.1 > ../outputs/t1925
    if diff ../outputs/t1925 ../originals/t1925 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1926) timeout -s 9 2 ../source/replace.exe '-?[@n]?[@@][^9-B][0-9]?' 'NEW'  < ../inputs/temp-test/884.inp.380.2 > ../outputs/t1926
    if diff ../outputs/t1926 ../originals/t1926 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1927) timeout -s 9 2 ../source/replace.exe '-?[^0-9]-' 'a@nb@tc'  < ../inputs/temp-test/2062.inp.874.1 > ../outputs/t1927
    if diff ../outputs/t1927 ../originals/t1927 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1928) timeout -s 9 2 ../source/replace.exe '-?[^0-9]-' 'a@nb@tc'  < ../inputs/temp-test/2063.inp.874.3 > ../outputs/t1928
    if diff ../outputs/t1928 ../originals/t1928 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1929) timeout -s 9 2 ../source/replace.exe '-?[^0-9]?' '&'  < ../inputs/temp-test/463.inp.203.1 > ../outputs/t1929
    if diff ../outputs/t1929 ../originals/t1929 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1930) timeout -s 9 2 ../source/replace.exe '-?[^0-9]?' '&'  < ../inputs/temp-test/464.inp.203.3 > ../outputs/t1930
    if diff ../outputs/t1930 ../originals/t1930 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1931) timeout -s 9 2 ../source/replace.exe '-?[^0-9]?' '&'  < ../inputs/temp-test/465.inp.203.4 > ../outputs/t1931
    if diff ../outputs/t1931 ../originals/t1931 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1932) timeout -s 9 2 ../source/replace.exe '-?[^9-B]?-?' 'a@nb@tc'  < ../inputs/temp-test/2099.inp.890.1 > ../outputs/t1932
    if diff ../outputs/t1932 ../originals/t1932 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1933) timeout -s 9 2 ../source/replace.exe '-?[^9-B]?-?' 'a@nb@tc'  < ../inputs/temp-test/2100.inp.890.2 > ../outputs/t1933
    if diff ../outputs/t1933 ../originals/t1933 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1934) timeout -s 9 2 ../source/replace.exe '-?[^9-B]?-?' 'a@nb@tc'  < ../inputs/temp-test/2101.inp.890.3 > ../outputs/t1934
    if diff ../outputs/t1934 ../originals/t1934 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1935) timeout -s 9 2 ../source/replace.exe '-?[^9-B]?-?' 'a@nb@tc'  < ../inputs/temp-test/2102.inp.890.4 > ../outputs/t1935
    if diff ../outputs/t1935 ../originals/t1935 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1936) timeout -s 9 2 ../source/replace.exe '-?[^9-B]@**[0-9]' '@n'  < ../inputs/temp-test/1872.inp.794.1 > ../outputs/t1936
    if diff ../outputs/t1936 ../originals/t1936 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1937) timeout -s 9 2 ../source/replace.exe '-?[^9-B]@**[0-9]' '@n'  < ../inputs/temp-test/1873.inp.794.3 > ../outputs/t1937
    if diff ../outputs/t1937 ../originals/t1937 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1938) timeout -s 9 2 ../source/replace.exe '-?[^9-B]@**[0-9]' '@n-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?-?A-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?'  < ../inputs/temp-test/1872.inp.794.1 > ../outputs/t1938
    if diff ../outputs/t1938 ../originals/t1938 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1939) timeout -s 9 2 ../source/replace.exe '-?[^a--]@[*[^9-B]A-[@@]' 'a@nb@tc'  < ../inputs/temp-test/1724.inp.734.1 > ../outputs/t1939
    if diff ../outputs/t1939 ../originals/t1939 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1940) timeout -s 9 2 ../source/replace.exe '-?[^a--]@[*[^9-B]A-[@@]' 'a@nb@tc'  < ../inputs/temp-test/1725.inp.734.2 > ../outputs/t1940
    if diff ../outputs/t1940 ../originals/t1940 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1941) timeout -s 9 2 ../source/replace.exe '-?[^a--]@[*[^9-B]A-[@@]' 'a@nb@tc'  < ../inputs/temp-test/1726.inp.734.3 > ../outputs/t1941
    if diff ../outputs/t1941 ../originals/t1941 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1942) timeout -s 9 2 ../source/replace.exe '-?[^a-c-*' 'a@n'  < ../inputs/temp-test/1262.inp.542.1 > ../outputs/t1942
    if diff ../outputs/t1942 ../originals/t1942 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1943) timeout -s 9 2 ../source/replace.exe '-?[^a-c-*' 'a@n'  < ../inputs/temp-test/1263.inp.542.3 > ../outputs/t1943
    if diff ../outputs/t1943 ../originals/t1943 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1944) timeout -s 9 2 ../source/replace.exe '-?[^a-c-*' 'a@n'  < ../inputs/temp-test/1264.inp.542.4 > ../outputs/t1944
    if diff ../outputs/t1944 ../originals/t1944 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1945) timeout -s 9 2 ../source/replace.exe '-?[^a-c]' 'b@t'  < ../inputs/temp-test/2238.inp.949.1 > ../outputs/t1945
    if diff ../outputs/t1945 ../originals/t1945 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1946) timeout -s 9 2 ../source/replace.exe '-?[^a-c]' 'b@t'  < ../inputs/temp-test/2239.inp.949.2 > ../outputs/t1946
    if diff ../outputs/t1946 ../originals/t1946 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1947) timeout -s 9 2 ../source/replace.exe '-?[^a-c]??-' '@%&a'  < ../inputs/temp-test/360.inp.158.1 > ../outputs/t1947
    if diff ../outputs/t1947 ../originals/t1947 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1948) timeout -s 9 2 ../source/replace.exe '-?[^a-c]??-' '@%&a'  < ../inputs/temp-test/361.inp.158.3 > ../outputs/t1948
    if diff ../outputs/t1948 ../originals/t1948 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1949) timeout -s 9 2 ../source/replace.exe '-?[^a-c]??-' '@%&a@'  < ../inputs/temp-test/361.inp.158.3 > ../outputs/t1949
    if diff ../outputs/t1949 ../originals/t1949 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1950) timeout -s 9 2 ../source/replace.exe '-?[^a-c]??-@' '@%&a'  < ../inputs/temp-test/360.inp.158.1 > ../outputs/t1950
    if diff ../outputs/t1950 ../originals/t1950 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1951) timeout -s 9 2 ../source/replace.exe '-?[a-c$*$'   < ../inputs/temp-test/210.inp.93.8 > ../outputs/t1951
    if diff ../outputs/t1951 ../originals/t1951 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1952) timeout -s 9 2 ../source/replace.exe '-?^*?-[^9-B]-[@n]-?[9-B]' '@%&a'  < ../inputs/temp-test/712.inp.308.1 > ../outputs/t1952
    if diff ../outputs/t1952 ../originals/t1952 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1953) timeout -s 9 2 ../source/replace.exe '-?^*?-[^9-B]-[@n]-?[9-B]' '@%&a'  < ../inputs/temp-test/713.inp.308.2 > ../outputs/t1953
    if diff ../outputs/t1953 ../originals/t1953 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1954) timeout -s 9 2 ../source/replace.exe '-?^*?-[^9-B]-[@n]-?[9-B]' '@%&a'  < ../inputs/temp-test/714.inp.308.3 > ../outputs/t1954
    if diff ../outputs/t1954 ../originals/t1954 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1955) timeout -s 9 2 ../source/replace.exe '-?^a-c]?^-]' 'a@nb@tc'  < ../inputs/temp-test/1423.inp.612.1 > ../outputs/t1955
    if diff ../outputs/t1955 ../originals/t1955 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1956) timeout -s 9 2 ../source/replace.exe '-?^a-c]?^-]' 'a@nb@tc'  < ../inputs/temp-test/1424.inp.612.2 > ../outputs/t1956
    if diff ../outputs/t1956 ../originals/t1956 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1957) timeout -s 9 2 ../source/replace.exe '-?^a-c]?^-]' 'a@nb@tc'  < ../inputs/temp-test/1425.inp.612.3 > ../outputs/t1957
    if diff ../outputs/t1957 ../originals/t1957 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1958) timeout -s 9 2 ../source/replace.exe '-@*' '@%&a'  < ../inputs/temp-test/319.inp.142.1 > ../outputs/t1958
    if diff ../outputs/t1958 ../originals/t1958 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1959) timeout -s 9 2 ../source/replace.exe '-@*' '@%&a'  < ../inputs/temp-test/320.inp.142.2 > ../outputs/t1959
    if diff ../outputs/t1959 ../originals/t1959 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1960) timeout -s 9 2 ../source/replace.exe '-@**' '&a@%'  < ../inputs/temp-test/830.inp.358.1 > ../outputs/t1960
    if diff ../outputs/t1960 ../originals/t1960 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1961) timeout -s 9 2 ../source/replace.exe '-@**' '&a@%'  < ../inputs/temp-test/831.inp.358.2 > ../outputs/t1961
    if diff ../outputs/t1961 ../originals/t1961 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1962) timeout -s 9 2 ../source/replace.exe '-@**' '&a@%'  < ../inputs/temp-test/832.inp.358.3 > ../outputs/t1962
    if diff ../outputs/t1962 ../originals/t1962 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1963) timeout -s 9 2 ../source/replace.exe '-@**' '@%@&'  < ../inputs/temp-test/2295.inp.973.1 > ../outputs/t1963
    if diff ../outputs/t1963 ../originals/t1963 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1964) timeout -s 9 2 ../source/replace.exe '-@**' '@%@&'  < ../inputs/temp-test/2296.inp.973.2 > ../outputs/t1964
    if diff ../outputs/t1964 ../originals/t1964 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1965) timeout -s 9 2 ../source/replace.exe '-@**' 'NEW'  < ../inputs/temp-test/1836.inp.781.1 > ../outputs/t1965
    if diff ../outputs/t1965 ../originals/t1965 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1966) timeout -s 9 2 ../source/replace.exe '-@**' 'NEW'  < ../inputs/temp-test/1837.inp.781.3 > ../outputs/t1966
    if diff ../outputs/t1966 ../originals/t1966 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1967) timeout -s 9 2 ../source/replace.exe '-@**' 'a@n'  < ../inputs/temp-test/896.inp.385.1 > ../outputs/t1967
    if diff ../outputs/t1967 ../originals/t1967 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1968) timeout -s 9 2 ../source/replace.exe '-@**?[^0-9][9-B]---[^0-9]-?' ''  < ../inputs/temp-test/2135.inp.904.1 > ../outputs/t1968
    if diff ../outputs/t1968 ../originals/t1968 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1969) timeout -s 9 2 ../source/replace.exe '-@**?[^0-9][9-B]---[^0-9]-?' ''  < ../inputs/temp-test/2136.inp.904.3 > ../outputs/t1969
    if diff ../outputs/t1969 ../originals/t1969 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1970) timeout -s 9 2 ../source/replace.exe '-@**[^a--]-^*[a-c]' 'a@nb@tc'  < ../inputs/temp-test/1391.inp.597.1 > ../outputs/t1970
    if diff ../outputs/t1970 ../originals/t1970 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1971) timeout -s 9 2 ../source/replace.exe '-@**[^a--]-^*[a-c]' 'a@nb@tc'  < ../inputs/temp-test/1392.inp.597.2 > ../outputs/t1971
    if diff ../outputs/t1971 ../originals/t1971 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1972) timeout -s 9 2 ../source/replace.exe '-@**[^a--]-^*[a-c]' 'a@nb@tc'  < ../inputs/temp-test/1393.inp.597.3 > ../outputs/t1972
    if diff ../outputs/t1972 ../originals/t1972 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1973) timeout -s 9 2 ../source/replace.exe '-@**[^a--]-^*[a-c]' 'a@nb@tc'  < ../inputs/temp-test/1394.inp.597.4 > ../outputs/t1973
    if diff ../outputs/t1973 ../originals/t1973 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1974) timeout -s 9 2 ../source/replace.exe '-@**[^a-c]?@[[^a-c]$' '@%&a'  < ../inputs/temp-test/1900.inp.805.8 > ../outputs/t1974
    if diff ../outputs/t1974 ../originals/t1974 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1975) timeout -s 9 2 ../source/replace.exe '-@**[^a-c]?@[[^a-c]' '@%&a'  < ../inputs/temp-test/1897.inp.805.1 > ../outputs/t1975
    if diff ../outputs/t1975 ../originals/t1975 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1976) timeout -s 9 2 ../source/replace.exe '-@**[^a-c]?@[[^a-c]' '@%&a'  < ../inputs/temp-test/1898.inp.805.2 > ../outputs/t1976
    if diff ../outputs/t1976 ../originals/t1976 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1977) timeout -s 9 2 ../source/replace.exe '-@**[^a-c]?@[[^a-c]' '@%&a'  < ../inputs/temp-test/1899.inp.805.3 > ../outputs/t1977
    if diff ../outputs/t1977 ../originals/t1977 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1978) timeout -s 9 2 ../source/replace.exe '-@*?[9-B]' 'a@nb@tc'  < ../inputs/temp-test/1657.inp.706.1 > ../outputs/t1978
    if diff ../outputs/t1978 ../originals/t1978 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1979) timeout -s 9 2 ../source/replace.exe '-@*[^a--]--' '&'  < ../inputs/temp-test/853.inp.367.1 > ../outputs/t1979
    if diff ../outputs/t1979 ../originals/t1979 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1980) timeout -s 9 2 ../source/replace.exe '-@*[^a--]--' '&'  < ../inputs/temp-test/854.inp.367.2 > ../outputs/t1980
    if diff ../outputs/t1980 ../originals/t1980 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1981) timeout -s 9 2 ../source/replace.exe '-@*[^a--]--' '&'  < ../inputs/temp-test/855.inp.367.3 > ../outputs/t1981
    if diff ../outputs/t1981 ../originals/t1981 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1982) timeout -s 9 2 ../source/replace.exe '-@*[a-c]? *[a-[^a-c]-' '@%&a'  < ../inputs/temp-test/685.inp.298.1 > ../outputs/t1982
    if diff ../outputs/t1982 ../originals/t1982 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1983) timeout -s 9 2 ../source/replace.exe '-@*[a-c]? *[a-[^a-c]-' '@%&a'  < ../inputs/temp-test/686.inp.298.2 > ../outputs/t1983
    if diff ../outputs/t1983 ../originals/t1983 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1984) timeout -s 9 2 ../source/replace.exe '-@*[a-c]? *[a-[^a-c]-' '@%&a'  < ../inputs/temp-test/687.inp.298.3 > ../outputs/t1984
    if diff ../outputs/t1984 ../originals/t1984 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1985) timeout -s 9 2 ../source/replace.exe '-@*a-c]?a-]^a-][^9-B]' 'a@nb@tc'  < ../inputs/temp-test/2174.inp.920.1 > ../outputs/t1985
    if diff ../outputs/t1985 ../originals/t1985 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1986) timeout -s 9 2 ../source/replace.exe '-@*a-c]?a-]^a-][^9-B]' 'a@nb@tc'  < ../inputs/temp-test/2175.inp.920.2 > ../outputs/t1986
    if diff ../outputs/t1986 ../originals/t1986 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1987) timeout -s 9 2 ../source/replace.exe '-@@(@@$' '.'  < ../inputs/input/ruin.994 > ../outputs/t1987
    if diff ../outputs/t1987 ../originals/t1987 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1988) timeout -s 9 2 ../source/replace.exe '-@@*[^9-B][_-z]@t*?' '&a@%'  < ../inputs/temp-test/415.inp.183.1 > ../outputs/t1988
    if diff ../outputs/t1988 ../originals/t1988 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1989) timeout -s 9 2 ../source/replace.exe '-@@*[^9-B][_-z]@t*?' '&a@%'  < ../inputs/temp-test/416.inp.183.3 > ../outputs/t1989
    if diff ../outputs/t1989 ../originals/t1989 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1990) timeout -s 9 2 ../source/replace.exe '-@[' '@%&a'  < ../inputs/temp-test/864.inp.372.1 > ../outputs/t1990
    if diff ../outputs/t1990 ../originals/t1990 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1991) timeout -s 9 2 ../source/replace.exe '-@[' '@%&a'  < ../inputs/temp-test/865.inp.372.2 > ../outputs/t1991
    if diff ../outputs/t1991 ../originals/t1991 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1992) timeout -s 9 2 ../source/replace.exe '-@[' '@%&a'  < ../inputs/temp-test/866.inp.372.4 > ../outputs/t1992
    if diff ../outputs/t1992 ../originals/t1992 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1993) timeout -s 9 2 ../source/replace.exe '-@[' 'NEW'  < ../inputs/temp-test/1761.inp.749.1 > ../outputs/t1993
    if diff ../outputs/t1993 ../originals/t1993 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1994) timeout -s 9 2 ../source/replace.exe '-@[*' '@%&a'  < ../inputs/temp-test/1403.inp.602.1 > ../outputs/t1994
    if diff ../outputs/t1994 ../originals/t1994 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1995) timeout -s 9 2 ../source/replace.exe '-@[*' '@%&a'  < ../inputs/temp-test/1404.inp.602.2 > ../outputs/t1995
    if diff ../outputs/t1995 ../originals/t1995 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1996) timeout -s 9 2 ../source/replace.exe '-@[*' '@%&a'  < ../inputs/temp-test/1405.inp.602.3 > ../outputs/t1996
    if diff ../outputs/t1996 ../originals/t1996 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1997) timeout -s 9 2 ../source/replace.exe '-@[*' '@%@&'  < ../inputs/temp-test/1456.inp.624.1 > ../outputs/t1997
    if diff ../outputs/t1997 ../originals/t1997 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1998) timeout -s 9 2 ../source/replace.exe '-@[*' '@%@&'  < ../inputs/temp-test/1457.inp.624.2 > ../outputs/t1998
    if diff ../outputs/t1998 ../originals/t1998 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p1999) timeout -s 9 2 ../source/replace.exe '-@[*' '@%@&'  < ../inputs/temp-test/1458.inp.624.3 > ../outputs/t1999
    if diff ../outputs/t1999 ../originals/t1999 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2000) timeout -s 9 2 ../source/replace.exe '-@[*-[0-9]?[^a-c][a-c]' '&'  < ../inputs/temp-test/1710.inp.729.1 > ../outputs/t2000
    if diff ../outputs/t2000 ../originals/t2000 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2001) timeout -s 9 2 ../source/replace.exe '-@[*-[0-9]?[^a-c][a-c]' '&'  < ../inputs/temp-test/1711.inp.729.3 > ../outputs/t2001
    if diff ../outputs/t2001 ../originals/t2001 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2002) timeout -s 9 2 ../source/replace.exe '-@[*[^9-B]?[^a-c *?--?' 'NEW'  < ../inputs/temp-test/1254.inp.538.1 > ../outputs/t2002
    if diff ../outputs/t2002 ../originals/t2002 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2003) timeout -s 9 2 ../source/replace.exe '-@[*[^9-B]?[^a-c *?--?' 'NEW'  < ../inputs/temp-test/1255.inp.538.2 > ../outputs/t2003
    if diff ../outputs/t2003 ../originals/t2003 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2004) timeout -s 9 2 ../source/replace.exe '-@[[^@@]-@**[a-c]' ''  < ../inputs/temp-test/453.inp.198.1 > ../outputs/t2004
    if diff ../outputs/t2004 ../originals/t2004 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2005) timeout -s 9 2 ../source/replace.exe '-@[[^@@]-@**[a-c]' ''  < ../inputs/temp-test/454.inp.198.3 > ../outputs/t2005
    if diff ../outputs/t2005 ../originals/t2005 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2006) timeout -s 9 2 ../source/replace.exe '-@n' '*U&:an"OMpY#Ei1WdZ>`'  < ../inputs/input/ruin.1277 > ../outputs/t2006
    if diff ../outputs/t2006 ../originals/t2006 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2007) timeout -s 9 2 ../source/replace.exe '-@n*' 'a&'  < ../inputs/temp-test/329.inp.146.1 > ../outputs/t2007
    if diff ../outputs/t2007 ../originals/t2007 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2008) timeout -s 9 2 ../source/replace.exe '-@n*' 'a&'  < ../inputs/temp-test/330.inp.146.2 > ../outputs/t2008
    if diff ../outputs/t2008 ../originals/t2008 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2009) timeout -s 9 2 ../source/replace.exe '-@n*' 'a&'  < ../inputs/temp-test/331.inp.146.3 > ../outputs/t2009
    if diff ../outputs/t2009 ../originals/t2009 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2010) timeout -s 9 2 ../source/replace.exe '-@n*' 'a&'  < ../inputs/temp-test/332.inp.146.4 > ../outputs/t2010
    if diff ../outputs/t2010 ../originals/t2010 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2011) timeout -s 9 2 ../source/replace.exe '-@n-@[[a-c]^a-c]-*?[^-z]-' '&a@%'  < ../inputs/temp-test/292.inp.132.1 > ../outputs/t2011
    if diff ../outputs/t2011 ../originals/t2011 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2012) timeout -s 9 2 ../source/replace.exe '-@n-@[[a-c]^a-c]-*?[^-z]-' '&a@%'  < ../inputs/temp-test/293.inp.132.2 > ../outputs/t2012
    if diff ../outputs/t2012 ../originals/t2012 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2013) timeout -s 9 2 ../source/replace.exe '-@n-@[[a-c]^a-c]-*?[^-z]-' '&a@%'  < ../inputs/temp-test/294.inp.132.4 > ../outputs/t2013
    if diff ../outputs/t2013 ../originals/t2013 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2014) timeout -s 9 2 ../source/replace.exe '-@t' ''  < ../inputs/temp-test/40.inp.17.1 > ../outputs/t2014
    if diff ../outputs/t2014 ../originals/t2014 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2015) timeout -s 9 2 ../source/replace.exe '-@t' ''  < ../inputs/temp-test/41.inp.17.2 > ../outputs/t2015
    if diff ../outputs/t2015 ../originals/t2015 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2016) timeout -s 9 2 ../source/replace.exe '-@t*-[@@]?-@[*?[^9-B]?[^0-9]-[^a--b] ' '@t'  < ../inputs/temp-test/1796.inp.764.1 > ../outputs/t2016
    if diff ../outputs/t2016 ../originals/t2016 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2017) timeout -s 9 2 ../source/replace.exe '-@t*-[@@]?-@[*?[^9-B]?[^0-9]-[^a--b] ' '@t'  < ../inputs/temp-test/1797.inp.764.2 > ../outputs/t2017
    if diff ../outputs/t2017 ../originals/t2017 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2018) timeout -s 9 2 ../source/replace.exe '-@t*@t*-@t?[-[a--]?[^a-c[0-9]^-]?-' '&'  < ../inputs/temp-test/1888.inp.801.1 > ../outputs/t2018
    if diff ../outputs/t2018 ../originals/t2018 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2019) timeout -s 9 2 ../source/replace.exe '-@t*@t*-@t?[-[a--]?[^a-c[0-9]^-]?-' '&'  < ../inputs/temp-test/1889.inp.801.2 > ../outputs/t2019
    if diff ../outputs/t2019 ../originals/t2019 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2020) timeout -s 9 2 ../source/replace.exe '-@t*@t*-@t?[-[a--]?[^a-c[0-9]^-]?-' '&'  < ../inputs/temp-test/1890.inp.801.3 > ../outputs/t2020
    if diff ../outputs/t2020 ../originals/t2020 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2021) timeout -s 9 2 ../source/replace.exe '-[-z]$' 'NEW'  < ../inputs/temp-test/368.inp.160.6 > ../outputs/t2021
    if diff ../outputs/t2021 ../originals/t2021 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2022) timeout -s 9 2 ../source/replace.exe '-[-z]' 'NEW'  < ../inputs/temp-test/366.inp.160.1 > ../outputs/t2022
    if diff ../outputs/t2022 ../originals/t2022 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2023) timeout -s 9 2 ../source/replace.exe '-[-z]' 'NEW'  < ../inputs/temp-test/367.inp.160.3 > ../outputs/t2023
    if diff ../outputs/t2023 ../originals/t2023 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2024) timeout -s 9 2 ../source/replace.exe '-[0-9]' 'NEW'  < ../inputs/temp-test/1410.inp.605.1 > ../outputs/t2024
    if diff ../outputs/t2024 ../originals/t2024 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2025) timeout -s 9 2 ../source/replace.exe '-[0-9]' 'a&'  < ../inputs/temp-test/646.inp.280.1 > ../outputs/t2025
    if diff ../outputs/t2025 ../originals/t2025 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2026) timeout -s 9 2 ../source/replace.exe '-[0-9]' 'a&'  < ../inputs/temp-test/647.inp.280.2 > ../outputs/t2026
    if diff ../outputs/t2026 ../originals/t2026 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2027) timeout -s 9 2 ../source/replace.exe '-[0-9]-?@[ -' ''  < ../inputs/temp-test/252.inp.112.1 > ../outputs/t2027
    if diff ../outputs/t2027 ../originals/t2027 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2028) timeout -s 9 2 ../source/replace.exe '-[0-9]-?@[ -' ''  < ../inputs/temp-test/253.inp.112.3 > ../outputs/t2028
    if diff ../outputs/t2028 ../originals/t2028 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2029) timeout -s 9 2 ../source/replace.exe '-[0-9]-[9-B][^0-9]-[0-9]?c-?[a-c@*-' ''  < ../inputs/temp-test/1322.inp.568.1 > ../outputs/t2029
    if diff ../outputs/t2029 ../originals/t2029 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2030) timeout -s 9 2 ../source/replace.exe '-[0-9]-[9-B][^0-9]-[0-9]?c-?[a-c@*-' ''  < ../inputs/temp-test/1323.inp.568.2 > ../outputs/t2030
    if diff ../outputs/t2030 ../originals/t2030 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2031) timeout -s 9 2 ../source/replace.exe '-[0-9]-[9-B][^0-9]-[0-9]?c-?[a-c@*-' ''  < ../inputs/temp-test/1324.inp.568.3 > ../outputs/t2031
    if diff ../outputs/t2031 ../originals/t2031 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2032) timeout -s 9 2 ../source/replace.exe '-[0-9][^-z]@**[^9-B]?[^a--]@[ *[9-B]$' '@%@&'  < ../inputs/temp-test/365.inp.159.6 > ../outputs/t2032
    if diff ../outputs/t2032 ../originals/t2032 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2033) timeout -s 9 2 ../source/replace.exe '-[0-9][^-z]@**[^9-B]?[^a--]@[ *[9-B]' '@%@&'  < ../inputs/temp-test/362.inp.159.1 > ../outputs/t2033
    if diff ../outputs/t2033 ../originals/t2033 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2034) timeout -s 9 2 ../source/replace.exe '-[0-9][^-z]@**[^9-B]?[^a--]@[ *[9-B]' '@%@&'  < ../inputs/temp-test/363.inp.159.2 > ../outputs/t2034
    if diff ../outputs/t2034 ../originals/t2034 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2035) timeout -s 9 2 ../source/replace.exe '-[0-9][^-z]@**[^9-B]?[^a--]@[ *[9-B]' '@%@&'  < ../inputs/temp-test/364.inp.159.3 > ../outputs/t2035
    if diff ../outputs/t2035 ../originals/t2035 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2036) timeout -s 9 2 ../source/replace.exe '-[0-9][^-z]@**[^9-B]?[^a--]@[ *[9-B]' '@%@&@'  < ../inputs/temp-test/363.inp.159.2 > ../outputs/t2036
    if diff ../outputs/t2036 ../originals/t2036 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2037) timeout -s 9 2 ../source/replace.exe '-[0-9][^-z]@**[^9-B]?[^a--]@[ *[9-B]' '@%@&@'  < ../inputs/temp-test/364.inp.159.3 > ../outputs/t2037
    if diff ../outputs/t2037 ../originals/t2037 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2038) timeout -s 9 2 ../source/replace.exe '-[0-9][^-z]@**[^9-B]?[^a--]@[ *[9-B]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t2038
    if diff ../outputs/t2038 ../originals/t2038 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2039) timeout -s 9 2 ../source/replace.exe '-[0-9][^-z]@**[^9-B]?[^a--]@[ *[9-B]@' '@%@&'  < ../inputs/temp-test/362.inp.159.1 > ../outputs/t2039
    if diff ../outputs/t2039 ../originals/t2039 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2040) timeout -s 9 2 ../source/replace.exe '-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t2040
    if diff ../outputs/t2040 ../originals/t2040 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2041) timeout -s 9 2 ../source/replace.exe '-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t2041
    if diff ../outputs/t2041 ../originals/t2041 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2042) timeout -s 9 2 ../source/replace.exe '-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1398.inp.600.2 > ../outputs/t2042
    if diff ../outputs/t2042 ../originals/t2042 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2043) timeout -s 9 2 ../source/replace.exe '-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1399.inp.600.3 > ../outputs/t2043
    if diff ../outputs/t2043 ../originals/t2043 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2044) timeout -s 9 2 ../source/replace.exe '-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1400.inp.600.4 > ../outputs/t2044
    if diff ../outputs/t2044 ../originals/t2044 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2045) timeout -s 9 2 ../source/replace.exe '-[0-9][^9-B][0-9]?[^0-9]' '@t'  < ../inputs/temp-test/1215.inp.522.1 > ../outputs/t2045
    if diff ../outputs/t2045 ../originals/t2045 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2046) timeout -s 9 2 ../source/replace.exe '-[0-9][^a-c]-?-[^9-B][0-9]' '&a@%'  < ../inputs/temp-test/2139.inp.906.1 > ../outputs/t2046
    if diff ../outputs/t2046 ../originals/t2046 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2047) timeout -s 9 2 ../source/replace.exe '-[9-B] [^0-9][0-9][^0-9]' '@%@&'  < ../inputs/temp-test/619.inp.267.1 > ../outputs/t2047
    if diff ../outputs/t2047 ../originals/t2047 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2048) timeout -s 9 2 ../source/replace.exe '-[9-B] [^0-9][0-9][^0-9]' '@%@&'  < ../inputs/temp-test/620.inp.267.2 > ../outputs/t2048
    if diff ../outputs/t2048 ../originals/t2048 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2049) timeout -s 9 2 ../source/replace.exe '-[9-B]' '&'  < ../inputs/temp-test/1335.inp.573.1 > ../outputs/t2049
    if diff ../outputs/t2049 ../originals/t2049 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2050) timeout -s 9 2 ../source/replace.exe '-[9-B]' '&'  < ../inputs/temp-test/1754.inp.745.1 > ../outputs/t2050
    if diff ../outputs/t2050 ../originals/t2050 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2051) timeout -s 9 2 ../source/replace.exe '-[9-B]' '&'  < ../inputs/temp-test/1755.inp.745.3 > ../outputs/t2051
    if diff ../outputs/t2051 ../originals/t2051 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2052) timeout -s 9 2 ../source/replace.exe '-[9-B]' ''  < ../inputs/temp-test/238.inp.106.1 > ../outputs/t2052
    if diff ../outputs/t2052 ../originals/t2052 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2053) timeout -s 9 2 ../source/replace.exe '-[9-B]' ''  < ../inputs/temp-test/239.inp.106.3 > ../outputs/t2053
    if diff ../outputs/t2053 ../originals/t2053 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2054) timeout -s 9 2 ../source/replace.exe '-[9-B]-[^0-9]' '&a@%'  < ../inputs/temp-test/1664.inp.710.1 > ../outputs/t2054
    if diff ../outputs/t2054 ../originals/t2054 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2055) timeout -s 9 2 ../source/replace.exe '-[9-B]-[^0-9]' '&a@%'  < ../inputs/temp-test/1665.inp.710.3 > ../outputs/t2055
    if diff ../outputs/t2055 ../originals/t2055 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2056) timeout -s 9 2 ../source/replace.exe '-[9-B][9-B] *-^*^a-]' '@n'  < ../inputs/temp-test/1044.inp.450.2 > ../outputs/t2056
    if diff ../outputs/t2056 ../originals/t2056 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2057) timeout -s 9 2 ../source/replace.exe '-[9-B][9-B] *-^*^a-][@n]' '@n'  < ../inputs/temp-test/1043.inp.450.1 > ../outputs/t2057
    if diff ../outputs/t2057 ../originals/t2057 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2058) timeout -s 9 2 ../source/replace.exe '-[9-B][9-B] *-^*^a-][@n]' '@n'  < ../inputs/temp-test/1044.inp.450.2 > ../outputs/t2058
    if diff ../outputs/t2058 ../originals/t2058 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2059) timeout -s 9 2 ../source/replace.exe '-[9-B][9-B] *-^*^a-][@n]' '@n'  < ../inputs/temp-test/1045.inp.450.3 > ../outputs/t2059
    if diff ../outputs/t2059 ../originals/t2059 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2060) timeout -s 9 2 ../source/replace.exe '-[9-B]a-] *[^0-9]' '&'  < ../inputs/temp-test/1042.inp.449.1 > ../outputs/t2060
    if diff ../outputs/t2060 ../originals/t2060 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2061) timeout -s 9 2 ../source/replace.exe '-[@n]'   < ../inputs/temp-test/213.inp.96.1 > ../outputs/t2061
    if diff ../outputs/t2061 ../originals/t2061 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2062) timeout -s 9 2 ../source/replace.exe '-[@n]*$' 'NEW'  < ../inputs/temp-test/213.inp.96.1 > ../outputs/t2062
    if diff ../outputs/t2062 ../originals/t2062 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2063) timeout -s 9 2 ../source/replace.exe '-[@n]*' 'NEW'  < ../inputs/temp-test/213.inp.96.1 > ../outputs/t2063
    if diff ../outputs/t2063 ../originals/t2063 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2064) timeout -s 9 2 ../source/replace.exe '-[@n][][^a--b]' 'NEW'  < ../inputs/temp-test/213.inp.96.1 > ../outputs/t2064
    if diff ../outputs/t2064 ../originals/t2064 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2065) timeout -s 9 2 ../source/replace.exe '-[@n][][^a--b]' 'NEW'  < ../inputs/temp-test/214.inp.96.3 > ../outputs/t2065
    if diff ../outputs/t2065 ../originals/t2065 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2066) timeout -s 9 2 ../source/replace.exe '-[@n][^][^a--b]' 'NEW'  < ../inputs/temp-test/213.inp.96.1 > ../outputs/t2066
    if diff ../outputs/t2066 ../originals/t2066 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2067) timeout -s 9 2 ../source/replace.exe '-[@n][^][^a--b]' 'NEW'  < ../inputs/temp-test/214.inp.96.3 > ../outputs/t2067
    if diff ../outputs/t2067 ../originals/t2067 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2068) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]$'   < ../inputs/temp-test/215.inp.96.8 > ../outputs/t2068
    if diff ../outputs/t2068 ../originals/t2068 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2069) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]$' 'NEW'  < ../inputs/temp-test/215.inp.96.8 > ../outputs/t2069
    if diff ../outputs/t2069 ../originals/t2069 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2070) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]'   < ../inputs/temp-test/213.inp.96.1 > ../outputs/t2070
    if diff ../outputs/t2070 ../originals/t2070 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2071) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]'   < ../inputs/temp-test/214.inp.96.3 > ../outputs/t2071
    if diff ../outputs/t2071 ../originals/t2071 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2072) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]' '&@n'   < ../inputs/temp-test/214.inp.96.3 > ../outputs/t2072
    if diff ../outputs/t2072 ../originals/t2072 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2073) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]' 'NEW'  < ../inputs/temp-test/213.inp.96.1 > ../outputs/t2073
    if diff ../outputs/t2073 ../originals/t2073 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2074) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]' 'NEW'  < ../inputs/temp-test/214.inp.96.3 > ../outputs/t2074
    if diff ../outputs/t2074 ../originals/t2074 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2075) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]*$' 'NEW'  < ../inputs/temp-test/214.inp.96.3 > ../outputs/t2075
    if diff ../outputs/t2075 ../originals/t2075 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2076) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]*$' 'NEW'  < ../inputs/temp-test/215.inp.96.8 > ../outputs/t2076
    if diff ../outputs/t2076 ../originals/t2076 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2077) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]*' 'NEW'  < ../inputs/temp-test/214.inp.96.3 > ../outputs/t2077
    if diff ../outputs/t2077 ../originals/t2077 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2078) timeout -s 9 2 ../source/replace.exe '-[@n][^a--b]*' 'NEW'  < ../inputs/temp-test/215.inp.96.8 > ../outputs/t2078
    if diff ../outputs/t2078 ../originals/t2078 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2079) timeout -s 9 2 ../source/replace.exe '-[@t]$' 'NEW'  < ../inputs/temp-test/1800.inp.765.9 > ../outputs/t2079
    if diff ../outputs/t2079 ../originals/t2079 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2080) timeout -s 9 2 ../source/replace.exe '-[@t]' 'NEW'  < ../inputs/temp-test/1798.inp.765.1 > ../outputs/t2080
    if diff ../outputs/t2080 ../originals/t2080 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2081) timeout -s 9 2 ../source/replace.exe '-[@t]' 'NEW'  < ../inputs/temp-test/1799.inp.765.4 > ../outputs/t2081
    if diff ../outputs/t2081 ../originals/t2081 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2082) timeout -s 9 2 ../source/replace.exe '-[^-' 'a@nb@tc'  < ../inputs/temp-test/1678.inp.715.1 > ../outputs/t2082
    if diff ../outputs/t2082 ../originals/t2082 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2083) timeout -s 9 2 ../source/replace.exe '-[^-' 'a@nb@tc'  < ../inputs/temp-test/1679.inp.715.2 > ../outputs/t2083
    if diff ../outputs/t2083 ../originals/t2083 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2084) timeout -s 9 2 ../source/replace.exe '-[^-' 'a@nb@tc'  < ../inputs/temp-test/1680.inp.715.3 > ../outputs/t2084
    if diff ../outputs/t2084 ../originals/t2084 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2085) timeout -s 9 2 ../source/replace.exe '-[^--z]' '@n'  < ../inputs/temp-test/1917.inp.815.1 > ../outputs/t2085
    if diff ../outputs/t2085 ../originals/t2085 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2086) timeout -s 9 2 ../source/replace.exe '-[^--z]' '@n'  < ../inputs/temp-test/1918.inp.815.2 > ../outputs/t2086
    if diff ../outputs/t2086 ../originals/t2086 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2087) timeout -s 9 2 ../source/replace.exe '-[^--z]' '@n'  < ../inputs/temp-test/1919.inp.815.3 > ../outputs/t2087
    if diff ../outputs/t2087 ../originals/t2087 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2088) timeout -s 9 2 ../source/replace.exe '-[^--z]-[^a--b][^0-9]@* *?-c' '@n'  < ../inputs/temp-test/902.inp.388.1 > ../outputs/t2088
    if diff ../outputs/t2088 ../originals/t2088 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2089) timeout -s 9 2 ../source/replace.exe '-[^--z]-[^a--b][^0-9]@* *?-c' '@n'  < ../inputs/temp-test/903.inp.388.3 > ../outputs/t2089
    if diff ../outputs/t2089 ../originals/t2089 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2090) timeout -s 9 2 ../source/replace.exe '-[^-z]' '&a@%'  < ../inputs/temp-test/768.inp.329.1 > ../outputs/t2090
    if diff ../outputs/t2090 ../originals/t2090 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2091) timeout -s 9 2 ../source/replace.exe '-[^-z]' ''  < ../inputs/temp-test/1163.inp.501.1 > ../outputs/t2091
    if diff ../outputs/t2091 ../originals/t2091 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2092) timeout -s 9 2 ../source/replace.exe '-[^-z]' ''  < ../inputs/temp-test/1164.inp.501.2 > ../outputs/t2092
    if diff ../outputs/t2092 ../originals/t2092 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2093) timeout -s 9 2 ../source/replace.exe '-[^-z]' ''  < ../inputs/temp-test/1165.inp.501.4 > ../outputs/t2093
    if diff ../outputs/t2093 ../originals/t2093 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2094) timeout -s 9 2 ../source/replace.exe '-[^-z][^a-c]-[a-c][^a-c]-*-?^?^a-c]?-?' 'a&'  < ../inputs/temp-test/2312.inp.981.1 > ../outputs/t2094
    if diff ../outputs/t2094 ../originals/t2094 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2095) timeout -s 9 2 ../source/replace.exe '-[^-z][^a-c]-[a-c][^a-c]-*-?^?^a-c]?-?' 'a&'  < ../inputs/temp-test/2313.inp.981.3 > ../outputs/t2095
    if diff ../outputs/t2095 ../originals/t2095 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2096) timeout -s 9 2 ../source/replace.exe '-[^-z][^a-c]-[a-c][^a-c]-*-?^?^a-c]?-?' 'a&'  < ../inputs/temp-test/2314.inp.981.4 > ../outputs/t2096
    if diff ../outputs/t2096 ../originals/t2096 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2097) timeout -s 9 2 ../source/replace.exe '-[^0-9] a-c]-@[[^0-9][a--b]A*' '&'  < ../inputs/temp-test/2209.inp.936.1 > ../outputs/t2097
    if diff ../outputs/t2097 ../originals/t2097 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2098) timeout -s 9 2 ../source/replace.exe '-[^0-9] a-c]-@[[^0-9][a--b]A*' '&'  < ../inputs/temp-test/2210.inp.936.2 > ../outputs/t2098
    if diff ../outputs/t2098 ../originals/t2098 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2099) timeout -s 9 2 ../source/replace.exe '-[^0-9]' '&a@%'  < ../inputs/temp-test/2213.inp.938.1 > ../outputs/t2099
    if diff ../outputs/t2099 ../originals/t2099 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2100) timeout -s 9 2 ../source/replace.exe '-[^0-9]' '&a@%'  < ../inputs/temp-test/2214.inp.938.2 > ../outputs/t2100
    if diff ../outputs/t2100 ../originals/t2100 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2101) timeout -s 9 2 ../source/replace.exe '-[^0-9]' '&a@%'  < ../inputs/temp-test/2215.inp.938.3 > ../outputs/t2101
    if diff ../outputs/t2101 ../originals/t2101 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2102) timeout -s 9 2 ../source/replace.exe '-[^0-9]' '@t'  < ../inputs/temp-test/1229.inp.527.1 > ../outputs/t2102
    if diff ../outputs/t2102 ../originals/t2102 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2103) timeout -s 9 2 ../source/replace.exe '-[^0-9]' '@t'  < ../inputs/temp-test/1230.inp.527.2 > ../outputs/t2103
    if diff ../outputs/t2103 ../originals/t2103 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2104) timeout -s 9 2 ../source/replace.exe '-[^0-9]' 'NEW'  < ../inputs/temp-test/2011.inp.854.1 > ../outputs/t2104
    if diff ../outputs/t2104 ../originals/t2104 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2105) timeout -s 9 2 ../source/replace.exe '-[^0-9]' 'NEW'  < ../inputs/temp-test/2012.inp.854.3 > ../outputs/t2105
    if diff ../outputs/t2105 ../originals/t2105 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2106) timeout -s 9 2 ../source/replace.exe '-[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/476.inp.208.1 > ../outputs/t2106
    if diff ../outputs/t2106 ../originals/t2106 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2107) timeout -s 9 2 ../source/replace.exe '-[^0-9]-?-[^9-B]?[^a--]a-c]-$' '@%&a'  < ../inputs/temp-test/1929.inp.819.9 > ../outputs/t2107
    if diff ../outputs/t2107 ../originals/t2107 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2108) timeout -s 9 2 ../source/replace.exe '-[^0-9]-?-[^9-B]?[^a--]a-c]-' '@%&a'  < ../inputs/temp-test/1926.inp.819.1 > ../outputs/t2108
    if diff ../outputs/t2108 ../originals/t2108 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2109) timeout -s 9 2 ../source/replace.exe '-[^0-9]-?-[^9-B]?[^a--]a-c]-' '@%&a'  < ../inputs/temp-test/1927.inp.819.2 > ../outputs/t2109
    if diff ../outputs/t2109 ../originals/t2109 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2110) timeout -s 9 2 ../source/replace.exe '-[^0-9]-?-[^9-B]?[^a--]a-c]-' '@%&a'  < ../inputs/temp-test/1928.inp.819.3 > ../outputs/t2110
    if diff ../outputs/t2110 ../originals/t2110 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2111) timeout -s 9 2 ../source/replace.exe '-[^0-9]?[a-c' '@t'  < ../inputs/temp-test/384.inp.167.1 > ../outputs/t2111
    if diff ../outputs/t2111 ../originals/t2111 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2112) timeout -s 9 2 ../source/replace.exe '-[^0-9][0-9]A@@*[^0-9][9-B]@@[^a-c]--[0-9][9-B][^a-]' 'NEW'  < ../inputs/temp-test/1584.inp.675.1 > ../outputs/t2112
    if diff ../outputs/t2112 ../originals/t2112 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2113) timeout -s 9 2 ../source/replace.exe '-[^0-9][0-9][^a--' 'a&'  < ../inputs/temp-test/1733.inp.737.1 > ../outputs/t2113
    if diff ../outputs/t2113 ../originals/t2113 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2114) timeout -s 9 2 ../source/replace.exe '-[^9-B]$' '&a@%'  < ../inputs/temp-test/178.inp.80.6 > ../outputs/t2114
    if diff ../outputs/t2114 ../originals/t2114 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2115) timeout -s 9 2 ../source/replace.exe '-[^9-B]$' '&a@%'  < ../inputs/temp-test/179.inp.80.9 > ../outputs/t2115
    if diff ../outputs/t2115 ../originals/t2115 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2116) timeout -s 9 2 ../source/replace.exe '-[^9-B]$' '@t'  < ../inputs/temp-test/973.inp.419.9 > ../outputs/t2116
    if diff ../outputs/t2116 ../originals/t2116 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2117) timeout -s 9 2 ../source/replace.exe '-[^9-B]$' 'NEW'  < ../inputs/temp-test/1219.inp.523.6 > ../outputs/t2117
    if diff ../outputs/t2117 ../originals/t2117 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2118) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '&a@%'  < ../inputs/temp-test/177.inp.80.1 > ../outputs/t2118
    if diff ../outputs/t2118 ../originals/t2118 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2119) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@%&a'  < ../inputs/temp-test/2079.inp.881.1 > ../outputs/t2119
    if diff ../outputs/t2119 ../originals/t2119 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2120) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@%&a'  < ../inputs/temp-test/2080.inp.881.2 > ../outputs/t2120
    if diff ../outputs/t2120 ../originals/t2120 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2121) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@%&a'  < ../inputs/temp-test/2081.inp.881.3 > ../outputs/t2121
    if diff ../outputs/t2121 ../originals/t2121 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2122) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@%@&'  < ../inputs/temp-test/561.inp.242.1 > ../outputs/t2122
    if diff ../outputs/t2122 ../originals/t2122 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2123) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@%@&'  < ../inputs/temp-test/562.inp.242.2 > ../outputs/t2123
    if diff ../outputs/t2123 ../originals/t2123 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2124) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@%@&'  < ../inputs/temp-test/563.inp.242.4 > ../outputs/t2124
    if diff ../outputs/t2124 ../originals/t2124 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2125) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@%@&'  < ../inputs/temp-test/897.inp.386.1 > ../outputs/t2125
    if diff ../outputs/t2125 ../originals/t2125 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2126) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@%@&'  < ../inputs/temp-test/898.inp.386.3 > ../outputs/t2126
    if diff ../outputs/t2126 ../originals/t2126 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2127) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@n'  < ../inputs/temp-test/748.inp.321.1 > ../outputs/t2127
    if diff ../outputs/t2127 ../originals/t2127 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2128) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@n'  < ../inputs/temp-test/749.inp.321.2 > ../outputs/t2128
    if diff ../outputs/t2128 ../originals/t2128 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2129) timeout -s 9 2 ../source/replace.exe '-[^9-B]' '@t'  < ../inputs/temp-test/972.inp.419.1 > ../outputs/t2129
    if diff ../outputs/t2129 ../originals/t2129 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2130) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'NEW'  < ../inputs/temp-test/1216.inp.523.1 > ../outputs/t2130
    if diff ../outputs/t2130 ../originals/t2130 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2131) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'NEW'  < ../inputs/temp-test/1217.inp.523.3 > ../outputs/t2131
    if diff ../outputs/t2131 ../originals/t2131 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2132) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'NEW'  < ../inputs/temp-test/1218.inp.523.4 > ../outputs/t2132
    if diff ../outputs/t2132 ../originals/t2132 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2133) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'NEW'  < ../inputs/temp-test/890.inp.383.1 > ../outputs/t2133
    if diff ../outputs/t2133 ../originals/t2133 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2134) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'NEW'  < ../inputs/temp-test/891.inp.383.2 > ../outputs/t2134
    if diff ../outputs/t2134 ../originals/t2134 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2135) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'a&'  < ../inputs/temp-test/989.inp.426.1 > ../outputs/t2135
    if diff ../outputs/t2135 ../originals/t2135 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2136) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'a&'  < ../inputs/temp-test/990.inp.426.3 > ../outputs/t2136
    if diff ../outputs/t2136 ../originals/t2136 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2137) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'a@nb@tc'  < ../inputs/temp-test/1716.inp.731.1 > ../outputs/t2137
    if diff ../outputs/t2137 ../originals/t2137 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2138) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'b@t'  < ../inputs/temp-test/1818.inp.773.1 > ../outputs/t2138
    if diff ../outputs/t2138 ../originals/t2138 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2139) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'b@t'  < ../inputs/temp-test/1819.inp.773.2 > ../outputs/t2139
    if diff ../outputs/t2139 ../originals/t2139 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2140) timeout -s 9 2 ../source/replace.exe '-[^9-B]' 'b@t'  < ../inputs/temp-test/1820.inp.773.4 > ../outputs/t2140
    if diff ../outputs/t2140 ../originals/t2140 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2141) timeout -s 9 2 ../source/replace.exe '-[^9-B]-' ''  < ../inputs/temp-test/2097.inp.889.1 > ../outputs/t2141
    if diff ../outputs/t2141 ../originals/t2141 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2142) timeout -s 9 2 ../source/replace.exe '-[^9-B]-' ''  < ../inputs/temp-test/2098.inp.889.3 > ../outputs/t2142
    if diff ../outputs/t2142 ../originals/t2142 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2143) timeout -s 9 2 ../source/replace.exe '-[^9-B]?[a-cc*[a-c][^a-c' 'a@nb@tc'  < ../inputs/temp-test/1852.inp.787.1 > ../outputs/t2143
    if diff ../outputs/t2143 ../originals/t2143 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2144) timeout -s 9 2 ../source/replace.exe '-[^9-B]?[a-cc*[a-c][^a-c' 'a@nb@tc'  < ../inputs/temp-test/1853.inp.787.2 > ../outputs/t2144
    if diff ../outputs/t2144 ../originals/t2144 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2145) timeout -s 9 2 ../source/replace.exe '-[^9-B]?[a-cc*[a-c][^a-c' 'a@nb@tc'  < ../inputs/temp-test/1854.inp.787.3 > ../outputs/t2145
    if diff ../outputs/t2145 ../originals/t2145 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2146) timeout -s 9 2 ../source/replace.exe '-[^9-B]?[a-cc*[a-c][^a-c' 'a@nb@tc'  < ../inputs/temp-test/1855.inp.787.4 > ../outputs/t2146
    if diff ../outputs/t2146 ../originals/t2146 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2147) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9] ' 'a@n'  < ../inputs/temp-test/2024.inp.859.1 > ../outputs/t2147
    if diff ../outputs/t2147 ../originals/t2147 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2148) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9] ' 'a@n'  < ../inputs/temp-test/2025.inp.859.2 > ../outputs/t2148
    if diff ../outputs/t2148 ../originals/t2148 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2149) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9]-' 'a&'  < ../inputs/temp-test/95.inp.43.1 > ../outputs/t2149
    if diff ../outputs/t2149 ../originals/t2149 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2150) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9]-' 'a&'  < ../inputs/temp-test/96.inp.43.2 > ../outputs/t2150
    if diff ../outputs/t2150 ../originals/t2150 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2151) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9]-[-' '&a@%'  < ../inputs/temp-test/774.inp.333.1 > ../outputs/t2151
    if diff ../outputs/t2151 ../originals/t2151 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2152) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9]-[-' '&a@%'  < ../inputs/temp-test/775.inp.333.2 > ../outputs/t2152
    if diff ../outputs/t2152 ../originals/t2152 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2153) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9]-[-' '&a@%'  < ../inputs/temp-test/776.inp.333.3 > ../outputs/t2153
    if diff ../outputs/t2153 ../originals/t2153 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2154) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9]?*' '&a@%'  < ../inputs/temp-test/391.inp.171.1 > ../outputs/t2154
    if diff ../outputs/t2154 ../originals/t2154 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2155) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9]?*' '&a@%'  < ../inputs/temp-test/392.inp.171.2 > ../outputs/t2155
    if diff ../outputs/t2155 ../originals/t2155 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2156) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9][^-z]' '&a@%'  < ../inputs/temp-test/391.inp.171.1 > ../outputs/t2156
    if diff ../outputs/t2156 ../originals/t2156 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2157) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9][^-z]' '&a@%'  < ../inputs/temp-test/392.inp.171.2 > ../outputs/t2157
    if diff ../outputs/t2157 ../originals/t2157 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2158) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9][_-z]?-^*?' '@n'  < ../inputs/temp-test/1049.inp.452.1 > ../outputs/t2158
    if diff ../outputs/t2158 ../originals/t2158 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2159) timeout -s 9 2 ../source/replace.exe '-[^9-B][^0-9][_-z]?-^*?' '@n'  < ../inputs/temp-test/1050.inp.452.3 > ../outputs/t2159
    if diff ../outputs/t2159 ../originals/t2159 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2160) timeout -s 9 2 ../source/replace.exe '-[^9-B][a--b][^9-B]--[^a--]' '&a@%'  < ../inputs/temp-test/1756.inp.746.1 > ../outputs/t2160
    if diff ../outputs/t2160 ../originals/t2160 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2161) timeout -s 9 2 ../source/replace.exe '-[^@n]?-?$' '&'  < ../inputs/temp-test/1613.inp.685.9 > ../outputs/t2161
    if diff ../outputs/t2161 ../originals/t2161 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2162) timeout -s 9 2 ../source/replace.exe '-[^@n]?-?' '&'  < ../inputs/temp-test/1610.inp.685.1 > ../outputs/t2162
    if diff ../outputs/t2162 ../originals/t2162 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2163) timeout -s 9 2 ../source/replace.exe '-[^@n]?-?' '&'  < ../inputs/temp-test/1611.inp.685.2 > ../outputs/t2163
    if diff ../outputs/t2163 ../originals/t2163 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2164) timeout -s 9 2 ../source/replace.exe '-[^@n]?-?' '&'  < ../inputs/temp-test/1612.inp.685.3 > ../outputs/t2164
    if diff ../outputs/t2164 ../originals/t2164 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2165) timeout -s 9 2 ../source/replace.exe '-[^a-' 'a&'  < ../inputs/temp-test/379.inp.165.1 > ../outputs/t2165
    if diff ../outputs/t2165 ../originals/t2165 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2166) timeout -s 9 2 ../source/replace.exe '-[^a-' 'a&'  < ../inputs/temp-test/380.inp.165.2 > ../outputs/t2166
    if diff ../outputs/t2166 ../originals/t2166 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2167) timeout -s 9 2 ../source/replace.exe '-[^a-c%' ''  < ../inputs/temp-test/2353.inp.999.1 > ../outputs/t2167
    if diff ../outputs/t2167 ../originals/t2167 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2168) timeout -s 9 2 ../source/replace.exe '-[^a-c' '&a@%'  < ../inputs/temp-test/422.inp.186.1 > ../outputs/t2168
    if diff ../outputs/t2168 ../originals/t2168 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2169) timeout -s 9 2 ../source/replace.exe '-[^a-c' '&a@%'  < ../inputs/temp-test/423.inp.186.3 > ../outputs/t2169
    if diff ../outputs/t2169 ../originals/t2169 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2170) timeout -s 9 2 ../source/replace.exe '-[^a-c' ''  < ../inputs/temp-test/2353.inp.999.1 > ../outputs/t2170
    if diff ../outputs/t2170 ../originals/t2170 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2171) timeout -s 9 2 ../source/replace.exe '-[^a-c' ''  < ../inputs/temp-test/2354.inp.999.2 > ../outputs/t2171
    if diff ../outputs/t2171 ../originals/t2171 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2172) timeout -s 9 2 ../source/replace.exe '-[^a-c' ''  < ../inputs/temp-test/2355.inp.999.3 > ../outputs/t2172
    if diff ../outputs/t2172 ../originals/t2172 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2173) timeout -s 9 2 ../source/replace.exe '-[^a-c' 'b@t'  < ../inputs/temp-test/1824.inp.776.1 > ../outputs/t2173
    if diff ../outputs/t2173 ../originals/t2173 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2174) timeout -s 9 2 ../source/replace.exe '-[^a-c]' '@%@&'  < ../inputs/temp-test/862.inp.371.1 > ../outputs/t2174
    if diff ../outputs/t2174 ../originals/t2174 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2175) timeout -s 9 2 ../source/replace.exe '-[^a-c]' 'b@t'  < ../inputs/temp-test/1651.inp.704.1 > ../outputs/t2175
    if diff ../outputs/t2175 ../originals/t2175 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2176) timeout -s 9 2 ../source/replace.exe '-[^a-c]' 'b@t'  < ../inputs/temp-test/1652.inp.704.3 > ../outputs/t2176
    if diff ../outputs/t2176 ../originals/t2176 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2177) timeout -s 9 2 ../source/replace.exe '-[^a-c]' 'b@t'  < ../inputs/temp-test/1653.inp.704.4 > ../outputs/t2177
    if diff ../outputs/t2177 ../originals/t2177 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2178) timeout -s 9 2 ../source/replace.exe '-[^a-c]--a-]' 'NEW'  < ../inputs/temp-test/1566.inp.669.1 > ../outputs/t2178
    if diff ../outputs/t2178 ../originals/t2178 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2179) timeout -s 9 2 ../source/replace.exe '-[^a-c]--a-]' 'NEW'  < ../inputs/temp-test/1567.inp.669.3 > ../outputs/t2179
    if diff ../outputs/t2179 ../originals/t2179 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2180) timeout -s 9 2 ../source/replace.exe '-[_-z]' '&'  < ../inputs/temp-test/1816.inp.772.1 > ../outputs/t2180
    if diff ../outputs/t2180 ../originals/t2180 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2181) timeout -s 9 2 ../source/replace.exe '-[_-z]' '&'  < ../inputs/temp-test/1817.inp.772.3 > ../outputs/t2181
    if diff ../outputs/t2181 ../originals/t2181 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2182) timeout -s 9 2 ../source/replace.exe '-[_-z]' '@%&a'  < ../inputs/temp-test/1960.inp.832.1 > ../outputs/t2182
    if diff ../outputs/t2182 ../originals/t2182 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2183) timeout -s 9 2 ../source/replace.exe '-[_-z]' '@%&a'  < ../inputs/temp-test/1961.inp.832.2 > ../outputs/t2183
    if diff ../outputs/t2183 ../originals/t2183 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2184) timeout -s 9 2 ../source/replace.exe '-[_-z]' 'a&'  < ../inputs/temp-test/498.inp.218.1 > ../outputs/t2184
    if diff ../outputs/t2184 ../originals/t2184 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2185) timeout -s 9 2 ../source/replace.exe '-[a--b]' 'a&'  < ../inputs/temp-test/1617.inp.687.1 > ../outputs/t2185
    if diff ../outputs/t2185 ../originals/t2185 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2186) timeout -s 9 2 ../source/replace.exe '-[a--b]' 'a&'  < ../inputs/temp-test/1618.inp.687.3 > ../outputs/t2186
    if diff ../outputs/t2186 ../originals/t2186 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2187) timeout -s 9 2 ../source/replace.exe '-[a--b]-' '@%&a'  < ../inputs/temp-test/2219.inp.940.1 > ../outputs/t2187
    if diff ../outputs/t2187 ../originals/t2187 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2188) timeout -s 9 2 ../source/replace.exe '-[a--b][0-9][^a-c[^9-B]-' 'a&'  < ../inputs/temp-test/1475.inp.633.1 > ../outputs/t2188
    if diff ../outputs/t2188 ../originals/t2188 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2189) timeout -s 9 2 ../source/replace.exe '-[a--b][0-9][^a-c[^9-B]-' 'a&'  < ../inputs/temp-test/1476.inp.633.2 > ../outputs/t2189
    if diff ../outputs/t2189 ../originals/t2189 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2190) timeout -s 9 2 ../source/replace.exe '-[a--b][0-9][^a-c[^9-B]-' 'a&'  < ../inputs/temp-test/1477.inp.633.3 > ../outputs/t2190
    if diff ../outputs/t2190 ../originals/t2190 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2191) timeout -s 9 2 ../source/replace.exe '-[a--b][^a--b]-@[a-c][^-z][a--b][^9-B]' ''  < ../inputs/temp-test/650.inp.282.1 > ../outputs/t2191
    if diff ../outputs/t2191 ../originals/t2191 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2192) timeout -s 9 2 ../source/replace.exe '-[a--b][^a--b]-@[a-c][^-z][a--b][^9-B]' ''  < ../inputs/temp-test/651.inp.282.3 > ../outputs/t2192
    if diff ../outputs/t2192 ../originals/t2192 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2193) timeout -s 9 2 ../source/replace.exe '-[a-c' ''  < ../inputs/temp-test/1681.inp.716.1 > ../outputs/t2193
    if diff ../outputs/t2193 ../originals/t2193 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2194) timeout -s 9 2 ../source/replace.exe '-[a-c' ''  < ../inputs/temp-test/1682.inp.716.2 > ../outputs/t2194
    if diff ../outputs/t2194 ../originals/t2194 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2195) timeout -s 9 2 ../source/replace.exe '-[a-c' 'a@nb@tc'  < ../inputs/temp-test/1225.inp.526.1 > ../outputs/t2195
    if diff ../outputs/t2195 ../originals/t2195 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2196) timeout -s 9 2 ../source/replace.exe '-[a-c' 'a@nb@tc'  < ../inputs/temp-test/1226.inp.526.2 > ../outputs/t2196
    if diff ../outputs/t2196 ../originals/t2196 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2197) timeout -s 9 2 ../source/replace.exe '-[a-c' 'a@nb@tc'  < ../inputs/temp-test/1227.inp.526.3 > ../outputs/t2197
    if diff ../outputs/t2197 ../originals/t2197 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2198) timeout -s 9 2 ../source/replace.exe '-[a-c' 'a@nb@tc'  < ../inputs/temp-test/1228.inp.526.4 > ../outputs/t2198
    if diff ../outputs/t2198 ../originals/t2198 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2199) timeout -s 9 2 ../source/replace.exe '-[a-c]' '&'  < ../inputs/temp-test/1023.inp.440.1 > ../outputs/t2199
    if diff ../outputs/t2199 ../originals/t2199 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2200) timeout -s 9 2 ../source/replace.exe '-[a-c]' '&'  < ../inputs/temp-test/1024.inp.440.2 > ../outputs/t2200
    if diff ../outputs/t2200 ../originals/t2200 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2201) timeout -s 9 2 ../source/replace.exe '-[a-c]' '@%@&'  < ../inputs/temp-test/358.inp.157.1 > ../outputs/t2201
    if diff ../outputs/t2201 ../originals/t2201 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2202) timeout -s 9 2 ../source/replace.exe '-[a-c]' '@%@&'  < ../inputs/temp-test/359.inp.157.3 > ../outputs/t2202
    if diff ../outputs/t2202 ../originals/t2202 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2203) timeout -s 9 2 ../source/replace.exe '-[a-c]' '@%@&@'  < ../inputs/temp-test/359.inp.157.3 > ../outputs/t2203
    if diff ../outputs/t2203 ../originals/t2203 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2204) timeout -s 9 2 ../source/replace.exe '-[a-c]' '@n'  < ../inputs/temp-test/1155.inp.497.1 > ../outputs/t2204
    if diff ../outputs/t2204 ../originals/t2204 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2205) timeout -s 9 2 ../source/replace.exe '-[a-c]' '@n'  < ../inputs/temp-test/1156.inp.497.3 > ../outputs/t2205
    if diff ../outputs/t2205 ../originals/t2205 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2206) timeout -s 9 2 ../source/replace.exe '-[a-c]' 'a@n'  < ../inputs/temp-test/1387.inp.595.1 > ../outputs/t2206
    if diff ../outputs/t2206 ../originals/t2206 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2207) timeout -s 9 2 ../source/replace.exe '-[a-c]' 'a@n'  < ../inputs/temp-test/1388.inp.595.3 > ../outputs/t2207
    if diff ../outputs/t2207 ../originals/t2207 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2208) timeout -s 9 2 ../source/replace.exe '-[a-c]' 'b@t'  < ../inputs/temp-test/2291.inp.971.1 > ../outputs/t2208
    if diff ../outputs/t2208 ../originals/t2208 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2209) timeout -s 9 2 ../source/replace.exe '-[a-c]-[^-z]' '@%&a'  < ../inputs/temp-test/1831.inp.779.1 > ../outputs/t2209
    if diff ../outputs/t2209 ../originals/t2209 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2210) timeout -s 9 2 ../source/replace.exe '-[a-c]-[^-z]' '@%&a'  < ../inputs/temp-test/1832.inp.779.2 > ../outputs/t2210
    if diff ../outputs/t2210 ../originals/t2210 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2211) timeout -s 9 2 ../source/replace.exe '-[a-c]@' '@%@&'  < ../inputs/temp-test/358.inp.157.1 > ../outputs/t2211
    if diff ../outputs/t2211 ../originals/t2211 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2212) timeout -s 9 2 ../source/replace.exe '-\|h4+5~' 'A+2wF)'  < ../inputs/input/ruin.948 > ../outputs/t2212
    if diff ../outputs/t2212 ../originals/t2212 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2213) timeout -s 9 2 ../source/replace.exe '-] ' 'NEW'  < ../inputs/temp-test/611.inp.263.1 > ../outputs/t2213
    if diff ../outputs/t2213 ../originals/t2213 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2214) timeout -s 9 2 ../source/replace.exe '-]' 'NEW'  < ../inputs/temp-test/2191.inp.928.1 > ../outputs/t2214
    if diff ../outputs/t2214 ../originals/t2214 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2215) timeout -s 9 2 ../source/replace.exe '-]-' '@n'  < ../inputs/temp-test/1122.inp.483.1 > ../outputs/t2215
    if diff ../outputs/t2215 ../originals/t2215 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2216) timeout -s 9 2 ../source/replace.exe '-]?' 'a&'  < ../inputs/temp-test/1121.inp.482.1 > ../outputs/t2216
    if diff ../outputs/t2216 ../originals/t2216 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2217) timeout -s 9 2 ../source/replace.exe '-]@**' '&'  < ../inputs/temp-test/406.inp.178.1 > ../outputs/t2217
    if diff ../outputs/t2217 ../originals/t2217 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2218) timeout -s 9 2 ../source/replace.exe '-]@**' '&'  < ../inputs/temp-test/407.inp.178.2 > ../outputs/t2218
    if diff ../outputs/t2218 ../originals/t2218 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2219) timeout -s 9 2 ../source/replace.exe '-]@**' '&'  < ../inputs/temp-test/408.inp.178.3 > ../outputs/t2219
    if diff ../outputs/t2219 ../originals/t2219 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2220) timeout -s 9 2 ../source/replace.exe '-]A*' '@%&a'  < ../inputs/temp-test/1209.inp.519.2 > ../outputs/t2220
    if diff ../outputs/t2220 ../originals/t2220 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2221) timeout -s 9 2 ../source/replace.exe '-]A*' '@%&a'  < ../inputs/temp-test/1210.inp.519.3 > ../outputs/t2221
    if diff ../outputs/t2221 ../originals/t2221 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2222) timeout -s 9 2 ../source/replace.exe '-][^0-9]' '@%@&'  < ../inputs/temp-test/629.inp.272.1 > ../outputs/t2222
    if diff ../outputs/t2222 ../originals/t2222 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2223) timeout -s 9 2 ../source/replace.exe '-][^0-9]' '@%@&'  < ../inputs/temp-test/630.inp.272.3 > ../outputs/t2223
    if diff ../outputs/t2223 ../originals/t2223 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2224) timeout -s 9 2 ../source/replace.exe '-][^0-9]' 'a@nb@tc'  < ../inputs/temp-test/578.inp.249.1 > ../outputs/t2224
    if diff ../outputs/t2224 ../originals/t2224 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2225) timeout -s 9 2 ../source/replace.exe '-][^0-9]' 'a@nb@tc'  < ../inputs/temp-test/579.inp.249.2 > ../outputs/t2225
    if diff ../outputs/t2225 ../originals/t2225 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2226) timeout -s 9 2 ../source/replace.exe '-][^0-9][a-' '&'  < ../inputs/temp-test/2262.inp.959.1 > ../outputs/t2226
    if diff ../outputs/t2226 ../originals/t2226 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2227) timeout -s 9 2 ../source/replace.exe '-][^0-9][a-' '&'  < ../inputs/temp-test/2263.inp.959.2 > ../outputs/t2227
    if diff ../outputs/t2227 ../originals/t2227 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2228) timeout -s 9 2 ../source/replace.exe '-][^0-9][a-' '&'  < ../inputs/temp-test/2264.inp.959.3 > ../outputs/t2228
    if diff ../outputs/t2228 ../originals/t2228 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2229) timeout -s 9 2 ../source/replace.exe '-]c*??- [^9-B]' 'b@t'  < ../inputs/temp-test/1981.inp.841.1 > ../outputs/t2229
    if diff ../outputs/t2229 ../originals/t2229 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2230) timeout -s 9 2 ../source/replace.exe '-]c*??- [^9-B]' 'b@t'  < ../inputs/temp-test/1982.inp.841.2 > ../outputs/t2230
    if diff ../outputs/t2230 ../originals/t2230 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2231) timeout -s 9 2 ../source/replace.exe '-^$' 'NEW'  < ../inputs/temp-test/1289.inp.553.6 > ../outputs/t2231
    if diff ../outputs/t2231 ../originals/t2231 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2232) timeout -s 9 2 ../source/replace.exe '-^$' 'a@nb@tc'  < ../inputs/temp-test/763.inp.326.6 > ../outputs/t2232
    if diff ../outputs/t2232 ../originals/t2232 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2233) timeout -s 9 2 ../source/replace.exe '-^' ''  < ../inputs/temp-test/573.inp.247.1 > ../outputs/t2233
    if diff ../outputs/t2233 ../originals/t2233 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2234) timeout -s 9 2 ../source/replace.exe '-^' ''  < ../inputs/temp-test/574.inp.247.2 > ../outputs/t2234
    if diff ../outputs/t2234 ../originals/t2234 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2235) timeout -s 9 2 ../source/replace.exe '-^' '@%&a'  < ../inputs/temp-test/1247.inp.535.1 > ../outputs/t2235
    if diff ../outputs/t2235 ../originals/t2235 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2236) timeout -s 9 2 ../source/replace.exe '-^' '@%&a'  < ../inputs/temp-test/1248.inp.535.2 > ../outputs/t2236
    if diff ../outputs/t2236 ../originals/t2236 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2237) timeout -s 9 2 ../source/replace.exe '-^' 'NEW'  < ../inputs/temp-test/1287.inp.553.1 > ../outputs/t2237
    if diff ../outputs/t2237 ../originals/t2237 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2238) timeout -s 9 2 ../source/replace.exe '-^' 'NEW'  < ../inputs/temp-test/1288.inp.553.3 > ../outputs/t2238
    if diff ../outputs/t2238 ../originals/t2238 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2239) timeout -s 9 2 ../source/replace.exe '-^' 'a&'  < ../inputs/temp-test/1426.inp.613.1 > ../outputs/t2239
    if diff ../outputs/t2239 ../originals/t2239 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2240) timeout -s 9 2 ../source/replace.exe '-^' 'a&'  < ../inputs/temp-test/1427.inp.613.2 > ../outputs/t2240
    if diff ../outputs/t2240 ../originals/t2240 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2241) timeout -s 9 2 ../source/replace.exe '-^' 'a&'  < ../inputs/temp-test/1428.inp.613.3 > ../outputs/t2241
    if diff ../outputs/t2241 ../originals/t2241 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2242) timeout -s 9 2 ../source/replace.exe '-^' 'a@nb@tc'  < ../inputs/temp-test/760.inp.326.1 > ../outputs/t2242
    if diff ../outputs/t2242 ../originals/t2242 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2243) timeout -s 9 2 ../source/replace.exe '-^' 'a@nb@tc'  < ../inputs/temp-test/761.inp.326.2 > ../outputs/t2243
    if diff ../outputs/t2243 ../originals/t2243 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2244) timeout -s 9 2 ../source/replace.exe '-^' 'a@nb@tc'  < ../inputs/temp-test/762.inp.326.3 > ../outputs/t2244
    if diff ../outputs/t2244 ../originals/t2244 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2245) timeout -s 9 2 ../source/replace.exe '-^*' '@t'  < ../inputs/temp-test/1060.inp.456.1 > ../outputs/t2245
    if diff ../outputs/t2245 ../originals/t2245 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2246) timeout -s 9 2 ../source/replace.exe '-^*' '@t'  < ../inputs/temp-test/1061.inp.456.3 > ../outputs/t2246
    if diff ../outputs/t2246 ../originals/t2246 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2247) timeout -s 9 2 ../source/replace.exe '-^*' 'NEW'  < ../inputs/temp-test/648.inp.281.1 > ../outputs/t2247
    if diff ../outputs/t2247 ../originals/t2247 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2248) timeout -s 9 2 ../source/replace.exe '-^*' 'NEW'  < ../inputs/temp-test/649.inp.281.3 > ../outputs/t2248
    if diff ../outputs/t2248 ../originals/t2248 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2249) timeout -s 9 2 ../source/replace.exe '-^*' 'a@nb@tc'  < ../inputs/temp-test/1721.inp.733.1 > ../outputs/t2249
    if diff ../outputs/t2249 ../originals/t2249 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2250) timeout -s 9 2 ../source/replace.exe '-^*' 'a@nb@tc'  < ../inputs/temp-test/1722.inp.733.2 > ../outputs/t2250
    if diff ../outputs/t2250 ../originals/t2250 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2251) timeout -s 9 2 ../source/replace.exe '-^*' 'a@nb@tc'  < ../inputs/temp-test/1723.inp.733.3 > ../outputs/t2251
    if diff ../outputs/t2251 ../originals/t2251 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2252) timeout -s 9 2 ../source/replace.exe '-^-]' '@%&a'  < ../inputs/temp-test/2309.inp.980.1 > ../outputs/t2252
    if diff ../outputs/t2252 ../originals/t2252 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2253) timeout -s 9 2 ../source/replace.exe '-^-]' '@%&a'  < ../inputs/temp-test/2310.inp.980.3 > ../outputs/t2253
    if diff ../outputs/t2253 ../originals/t2253 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2254) timeout -s 9 2 ../source/replace.exe '-^-]' '@%@&'  < ../inputs/temp-test/376.inp.163.1 > ../outputs/t2254
    if diff ../outputs/t2254 ../originals/t2254 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2255) timeout -s 9 2 ../source/replace.exe '-^-]' '@t'  < ../inputs/temp-test/1071.inp.461.1 > ../outputs/t2255
    if diff ../outputs/t2255 ../originals/t2255 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2256) timeout -s 9 2 ../source/replace.exe '-^-]' '@t'  < ../inputs/temp-test/1072.inp.461.2 > ../outputs/t2256
    if diff ../outputs/t2256 ../originals/t2256 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2257) timeout -s 9 2 ../source/replace.exe '-^-]' '@t'  < ../inputs/temp-test/1073.inp.461.3 > ../outputs/t2257
    if diff ../outputs/t2257 ../originals/t2257 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2258) timeout -s 9 2 ../source/replace.exe '-^?*' ''  < ../inputs/temp-test/574.inp.247.2 > ../outputs/t2258
    if diff ../outputs/t2258 ../originals/t2258 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2259) timeout -s 9 2 ../source/replace.exe '-^[^--z]--[a-c?[^-@[[^a-c]^-]@**?-' '@t'  < ../inputs/temp-test/2115.inp.897.1 > ../outputs/t2259
    if diff ../outputs/t2259 ../originals/t2259 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2260) timeout -s 9 2 ../source/replace.exe '-^[^--z]--[a-c?[^-@[[^a-c]^-]@**?-' '@t'  < ../inputs/temp-test/2116.inp.897.3 > ../outputs/t2260
    if diff ../outputs/t2260 ../originals/t2260 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2261) timeout -s 9 2 ../source/replace.exe '-^a-]-]?' '&a@%'  < ../inputs/temp-test/1459.inp.625.1 > ../outputs/t2261
    if diff ../outputs/t2261 ../originals/t2261 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2262) timeout -s 9 2 ../source/replace.exe '-^a-]-]?' '&a@%'  < ../inputs/temp-test/1460.inp.625.2 > ../outputs/t2262
    if diff ../outputs/t2262 ../originals/t2262 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2263) timeout -s 9 2 ../source/replace.exe '-^a-c][^a-c][a--]a-c]? ?@n*^a-c]a-]?' ''  < ../inputs/temp-test/1493.inp.640.1 > ../outputs/t2263
    if diff ../outputs/t2263 ../originals/t2263 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2264) timeout -s 9 2 ../source/replace.exe '-a-]?[^a-c]--[_-z]-' '@n'  < ../inputs/temp-test/1891.inp.802.1 > ../outputs/t2264
    if diff ../outputs/t2264 ../originals/t2264 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2265) timeout -s 9 2 ../source/replace.exe '-a-]?[^a-c]--[_-z]-' '@n'  < ../inputs/temp-test/1892.inp.802.2 > ../outputs/t2265
    if diff ../outputs/t2265 ../originals/t2265 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2266) timeout -s 9 2 ../source/replace.exe '-a-c]-A[^@@]' '@%&a'  < ../inputs/temp-test/417.inp.184.1 > ../outputs/t2266
    if diff ../outputs/t2266 ../originals/t2266 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2267) timeout -s 9 2 ../source/replace.exe '-a-c]-A[^@@]' '@%&a'  < ../inputs/temp-test/418.inp.184.3 > ../outputs/t2267
    if diff ../outputs/t2267 ../originals/t2267 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2268) timeout -s 9 2 ../source/replace.exe '-a-c]A*-?' ''  < ../inputs/temp-test/260.inp.115.1 > ../outputs/t2268
    if diff ../outputs/t2268 ../originals/t2268 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2269) timeout -s 9 2 ../source/replace.exe '-a-c][^0-9][0-9]?@n*[^0-9]@*c[0-9]' 'b@t'  < ../inputs/temp-test/1655.inp.705.1 > ../outputs/t2269
    if diff ../outputs/t2269 ../originals/t2269 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2270) timeout -s 9 2 ../source/replace.exe '-a-c][^0-9][0-9]?@n*[^0-9]@*c[0-9]' 'b@t'  < ../inputs/temp-test/1656.inp.705.2 > ../outputs/t2270
    if diff ../outputs/t2270 ../originals/t2270 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2271) timeout -s 9 2 ../source/replace.exe '-a]#[0-9]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t2271
    if diff ../outputs/t2271 ../originals/t2271 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2272) timeout -s 9 2 ../source/replace.exe '-c*' 'a&'  < ../inputs/temp-test/2027.inp.860.1 > ../outputs/t2272
    if diff ../outputs/t2272 ../originals/t2272 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2273) timeout -s 9 2 ../source/replace.exe '-c*' 'a&'  < ../inputs/temp-test/2028.inp.860.3 > ../outputs/t2273
    if diff ../outputs/t2273 ../originals/t2273 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2274) timeout -s 9 2 ../source/replace.exe '-c*?-?' 'NEW'  < ../inputs/temp-test/547.inp.237.1 > ../outputs/t2274
    if diff ../outputs/t2274 ../originals/t2274 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2275) timeout -s 9 2 ../source/replace.exe '-c*?-?' 'NEW'  < ../inputs/temp-test/548.inp.237.2 > ../outputs/t2275
    if diff ../outputs/t2275 ../originals/t2275 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2276) timeout -s 9 2 ../source/replace.exe '-c*?-?' 'NEW'  < ../inputs/temp-test/549.inp.237.3 > ../outputs/t2276
    if diff ../outputs/t2276 ../originals/t2276 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2277) timeout -s 9 2 ../source/replace.exe '-c---[^0-9][0-9][9-B]-' '@n'  < ../inputs/temp-test/1032.inp.444.1 > ../outputs/t2277
    if diff ../outputs/t2277 ../originals/t2277 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2278) timeout -s 9 2 ../source/replace.exe '-c---[^0-9][0-9][9-B]-' '@n'  < ../inputs/temp-test/1033.inp.444.2 > ../outputs/t2278
    if diff ../outputs/t2278 ../originals/t2278 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2279) timeout -s 9 2 ../source/replace.exe '-c?$' '@%@&'  < ../inputs/temp-test/606.inp.260.9 > ../outputs/t2279
    if diff ../outputs/t2279 ../originals/t2279 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2280) timeout -s 9 2 ../source/replace.exe '-c?' '@%@&'  < ../inputs/temp-test/603.inp.260.1 > ../outputs/t2280
    if diff ../outputs/t2280 ../originals/t2280 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2281) timeout -s 9 2 ../source/replace.exe '-c?' '@%@&'  < ../inputs/temp-test/604.inp.260.3 > ../outputs/t2281
    if diff ../outputs/t2281 ../originals/t2281 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2282) timeout -s 9 2 ../source/replace.exe '-c[^9-B][9-B]-[^-z]?-' '&a@%'  < ../inputs/temp-test/2010.inp.853.1 > ../outputs/t2282
    if diff ../outputs/t2282 ../originals/t2282 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2283) timeout -s 9 2 ../source/replace.exe '-c[^9-B][9-B]-[^-z]?-c[^9-B][9-B]-[^-z]?---c[^9-B][9-B]-[^-z]?--c[^9-B][9-B]-[^-z]?--c[^9-B][9-B]-[^-z]?--c[^9-B][9-B]-[^-z]?--c[^9-B][9-B]-[^-z]?-' '&a@%'  < ../inputs/temp-test/2010.inp.853.1 > ../outputs/t2283
    if diff ../outputs/t2283 ../originals/t2283 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2284) timeout -s 9 2 ../source/replace.exe '.' '+h8aqrDP='  < ../inputs/input/ruin.513 > ../outputs/t2284
    if diff ../outputs/t2284 ../originals/t2284 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2285) timeout -s 9 2 ../source/replace.exe '.' '8]AE9Lk)owK TbxK<5-7bhAVK2'  < ../inputs/input/ruin.1409 > ../outputs/t2285
    if diff ../outputs/t2285 ../originals/t2285 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2286) timeout -s 9 2 ../source/replace.exe '.' '<~Q;^ZUey}p(>R: eER_h|%#heV=M~P8uEQV_#T72=Gg-O'\''}iI8H]=^c[MV]GR7_t'  < ../inputs/input/ruin.670 > ../outputs/t2286
    if diff ../outputs/t2286 ../originals/t2286 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2287) timeout -s 9 2 ../source/replace.exe '.' 'R'  < ../inputs/input/ruin.1930 > ../outputs/t2287
    if diff ../outputs/t2287 ../originals/t2287 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2288) timeout -s 9 2 ../source/replace.exe '/$' ','  < ../inputs/input/ruin.1840 > ../outputs/t2288
    if diff ../outputs/t2288 ../originals/t2288 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2289) timeout -s 9 2 ../source/replace.exe '/' 'P'  < ../inputs/input/ruin.755 > ../outputs/t2289
    if diff ../outputs/t2289 ../originals/t2289 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2290) timeout -s 9 2 ../source/replace.exe '/' 'd=f'  < ../inputs/input/ruin.1856 > ../outputs/t2290
    if diff ../outputs/t2290 ../originals/t2290 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2291) timeout -s 9 2 ../source/replace.exe '/' 't'  < ../inputs/input/ruin.1826 > ../outputs/t2291
    if diff ../outputs/t2291 ../originals/t2291 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2292) timeout -s 9 2 ../source/replace.exe '/' '}wTFVi.Wr"L7RYg!cd\XO7'  < ../inputs/input/ruin.1651 > ../outputs/t2292
    if diff ../outputs/t2292 ../originals/t2292 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2293) timeout -s 9 2 ../source/replace.exe '0' 'EXO^}tG*4[M'\'''\''UEUY^*K}AhDu'  < ../inputs/input/ruin.1617 > ../outputs/t2293
    if diff ../outputs/t2293 ../originals/t2293 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2294) timeout -s 9 2 ../source/replace.exe '0' 'LB'  < ../inputs/input/ruin.1028 > ../outputs/t2294
    if diff ../outputs/t2294 ../originals/t2294 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2295) timeout -s 9 2 ../source/replace.exe '0' 'Z?7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpn'  < ../inputs/input/ruin.1060 > ../outputs/t2295
    if diff ../outputs/t2295 ../originals/t2295 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2296) timeout -s 9 2 ../source/replace.exe '0' 'Z?n'  < ../inputs/input/ruin.1060 > ../outputs/t2296
    if diff ../outputs/t2296 ../originals/t2296 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2297) timeout -s 9 2 ../source/replace.exe '0' '{q2n8KrM4f"NA#l+YD-M].S{C4vS@{!w!\]@)zzgx'  < ../inputs/input/ruin.1562 > ../outputs/t2297
    if diff ../outputs/t2297 ../originals/t2297 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2298) timeout -s 9 2 ../source/replace.exe '0-9][a-c]-?A-?-c[0-9][a-c]-?AWzWz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`]-*[*0-9][^0-9]*[@t][@t@]' ''  < ../inputs/moni/f8.inp > ../outputs/t2298
    if diff ../outputs/t2298 ../originals/t2298 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2299) timeout -s 9 2 ../source/replace.exe '0?' 'XBu4dy6FR#+F"V|Z-B.[{PW'  < ../inputs/input/ruin.936 > ../outputs/t2299
    if diff ../outputs/t2299 ../originals/t2299 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2300) timeout -s 9 2 ../source/replace.exe '0?*' 'EXO^}tG*4[M'\'''\''UEUY^*K}AhDu'  < ../inputs/input/ruin.1617 > ../outputs/t2300
    if diff ../outputs/t2300 ../originals/t2300 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2301) timeout -s 9 2 ../source/replace.exe '1' '0%!X/d_[P@,!+=*a!b4ci!'  < ../inputs/input/ruin.763 > ../outputs/t2301
    if diff ../outputs/t2301 ../originals/t2301 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2302) timeout -s 9 2 ../source/replace.exe '1' 'M_Toh|[aPbaYoj5Uau@&qg]4@sRFU+FAt-LwrFS'  < ../inputs/input/ruin.1091 > ../outputs/t2302
    if diff ../outputs/t2302 ../originals/t2302 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2303) timeout -s 9 2 ../source/replace.exe '12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890' '12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890'  < ../inputs/moni/f7.inp > ../outputs/t2303
    if diff ../outputs/t2303 ../originals/t2303 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2304) timeout -s 9 2 ../source/replace.exe '12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890' 'a'  < ../inputs/moni/f7.inp > ../outputs/t2304
    if diff ../outputs/t2304 ../originals/t2304 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2305) timeout -s 9 2 ../source/replace.exe '2' 'gU'  < ../inputs/input/ruin.1497 > ../outputs/t2305
    if diff ../outputs/t2305 ../originals/t2305 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2306) timeout -s 9 2 ../source/replace.exe '2' 'n'  < ../inputs/input/ruin.153 > ../outputs/t2306
    if diff ../outputs/t2306 ../originals/t2306 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2307) timeout -s 9 2 ../source/replace.exe '2?' '6'\''C'  < ../inputs/input/ruin.1558 > ../outputs/t2307
    if diff ../outputs/t2307 ../originals/t2307 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2308) timeout -s 9 2 ../source/replace.exe '3 3 ?' '@t67@t67@n'  < ../inputs/moni/f8.inp > ../outputs/t2308
    if diff ../outputs/t2308 ../originals/t2308 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2309) timeout -s 9 2 ../source/replace.exe '3' '%j^S0TxA[;rv*vwcH0v}f1]?o+\Kjds,MC;@Qu@Vr2}HP#{c&FBfG"&JR\(=>ZU;D]@O$xv;xaoScl;%3'  < ../inputs/input/ruin.828 > ../outputs/t2309
    if diff ../outputs/t2309 ../originals/t2309 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2310) timeout -s 9 2 ../source/replace.exe '3' '4R NQlkJ:NBlz'  < ../inputs/input/ruin.754 > ../outputs/t2310
    if diff ../outputs/t2310 ../originals/t2310 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2311) timeout -s 9 2 ../source/replace.exe '3' '5'  < ../inputs/input/ruin.675 > ../outputs/t2311
    if diff ../outputs/t2311 ../originals/t2311 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2312) timeout -s 9 2 ../source/replace.exe '3' '9|'  < ../inputs/input/ruin.122 > ../outputs/t2312
    if diff ../outputs/t2312 ../originals/t2312 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2313) timeout -s 9 2 ../source/replace.exe '3' '=-9R'\''azqd96m</'  < ../inputs/input/ruin.169 > ../outputs/t2313
    if diff ../outputs/t2313 ../originals/t2313 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2314) timeout -s 9 2 ../source/replace.exe '3' '_r*?'\''z?z8x$#._@8RQ3b:[UxRVn>M[D7xnp,+G|zM.mV.dDGw`@<ZRoT]_W'  < ../inputs/input/ruin.1867 > ../outputs/t2314
    if diff ../outputs/t2314 ../originals/t2314 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2315) timeout -s 9 2 ../source/replace.exe '3@@' ' '  < ../inputs/input/ruin.971 > ../outputs/t2315
    if diff ../outputs/t2315 ../originals/t2315 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2316) timeout -s 9 2 ../source/replace.exe '3BLytQ3BLytQ69ILh[Q=v@3BLytQ69ILh[Q=v@69ILh[Q=v@3B3BLytQ69ILh[Q=v@3BLytQ69ILh[Q=v@3BLytQ69ILh[Q=v@3BLytQ69ILh[Q=v@LytQ69ILh[Q=v@[0-9]*' ''  < ../inputs/moni/f8.inp > ../outputs/t2316
    if diff ../outputs/t2316 ../originals/t2316 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2317) timeout -s 9 2 ../source/replace.exe '4' 'GC~b-h:p- 1}(N|2'  < ../inputs/input/ruin.1096 > ../outputs/t2317
    if diff ../outputs/t2317 ../originals/t2317 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2318) timeout -s 9 2 ../source/replace.exe '4?' '0#z#_$#r'  < ../inputs/input/ruin.48 > ../outputs/t2318
    if diff ../outputs/t2318 ../originals/t2318 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2319) timeout -s 9 2 ../source/replace.exe '4@t@@\M)BP@@d@@' '(J%$7-Km+F*y,%RQ::$`Oxsb-*k*$<nGwt43]!f.+D{'  < ../inputs/input/ruin.1706 > ../outputs/t2319
    if diff ../outputs/t2319 ../originals/t2319 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2320) timeout -s 9 2 ../source/replace.exe '5' '3xcvLGp",ED"xmUT]z-FB'  < ../inputs/input/ruin.834 > ../outputs/t2320
    if diff ../outputs/t2320 ../originals/t2320 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2321) timeout -s 9 2 ../source/replace.exe '5' 'Pcgl|PFbg#{4>i$ZgBymQ}A2<i>(]8Au:C}VK4Akc#oM'  < ../inputs/input/ruin.1171 > ../outputs/t2321
    if diff ../outputs/t2321 ../originals/t2321 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2322) timeout -s 9 2 ../source/replace.exe '5' 'R}^(/YRR'  < ../inputs/input/ruin.347 > ../outputs/t2322
    if diff ../outputs/t2322 ../originals/t2322 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2323) timeout -s 9 2 ../source/replace.exe '5' 'd'  < ../inputs/input/ruin.1428 > ../outputs/t2323
    if diff ../outputs/t2323 ../originals/t2323 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2324) timeout -s 9 2 ../source/replace.exe '5' 'h7xEY D >9[8^X.N2xO}Ne'\''Ar'\''cKa7}*S'  < ../inputs/input/ruin.723 > ../outputs/t2324
    if diff ../outputs/t2324 ../originals/t2324 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2325) timeout -s 9 2 ../source/replace.exe '5' 'p$jpcdc+?y'  < ../inputs/input/ruin.1527 > ../outputs/t2325
    if diff ../outputs/t2325 ../originals/t2325 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2326) timeout -s 9 2 ../source/replace.exe '5[>-A]' 'rv0,](\@J5=CG3F%m;"*|]gT)V'  < ../inputs/input/ruin.342 > ../outputs/t2326
    if diff ../outputs/t2326 ../originals/t2326 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2327) timeout -s 9 2 ../source/replace.exe '6' '_%>N,Bf#:|\xD>emL$bK^QbIRG?jle]Jf=it6/.`'  < ../inputs/input/ruin.131 > ../outputs/t2327
    if diff ../outputs/t2327 ../originals/t2327 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2328) timeout -s 9 2 ../source/replace.exe '6*' ')W"v#jga.ue\v[5syHzI,K,QJ+\k#52`Q%<B(@I^t'  < ../inputs/input/ruin.1736 > ../outputs/t2328
    if diff ../outputs/t2328 ../originals/t2328 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2329) timeout -s 9 2 ../source/replace.exe '7' ''  < ../inputs/input/ruin.545 > ../outputs/t2329
    if diff ../outputs/t2329 ../originals/t2329 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2330) timeout -s 9 2 ../source/replace.exe '8' '"'  < ../inputs/input/ruin.484 > ../outputs/t2330
    if diff ../outputs/t2330 ../originals/t2330 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2331) timeout -s 9 2 ../source/replace.exe '8' ''  < ../inputs/input/ruin.448 > ../outputs/t2331
    if diff ../outputs/t2331 ../originals/t2331 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2332) timeout -s 9 2 ../source/replace.exe '8' '[|'  < ../inputs/input/ruin.1573 > ../outputs/t2332
    if diff ../outputs/t2332 ../originals/t2332 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2333) timeout -s 9 2 ../source/replace.exe '8' 'b'  < ../inputs/input/ruin.1768 > ../outputs/t2333
    if diff ../outputs/t2333 ../originals/t2333 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2334) timeout -s 9 2 ../source/replace.exe '8' 'e'  < ../inputs/input/ruin.1076 > ../outputs/t2334
    if diff ../outputs/t2334 ../originals/t2334 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2335) timeout -s 9 2 ../source/replace.exe '9' ':'  < ../inputs/input/ruin.206 > ../outputs/t2335
    if diff ../outputs/t2335 ../originals/t2335 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2336) timeout -s 9 2 ../source/replace.exe '9' '>=rt)q>M}/'  < ../inputs/input/ruin.748 > ../outputs/t2336
    if diff ../outputs/t2336 ../originals/t2336 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2337) timeout -s 9 2 ../source/replace.exe '9' '@Z-Co8/r+-k_V3^|>xU#m:Zn4 '  < ../inputs/input/ruin.836 > ../outputs/t2337
    if diff ../outputs/t2337 ../originals/t2337 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2338) timeout -s 9 2 ../source/replace.exe '9@@*[^Z-a]^_`a]' '"'  < ../inputs/input/ruin.28 > ../outputs/t2338
    if diff ../outputs/t2338 ../originals/t2338 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2339) timeout -s 9 2 ../source/replace.exe ':' '-'  < ../inputs/input/ruin.1037 > ../outputs/t2339
    if diff ../outputs/t2339 ../originals/t2339 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2340) timeout -s 9 2 ../source/replace.exe ':' 'KNy,h0_sbVxG=nOfKNy,h0_sbVxG=nOfj@j@KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@-'  < ../inputs/input/ruin.1037 > ../outputs/t2340
    if diff ../outputs/t2340 ../originals/t2340 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2341) timeout -s 9 2 ../source/replace.exe ':@@*' '&'  < ../inputs/input/ruin.1279 > ../outputs/t2341
    if diff ../outputs/t2341 ../originals/t2341 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2342) timeout -s 9 2 ../source/replace.exe ';' 'PuDC_y|{43P)%'\'';2IMC'  < ../inputs/input/ruin.1459 > ../outputs/t2342
    if diff ../outputs/t2342 ../originals/t2342 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2343) timeout -s 9 2 ../source/replace.exe ';?' 'l'  < ../inputs/input/ruin.835 > ../outputs/t2343
    if diff ../outputs/t2343 ../originals/t2343 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2344) timeout -s 9 2 ../source/replace.exe ';v;vc2#{V7TVUA[lGcZR)h\M7+(Fn;vc2#{V7TVUA[lGcZR)h\M7+(Fn;vc2#{V7TVUA[lGcZR)h\M7+(Fn;vc2#{V7TVUA[lGcZR)h\M7+(Fnc2#{V7TVUA[lGcZR)h\M7+(Fn[Z-a]^_*[Z-a]^_*' 'foo&'  < ../inputs/input/ruin.506 > ../outputs/t2344
    if diff ../outputs/t2344 ../originals/t2344 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2345) timeout -s 9 2 ../source/replace.exe '<' 'S'  < ../inputs/input/ruin.775 > ../outputs/t2345
    if diff ../outputs/t2345 ../originals/t2345 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2346) timeout -s 9 2 ../source/replace.exe '<' 'v'  < ../inputs/input/ruin.428 > ../outputs/t2346
    if diff ../outputs/t2346 ../originals/t2346 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2347) timeout -s 9 2 ../source/replace.exe '<n[D6' ''  < ../inputs/input/ruin.49 > ../outputs/t2347
    if diff ../outputs/t2347 ../originals/t2347 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2348) timeout -s 9 2 ../source/replace.exe '=' '&g=Vs@DVtKv;1f. _Ep8=Z <(H&'\''qa&&0rVBXTKdv<G31kbGiPE1^kzBV;j=@'  < ../inputs/input/ruin.552 > ../outputs/t2348
    if diff ../outputs/t2348 ../originals/t2348 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2349) timeout -s 9 2 ../source/replace.exe '=' 'B'  < ../inputs/input/ruin.412 > ../outputs/t2349
    if diff ../outputs/t2349 ../originals/t2349 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2350) timeout -s 9 2 ../source/replace.exe '=' 'FHShmfVlkj.v$ 8Jrza"8Lbzb\h.[l$/_FJ9Ws?'  < ../inputs/input/ruin.13 > ../outputs/t2350
    if diff ../outputs/t2350 ../originals/t2350 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2351) timeout -s 9 2 ../source/replace.exe '=' 'M8s?F;+~?xx;<>"i![@}paufqF[PvP.5C/xIc;i-vj0:Fbo'  < ../inputs/input/ruin.1553 > ../outputs/t2351
    if diff ../outputs/t2351 ../originals/t2351 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2352) timeout -s 9 2 ../source/replace.exe '>' 'l'  < ../inputs/input/ruin.1462 > ../outputs/t2352
    if diff ../outputs/t2352 ../originals/t2352 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2353) timeout -s 9 2 ../source/replace.exe '>[0-9]' 'YUt'\''=R]f\U&)'  < ../inputs/input/ruin.1548 > ../outputs/t2353
    if diff ../outputs/t2353 ../originals/t2353 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2354) timeout -s 9 2 ../source/replace.exe '? '   < ../inputs/temp-test/217.inp.97.1 > ../outputs/t2354
    if diff ../outputs/t2354 ../originals/t2354 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2355) timeout -s 9 2 ../source/replace.exe '? ' 'a&'  < ../inputs/temp-test/609.inp.262.1 > ../outputs/t2355
    if diff ../outputs/t2355 ../originals/t2355 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2356) timeout -s 9 2 ../source/replace.exe '? ' 'a&'  < ../inputs/temp-test/610.inp.262.2 > ../outputs/t2356
    if diff ../outputs/t2356 ../originals/t2356 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2357) timeout -s 9 2 ../source/replace.exe '? ' 'a@nb@tc'  < ../inputs/temp-test/217.inp.97.1 > ../outputs/t2357
    if diff ../outputs/t2357 ../originals/t2357 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2358) timeout -s 9 2 ../source/replace.exe '? *' '@t'  < ../inputs/temp-test/858.inp.369.1 > ../outputs/t2358
    if diff ../outputs/t2358 ../originals/t2358 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2359) timeout -s 9 2 ../source/replace.exe '? *--[a--b]?-]?[a-c]' 'a&'  < ../inputs/temp-test/346.inp.152.1 > ../outputs/t2359
    if diff ../outputs/t2359 ../originals/t2359 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2360) timeout -s 9 2 ../source/replace.exe '? *--[a--b]?-]?[a-c]' 'a&'  < ../inputs/temp-test/347.inp.152.2 > ../outputs/t2360
    if diff ../outputs/t2360 ../originals/t2360 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2361) timeout -s 9 2 ../source/replace.exe '? *--[a--b]?-]?[a-c]' 'a&'  < ../inputs/temp-test/348.inp.152.3 > ../outputs/t2361
    if diff ../outputs/t2361 ../originals/t2361 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2362) timeout -s 9 2 ../source/replace.exe '? *--[a--b]?-]?[a-c]' 'a&@'  < ../inputs/temp-test/346.inp.152.1 > ../outputs/t2362
    if diff ../outputs/t2362 ../originals/t2362 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2363) timeout -s 9 2 ../source/replace.exe '? *--[a--b]?-]?[a-c]' 'a&@'  < ../inputs/temp-test/348.inp.152.3 > ../outputs/t2363
    if diff ../outputs/t2363 ../originals/t2363 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2364) timeout -s 9 2 ../source/replace.exe '? *--[a--b]?-]?[a-c]@' 'a&'  < ../inputs/temp-test/347.inp.152.2 > ../outputs/t2364
    if diff ../outputs/t2364 ../originals/t2364 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2365) timeout -s 9 2 ../source/replace.exe '? *@[[^9-B][^0-9]A[^a-c]' 'a&'  < ../inputs/temp-test/1908.inp.810.1 > ../outputs/t2365
    if diff ../outputs/t2365 ../originals/t2365 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2366) timeout -s 9 2 ../source/replace.exe '? *@[[^9-B][^0-9]A[^a-c]' 'a&'  < ../inputs/temp-test/1909.inp.810.2 > ../outputs/t2366
    if diff ../outputs/t2366 ../originals/t2366 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2367) timeout -s 9 2 ../source/replace.exe '? *[^--^a-c]$' 'a&'  < ../inputs/temp-test/1369.inp.587.6 > ../outputs/t2367
    if diff ../outputs/t2367 ../originals/t2367 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2368) timeout -s 9 2 ../source/replace.exe '? *[^--^a-c]' 'a&'  < ../inputs/temp-test/1367.inp.587.1 > ../outputs/t2368
    if diff ../outputs/t2368 ../originals/t2368 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2369) timeout -s 9 2 ../source/replace.exe '? *[^--^a-c]' 'a&'  < ../inputs/temp-test/1368.inp.587.3 > ../outputs/t2369
    if diff ../outputs/t2369 ../originals/t2369 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2370) timeout -s 9 2 ../source/replace.exe '? *[^a-][9-B]--' '@%&a'  < ../inputs/temp-test/1705.inp.727.1 > ../outputs/t2370
    if diff ../outputs/t2370 ../originals/t2370 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2371) timeout -s 9 2 ../source/replace.exe '? *[^a-][9-B]--' '@%&a'  < ../inputs/temp-test/1706.inp.727.2 > ../outputs/t2371
    if diff ../outputs/t2371 ../originals/t2371 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2372) timeout -s 9 2 ../source/replace.exe '? *[^a-][9-B]--' '@%&a'  < ../inputs/temp-test/1707.inp.727.3 > ../outputs/t2372
    if diff ../outputs/t2372 ../originals/t2372 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2373) timeout -s 9 2 ../source/replace.exe '?!' 'E2}-sQuI['  < ../inputs/input/ruin.639 > ../outputs/t2373
    if diff ../outputs/t2373 ../originals/t2373 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2374) timeout -s 9 2 ../source/replace.exe '?$' '$Ci@3^s4Mt/r6s/"jopElFXsAmp8CE#!&p!d:J&e7*F0`/RFf*M[8l3*.CM@/|pucY'  < ../inputs/input/ruin.1937 > ../outputs/t2374
    if diff ../outputs/t2374 ../originals/t2374 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2375) timeout -s 9 2 ../source/replace.exe '?$' '$Z'  < ../inputs/input/ruin.387 > ../outputs/t2375
    if diff ../outputs/t2375 ../originals/t2375 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2376) timeout -s 9 2 ../source/replace.exe '?$' '*U*'\''I8uu@VloES@|VT4+e|'  < ../inputs/input/ruin.1285 > ../outputs/t2376
    if diff ../outputs/t2376 ../originals/t2376 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2377) timeout -s 9 2 ../source/replace.exe '?$' '2'  < ../inputs/input/ruin.505 > ../outputs/t2377
    if diff ../outputs/t2377 ../originals/t2377 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2378) timeout -s 9 2 ../source/replace.exe '?$' '=MoPU`!tL"6E$'  < ../inputs/input/ruin.1084 > ../outputs/t2378
    if diff ../outputs/t2378 ../originals/t2378 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2379) timeout -s 9 2 ../source/replace.exe '?$' 'E'  < ../inputs/input/ruin.1113 > ../outputs/t2379
    if diff ../outputs/t2379 ../originals/t2379 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2380) timeout -s 9 2 ../source/replace.exe '?$' 'Mbtz>x/9wXMF<9)g/A-g#!ci/5cX}I+x\'\''AU$*rX0&~5q'  < ../inputs/input/ruin.759 > ../outputs/t2380
    if diff ../outputs/t2380 ../originals/t2380 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2381) timeout -s 9 2 ../source/replace.exe '?$' 'a&'  < ../inputs/temp-test/826.inp.355.6 > ../outputs/t2381
    if diff ../outputs/t2381 ../originals/t2381 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2382) timeout -s 9 2 ../source/replace.exe '?$' 'k#j>k?tL'\''lxD6JM$0j,))D@-]OI]DpDxwc?,xlmDr5F}}h"qU.Lp;'  < ../inputs/input/ruin.1406 > ../outputs/t2382
    if diff ../outputs/t2382 ../originals/t2382 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2383) timeout -s 9 2 ../source/replace.exe '?$' 'q'  < ../inputs/input/ruin.644 > ../outputs/t2383
    if diff ../outputs/t2383 ../originals/t2383 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2384) timeout -s 9 2 ../source/replace.exe '?%-' '&'  < ../inputs/temp-test/2347.inp.997.1 > ../outputs/t2384
    if diff ../outputs/t2384 ../originals/t2384 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2385) timeout -s 9 2 ../source/replace.exe '?%-' '&'  < ../inputs/temp-test/2348.inp.997.2 > ../outputs/t2385
    if diff ../outputs/t2385 ../originals/t2385 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2386) timeout -s 9 2 ../source/replace.exe '?%-**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t2386
    if diff ../outputs/t2386 ../originals/t2386 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2387) timeout -s 9 2 ../source/replace.exe '?%[^9-B]' ''  < ../inputs/temp-test/11.inp.5.2 > ../outputs/t2387
    if diff ../outputs/t2387 ../originals/t2387 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2388) timeout -s 9 2 ../source/replace.exe '?'   < ../inputs/input/ruin.1153 > ../outputs/t2388
    if diff ../outputs/t2388 ../originals/t2388 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2389) timeout -s 9 2 ../source/replace.exe '?' ' '  < ../inputs/input/ruin.1434 > ../outputs/t2389
    if diff ../outputs/t2389 ../originals/t2389 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2390) timeout -s 9 2 ../source/replace.exe '?' ' '  < ../inputs/input/ruin.457 > ../outputs/t2390
    if diff ../outputs/t2390 ../originals/t2390 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2391) timeout -s 9 2 ../source/replace.exe '?' '!wR{-znFqOsen$'  < ../inputs/input/ruin.643 > ../outputs/t2391
    if diff ../outputs/t2391 ../originals/t2391 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2392) timeout -s 9 2 ../source/replace.exe '?' '"\]({uYH3x5zs{.$s)G2Pzxji.o]- _Pzt'\''~6m#[}UH+'  < ../inputs/input/ruin.318 > ../outputs/t2392
    if diff ../outputs/t2392 ../originals/t2392 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2393) timeout -s 9 2 ../source/replace.exe '?' '"w4yF;^%V{=[g" GQ!^)U'\''6G+5J[ejzJ=>IXG>MUU*;c:LUh'\''sz` ;i)-cxBKFwk%b`+L'  < ../inputs/input/ruin.1189 > ../outputs/t2393
    if diff ../outputs/t2393 ../originals/t2393 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2394) timeout -s 9 2 ../source/replace.exe '?' '#((G)KKH'  < ../inputs/input/ruin.1245 > ../outputs/t2394
    if diff ../outputs/t2394 ../originals/t2394 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2395) timeout -s 9 2 ../source/replace.exe '?' '#:07uLCQLG\b`P(5t'  < ../inputs/input/ruin.939 > ../outputs/t2395
    if diff ../outputs/t2395 ../originals/t2395 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2396) timeout -s 9 2 ../source/replace.exe '?' '$'  < ../inputs/input/ruin.1336 > ../outputs/t2396
    if diff ../outputs/t2396 ../originals/t2396 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2397) timeout -s 9 2 ../source/replace.exe '?' '$bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<bJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<'  < ../inputs/input/ruin.1336 > ../outputs/t2397
    if diff ../outputs/t2397 ../originals/t2397 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2398) timeout -s 9 2 ../source/replace.exe '?' '%'  < ../inputs/input/ruin.72 > ../outputs/t2398
    if diff ../outputs/t2398 ../originals/t2398 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2399) timeout -s 9 2 ../source/replace.exe '?' '%5\")?O5'\''y2k>Z=\MH%y:6*~h'  < ../inputs/input/ruin.969 > ../outputs/t2399
    if diff ../outputs/t2399 ../originals/t2399 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2400) timeout -s 9 2 ../source/replace.exe '?' '%HMhn>OvlKt*Ca5KQC"Zjjtm<0$4C\@!u_Lp`%J)qy("dr>Im'\''IRO'  < ../inputs/input/ruin.296 > ../outputs/t2400
    if diff ../outputs/t2400 ../originals/t2400 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2401) timeout -s 9 2 ../source/replace.exe '?' '&'  < ../inputs/input/ruin.1767 > ../outputs/t2401
    if diff ../outputs/t2401 ../originals/t2401 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2402) timeout -s 9 2 ../source/replace.exe '?' '&'  < ../inputs/input/ruin.185 > ../outputs/t2402
    if diff ../outputs/t2402 ../originals/t2402 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2403) timeout -s 9 2 ../source/replace.exe '?' '&/CK/ck ZYhUC('  < ../inputs/input/ruin.1355 > ../outputs/t2403
    if diff ../outputs/t2403 ../originals/t2403 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2404) timeout -s 9 2 ../source/replace.exe '?' '&4fw/&r2!st;I9'  < ../inputs/input/ruin.1689 > ../outputs/t2404
    if diff ../outputs/t2404 ../originals/t2404 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2405) timeout -s 9 2 ../source/replace.exe '?' '&RO-^P6-QT4o%.LR>%%g@7t3Yn7!#QeIrm}[.1.'  < ../inputs/input/ruin.1501 > ../outputs/t2405
    if diff ../outputs/t2405 ../originals/t2405 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2406) timeout -s 9 2 ../source/replace.exe '?' '&a@%'  < ../inputs/temp-test/88.inp.40.1 > ../outputs/t2406
    if diff ../outputs/t2406 ../originals/t2406 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2407) timeout -s 9 2 ../source/replace.exe '?' '&a@%'  < ../inputs/temp-test/89.inp.40.2 > ../outputs/t2407
    if diff ../outputs/t2407 ../originals/t2407 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2408) timeout -s 9 2 ../source/replace.exe '?' '&a@%'  < ../inputs/temp-test/90.inp.40.3 > ../outputs/t2408
    if diff ../outputs/t2408 ../originals/t2408 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2409) timeout -s 9 2 ../source/replace.exe '?' '&mY@.8om'  < ../inputs/input/ruin.1923 > ../outputs/t2409
    if diff ../outputs/t2409 ../originals/t2409 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2410) timeout -s 9 2 ../source/replace.exe '?' ''  < ../inputs/input/ruin.1235 > ../outputs/t2410
    if diff ../outputs/t2410 ../originals/t2410 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2411) timeout -s 9 2 ../source/replace.exe '?' ''  < ../inputs/input/ruin.1723 > ../outputs/t2411
    if diff ../outputs/t2411 ../originals/t2411 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2412) timeout -s 9 2 ../source/replace.exe '?' ''  < ../inputs/input/ruin.1830 > ../outputs/t2412
    if diff ../outputs/t2412 ../originals/t2412 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2413) timeout -s 9 2 ../source/replace.exe '?' ''  < ../inputs/input/ruin.571 > ../outputs/t2413
    if diff ../outputs/t2413 ../originals/t2413 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2414) timeout -s 9 2 ../source/replace.exe '?' ''  < ../inputs/input/ruin.590 > ../outputs/t2414
    if diff ../outputs/t2414 ../originals/t2414 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2415) timeout -s 9 2 ../source/replace.exe '?' ''  < ../inputs/input/ruin.821 > ../outputs/t2415
    if diff ../outputs/t2415 ../originals/t2415 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2416) timeout -s 9 2 ../source/replace.exe '?' ''\'''  < ../inputs/input/ruin.1176 > ../outputs/t2416
    if diff ../outputs/t2416 ../originals/t2416 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2417) timeout -s 9 2 ../source/replace.exe '?' ''\''7P5n5'\''lRpz=:pn#5?'  < ../inputs/input/ruin.1370 > ../outputs/t2417
    if diff ../outputs/t2417 ../originals/t2417 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2418) timeout -s 9 2 ../source/replace.exe '?' ''\''["<]>V(0?ks?"32CO!wk-P)_U,v\,?v$/eL7Gk$'  < ../inputs/input/ruin.507 > ../outputs/t2418
    if diff ../outputs/t2418 ../originals/t2418 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2419) timeout -s 9 2 ../source/replace.exe '?' ''\''m'  < ../inputs/input/ruin.646 > ../outputs/t2419
    if diff ../outputs/t2419 ../originals/t2419 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2420) timeout -s 9 2 ../source/replace.exe '?' ''\''~'  < ../inputs/input/ruin.1252 > ../outputs/t2420
    if diff ../outputs/t2420 ../originals/t2420 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2421) timeout -s 9 2 ../source/replace.exe '?' '('  < ../inputs/input/ruin.1296 > ../outputs/t2421
    if diff ../outputs/t2421 ../originals/t2421 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2422) timeout -s 9 2 ../source/replace.exe '?' '('  < ../inputs/input/ruin.179 > ../outputs/t2422
    if diff ../outputs/t2422 ../originals/t2422 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2423) timeout -s 9 2 ../source/replace.exe '?' ')'  < ../inputs/input/ruin.1751 > ../outputs/t2423
    if diff ../outputs/t2423 ../originals/t2423 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2424) timeout -s 9 2 ../source/replace.exe '?' ')'  < ../inputs/input/ruin.600 > ../outputs/t2424
    if diff ../outputs/t2424 ../originals/t2424 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2425) timeout -s 9 2 ../source/replace.exe '?' ')P\g38V7('\''R<=PA[vEnl}V;-'  < ../inputs/input/ruin.1375 > ../outputs/t2425
    if diff ../outputs/t2425 ../originals/t2425 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2426) timeout -s 9 2 ../source/replace.exe '?' '*Y)d1^+BPVi6}-,@Fhp%c9[8=7PJ$[+'  < ../inputs/input/ruin.725 > ../outputs/t2426
    if diff ../outputs/t2426 ../originals/t2426 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2427) timeout -s 9 2 ../source/replace.exe '?' '*dvM[t?`D}k'\'';y+;`)<Z%e TPV`D5\Vcq9bq/1:3Q@+RnI'  < ../inputs/input/ruin.1407 > ../outputs/t2427
    if diff ../outputs/t2427 ../originals/t2427 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2428) timeout -s 9 2 ../source/replace.exe '?' '+q^RHGG^&;>#u@F]^1iRwc1mpuk_2 FZS)?aAVpejj96'  < ../inputs/input/ruin.1299 > ../outputs/t2428
    if diff ../outputs/t2428 ../originals/t2428 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2429) timeout -s 9 2 ../source/replace.exe '?' ','  < ../inputs/input/ruin.1508 > ../outputs/t2429
    if diff ../outputs/t2429 ../originals/t2429 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2430) timeout -s 9 2 ../source/replace.exe '?' ','  < ../inputs/input/ruin.1909 > ../outputs/t2430
    if diff ../outputs/t2430 ../originals/t2430 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2431) timeout -s 9 2 ../source/replace.exe '?' ','  < ../inputs/input/ruin.658 > ../outputs/t2431
    if diff ../outputs/t2431 ../originals/t2431 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2432) timeout -s 9 2 ../source/replace.exe '?' ',^BP#j2(t'  < ../inputs/input/ruin.1804 > ../outputs/t2432
    if diff ../outputs/t2432 ../originals/t2432 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2433) timeout -s 9 2 ../source/replace.exe '?' ',gAEa`/^PQWZZa^F'  < ../inputs/input/ruin.1612 > ../outputs/t2433
    if diff ../outputs/t2433 ../originals/t2433 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2434) timeout -s 9 2 ../source/replace.exe '?' '.'  < ../inputs/input/ruin.264 > ../outputs/t2434
    if diff ../outputs/t2434 ../originals/t2434 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2435) timeout -s 9 2 ../source/replace.exe '?' '.'  < ../inputs/input/ruin.496 > ../outputs/t2435
    if diff ../outputs/t2435 ../originals/t2435 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2436) timeout -s 9 2 ../source/replace.exe '?' '.koDO;b.|5'  < ../inputs/input/ruin.402 > ../outputs/t2436
    if diff ../outputs/t2436 ../originals/t2436 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2437) timeout -s 9 2 ../source/replace.exe '?' '.mCbJwgx z1X{xc0.PG"hg]OjMQ$ol]SYG!<.<VS(.DdErr'  < ../inputs/input/ruin.403 > ../outputs/t2437
    if diff ../outputs/t2437 ../originals/t2437 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2438) timeout -s 9 2 ../source/replace.exe '?' '/DcINi{MtBKO9S<U>&]qaS&QFn#Ow0U<1.yn>bIQ<,ak#&_vVh6:2{^#'  < ../inputs/input/ruin.1841 > ../outputs/t2438
    if diff ../outputs/t2438 ../originals/t2438 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2439) timeout -s 9 2 ../source/replace.exe '?' '/~OE"QNi/dprl$J~oOt0kPNb:6#I&zya SA~OXg/l+^bcES"n5ig.M:E<Ygto))h'\''<j~E:I@sFaiXXf'\'''  < ../inputs/input/ruin.155 > ../outputs/t2439
    if diff ../outputs/t2439 ../originals/t2439 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2440) timeout -s 9 2 ../source/replace.exe '?' '0yd{(t"'\''bw/ i+JO/F,1bSmIlg'  < ../inputs/input/ruin.282 > ../outputs/t2440
    if diff ../outputs/t2440 ../originals/t2440 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2441) timeout -s 9 2 ../source/replace.exe '?' '1'  < ../inputs/input/ruin.1877 > ../outputs/t2441
    if diff ../outputs/t2441 ../originals/t2441 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2442) timeout -s 9 2 ../source/replace.exe '?' '1'  < ../inputs/input/ruin.868 > ../outputs/t2442
    if diff ../outputs/t2442 ../originals/t2442 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2443) timeout -s 9 2 ../source/replace.exe '?' '1u;:JqX:hb3bS'  < ../inputs/input/ruin.1153 > ../outputs/t2443
    if diff ../outputs/t2443 ../originals/t2443 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2444) timeout -s 9 2 ../source/replace.exe '?' '2'  < ../inputs/input/ruin.1865 > ../outputs/t2444
    if diff ../outputs/t2444 ../originals/t2444 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2445) timeout -s 9 2 ../source/replace.exe '?' '2Ax#Mv_@DjcWz"~F]km'  < ../inputs/input/ruin.1241 > ../outputs/t2445
    if diff ../outputs/t2445 ../originals/t2445 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2446) timeout -s 9 2 ../source/replace.exe '?' '2U+URc}6Uk:Eso9T'  < ../inputs/input/ruin.1726 > ../outputs/t2446
    if diff ../outputs/t2446 ../originals/t2446 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2447) timeout -s 9 2 ../source/replace.exe '?' '4J R'  < ../inputs/input/ruin.845 > ../outputs/t2447
    if diff ../outputs/t2447 ../originals/t2447 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2448) timeout -s 9 2 ../source/replace.exe '?' '5'  < ../inputs/input/ruin.1878 > ../outputs/t2448
    if diff ../outputs/t2448 ../originals/t2448 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2449) timeout -s 9 2 ../source/replace.exe '?' '5<WMaE'\''r{G`Diz:pyjW'  < ../inputs/input/ruin.1979 > ../outputs/t2449
    if diff ../outputs/t2449 ../originals/t2449 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2450) timeout -s 9 2 ../source/replace.exe '?' '6'  < ../inputs/input/ruin.1494 > ../outputs/t2450
    if diff ../outputs/t2450 ../originals/t2450 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2451) timeout -s 9 2 ../source/replace.exe '?' '7/@`=G"5tu`>7#`st[D~6!6"/PndJ'  < ../inputs/input/ruin.586 > ../outputs/t2451
    if diff ../outputs/t2451 ../originals/t2451 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2452) timeout -s 9 2 ../source/replace.exe '?' '8"'  < ../inputs/input/ruin.511 > ../outputs/t2452
    if diff ../outputs/t2452 ../originals/t2452 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2453) timeout -s 9 2 ../source/replace.exe '?' '80LT@fdFy'  < ../inputs/input/ruin.601 > ../outputs/t2453
    if diff ../outputs/t2453 ../originals/t2453 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2454) timeout -s 9 2 ../source/replace.exe '?' '8l;V'  < ../inputs/input/ruin.1337 > ../outputs/t2454
    if diff ../outputs/t2454 ../originals/t2454 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2455) timeout -s 9 2 ../source/replace.exe '?' '8l;V3&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J43&YEy?NDqT |ye3E+7WmBD#X-J4'  < ../inputs/input/ruin.1337 > ../outputs/t2455
    if diff ../outputs/t2455 ../originals/t2455 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2456) timeout -s 9 2 ../source/replace.exe '?' '9'  < ../inputs/input/ruin.1743 > ../outputs/t2456
    if diff ../outputs/t2456 ../originals/t2456 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2457) timeout -s 9 2 ../source/replace.exe '?' '9'  < ../inputs/input/ruin.419 > ../outputs/t2457
    if diff ../outputs/t2457 ../originals/t2457 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2458) timeout -s 9 2 ../source/replace.exe '?' '9'  < ../inputs/input/ruin.533 > ../outputs/t2458
    if diff ../outputs/t2458 ../originals/t2458 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2459) timeout -s 9 2 ../source/replace.exe '?' '980/#_O^H>7fd&'  < ../inputs/input/ruin.532 > ../outputs/t2459
    if diff ../outputs/t2459 ../originals/t2459 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2460) timeout -s 9 2 ../source/replace.exe '?' '9ytHHUHo0O{;N1(n*Se{S < 3k'  < ../inputs/input/ruin.405 > ../outputs/t2460
    if diff ../outputs/t2460 ../originals/t2460 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2461) timeout -s 9 2 ../source/replace.exe '?' ':'  < ../inputs/input/ruin.1641 > ../outputs/t2461
    if diff ../outputs/t2461 ../originals/t2461 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2462) timeout -s 9 2 ../source/replace.exe '?' ':'  < ../inputs/input/ruin.366 > ../outputs/t2462
    if diff ../outputs/t2462 ../originals/t2462 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2463) timeout -s 9 2 ../source/replace.exe '?' ';'  < ../inputs/input/ruin.1018 > ../outputs/t2463
    if diff ../outputs/t2463 ../originals/t2463 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2464) timeout -s 9 2 ../source/replace.exe '?' ';'  < ../inputs/input/ruin.1520 > ../outputs/t2464
    if diff ../outputs/t2464 ../originals/t2464 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2465) timeout -s 9 2 ../source/replace.exe '?' ';exh\3*?mQqR,l:89C5.q2u\,`qPW:[zYi<c+xL`A^d[&PA:xddT0Et0-ux H8'  < ../inputs/input/ruin.962 > ../outputs/t2465
    if diff ../outputs/t2465 ../originals/t2465 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2466) timeout -s 9 2 ../source/replace.exe '?' ';kh2\M8\&a4Pm=OF^-(G|-p8:i9ovm>xcJ,5e]>y%~kSEJ$[z@RzG}'  < ../inputs/input/ruin.966 > ../outputs/t2466
    if diff ../outputs/t2466 ../originals/t2466 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2467) timeout -s 9 2 ../source/replace.exe '?' '<'  < ../inputs/input/ruin.143 > ../outputs/t2467
    if diff ../outputs/t2467 ../originals/t2467 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2468) timeout -s 9 2 ../source/replace.exe '?' '<-DXZCR-P^y]}]T`l!/ue4S|LI|TZ\E~Bm>ZK!ml'  < ../inputs/input/ruin.46 > ../outputs/t2468
    if diff ../outputs/t2468 ../originals/t2468 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2469) timeout -s 9 2 ../source/replace.exe '?' '</Dco9Q(Uc0D'\''t:qBs3QUn;'\'''  < ../inputs/input/ruin.474 > ../outputs/t2469
    if diff ../outputs/t2469 ../originals/t2469 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2470) timeout -s 9 2 ../source/replace.exe '?' '<O'  < ../inputs/input/ruin.1579 > ../outputs/t2470
    if diff ../outputs/t2470 ../originals/t2470 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2471) timeout -s 9 2 ../source/replace.exe '?' '<Vod'\''|tm%p>|GpQ{JP^'  < ../inputs/input/ruin.1868 > ../outputs/t2471
    if diff ../outputs/t2471 ../originals/t2471 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2472) timeout -s 9 2 ../source/replace.exe '?' '<{'  < ../inputs/input/ruin.101 > ../outputs/t2472
    if diff ../outputs/t2472 ../originals/t2472 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2473) timeout -s 9 2 ../source/replace.exe '?' '='  < ../inputs/input/ruin.1217 > ../outputs/t2473
    if diff ../outputs/t2473 ../originals/t2473 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2474) timeout -s 9 2 ../source/replace.exe '?' '='  < ../inputs/input/ruin.1556 > ../outputs/t2474
    if diff ../outputs/t2474 ../originals/t2474 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2475) timeout -s 9 2 ../source/replace.exe '?' '=S&l@*,k=#&'  < ../inputs/input/ruin.470 > ../outputs/t2475
    if diff ../outputs/t2475 ../originals/t2475 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2476) timeout -s 9 2 ../source/replace.exe '?' '=|0$@9jg(x)\|.;{:xQ'  < ../inputs/input/ruin.970 > ../outputs/t2476
    if diff ../outputs/t2476 ../originals/t2476 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2477) timeout -s 9 2 ../source/replace.exe '?' '>'  < ../inputs/input/ruin.345 > ../outputs/t2477
    if diff ../outputs/t2477 ../originals/t2477 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2478) timeout -s 9 2 ../source/replace.exe '?' '>0\MtN5k&5!Q./'  < ../inputs/input/ruin.358 > ../outputs/t2478
    if diff ../outputs/t2478 ../originals/t2478 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2479) timeout -s 9 2 ../source/replace.exe '?' '>\cj;-`N(Qi&s5nTV-3sEXm*'  < ../inputs/input/ruin.882 > ../outputs/t2479
    if diff ../outputs/t2479 ../originals/t2479 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2480) timeout -s 9 2 ../source/replace.exe '?' '>b})}d%:+~EdJc2\! ug7;'  < ../inputs/input/ruin.1335 > ../outputs/t2480
    if diff ../outputs/t2480 ../originals/t2480 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2481) timeout -s 9 2 ../source/replace.exe '?' '>nHA0p'\''Ou1foR!WVdb0*KDL3]#o35lH%'  < ../inputs/input/ruin.1364 > ../outputs/t2481
    if diff ../outputs/t2481 ../originals/t2481 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2482) timeout -s 9 2 ../source/replace.exe '?' '?&'  < ../inputs/input/ruin.744 > ../outputs/t2482
    if diff ../outputs/t2482 ../originals/t2482 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2483) timeout -s 9 2 ../source/replace.exe '?' '?Tp4fnmE6"Pe_j`:'  < ../inputs/input/ruin.247 > ../outputs/t2483
    if diff ../outputs/t2483 ../originals/t2483 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2484) timeout -s 9 2 ../source/replace.exe '?' '?b&+AjmcI]eV'\''|:7(2&q@pmv;p3/#;RBU8z}&?C4hjPC3x1{3?wfI6hN-'  < ../inputs/input/ruin.168 > ../outputs/t2484
    if diff ../outputs/t2484 ../originals/t2484 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2485) timeout -s 9 2 ../source/replace.exe '?' '?wWkfB0{Olvu!$q9j0|Q&niewx~wpw+G.dVNB$$x0&VHId'  < ../inputs/input/ruin.1389 > ../outputs/t2485
    if diff ../outputs/t2485 ../originals/t2485 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2486) timeout -s 9 2 ../source/replace.exe '?' '@%&a'  < ../inputs/temp-test/71.inp.31.1 > ../outputs/t2486
    if diff ../outputs/t2486 ../originals/t2486 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2487) timeout -s 9 2 ../source/replace.exe '?' '@%&a'  < ../inputs/temp-test/72.inp.31.2 > ../outputs/t2487
    if diff ../outputs/t2487 ../originals/t2487 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2488) timeout -s 9 2 ../source/replace.exe '?' '@%&a'  < ../inputs/temp-test/73.inp.31.3 > ../outputs/t2488
    if diff ../outputs/t2488 ../originals/t2488 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2489) timeout -s 9 2 ../source/replace.exe '?' '@'  < ../inputs/input/ruin.951 > ../outputs/t2489
    if diff ../outputs/t2489 ../originals/t2489 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2490) timeout -s 9 2 ../source/replace.exe '?' '@V@=ehA6m.N^nI2LfcXe_'  < ../inputs/input/ruin.1919 > ../outputs/t2490
    if diff ../outputs/t2490 ../originals/t2490 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2491) timeout -s 9 2 ../source/replace.exe '?' '@b +$xs[.Nh$2O|'  < ../inputs/input/ruin.952 > ../outputs/t2491
    if diff ../outputs/t2491 ../originals/t2491 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2492) timeout -s 9 2 ../source/replace.exe '?' '@fcA'\''DvQsI^6t.kwEqv'  < ../inputs/input/ruin.116 > ../outputs/t2492
    if diff ../outputs/t2492 ../originals/t2492 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2493) timeout -s 9 2 ../source/replace.exe '?' '@n'  < ../inputs/temp-test/53.inp.22.1 > ../outputs/t2493
    if diff ../outputs/t2493 ../originals/t2493 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2494) timeout -s 9 2 ../source/replace.exe '?' '@o@KFH{>4`U9P+*vh?|$QnmR!k"^X=gQm3_JMfyxy}.ZI<K!U( GS"A4I7AHNHp?x!nL%T{Og%LeK8>PdhyfE$yz5a</&:6{&`/3:zG'  < ../inputs/input/ruin.384 > ../outputs/t2494
    if diff ../outputs/t2494 ../originals/t2494 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2495) timeout -s 9 2 ../source/replace.exe '?' 'A'  < ../inputs/input/ruin.1010 > ../outputs/t2495
    if diff ../outputs/t2495 ../originals/t2495 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2496) timeout -s 9 2 ../source/replace.exe '?' 'AF'  < ../inputs/input/ruin.1836 > ../outputs/t2496
    if diff ../outputs/t2496 ../originals/t2496 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2497) timeout -s 9 2 ../source/replace.exe '?' 'B'  < ../inputs/input/ruin.1412 > ../outputs/t2497
    if diff ../outputs/t2497 ../originals/t2497 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2498) timeout -s 9 2 ../source/replace.exe '?' 'BUoa41Xis8O!z)THM+k-UQ'  < ../inputs/input/ruin.433 > ../outputs/t2498
    if diff ../outputs/t2498 ../originals/t2498 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2499) timeout -s 9 2 ../source/replace.exe '?' 'Bf/nz5#;N'  < ../inputs/input/ruin.242 > ../outputs/t2499
    if diff ../outputs/t2499 ../originals/t2499 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2500) timeout -s 9 2 ../source/replace.exe '?' 'C'  < ../inputs/input/ruin.1343 > ../outputs/t2500
    if diff ../outputs/t2500 ../originals/t2500 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2501) timeout -s 9 2 ../source/replace.exe '?' 'C@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-@*[a--b]^*-[^-'  < ../inputs/input/ruin.1343 > ../outputs/t2501
    if diff ../outputs/t2501 ../originals/t2501 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2502) timeout -s 9 2 ../source/replace.exe '?' 'CC'\''vJXblh:Zwt&:'  < ../inputs/input/ruin.338 > ../outputs/t2502
    if diff ../outputs/t2502 ../originals/t2502 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2503) timeout -s 9 2 ../source/replace.exe '?' 'CE(8]nlKTDmLw~YL"~TMBV%#@B1b'\''9$'  < ../inputs/input/ruin.374 > ../outputs/t2503
    if diff ../outputs/t2503 ../originals/t2503 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2504) timeout -s 9 2 ../source/replace.exe '?' 'D'  < ../inputs/input/ruin.1196 > ../outputs/t2504
    if diff ../outputs/t2504 ../originals/t2504 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2505) timeout -s 9 2 ../source/replace.exe '?' 'D+7t>fY~<_'  < ../inputs/input/ruin.1904 > ../outputs/t2505
    if diff ../outputs/t2505 ../originals/t2505 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2506) timeout -s 9 2 ../source/replace.exe '?' 'DF\2'  < ../inputs/input/ruin.1482 > ../outputs/t2506
    if diff ../outputs/t2506 ../originals/t2506 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2507) timeout -s 9 2 ../source/replace.exe '?' 'F'  < ../inputs/input/ruin.926 > ../outputs/t2507
    if diff ../outputs/t2507 ../originals/t2507 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2508) timeout -s 9 2 ../source/replace.exe '?' 'F@DPQ8u2.0:==Dsj251Al-d\Z'  < ../inputs/input/ruin.111 > ../outputs/t2508
    if diff ../outputs/t2508 ../originals/t2508 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2509) timeout -s 9 2 ../source/replace.exe '?' 'FSaq)g'  < ../inputs/input/ruin.844 > ../outputs/t2509
    if diff ../outputs/t2509 ../originals/t2509 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2510) timeout -s 9 2 ../source/replace.exe '?' 'Gj154]Jjcc\^H?[iW;|>#5"?lm_#?K8no~(Z?!lV%m=?Gx*4,)-orqHg?`B|P-nsUv#a@k%zXg('\''\=G`4,0'  < ../inputs/input/ruin.1166 > ../outputs/t2510
    if diff ../outputs/t2510 ../originals/t2510 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2511) timeout -s 9 2 ../source/replace.exe '?' 'H#I|."*BcMtK)["_)'  < ../inputs/input/ruin.995 > ../outputs/t2511
    if diff ../outputs/t2511 ../originals/t2511 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2512) timeout -s 9 2 ../source/replace.exe '?' 'H'  < ../inputs/input/ruin.642 > ../outputs/t2512
    if diff ../outputs/t2512 ../originals/t2512 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2513) timeout -s 9 2 ../source/replace.exe '?' 'HqJ[APZc=u{VE'  < ../inputs/input/ruin.103 > ../outputs/t2513
    if diff ../outputs/t2513 ../originals/t2513 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2514) timeout -s 9 2 ../source/replace.exe '?' 'Iv*a+"a+_d)K~"^<AvGzg.*0pQl1[Yrs;,`%"AB7k'  < ../inputs/input/ruin.1582 > ../outputs/t2514
    if diff ../outputs/t2514 ../originals/t2514 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2515) timeout -s 9 2 ../source/replace.exe '?' 'J'  < ../inputs/input/ruin.1977 > ../outputs/t2515
    if diff ../outputs/t2515 ../originals/t2515 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2516) timeout -s 9 2 ../source/replace.exe '?' 'K'  < ../inputs/input/ruin.1121 > ../outputs/t2516
    if diff ../outputs/t2516 ../originals/t2516 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2517) timeout -s 9 2 ../source/replace.exe '?' 'K<?B4$`6O1>J#&OM4K$2QDiT<ji'  < ../inputs/input/ruin.524 > ../outputs/t2517
    if diff ../outputs/t2517 ../originals/t2517 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2518) timeout -s 9 2 ../source/replace.exe '?' 'KsxI474&Q(C}u4M|o2T`<`;S^`NUPxX'  < ../inputs/input/ruin.291 > ../outputs/t2518
    if diff ../outputs/t2518 ../originals/t2518 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2519) timeout -s 9 2 ../source/replace.exe '?' 'L/kw\'  < ../inputs/input/ruin.404 > ../outputs/t2519
    if diff ../outputs/t2519 ../originals/t2519 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2520) timeout -s 9 2 ../source/replace.exe '?' 'L;vc2#{V7TVUA[lGcZR)h\M7+(FnC`>q'  < ../inputs/input/ruin.1593 > ../outputs/t2520
    if diff ../outputs/t2520 ../originals/t2520 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2521) timeout -s 9 2 ../source/replace.exe '?' 'Lvu77k}K'  < ../inputs/input/ruin.1239 > ../outputs/t2521
    if diff ../outputs/t2521 ../originals/t2521 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2522) timeout -s 9 2 ../source/replace.exe '?' 'M%&;~-{;<(48m;Dv)aQS0bkh'\''eK'  < ../inputs/input/ruin.1613 > ../outputs/t2522
    if diff ../outputs/t2522 ../originals/t2522 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2523) timeout -s 9 2 ../source/replace.exe '?' 'M'  < ../inputs/input/ruin.135 > ../outputs/t2523
    if diff ../outputs/t2523 ../originals/t2523 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2524) timeout -s 9 2 ../source/replace.exe '?' 'M\M/(+Q(30LI2#Tq'  < ../inputs/input/ruin.1777 > ../outputs/t2524
    if diff ../outputs/t2524 ../originals/t2524 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2525) timeout -s 9 2 ../source/replace.exe '?' 'N#D{(1Gn[8UCLC}OnP^},P|FWYtd99MB_Kco_$[Z-<i-RL'  < ../inputs/input/ruin.953 > ../outputs/t2525
    if diff ../outputs/t2525 ../originals/t2525 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2526) timeout -s 9 2 ../source/replace.exe '?' 'N&5vC\L {wtz|wCl|^@'  < ../inputs/input/ruin.165 > ../outputs/t2526
    if diff ../outputs/t2526 ../originals/t2526 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2527) timeout -s 9 2 ../source/replace.exe '?' 'N)[e.{p6mu6~p;u0r*3|}'  < ../inputs/input/ruin.1168 > ../outputs/t2527
    if diff ../outputs/t2527 ../originals/t2527 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2528) timeout -s 9 2 ../source/replace.exe '?' 'NEW'  < ../inputs/temp-test/1384.inp.594.1 > ../outputs/t2528
    if diff ../outputs/t2528 ../originals/t2528 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2529) timeout -s 9 2 ../source/replace.exe '?' 'NEW'  < ../inputs/temp-test/1385.inp.594.3 > ../outputs/t2529
    if diff ../outputs/t2529 ../originals/t2529 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2530) timeout -s 9 2 ../source/replace.exe '?' 'NEW'  < ../inputs/temp-test/1386.inp.594.4 > ../outputs/t2530
    if diff ../outputs/t2530 ../originals/t2530 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2531) timeout -s 9 2 ../source/replace.exe '?' 'NT*x]<L/3",r6SrEiVl>/'  < ../inputs/input/ruin.40 > ../outputs/t2531
    if diff ../outputs/t2531 ../originals/t2531 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2532) timeout -s 9 2 ../source/replace.exe '?' 'O'  < ../inputs/input/ruin.1950 > ../outputs/t2532
    if diff ../outputs/t2532 ../originals/t2532 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2533) timeout -s 9 2 ../source/replace.exe '?' 'P'  < ../inputs/input/ruin.1300 > ../outputs/t2533
    if diff ../outputs/t2533 ../originals/t2533 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2534) timeout -s 9 2 ../source/replace.exe '?' 'P'  < ../inputs/input/ruin.63 > ../outputs/t2534
    if diff ../outputs/t2534 ../originals/t2534 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2535) timeout -s 9 2 ../source/replace.exe '?' 'P'  < ../inputs/input/ruin.977 > ../outputs/t2535
    if diff ../outputs/t2535 ../originals/t2535 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2536) timeout -s 9 2 ../source/replace.exe '?' 'Q'  < ../inputs/input/ruin.385 > ../outputs/t2536
    if diff ../outputs/t2536 ../originals/t2536 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2537) timeout -s 9 2 ../source/replace.exe '?' 'QAbcG]<+#'  < ../inputs/input/ruin.1431 > ../outputs/t2537
    if diff ../outputs/t2537 ../originals/t2537 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2538) timeout -s 9 2 ../source/replace.exe '?' 'QCGA\X(?Z#pI;PhS&YE|'  < ../inputs/input/ruin.1232 > ../outputs/t2538
    if diff ../outputs/t2538 ../originals/t2538 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2539) timeout -s 9 2 ../source/replace.exe '?' 'R(J/X%MoiFZWrD3`LiS^'  < ../inputs/input/ruin.354 > ../outputs/t2539
    if diff ../outputs/t2539 ../originals/t2539 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2540) timeout -s 9 2 ../source/replace.exe '?' 'S'  < ../inputs/input/ruin.887 > ../outputs/t2540
    if diff ../outputs/t2540 ../originals/t2540 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2541) timeout -s 9 2 ../source/replace.exe '?' 'T'  < ../inputs/input/ruin.1866 > ../outputs/t2541
    if diff ../outputs/t2541 ../originals/t2541 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2542) timeout -s 9 2 ../source/replace.exe '?' 'T'  < ../inputs/input/ruin.543 > ../outputs/t2542
    if diff ../outputs/t2542 ../originals/t2542 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2543) timeout -s 9 2 ../source/replace.exe '?' 'TVr2G'  < ../inputs/input/ruin.381 > ../outputs/t2543
    if diff ../outputs/t2543 ../originals/t2543 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2544) timeout -s 9 2 ../source/replace.exe '?' 'V'  < ../inputs/input/ruin.519 > ../outputs/t2544
    if diff ../outputs/t2544 ../originals/t2544 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2545) timeout -s 9 2 ../source/replace.exe '?' 'W'  < ../inputs/input/ruin.5 > ../outputs/t2545
    if diff ../outputs/t2545 ../originals/t2545 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2546) timeout -s 9 2 ../source/replace.exe '?' 'X'  < ../inputs/input/ruin.541 > ../outputs/t2546
    if diff ../outputs/t2546 ../originals/t2546 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2547) timeout -s 9 2 ../source/replace.exe '?' 'XM:AR~,."oRZ=YEND@<A}O16:Prv[2k&'  < ../inputs/input/ruin.1144 > ../outputs/t2547
    if diff ../outputs/t2547 ../originals/t2547 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2548) timeout -s 9 2 ../source/replace.exe '?' 'Z#:;1Z}X$]Lyh~'  < ../inputs/input/ruin.534 > ../outputs/t2548
    if diff ../outputs/t2548 ../originals/t2548 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2549) timeout -s 9 2 ../source/replace.exe '?' 'Z'  < ../inputs/input/ruin.1278 > ../outputs/t2549
    if diff ../outputs/t2549 ../originals/t2549 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2550) timeout -s 9 2 ../source/replace.exe '?' 'Z'  < ../inputs/input/ruin.1658 > ../outputs/t2550
    if diff ../outputs/t2550 ../originals/t2550 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2551) timeout -s 9 2 ../source/replace.exe '?' '[!%Kk\zSLS\.sd"~7vJ0E0<FN7Qt@<1!@{TtBay}DndZ 7]An5h{EZ0Tk;h;T> $qR7oi3a.D8}y]'  < ../inputs/input/ruin.1647 > ../outputs/t2551
    if diff ../outputs/t2551 ../originals/t2551 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2552) timeout -s 9 2 ../source/replace.exe '?' '['  < ../inputs/input/ruin.463 > ../outputs/t2552
    if diff ../outputs/t2552 ../originals/t2552 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2553) timeout -s 9 2 ../source/replace.exe '?' '[fu'  < ../inputs/input/ruin.1366 > ../outputs/t2553
    if diff ../outputs/t2553 ../originals/t2553 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2554) timeout -s 9 2 ../source/replace.exe '?' '\'  < ../inputs/input/ruin.1490 > ../outputs/t2554
    if diff ../outputs/t2554 ../originals/t2554 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2555) timeout -s 9 2 ../source/replace.exe '?' '\'  < ../inputs/input/ruin.907 > ../outputs/t2555
    if diff ../outputs/t2555 ../originals/t2555 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2556) timeout -s 9 2 ../source/replace.exe '?' '].&7+CP1"L0aV#jId`1nde#Cn==C6@v<"]'  < ../inputs/input/ruin.1284 > ../outputs/t2556
    if diff ../outputs/t2556 ../originals/t2556 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2557) timeout -s 9 2 ../source/replace.exe '?' ']P@11+*4RS!'\''mW<:nB9.Oi%rf%ZIQkWmu'  < ../inputs/input/ruin.761 > ../outputs/t2557
    if diff ../outputs/t2557 ../originals/t2557 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2558) timeout -s 9 2 ../source/replace.exe '?' ']rZLj'  < ../inputs/input/ruin.1566 > ../outputs/t2558
    if diff ../outputs/t2558 ../originals/t2558 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2559) timeout -s 9 2 ../source/replace.exe '?' '^0aw^ijt96Qs<g\Ykb8w0,vv]v-#L'  < ../inputs/input/ruin.500 > ../outputs/t2559
    if diff ../outputs/t2559 ../originals/t2559 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2560) timeout -s 9 2 ../source/replace.exe '?' '^ce]WKN5- s+C)y11|8o7z'  < ../inputs/input/ruin.204 > ../outputs/t2560
    if diff ../outputs/t2560 ../originals/t2560 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2561) timeout -s 9 2 ../source/replace.exe '?' '_'  < ../inputs/input/ruin.1024 > ../outputs/t2561
    if diff ../outputs/t2561 ../originals/t2561 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2562) timeout -s 9 2 ../source/replace.exe '?' '_'  < ../inputs/input/ruin.248 > ../outputs/t2562
    if diff ../outputs/t2562 ../originals/t2562 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2563) timeout -s 9 2 ../source/replace.exe '?' '_Zm,B$H3+dOxCXpLjJB<}WOIix\+*'  < ../inputs/input/ruin.913 > ../outputs/t2563
    if diff ../outputs/t2563 ../originals/t2563 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2564) timeout -s 9 2 ../source/replace.exe '?' '_^ [H<2pLeGVat'  < ../inputs/input/ruin.1289 > ../outputs/t2564
    if diff ../outputs/t2564 ../originals/t2564 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2565) timeout -s 9 2 ../source/replace.exe '?' '_r-c9Hs(>!-fB8qY'  < ../inputs/input/ruin.1293 > ../outputs/t2565
    if diff ../outputs/t2565 ../originals/t2565 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2566) timeout -s 9 2 ../source/replace.exe '?' '`'  < ../inputs/input/ruin.1288 > ../outputs/t2566
    if diff ../outputs/t2566 ../originals/t2566 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2567) timeout -s 9 2 ../source/replace.exe '?' '`'  < ../inputs/input/ruin.1812 > ../outputs/t2567
    if diff ../outputs/t2567 ../originals/t2567 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2568) timeout -s 9 2 ../source/replace.exe '?' '`OM,I.7$B>8KwR3#e1>SqfWB3_5]@4o'  < ../inputs/input/ruin.776 > ../outputs/t2568
    if diff ../outputs/t2568 ../originals/t2568 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2569) timeout -s 9 2 ../source/replace.exe '?' 'a&'  < ../inputs/temp-test/823.inp.355.1 > ../outputs/t2569
    if diff ../outputs/t2569 ../originals/t2569 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2570) timeout -s 9 2 ../source/replace.exe '?' 'a&'  < ../inputs/temp-test/824.inp.355.2 > ../outputs/t2570
    if diff ../outputs/t2570 ../originals/t2570 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2571) timeout -s 9 2 ../source/replace.exe '?' 'a&'  < ../inputs/temp-test/825.inp.355.3 > ../outputs/t2571
    if diff ../outputs/t2571 ../originals/t2571 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2572) timeout -s 9 2 ../source/replace.exe '?' 'a'  < ../inputs/input/ruin.1884 > ../outputs/t2572
    if diff ../outputs/t2572 ../originals/t2572 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2573) timeout -s 9 2 ../source/replace.exe '?' 'a'  < ../inputs/input/ruin.1994 > ../outputs/t2573
    if diff ../outputs/t2573 ../originals/t2573 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2574) timeout -s 9 2 ../source/replace.exe '?' 'a9e6'  < ../inputs/input/ruin.1861 > ../outputs/t2574
    if diff ../outputs/t2574 ../originals/t2574 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2575) timeout -s 9 2 ../source/replace.exe '?' 'a@nb@tc'  < ../inputs/temp-test/385.inp.168.1 > ../outputs/t2575
    if diff ../outputs/t2575 ../originals/t2575 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2576) timeout -s 9 2 ../source/replace.exe '?' 'a@nb@tc'  < ../inputs/temp-test/386.inp.168.3 > ../outputs/t2576
    if diff ../outputs/t2576 ../originals/t2576 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2577) timeout -s 9 2 ../source/replace.exe '?' 'b'  < ../inputs/input/ruin.91 > ../outputs/t2577
    if diff ../outputs/t2577 ../originals/t2577 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2578) timeout -s 9 2 ../source/replace.exe '?' 'b@t'  < ../inputs/temp-test/274.inp.123.1 > ../outputs/t2578
    if diff ../outputs/t2578 ../originals/t2578 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2579) timeout -s 9 2 ../source/replace.exe '?' 'b@t'  < ../inputs/temp-test/275.inp.123.3 > ../outputs/t2579
    if diff ../outputs/t2579 ../originals/t2579 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2580) timeout -s 9 2 ../source/replace.exe '?' 'cLZbxdY4&gv/6)zVmA7Uw_^3:l'  < ../inputs/input/ruin.1383 > ../outputs/t2580
    if diff ../outputs/t2580 ../originals/t2580 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2581) timeout -s 9 2 ../source/replace.exe '?' 'cS*DPP`6W8y'  < ../inputs/input/ruin.1799 > ../outputs/t2581
    if diff ../outputs/t2581 ../originals/t2581 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2582) timeout -s 9 2 ../source/replace.exe '?' 'ct1wu;.15`H=u?$2O^&hCvZ\'  < ../inputs/input/ruin.260 > ../outputs/t2582
    if diff ../outputs/t2582 ../originals/t2582 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2583) timeout -s 9 2 ../source/replace.exe '?' 'd%/a-$ATcA3nUs!95iZeLi;y+G}h)hT=\9'  < ../inputs/input/ruin.1322 > ../outputs/t2583
    if diff ../outputs/t2583 ../originals/t2583 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2584) timeout -s 9 2 ../source/replace.exe '?' 'd'  < ../inputs/input/ruin.833 > ../outputs/t2584
    if diff ../outputs/t2584 ../originals/t2584 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2585) timeout -s 9 2 ../source/replace.exe '?' 'd6URU'  < ../inputs/input/ruin.480 > ../outputs/t2585
    if diff ../outputs/t2585 ../originals/t2585 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2586) timeout -s 9 2 ../source/replace.exe '?' 'e'  < ../inputs/input/ruin.1817 > ../outputs/t2586
    if diff ../outputs/t2586 ../originals/t2586 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2587) timeout -s 9 2 ../source/replace.exe '?' 'e'  < ../inputs/input/ruin.583 > ../outputs/t2587
    if diff ../outputs/t2587 ../originals/t2587 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2588) timeout -s 9 2 ../source/replace.exe '?' 'ee@u{Iy+h&o"Z'  < ../inputs/input/ruin.1942 > ../outputs/t2588
    if diff ../outputs/t2588 ../originals/t2588 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2589) timeout -s 9 2 ../source/replace.exe '?' 'f'  < ../inputs/input/ruin.1740 > ../outputs/t2589
    if diff ../outputs/t2589 ../originals/t2589 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2590) timeout -s 9 2 ../source/replace.exe '?' 'fB'  < ../inputs/input/ruin.250 > ../outputs/t2590
    if diff ../outputs/t2590 ../originals/t2590 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2591) timeout -s 9 2 ../source/replace.exe '?' 'g//MMd|LTvsuwT0p=!+1pK6/L{i^ja[u`.s--2#{3i)"1UtS|p~Nab;nu~M;r+C'\''$'  < ../inputs/input/ruin.1327 > ../outputs/t2591
    if diff ../outputs/t2591 ../originals/t2591 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2592) timeout -s 9 2 ../source/replace.exe '?' 'g//MMd|LTvsuwT0p=!+1pK6/L{i^ja[u`.s--2#{3i)"1UtS|p~Nab;nu~M;r+C'\''$pK6/L{i^ja[0-9]*[a-p]K6/L{i^japK6/L{i^japK6/L{i^japK6/L{i^japK6/L{i^japK6/L{i^japK6/L[0-9]*[a-b]{i^ja'  < ../inputs/input/ruin.1327 > ../outputs/t2592
    if diff ../outputs/t2592 ../originals/t2592 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2593) timeout -s 9 2 ../source/replace.exe '?' 'gZ<vfWgGbk.(3R1<u^p|)<Y!kD90 l'  < ../inputs/input/ruin.984 > ../outputs/t2593
    if diff ../outputs/t2593 ../originals/t2593 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2594) timeout -s 9 2 ../source/replace.exe '?' 'gqPd|-L'  < ../inputs/input/ruin.581 > ../outputs/t2594
    if diff ../outputs/t2594 ../originals/t2594 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2595) timeout -s 9 2 ../source/replace.exe '?' 'h'  < ../inputs/input/ruin.1629 > ../outputs/t2595
    if diff ../outputs/t2595 ../originals/t2595 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2596) timeout -s 9 2 ../source/replace.exe '?' 'h,r7xS45pAkON:?;ON=1V3'  < ../inputs/input/ruin.654 > ../outputs/t2596
    if diff ../outputs/t2596 ../originals/t2596 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2597) timeout -s 9 2 ../source/replace.exe '?' 'hFJAsc%Fy%fQcz'  < ../inputs/input/ruin.680 > ../outputs/t2597
    if diff ../outputs/t2597 ../originals/t2597 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2598) timeout -s 9 2 ../source/replace.exe '?' 'i'  < ../inputs/input/ruin.1849 > ../outputs/t2598
    if diff ../outputs/t2598 ../originals/t2598 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2599) timeout -s 9 2 ../source/replace.exe '?' 'i'  < ../inputs/input/ruin.1971 > ../outputs/t2599
    if diff ../outputs/t2599 ../originals/t2599 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2600) timeout -s 9 2 ../source/replace.exe '?' 'i'  < ../inputs/input/ruin.961 > ../outputs/t2600
    if diff ../outputs/t2600 ../originals/t2600 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2601) timeout -s 9 2 ../source/replace.exe '?' 'i1BOet56'  < ../inputs/input/ruin.1133 > ../outputs/t2601
    if diff ../outputs/t2601 ../originals/t2601 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2602) timeout -s 9 2 ../source/replace.exe '?' 'iZVC>'  < ../inputs/input/ruin.1509 > ../outputs/t2602
    if diff ../outputs/t2602 ../originals/t2602 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2603) timeout -s 9 2 ../source/replace.exe '?' 'j'  < ../inputs/input/ruin.711 > ../outputs/t2603
    if diff ../outputs/t2603 ../originals/t2603 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2604) timeout -s 9 2 ../source/replace.exe '?' 'j[&q,X^+;N{V?Cs(!KE2XmLQ2n;x6'  < ../inputs/input/ruin.65 > ../outputs/t2604
    if diff ../outputs/t2604 ../originals/t2604 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2605) timeout -s 9 2 ../source/replace.exe '?' 'jfG;doo?~`NQIn:H#b9M)wdL3[2EMTs37JH.s$"ct_o8 D.8_1_w'  < ../inputs/input/ruin.89 > ../outputs/t2605
    if diff ../outputs/t2605 ../originals/t2605 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2606) timeout -s 9 2 ../source/replace.exe '?' 'kaSvYO>o!'\'':$'\''u~K4o/z,rY6#)BhoGsz=M.8,/'  < ../inputs/input/ruin.1128 > ../outputs/t2606
    if diff ../outputs/t2606 ../originals/t2606 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2607) timeout -s 9 2 ../source/replace.exe '?' 'l!&'  < ../inputs/input/ruin.1897 > ../outputs/t2607
    if diff ../outputs/t2607 ../originals/t2607 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2608) timeout -s 9 2 ../source/replace.exe '?' 'm$$CvL9Dqle@V'  < ../inputs/input/ruin.911 > ../outputs/t2608
    if diff ../outputs/t2608 ../originals/t2608 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2609) timeout -s 9 2 ../source/replace.exe '?' 'm'  < ../inputs/input/ruin.625 > ../outputs/t2609
    if diff ../outputs/t2609 ../originals/t2609 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2610) timeout -s 9 2 ../source/replace.exe '?' 'n@3l'  < ../inputs/input/ruin.386 > ../outputs/t2610
    if diff ../outputs/t2610 ../originals/t2610 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2611) timeout -s 9 2 ../source/replace.exe '?' 'nFP*8oz+T]]SY'\''xlii [u^qu}PRh:+t4H@8pA;j}2CBL+ I%i>v9LV&SOia"Y'  < ../inputs/input/ruin.1980 > ../outputs/t2611
    if diff ../outputs/t2611 ../originals/t2611 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2612) timeout -s 9 2 ../source/replace.exe '?' 'o/MQMfmP2]QS'  < ../inputs/input/ruin.1934 > ../outputs/t2612
    if diff ../outputs/t2612 ../originals/t2612 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2613) timeout -s 9 2 ../source/replace.exe '?' 'p'  < ../inputs/input/ruin.140 > ../outputs/t2613
    if diff ../outputs/t2613 ../originals/t2613 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2614) timeout -s 9 2 ../source/replace.exe '?' 'p'  < ../inputs/input/ruin.1805 > ../outputs/t2614
    if diff ../outputs/t2614 ../originals/t2614 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2615) timeout -s 9 2 ../source/replace.exe '?' 'pvDPT~*,@txdKMQwIQtir+O|sN{.P'\''\=TrH15QQ8^]u"F,OcZ~GOn|XDA5jxdO!Y83'  < ../inputs/input/ruin.301 > ../outputs/t2615
    if diff ../outputs/t2615 ../originals/t2615 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2616) timeout -s 9 2 ../source/replace.exe '?' 'r'  < ../inputs/input/ruin.319 > ../outputs/t2616
    if diff ../outputs/t2616 ../originals/t2616 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2617) timeout -s 9 2 ../source/replace.exe '?' 'rZDfy0eU~Ie6=aT!R0Q[sra^>2/hN:'  < ../inputs/input/ruin.739 > ../outputs/t2617
    if diff ../outputs/t2617 ../originals/t2617 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2618) timeout -s 9 2 ../source/replace.exe '?' 'sI0(^vBOJ,`h%VIM+k;cgE*KoPv-ioemER5bmc@K,~bKUI7"b8QG'  < ../inputs/input/ruin.1807 > ../outputs/t2618
    if diff ../outputs/t2618 ../originals/t2618 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2619) timeout -s 9 2 ../source/replace.exe '?' 'sWf&v]I=(jlZm2xA__O~'  < ../inputs/input/ruin.355 > ../outputs/t2619
    if diff ../outputs/t2619 ../originals/t2619 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2620) timeout -s 9 2 ../source/replace.exe '?' 'tv*#&:J!wgjLzvS${r p~[7[6\=,S[0m$kk'  < ../inputs/input/ruin.14 > ../outputs/t2620
    if diff ../outputs/t2620 ../originals/t2620 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2621) timeout -s 9 2 ../source/replace.exe '?' 'u'  < ../inputs/input/ruin.1672 > ../outputs/t2621
    if diff ../outputs/t2621 ../originals/t2621 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2622) timeout -s 9 2 ../source/replace.exe '?' 'uGaumQ2'\''P{3:r"B"#2]?Kx k&'  < ../inputs/input/ruin.819 > ../outputs/t2622
    if diff ../outputs/t2622 ../originals/t2622 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2623) timeout -s 9 2 ../source/replace.exe '?' 'v'  < ../inputs/input/ruin.1362 > ../outputs/t2623
    if diff ../outputs/t2623 ../originals/t2623 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2624) timeout -s 9 2 ../source/replace.exe '?' 'v}sNX;c8YQyksA'  < ../inputs/input/ruin.311 > ../outputs/t2624
    if diff ../outputs/t2624 ../originals/t2624 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2625) timeout -s 9 2 ../source/replace.exe '?' 'wkbyQaEQ'  < ../inputs/input/ruin.1770 > ../outputs/t2625
    if diff ../outputs/t2625 ../originals/t2625 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2626) timeout -s 9 2 ../source/replace.exe '?' 'xv/w'  < ../inputs/input/ruin.234 > ../outputs/t2626
    if diff ../outputs/t2626 ../originals/t2626 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2627) timeout -s 9 2 ../source/replace.exe '?' 'y"?0u];'\''_xwJ.X|p#(5;):1DsdamaV'  < ../inputs/input/ruin.199 > ../outputs/t2627
    if diff ../outputs/t2627 ../originals/t2627 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2628) timeout -s 9 2 ../source/replace.exe '?' 'y,l/Nu^x9o4<WBXS,6]j{R^EdlGsRtTVRa\OY+'  < ../inputs/input/ruin.1463 > ../outputs/t2628
    if diff ../outputs/t2628 ../originals/t2628 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2629) timeout -s 9 2 ../source/replace.exe '?' 'yH{$>>[3/4E<+|`x:M>wzhBPey#L1'  < ../inputs/input/ruin.1958 > ../outputs/t2629
    if diff ../outputs/t2629 ../originals/t2629 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2630) timeout -s 9 2 ../source/replace.exe '?' 'y[}5M!Ju"H&-Vu+rks'  < ../inputs/input/ruin.240 > ../outputs/t2630
    if diff ../outputs/t2630 ../originals/t2630 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2631) timeout -s 9 2 ../source/replace.exe '?' 'zs'  < ../inputs/input/ruin.591 > ../outputs/t2631
    if diff ../outputs/t2631 ../originals/t2631 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2632) timeout -s 9 2 ../source/replace.exe '?' '{Y|k{o'\''V/{R&sucpF{M|ZuJKnay&:E6]H=xd,zj'  < ../inputs/input/ruin.839 > ../outputs/t2632
    if diff ../outputs/t2632 ../originals/t2632 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2633) timeout -s 9 2 ../source/replace.exe '?' '{yuSgfAgJ?'  < ../inputs/input/ruin.16 > ../outputs/t2633
    if diff ../outputs/t2633 ../originals/t2633 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2634) timeout -s 9 2 ../source/replace.exe '?' '}'  < ../inputs/input/ruin.1692 > ../outputs/t2634
    if diff ../outputs/t2634 ../originals/t2634 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2635) timeout -s 9 2 ../source/replace.exe '?' '}'  < ../inputs/input/ruin.26 > ../outputs/t2635
    if diff ../outputs/t2635 ../originals/t2635 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2636) timeout -s 9 2 ../source/replace.exe '?' '})0'\''J&Y6XsPqpxC53aKh3HTW9ITsk@m9aFOys4{Ym@&Eg1[G|ntmx;o|2xwF'  < ../inputs/input/ruin.1616 > ../outputs/t2636
    if diff ../outputs/t2636 ../originals/t2636 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2637) timeout -s 9 2 ../source/replace.exe '?' '}v]6Mz6_|{XHut)!tVgIrm<|P,ANu(q]B](~0W@z'  < ../inputs/input/ruin.1989 > ../outputs/t2637
    if diff ../outputs/t2637 ../originals/t2637 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2638) timeout -s 9 2 ../source/replace.exe '?' '~%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$%A*[^0-9]*$'  < ../inputs/input/ruin.1339 > ../outputs/t2638
    if diff ../outputs/t2638 ../originals/t2638 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2639) timeout -s 9 2 ../source/replace.exe '?' '~'  < ../inputs/input/ruin.1236 > ../outputs/t2639
    if diff ../outputs/t2639 ../originals/t2639 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2640) timeout -s 9 2 ../source/replace.exe '?' '~'  < ../inputs/input/ruin.1339 > ../outputs/t2640
    if diff ../outputs/t2640 ../originals/t2640 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2641) timeout -s 9 2 ../source/replace.exe '?' '~AG[TM12_x}fd`$WQ_vmxUl!4p,f,g[UF^.N7qG'  < ../inputs/input/ruin.897 > ../outputs/t2641
    if diff ../outputs/t2641 ../originals/t2641 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2642) timeout -s 9 2 ../source/replace.exe '?'\''!!rY' '`LWwk[pKuya#yj Y%;9I4#0o]4wG$X^FP9;"Hr1Gzlciu+[#'  < ../inputs/input/ruin.1565 > ../outputs/t2642
    if diff ../outputs/t2642 ../originals/t2642 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2643) timeout -s 9 2 ../source/replace.exe '?'\''"V)9' 'Gw:<Ace)+JC}83'\''|qfH4!.gc@OrMnEi9:ZRYM;9}aFF'  < ../inputs/input/ruin.1683 > ../outputs/t2643
    if diff ../outputs/t2643 ../originals/t2643 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2644) timeout -s 9 2 ../source/replace.exe '?'\''' 'V<}${'  < ../inputs/input/ruin.780 > ../outputs/t2644
    if diff ../outputs/t2644 ../originals/t2644 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2645) timeout -s 9 2 ../source/replace.exe '?'\''@@' 'v\`{+AlBygo>42G2jE|6;A=U7|>_+"H6*0nmx7nS/%c6>(E6>b&TP'  < ../inputs/input/ruin.1027 > ../outputs/t2645
    if diff ../outputs/t2645 ../originals/t2645 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2646) timeout -s 9 2 ../source/replace.exe '?*$' '#((G)KKH'  < ../inputs/input/ruin.1245 > ../outputs/t2646
    if diff ../outputs/t2646 ../originals/t2646 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2647) timeout -s 9 2 ../source/replace.exe '?*$' ''\''~'  < ../inputs/input/ruin.1252 > ../outputs/t2647
    if diff ../outputs/t2647 ../originals/t2647 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2648) timeout -s 9 2 ../source/replace.exe '?*$' '2Ax#Mv_@DjcWz"~F]km'  < ../inputs/input/ruin.1241 > ../outputs/t2648
    if diff ../outputs/t2648 ../originals/t2648 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2649) timeout -s 9 2 ../source/replace.exe '?*$' 'E'  < ../inputs/input/ruin.1113 > ../outputs/t2649
    if diff ../outputs/t2649 ../originals/t2649 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2650) timeout -s 9 2 ../source/replace.exe '?*$' 'Lvu77k}K'  < ../inputs/input/ruin.1239 > ../outputs/t2650
    if diff ../outputs/t2650 ../originals/t2650 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2651) timeout -s 9 2 ../source/replace.exe '?*$' 'i'  < ../inputs/input/ruin.1625 > ../outputs/t2651
    if diff ../outputs/t2651 ../originals/t2651 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2652) timeout -s 9 2 ../source/replace.exe '?*$' '~'  < ../inputs/input/ruin.1236 > ../outputs/t2652
    if diff ../outputs/t2652 ../originals/t2652 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2653) timeout -s 9 2 ../source/replace.exe '?*' '#'  < ../inputs/input/ruin.1622 > ../outputs/t2653
    if diff ../outputs/t2653 ../originals/t2653 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2654) timeout -s 9 2 ../source/replace.exe '?*' '&'  < ../inputs/temp-test/577.inp.248.2 > ../outputs/t2654
    if diff ../outputs/t2654 ../originals/t2654 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2655) timeout -s 9 2 ../source/replace.exe '?*' '&a@%'  < ../inputs/temp-test/196.inp.88.2 > ../outputs/t2655
    if diff ../outputs/t2655 ../originals/t2655 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2656) timeout -s 9 2 ../source/replace.exe '?*' ',gAEa`/^PQWZZa^F'  < ../inputs/input/ruin.1612 > ../outputs/t2656
    if diff ../outputs/t2656 ../originals/t2656 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2657) timeout -s 9 2 ../source/replace.exe '?*' '.'  < ../inputs/input/ruin.391 > ../outputs/t2657
    if diff ../outputs/t2657 ../originals/t2657 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2658) timeout -s 9 2 ../source/replace.exe '?*' '9'  < ../inputs/input/ruin.109 > ../outputs/t2658
    if diff ../outputs/t2658 ../originals/t2658 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2659) timeout -s 9 2 ../source/replace.exe '?*' 'M%&;~-{;<(48m;Dv)aQS0bkh'\''eK'  < ../inputs/input/ruin.1613 > ../outputs/t2659
    if diff ../outputs/t2659 ../originals/t2659 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2660) timeout -s 9 2 ../source/replace.exe '?*' 'P54;@=_4xdN:$7^We'  < ../inputs/input/ruin.1620 > ../outputs/t2660
    if diff ../outputs/t2660 ../originals/t2660 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2661) timeout -s 9 2 ../source/replace.exe '?*' 'vB|CqDQNo,Fg|RTv5;bkJFE.twyj39J13'\''TcKY1sb&G<g]|ZaPL`0=8`YdR,'  < ../inputs/input/ruin.1614 > ../outputs/t2661
    if diff ../outputs/t2661 ../originals/t2661 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2662) timeout -s 9 2 ../source/replace.exe '?*' 'w'  < ../inputs/input/ruin.1610 > ../outputs/t2662
    if diff ../outputs/t2662 ../originals/t2662 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2663) timeout -s 9 2 ../source/replace.exe '?*' 'zCF&lL=IT'  < ../inputs/input/ruin.287 > ../outputs/t2663
    if diff ../outputs/t2663 ../originals/t2663 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2664) timeout -s 9 2 ../source/replace.exe '?*' '})0'\''J&Y6XsPqpxC53aKh3HTW9ITsk@m9aFOys4{Ym@&Eg1[G|ntmx;o|2xwF'  < ../inputs/input/ruin.1616 > ../outputs/t2664
    if diff ../outputs/t2664 ../originals/t2664 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2665) timeout -s 9 2 ../source/replace.exe '?*@*' 'NEW'  < ../inputs/temp-test/521.inp.226.1 > ../outputs/t2665
    if diff ../outputs/t2665 ../originals/t2665 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2666) timeout -s 9 2 ../source/replace.exe '?*@*' 'NEW'  < ../inputs/temp-test/522.inp.226.3 > ../outputs/t2666
    if diff ../outputs/t2666 ../originals/t2666 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2667) timeout -s 9 2 ../source/replace.exe '?*[9-B]?%[9-B]*?-[9-B]' '&a@%'  < ../inputs/temp-test/9.inp.4.1 > ../outputs/t2667
    if diff ../outputs/t2667 ../originals/t2667 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2668) timeout -s 9 2 ../source/replace.exe '?*[9-B]?[9-B]*?-[9-B]' '&a@%'  < ../inputs/temp-test/9.inp.4.1 > ../outputs/t2668
    if diff ../outputs/t2668 ../originals/t2668 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2669) timeout -s 9 2 ../source/replace.exe '?*[>-A]' 'O'  < ../inputs/input/ruin.1623 > ../outputs/t2669
    if diff ../outputs/t2669 ../originals/t2669 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2670) timeout -s 9 2 ../source/replace.exe '?*[A-G]' '`'  < ../inputs/input/ruin.998 > ../outputs/t2670
    if diff ../outputs/t2670 ../originals/t2670 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2671) timeout -s 9 2 ../source/replace.exe '?*z-}0-9Z-a]^_`a]' 'U'  < ../inputs/input/ruin.1611 > ../outputs/t2671
    if diff ../outputs/t2671 ../originals/t2671 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2672) timeout -s 9 2 ../source/replace.exe '?- ?[9-B]-*$' 'a&'  < ../inputs/temp-test/2320.inp.984.6 > ../outputs/t2672
    if diff ../outputs/t2672 ../originals/t2672 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2673) timeout -s 9 2 ../source/replace.exe '?- ?[9-B]-*' 'a&'  < ../inputs/temp-test/2318.inp.984.1 > ../outputs/t2673
    if diff ../outputs/t2673 ../originals/t2673 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2674) timeout -s 9 2 ../source/replace.exe '?- ?[9-B]-*' 'a&'  < ../inputs/temp-test/2319.inp.984.2 > ../outputs/t2674
    if diff ../outputs/t2674 ../originals/t2674 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2675) timeout -s 9 2 ../source/replace.exe '?-$' '@%&a'  < ../inputs/temp-test/572.inp.246.6 > ../outputs/t2675
    if diff ../outputs/t2675 ../originals/t2675 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2676) timeout -s 9 2 ../source/replace.exe '?-%' '&'  < ../inputs/temp-test/2349.inp.997.3 > ../outputs/t2676
    if diff ../outputs/t2676 ../originals/t2676 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2677) timeout -s 9 2 ../source/replace.exe '?-' '&'  < ../inputs/temp-test/180.inp.81.1 > ../outputs/t2677
    if diff ../outputs/t2677 ../originals/t2677 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2678) timeout -s 9 2 ../source/replace.exe '?-' '&'  < ../inputs/temp-test/181.inp.81.2 > ../outputs/t2678
    if diff ../outputs/t2678 ../originals/t2678 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2679) timeout -s 9 2 ../source/replace.exe '?-' '&'  < ../inputs/temp-test/182.inp.81.3 > ../outputs/t2679
    if diff ../outputs/t2679 ../originals/t2679 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2680) timeout -s 9 2 ../source/replace.exe '?-' '&'  < ../inputs/temp-test/2347.inp.997.1 > ../outputs/t2680
    if diff ../outputs/t2680 ../originals/t2680 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2681) timeout -s 9 2 ../source/replace.exe '?-' '&'  < ../inputs/temp-test/2348.inp.997.2 > ../outputs/t2681
    if diff ../outputs/t2681 ../originals/t2681 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2682) timeout -s 9 2 ../source/replace.exe '?-' '&'  < ../inputs/temp-test/2349.inp.997.3 > ../outputs/t2682
    if diff ../outputs/t2682 ../originals/t2682 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2683) timeout -s 9 2 ../source/replace.exe '?-' '&a@%'  < ../inputs/temp-test/1104.inp.475.1 > ../outputs/t2683
    if diff ../outputs/t2683 ../originals/t2683 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2684) timeout -s 9 2 ../source/replace.exe '?-' '&a@%'  < ../inputs/temp-test/1105.inp.475.3 > ../outputs/t2684
    if diff ../outputs/t2684 ../originals/t2684 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2685) timeout -s 9 2 ../source/replace.exe '?-' ''  < ../inputs/temp-test/1117.inp.480.1 > ../outputs/t2685
    if diff ../outputs/t2685 ../originals/t2685 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2686) timeout -s 9 2 ../source/replace.exe '?-' ''  < ../inputs/temp-test/1118.inp.480.2 > ../outputs/t2686
    if diff ../outputs/t2686 ../originals/t2686 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2687) timeout -s 9 2 ../source/replace.exe '?-' ''  < ../inputs/temp-test/1791.inp.762.1 > ../outputs/t2687
    if diff ../outputs/t2687 ../originals/t2687 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2688) timeout -s 9 2 ../source/replace.exe '?-' ''  < ../inputs/temp-test/1792.inp.762.2 > ../outputs/t2688
    if diff ../outputs/t2688 ../originals/t2688 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2689) timeout -s 9 2 ../source/replace.exe '?-' ''  < ../inputs/temp-test/1793.inp.762.3 > ../outputs/t2689
    if diff ../outputs/t2689 ../originals/t2689 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2690) timeout -s 9 2 ../source/replace.exe '?-' ''  < ../inputs/temp-test/1794.inp.762.4 > ../outputs/t2690
    if diff ../outputs/t2690 ../originals/t2690 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2691) timeout -s 9 2 ../source/replace.exe '?-' '@%&a'  < ../inputs/temp-test/571.inp.246.1 > ../outputs/t2691
    if diff ../outputs/t2691 ../originals/t2691 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2692) timeout -s 9 2 ../source/replace.exe '?-' '@%@&'  < ../inputs/temp-test/1200.inp.515.1 > ../outputs/t2692
    if diff ../outputs/t2692 ../originals/t2692 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2693) timeout -s 9 2 ../source/replace.exe '?-' '@%@&'  < ../inputs/temp-test/1201.inp.515.2 > ../outputs/t2693
    if diff ../outputs/t2693 ../originals/t2693 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2694) timeout -s 9 2 ../source/replace.exe '?-' '@n'  < ../inputs/temp-test/911.inp.393.1 > ../outputs/t2694
    if diff ../outputs/t2694 ../originals/t2694 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2695) timeout -s 9 2 ../source/replace.exe '?-' '@n'  < ../inputs/temp-test/912.inp.393.2 > ../outputs/t2695
    if diff ../outputs/t2695 ../originals/t2695 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2696) timeout -s 9 2 ../source/replace.exe '?-' '@n'  < ../inputs/temp-test/94.inp.42.1 > ../outputs/t2696
    if diff ../outputs/t2696 ../originals/t2696 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2697) timeout -s 9 2 ../source/replace.exe '?-' '@t'  < ../inputs/temp-test/1016.inp.437.1 > ../outputs/t2697
    if diff ../outputs/t2697 ../originals/t2697 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2698) timeout -s 9 2 ../source/replace.exe '?-' '@t'  < ../inputs/temp-test/1868.inp.793.1 > ../outputs/t2698
    if diff ../outputs/t2698 ../originals/t2698 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2699) timeout -s 9 2 ../source/replace.exe '?-' '@t'  < ../inputs/temp-test/1869.inp.793.2 > ../outputs/t2699
    if diff ../outputs/t2699 ../originals/t2699 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2700) timeout -s 9 2 ../source/replace.exe '?-' '@t'  < ../inputs/temp-test/1870.inp.793.3 > ../outputs/t2700
    if diff ../outputs/t2700 ../originals/t2700 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2701) timeout -s 9 2 ../source/replace.exe '?-' 'NEW'  < ../inputs/temp-test/893.inp.384.1 > ../outputs/t2701
    if diff ../outputs/t2701 ../originals/t2701 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2702) timeout -s 9 2 ../source/replace.exe '?-' 'NEW'  < ../inputs/temp-test/894.inp.384.3 > ../outputs/t2702
    if diff ../outputs/t2702 ../originals/t2702 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2703) timeout -s 9 2 ../source/replace.exe '?-' 'NEW'  < ../inputs/temp-test/895.inp.384.4 > ../outputs/t2703
    if diff ../outputs/t2703 ../originals/t2703 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2704) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/321.inp.143.1 > ../outputs/t2704
    if diff ../outputs/t2704 ../originals/t2704 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2705) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/322.inp.143.3 > ../outputs/t2705
    if diff ../outputs/t2705 ../originals/t2705 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2706) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/323.inp.143.4 > ../outputs/t2706
    if diff ../outputs/t2706 ../originals/t2706 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2707) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/504.inp.220.1 > ../outputs/t2707
    if diff ../outputs/t2707 ../originals/t2707 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2708) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/505.inp.220.2 > ../outputs/t2708
    if diff ../outputs/t2708 ../originals/t2708 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2709) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/506.inp.220.3 > ../outputs/t2709
    if diff ../outputs/t2709 ../originals/t2709 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2710) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/845.inp.363.1 > ../outputs/t2710
    if diff ../outputs/t2710 ../originals/t2710 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2711) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/846.inp.363.2 > ../outputs/t2711
    if diff ../outputs/t2711 ../originals/t2711 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2712) timeout -s 9 2 ../source/replace.exe '?-' 'a@nb@tc'  < ../inputs/temp-test/847.inp.363.3 > ../outputs/t2712
    if diff ../outputs/t2712 ../originals/t2712 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2713) timeout -s 9 2 ../source/replace.exe '?-*' '@%@&'  < ../inputs/temp-test/1691.inp.721.1 > ../outputs/t2713
    if diff ../outputs/t2713 ../originals/t2713 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2714) timeout -s 9 2 ../source/replace.exe '?-*' '@%@&'  < ../inputs/temp-test/1692.inp.721.2 > ../outputs/t2714
    if diff ../outputs/t2714 ../originals/t2714 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2715) timeout -s 9 2 ../source/replace.exe '?-**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t2715
    if diff ../outputs/t2715 ../originals/t2715 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2716) timeout -s 9 2 ../source/replace.exe '?-*?' 'NEW'  < ../inputs/temp-test/1701.inp.726.1 > ../outputs/t2716
    if diff ../outputs/t2716 ../originals/t2716 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2717) timeout -s 9 2 ../source/replace.exe '?-*?' 'NEW'  < ../inputs/temp-test/1702.inp.726.2 > ../outputs/t2717
    if diff ../outputs/t2717 ../originals/t2717 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2718) timeout -s 9 2 ../source/replace.exe '?-*?' 'NEW'  < ../inputs/temp-test/1703.inp.726.3 > ../outputs/t2718
    if diff ../outputs/t2718 ../originals/t2718 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2719) timeout -s 9 2 ../source/replace.exe '?-*?' 'NEW'  < ../inputs/temp-test/1704.inp.726.4 > ../outputs/t2719
    if diff ../outputs/t2719 ../originals/t2719 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2720) timeout -s 9 2 ../source/replace.exe '?--?-[^a-c]?@*?-[_-z]?-[^9-B]' ''  < ../inputs/temp-test/2292.inp.972.1 > ../outputs/t2720
    if diff ../outputs/t2720 ../originals/t2720 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2721) timeout -s 9 2 ../source/replace.exe '?--?-[^a-c]?@*?-[_-z]?-[^9-B]' ''  < ../inputs/temp-test/2293.inp.972.2 > ../outputs/t2721
    if diff ../outputs/t2721 ../originals/t2721 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2722) timeout -s 9 2 ../source/replace.exe '?--?-[^a-c]?@*?-[_-z]?-[^9-B]' ''  < ../inputs/temp-test/2294.inp.972.3 > ../outputs/t2722
    if diff ../outputs/t2722 ../originals/t2722 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2723) timeout -s 9 2 ../source/replace.exe '?--@**[^0-9]-*[-z]@n*$' '&'  < ../inputs/temp-test/1026.inp.441.6 > ../outputs/t2723
    if diff ../outputs/t2723 ../originals/t2723 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2724) timeout -s 9 2 ../source/replace.exe '?--@**[^0-9]-*[-z]@n*' '&'  < ../inputs/temp-test/1025.inp.441.1 > ../outputs/t2724
    if diff ../outputs/t2724 ../originals/t2724 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2725) timeout -s 9 2 ../source/replace.exe '?--[-- ' '@%&a'  < ../inputs/temp-test/2192.inp.929.1 > ../outputs/t2725
    if diff ../outputs/t2725 ../originals/t2725 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2726) timeout -s 9 2 ../source/replace.exe '?--[_-z][^a-c@n *' '&@n'  < ../inputs/temp-test/637.inp.275.1 > ../outputs/t2726
    if diff ../outputs/t2726 ../originals/t2726 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2727) timeout -s 9 2 ../source/replace.exe '?--[_-z][^a-c@n *' '&@n'  < ../inputs/temp-test/638.inp.275.2 > ../outputs/t2727
    if diff ../outputs/t2727 ../originals/t2727 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2728) timeout -s 9 2 ../source/replace.exe '?--[_-z][^a-c@n *' '@%&a'  < ../inputs/temp-test/637.inp.275.1 > ../outputs/t2728
    if diff ../outputs/t2728 ../originals/t2728 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2729) timeout -s 9 2 ../source/replace.exe '?--[_-z][^a-c@n *' '@%&a'  < ../inputs/temp-test/638.inp.275.2 > ../outputs/t2729
    if diff ../outputs/t2729 ../originals/t2729 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2730) timeout -s 9 2 ../source/replace.exe '?-?[9-B]-[@@][^a-c]- *--?^a-]@t-[_-z]' '@%&a'  < ../inputs/temp-test/2148.inp.910.1 > ../outputs/t2730
    if diff ../outputs/t2730 ../originals/t2730 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2731) timeout -s 9 2 ../source/replace.exe '?-?[9-B]-[@@][^a-c]- *--?^a-]@t-[_-z]' '@%&a'  < ../inputs/temp-test/2149.inp.910.2 > ../outputs/t2731
    if diff ../outputs/t2731 ../originals/t2731 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2732) timeout -s 9 2 ../source/replace.exe '?-?[9-B]-[@@][^a-c]- *--?^a-]@t-[_-z]' '@%&a'  < ../inputs/temp-test/2150.inp.910.3 > ../outputs/t2732
    if diff ../outputs/t2732 ../originals/t2732 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2733) timeout -s 9 2 ../source/replace.exe '?-@*[a-c]@[*[^a-c[^a--b][a-c' '@n'  < ../inputs/temp-test/276.inp.124.1 > ../outputs/t2733
    if diff ../outputs/t2733 ../originals/t2733 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2734) timeout -s 9 2 ../source/replace.exe '?-@*[a-c]@[*[^a-c[^a--b][a-c' '@n'  < ../inputs/temp-test/277.inp.124.2 > ../outputs/t2734
    if diff ../outputs/t2734 ../originals/t2734 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2735) timeout -s 9 2 ../source/replace.exe '?-[-z]-?-' '&'  < ../inputs/temp-test/485.inp.212.1 > ../outputs/t2735
    if diff ../outputs/t2735 ../originals/t2735 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2736) timeout -s 9 2 ../source/replace.exe '?-[-z]-?-' '&'  < ../inputs/temp-test/486.inp.212.3 > ../outputs/t2736
    if diff ../outputs/t2736 ../originals/t2736 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2737) timeout -s 9 2 ../source/replace.exe '?-[-z]-?-' '&'  < ../inputs/temp-test/487.inp.212.4 > ../outputs/t2737
    if diff ../outputs/t2737 ../originals/t2737 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2738) timeout -s 9 2 ../source/replace.exe '?-[0-9][^0-9]?' 'a@n'  < ../inputs/temp-test/1235.inp.530.1 > ../outputs/t2738
    if diff ../outputs/t2738 ../originals/t2738 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2739) timeout -s 9 2 ../source/replace.exe '?-[0-9][^0-9]?' 'a@n'  < ../inputs/temp-test/1236.inp.530.2 > ../outputs/t2739
    if diff ../outputs/t2739 ../originals/t2739 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2740) timeout -s 9 2 ../source/replace.exe '?-[9-B]@[' 'a&'  < ../inputs/temp-test/1299.inp.558.1 > ../outputs/t2740
    if diff ../outputs/t2740 ../originals/t2740 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2741) timeout -s 9 2 ../source/replace.exe '?-[9-B]@[' 'a&'  < ../inputs/temp-test/1300.inp.558.3 > ../outputs/t2741
    if diff ../outputs/t2741 ../originals/t2741 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2742) timeout -s 9 2 ../source/replace.exe '?-[^-z][0-9]' '&a@%'  < ../inputs/temp-test/224.inp.100.1 > ../outputs/t2742
    if diff ../outputs/t2742 ../originals/t2742 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2743) timeout -s 9 2 ../source/replace.exe '?-[^-z][0-9]*$' '&a@%'  < ../inputs/temp-test/224.inp.100.1 > ../outputs/t2743
    if diff ../outputs/t2743 ../originals/t2743 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2744) timeout -s 9 2 ../source/replace.exe '?-[^-z][0-9]*' '&a@%'  < ../inputs/temp-test/224.inp.100.1 > ../outputs/t2744
    if diff ../outputs/t2744 ../originals/t2744 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2745) timeout -s 9 2 ../source/replace.exe '?-[^-z][][0-9]' '&a@%'  < ../inputs/temp-test/224.inp.100.1 > ../outputs/t2745
    if diff ../outputs/t2745 ../originals/t2745 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2746) timeout -s 9 2 ../source/replace.exe '?-[^-z][^][0-9]' '&a@%'  < ../inputs/temp-test/224.inp.100.1 > ../outputs/t2746
    if diff ../outputs/t2746 ../originals/t2746 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2747) timeout -s 9 2 ../source/replace.exe '?-[^0-9]??--?[9-B]' '@%@&'  < ../inputs/temp-test/1769.inp.753.1 > ../outputs/t2747
    if diff ../outputs/t2747 ../originals/t2747 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2748) timeout -s 9 2 ../source/replace.exe '?-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^a-?' '@%&a'  < ../inputs/temp-test/142.inp.66.1 > ../outputs/t2748
    if diff ../outputs/t2748 ../originals/t2748 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2749) timeout -s 9 2 ../source/replace.exe '?-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^a-?' '@%&a'  < ../inputs/temp-test/143.inp.66.2 > ../outputs/t2749
    if diff ../outputs/t2749 ../originals/t2749 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2750) timeout -s 9 2 ../source/replace.exe '?-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^a-?' '@%&a'  < ../inputs/temp-test/144.inp.66.3 > ../outputs/t2750
    if diff ../outputs/t2750 ../originals/t2750 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2751) timeout -s 9 2 ../source/replace.exe '?-[a-][^9-B]?@**[^0-9][9-B][^9-B]' '@%&a'  < ../inputs/temp-test/998.inp.430.1 > ../outputs/t2751
    if diff ../outputs/t2751 ../originals/t2751 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2752) timeout -s 9 2 ../source/replace.exe '?-[a-][^9-B]?@**[^0-9][9-B][^9-B]' '@%&a'  < ../inputs/temp-test/999.inp.430.2 > ../outputs/t2752
    if diff ../outputs/t2752 ../originals/t2752 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2753) timeout -s 9 2 ../source/replace.exe '?-]-?[^0-9]A' 'NEW'  < ../inputs/temp-test/458.inp.201.1 > ../outputs/t2753
    if diff ../outputs/t2753 ../originals/t2753 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2754) timeout -s 9 2 ../source/replace.exe '?-]-?[^0-9]A' 'NEW'  < ../inputs/temp-test/459.inp.201.3 > ../outputs/t2754
    if diff ../outputs/t2754 ../originals/t2754 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2755) timeout -s 9 2 ../source/replace.exe '?-^a-c][^-z]a-c]?[a-' '&'  < ../inputs/temp-test/628.inp.271.1 > ../outputs/t2755
    if diff ../outputs/t2755 ../originals/t2755 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2756) timeout -s 9 2 ../source/replace.exe '?5' 'Q;G'  < ../inputs/input/ruin.1385 > ../outputs/t2756
    if diff ../outputs/t2756 ../originals/t2756 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2757) timeout -s 9 2 ../source/replace.exe '?9][^0-9][@t][^@][9-B]-[0-9][^0-9][@t0-9]@@]@][9-B]-[0-9][^0-9][@t@][9-B]-[0-9][^0-9][@t@][9-B]-[0-9][^0-9][@t[9-B]-[0-@][9-B]-[0-9][^0-9][@t9][^0-9@][9-B]-[0-9][^0-9][@t@][9-B]-[0-9][^0-9][@t]*[@t@][9-B]-*[0-9][^0-9][@' '"\]({uYH3x5zs{.$s)G2Pzxji.o]- _Pzt'\''~6m#[}UH+'  < ../inputs/input/ruin.318 > ../outputs/t2757
    if diff ../outputs/t2757 ../originals/t2757 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2758) timeout -s 9 2 ../source/replace.exe '?? *' 'NEW'  < ../inputs/temp-test/1528.inp.655.1 > ../outputs/t2758
    if diff ../outputs/t2758 ../originals/t2758 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2759) timeout -s 9 2 ../source/replace.exe '?? *' 'NEW'  < ../inputs/temp-test/1529.inp.655.2 > ../outputs/t2759
    if diff ../outputs/t2759 ../originals/t2759 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2760) timeout -s 9 2 ../source/replace.exe '?? *' 'NEW'  < ../inputs/temp-test/1530.inp.655.3 > ../outputs/t2760
    if diff ../outputs/t2760 ../originals/t2760 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2761) timeout -s 9 2 ../source/replace.exe '??&' '9xoE\p_Un[?@!<f<10'\''NLF]{HC<5S)0ft3+1A]yP=~y-v/R.'\''64h`~~R4d(.nK`}fRB82&'  < ../inputs/input/ruin.1411 > ../outputs/t2761
    if diff ../outputs/t2761 ../originals/t2761 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2762) timeout -s 9 2 ../source/replace.exe '??' '&'  < ../inputs/temp-test/1461.inp.626.1 > ../outputs/t2762
    if diff ../outputs/t2762 ../originals/t2762 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2763) timeout -s 9 2 ../source/replace.exe '??' '&'  < ../inputs/temp-test/1462.inp.626.2 > ../outputs/t2763
    if diff ../outputs/t2763 ../originals/t2763 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2764) timeout -s 9 2 ../source/replace.exe '??' '0LcGrfGr r,X@m,;,+r/AlJ>Uv)\ |Cr_fk[JEoA=}sUma`8rt]'  < ../inputs/input/ruin.1130 > ../outputs/t2764
    if diff ../outputs/t2764 ../originals/t2764 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2765) timeout -s 9 2 ../source/replace.exe '??' 'kU.apBPAkew_"lFw!K;?J|IVb@XM3doSquoTX1J=[a&cJ'  < ../inputs/input/ruin.1607 > ../outputs/t2765
    if diff ../outputs/t2765 ../originals/t2765 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2766) timeout -s 9 2 ../source/replace.exe '??'\''@@*' '5'  < ../inputs/input/ruin.935 > ../outputs/t2766
    if diff ../outputs/t2766 ../originals/t2766 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2767) timeout -s 9 2 ../source/replace.exe '??*' 'kU.apBPAkew_"lFw!K;?J|IVb@XM3doSquoTX1J=[a&cJ'  < ../inputs/input/ruin.1607 > ../outputs/t2767
    if diff ../outputs/t2767 ../originals/t2767 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2768) timeout -s 9 2 ../source/replace.exe '??-?[^@n][a-]-@*[^a--b][0-9]-' '@%&a'  < ../inputs/temp-test/2248.inp.953.1 > ../outputs/t2768
    if diff ../outputs/t2768 ../originals/t2768 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2769) timeout -s 9 2 ../source/replace.exe '??[@n]-?[9-B]-^-]??[9-B]-*[^0-9]-' '@n'  < ../inputs/temp-test/1345.inp.578.1 > ../outputs/t2769
    if diff ../outputs/t2769 ../originals/t2769 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2770) timeout -s 9 2 ../source/replace.exe '??[@n]-?[9-B]-^-]??[9-B]-*[^0-9]-' '@n'  < ../inputs/temp-test/1346.inp.578.2 > ../outputs/t2770
    if diff ../outputs/t2770 ../originals/t2770 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2771) timeout -s 9 2 ../source/replace.exe '??^[^9-B]@*?@**' '@n'  < ../inputs/temp-test/249.inp.111.1 > ../outputs/t2771
    if diff ../outputs/t2771 ../originals/t2771 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2772) timeout -s 9 2 ../source/replace.exe '??^[^9-B]@*?@**' '@n'  < ../inputs/temp-test/250.inp.111.2 > ../outputs/t2772
    if diff ../outputs/t2772 ../originals/t2772 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2773) timeout -s 9 2 ../source/replace.exe '?@*'   < ../inputs/temp-test/521.inp.226.1 > ../outputs/t2773
    if diff ../outputs/t2773 ../originals/t2773 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2774) timeout -s 9 2 ../source/replace.exe '?@*'   < ../inputs/temp-test/532.inp.231.1 > ../outputs/t2774
    if diff ../outputs/t2774 ../originals/t2774 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2775) timeout -s 9 2 ../source/replace.exe '?@*' '@%&a'  < ../inputs/temp-test/532.inp.231.1 > ../outputs/t2775
    if diff ../outputs/t2775 ../originals/t2775 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2776) timeout -s 9 2 ../source/replace.exe '?@*' '@%&a'  < ../inputs/temp-test/533.inp.231.2 > ../outputs/t2776
    if diff ../outputs/t2776 ../originals/t2776 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2777) timeout -s 9 2 ../source/replace.exe '?@*' 'NEW'  < ../inputs/temp-test/521.inp.226.1 > ../outputs/t2777
    if diff ../outputs/t2777 ../originals/t2777 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2778) timeout -s 9 2 ../source/replace.exe '?@*' 'NEW'  < ../inputs/temp-test/522.inp.226.3 > ../outputs/t2778
    if diff ../outputs/t2778 ../originals/t2778 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2779) timeout -s 9 2 ../source/replace.exe '?@*' 'b@t'  < ../inputs/temp-test/932.inp.402.1 > ../outputs/t2779
    if diff ../outputs/t2779 ../originals/t2779 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2780) timeout -s 9 2 ../source/replace.exe '?@*' 'b@t'  < ../inputs/temp-test/933.inp.402.2 > ../outputs/t2780
    if diff ../outputs/t2780 ../originals/t2780 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2781) timeout -s 9 2 ../source/replace.exe '?@*' 'b@t'  < ../inputs/temp-test/934.inp.402.3 > ../outputs/t2781
    if diff ../outputs/t2781 ../originals/t2781 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2782) timeout -s 9 2 ../source/replace.exe '?@**' ''  < ../inputs/temp-test/1465.inp.628.1 > ../outputs/t2782
    if diff ../outputs/t2782 ../originals/t2782 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2783) timeout -s 9 2 ../source/replace.exe '?@**' ''  < ../inputs/temp-test/1466.inp.628.4 > ../outputs/t2783
    if diff ../outputs/t2783 ../originals/t2783 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2784) timeout -s 9 2 ../source/replace.exe '?@**' 'a@nb@tc'  < ../inputs/temp-test/2301.inp.977.1 > ../outputs/t2784
    if diff ../outputs/t2784 ../originals/t2784 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2785) timeout -s 9 2 ../source/replace.exe '?@**@[*-[9-B]-' '&'  < ../inputs/temp-test/1984.inp.843.1 > ../outputs/t2785
    if diff ../outputs/t2785 ../originals/t2785 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2786) timeout -s 9 2 ../source/replace.exe '?@**@[*-[9-B]-' '&'  < ../inputs/temp-test/1985.inp.843.2 > ../outputs/t2786
    if diff ../outputs/t2786 ../originals/t2786 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2787) timeout -s 9 2 ../source/replace.exe '?@*?[-?-[^9-B]A*' 'a@nb@tc'  < ../inputs/temp-test/1609.inp.684.1 > ../outputs/t2787
    if diff ../outputs/t2787 ../originals/t2787 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2788) timeout -s 9 2 ../source/replace.exe '?@*[^0-9]^*' '&'  < ../inputs/temp-test/773.inp.332.1 > ../outputs/t2788
    if diff ../outputs/t2788 ../originals/t2788 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2789) timeout -s 9 2 ../source/replace.exe '?@*[a--b]^*-[^--$' 'NEW'  < ../inputs/temp-test/189.inp.85.8 > ../outputs/t2789
    if diff ../outputs/t2789 ../originals/t2789 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2790) timeout -s 9 2 ../source/replace.exe '?@*[a--b]^*-[^--' 'NEW'  < ../inputs/temp-test/187.inp.85.1 > ../outputs/t2790
    if diff ../outputs/t2790 ../originals/t2790 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2791) timeout -s 9 2 ../source/replace.exe '?@*[a--b]^*-[^--' 'NEW'  < ../inputs/temp-test/188.inp.85.2 > ../outputs/t2791
    if diff ../outputs/t2791 ../originals/t2791 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2792) timeout -s 9 2 ../source/replace.exe '?@=' 'f'  < ../inputs/input/ruin.31 > ../outputs/t2792
    if diff ../outputs/t2792 ../originals/t2792 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2793) timeout -s 9 2 ../source/replace.exe '?@@$' '&a@%'  < ../inputs/temp-test/2231.inp.945.8 > ../outputs/t2793
    if diff ../outputs/t2793 ../originals/t2793 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2794) timeout -s 9 2 ../source/replace.exe '?@@' '&a@%'  < ../inputs/temp-test/2228.inp.945.1 > ../outputs/t2794
    if diff ../outputs/t2794 ../originals/t2794 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2795) timeout -s 9 2 ../source/replace.exe '?@@' '&a@%'  < ../inputs/temp-test/2229.inp.945.3 > ../outputs/t2795
    if diff ../outputs/t2795 ../originals/t2795 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2796) timeout -s 9 2 ../source/replace.exe '?@@' '8&!J.D o'  < ../inputs/input/ruin.1290 > ../outputs/t2796
    if diff ../outputs/t2796 ../originals/t2796 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2797) timeout -s 9 2 ../source/replace.exe '?@@' 'G'  < ../inputs/input/ruin.1659 > ../outputs/t2797
    if diff ../outputs/t2797 ../originals/t2797 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2798) timeout -s 9 2 ../source/replace.exe '?@@' '[0fwc0yF</B^'  < ../inputs/input/ruin.1982 > ../outputs/t2798
    if diff ../outputs/t2798 ../originals/t2798 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2799) timeout -s 9 2 ../source/replace.exe '?@@' 'f>wlV.*t_>BC?n6sqXRSE}a/ttH,'  < ../inputs/input/ruin.1602 > ../outputs/t2799
    if diff ../outputs/t2799 ../originals/t2799 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2800) timeout -s 9 2 ../source/replace.exe '?@@' 'ot'\''N[U7FH f#8W$ekHhjvkc2}L>mY3u\f&B4*o.,t=ohIK`!{b9%+q*C\H~r!I:!RgLH 88'  < ../inputs/input/ruin.1106 > ../outputs/t2800
    if diff ../outputs/t2800 ../originals/t2800 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2801) timeout -s 9 2 ../source/replace.exe '?@@' 'zRixjQ`>-1lWM|#=R'  < ../inputs/input/ruin.58 > ../outputs/t2801
    if diff ../outputs/t2801 ../originals/t2801 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2802) timeout -s 9 2 ../source/replace.exe '?@@' '|Mi+'\''s OXxRu~W2bMVQrfx+GT$4>}5J5XNph:`xe! zY'  < ../inputs/input/ruin.275 > ../outputs/t2802
    if diff ../outputs/t2802 ../originals/t2802 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2803) timeout -s 9 2 ../source/replace.exe '?@@*' '&a@%'  < ../inputs/temp-test/1662.inp.709.1 > ../outputs/t2803
    if diff ../outputs/t2803 ../originals/t2803 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2804) timeout -s 9 2 ../source/replace.exe '?@@*' '&a@%'  < ../inputs/temp-test/1663.inp.709.3 > ../outputs/t2804
    if diff ../outputs/t2804 ../originals/t2804 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2805) timeout -s 9 2 ../source/replace.exe '?@@?' 'E'  < ../inputs/input/ruin.827 > ../outputs/t2805
    if diff ../outputs/t2805 ../originals/t2805 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2806) timeout -s 9 2 ../source/replace.exe '?@@?*' 'f>wlV.*t_>BC?n6sqXRSE}a/ttH,'  < ../inputs/input/ruin.1602 > ../outputs/t2806
    if diff ../outputs/t2806 ../originals/t2806 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2807) timeout -s 9 2 ../source/replace.exe '?@@Tb[^A-G]' '`'  < ../inputs/input/ruin.528 > ../outputs/t2807
    if diff ../outputs/t2807 ../originals/t2807 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2808) timeout -s 9 2 ../source/replace.exe '?@@Zg' 'oq0+3}K@*# t,Gf(;%tz>|LA!y:,~Of0'  < ../inputs/input/ruin.857 > ../outputs/t2808
    if diff ../outputs/t2808 ../originals/t2808 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2809) timeout -s 9 2 ../source/replace.exe '?@@[^9-B]@**-@*[^a-@t[^0-9]-^?' 'NEW'  < ../inputs/temp-test/1635.inp.696.1 > ../outputs/t2809
    if diff ../outputs/t2809 ../originals/t2809 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2810) timeout -s 9 2 ../source/replace.exe '?@[' '@%&a'  < ../inputs/temp-test/240.inp.107.1 > ../outputs/t2810
    if diff ../outputs/t2810 ../originals/t2810 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2811) timeout -s 9 2 ../source/replace.exe '?@[' '@%&a'  < ../inputs/temp-test/241.inp.107.3 > ../outputs/t2811
    if diff ../outputs/t2811 ../originals/t2811 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2812) timeout -s 9 2 ../source/replace.exe '?@[' 'a@n'  < ../inputs/temp-test/424.inp.187.1 > ../outputs/t2812
    if diff ../outputs/t2812 ../originals/t2812 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2813) timeout -s 9 2 ../source/replace.exe '?@[' 'a@n'  < ../inputs/temp-test/425.inp.187.2 > ../outputs/t2813
    if diff ../outputs/t2813 ../originals/t2813 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2814) timeout -s 9 2 ../source/replace.exe '?@[' 'a@n'  < ../inputs/temp-test/426.inp.187.3 > ../outputs/t2814
    if diff ../outputs/t2814 ../originals/t2814 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2815) timeout -s 9 2 ../source/replace.exe '?@[*' '&'  < ../inputs/temp-test/104.inp.47.1 > ../outputs/t2815
    if diff ../outputs/t2815 ../originals/t2815 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2816) timeout -s 9 2 ../source/replace.exe '?@[*' '&'  < ../inputs/temp-test/105.inp.47.3 > ../outputs/t2816
    if diff ../outputs/t2816 ../originals/t2816 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2817) timeout -s 9 2 ../source/replace.exe '?@[*' ''  < ../inputs/temp-test/1966.inp.835.1 > ../outputs/t2817
    if diff ../outputs/t2817 ../originals/t2817 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2818) timeout -s 9 2 ../source/replace.exe '?@[*' 'a&'  < ../inputs/temp-test/538.inp.233.1 > ../outputs/t2818
    if diff ../outputs/t2818 ../originals/t2818 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2819) timeout -s 9 2 ../source/replace.exe '?@[*' 'a&'  < ../inputs/temp-test/539.inp.233.3 > ../outputs/t2819
    if diff ../outputs/t2819 ../originals/t2819 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2820) timeout -s 9 2 ../source/replace.exe '?@[*?-]$' '@%&a'  < ../inputs/temp-test/353.inp.154.9 > ../outputs/t2820
    if diff ../outputs/t2820 ../originals/t2820 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2821) timeout -s 9 2 ../source/replace.exe '?@[*?-]$' '@%&a@'  < ../inputs/temp-test/353.inp.154.9 > ../outputs/t2821
    if diff ../outputs/t2821 ../originals/t2821 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2822) timeout -s 9 2 ../source/replace.exe '?@[*?-]' '@%&a'  < ../inputs/temp-test/351.inp.154.1 > ../outputs/t2822
    if diff ../outputs/t2822 ../originals/t2822 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2823) timeout -s 9 2 ../source/replace.exe '?@[*?-]' '@%&a'  < ../inputs/temp-test/352.inp.154.2 > ../outputs/t2823
    if diff ../outputs/t2823 ../originals/t2823 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2824) timeout -s 9 2 ../source/replace.exe '?@[*?-]' '@%&a@'  < ../inputs/temp-test/351.inp.154.1 > ../outputs/t2824
    if diff ../outputs/t2824 ../originals/t2824 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2825) timeout -s 9 2 ../source/replace.exe '?@[*?-]@' '@%&a'  < ../inputs/temp-test/352.inp.154.2 > ../outputs/t2825
    if diff ../outputs/t2825 ../originals/t2825 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2826) timeout -s 9 2 ../source/replace.exe '?@[*?@[*@*[^-' '@%&a'  < ../inputs/temp-test/1351.inp.580.1 > ../outputs/t2826
    if diff ../outputs/t2826 ../originals/t2826 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2827) timeout -s 9 2 ../source/replace.exe '?@[*?@[*@*[^-' '@%&a'  < ../inputs/temp-test/1352.inp.580.2 > ../outputs/t2827
    if diff ../outputs/t2827 ../originals/t2827 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2828) timeout -s 9 2 ../source/replace.exe '?@n' '|M&i+'\''s OXxRu~W2bMVQrfx+GT$4>}5J5XNph:`xe! zY'  < ../inputs/input/ruin.275 > ../outputs/t2828
    if diff ../outputs/t2828 ../originals/t2828 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2829) timeout -s 9 2 ../source/replace.exe '?@n-?--$' ''  < ../inputs/temp-test/33.inp.14.8 > ../outputs/t2829
    if diff ../outputs/t2829 ../originals/t2829 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2830) timeout -s 9 2 ../source/replace.exe '?@n-?--$' ''  < ../inputs/temp-test/34.inp.14.9 > ../outputs/t2830
    if diff ../outputs/t2830 ../originals/t2830 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2831) timeout -s 9 2 ../source/replace.exe '?@n-?--' ''  < ../inputs/temp-test/32.inp.14.1 > ../outputs/t2831
    if diff ../outputs/t2831 ../originals/t2831 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2832) timeout -s 9 2 ../source/replace.exe '?@t*$' 'b@t'  < ../inputs/temp-test/1006.inp.432.6 > ../outputs/t2832
    if diff ../outputs/t2832 ../originals/t2832 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2833) timeout -s 9 2 ../source/replace.exe '?@t*' 'b@t'  < ../inputs/temp-test/1003.inp.432.1 > ../outputs/t2833
    if diff ../outputs/t2833 ../originals/t2833 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2834) timeout -s 9 2 ../source/replace.exe '?@t*' 'b@t'  < ../inputs/temp-test/1004.inp.432.2 > ../outputs/t2834
    if diff ../outputs/t2834 ../originals/t2834 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2835) timeout -s 9 2 ../source/replace.exe '?@t*' 'b@t'  < ../inputs/temp-test/1005.inp.432.3 > ../outputs/t2835
    if diff ../outputs/t2835 ../originals/t2835 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2836) timeout -s 9 2 ../source/replace.exe '?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*?@t*' 'b@t'  < ../inputs/temp-test/1003.inp.432.1 > ../outputs/t2836
    if diff ../outputs/t2836 ../originals/t2836 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2837) timeout -s 9 2 ../source/replace.exe '?@t[^0-9]?[a-c]?$' '@n'  < ../inputs/temp-test/1056.inp.454.9 > ../outputs/t2837
    if diff ../outputs/t2837 ../originals/t2837 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2838) timeout -s 9 2 ../source/replace.exe '?@t[^0-9]?[a-c]?' '@n'  < ../inputs/temp-test/1054.inp.454.1 > ../outputs/t2838
    if diff ../outputs/t2838 ../originals/t2838 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2839) timeout -s 9 2 ../source/replace.exe '?@t[^0-9]?[a-c]?' '@n'  < ../inputs/temp-test/1055.inp.454.2 > ../outputs/t2839
    if diff ../outputs/t2839 ../originals/t2839 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2840) timeout -s 9 2 ../source/replace.exe '?A' 'NEW'  < ../inputs/temp-test/1546.inp.662.1 > ../outputs/t2840
    if diff ../outputs/t2840 ../originals/t2840 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2841) timeout -s 9 2 ../source/replace.exe '?A' 'NEW'  < ../inputs/temp-test/1547.inp.662.2 > ../outputs/t2841
    if diff ../outputs/t2841 ../originals/t2841 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2842) timeout -s 9 2 ../source/replace.exe '?A' 'NEW'  < ../inputs/temp-test/1548.inp.662.3 > ../outputs/t2842
    if diff ../outputs/t2842 ../originals/t2842 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2843) timeout -s 9 2 ../source/replace.exe '?A*' '&'  < ../inputs/temp-test/1687.inp.719.1 > ../outputs/t2843
    if diff ../outputs/t2843 ../originals/t2843 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2844) timeout -s 9 2 ../source/replace.exe '?A*' '&'  < ../inputs/temp-test/1688.inp.719.2 > ../outputs/t2844
    if diff ../outputs/t2844 ../originals/t2844 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2845) timeout -s 9 2 ../source/replace.exe '?A*?[^a-c?$' '&'  < ../inputs/temp-test/335.inp.147.9 > ../outputs/t2845
    if diff ../outputs/t2845 ../originals/t2845 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2846) timeout -s 9 2 ../source/replace.exe '?A*?[^a-c?' '&'  < ../inputs/temp-test/333.inp.147.1 > ../outputs/t2846
    if diff ../outputs/t2846 ../originals/t2846 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2847) timeout -s 9 2 ../source/replace.exe '?A*?[^a-c?' '&'  < ../inputs/temp-test/334.inp.147.3 > ../outputs/t2847
    if diff ../outputs/t2847 ../originals/t2847 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2848) timeout -s 9 2 ../source/replace.exe '?Ao?' '/'  < ../inputs/input/ruin.1208 > ../outputs/t2848
    if diff ../outputs/t2848 ../originals/t2848 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2849) timeout -s 9 2 ../source/replace.exe '?S' 'N[E*MfGK'  < ../inputs/input/ruin.1349 > ../outputs/t2849
    if diff ../outputs/t2849 ../originals/t2849 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2850) timeout -s 9 2 ../source/replace.exe '?SjGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~ljGU}XIi?]qLF"YtOv~~l[0-9]* *[a--b][^a-c][^a-' 'N[E*MfGK'  < ../inputs/input/ruin.1349 > ../outputs/t2850
    if diff ../outputs/t2850 ../originals/t2850 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2851) timeout -s 9 2 ../source/replace.exe '?U' 'k6'  < ../inputs/input/ruin.618 > ../outputs/t2851
    if diff ../outputs/t2851 ../originals/t2851 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2852) timeout -s 9 2 ../source/replace.exe '?Y' 't'  < ../inputs/input/ruin.1033 > ../outputs/t2852
    if diff ../outputs/t2852 ../originals/t2852 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2853) timeout -s 9 2 ../source/replace.exe '?Y' 't2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G'  < ../inputs/input/ruin.1033 > ../outputs/t2853
    if diff ../outputs/t2853 ../originals/t2853 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2854) timeout -s 9 2 ../source/replace.exe '?[-' 'a&'  < ../inputs/temp-test/783.inp.337.1 > ../outputs/t2854
    if diff ../outputs/t2854 ../originals/t2854 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2855) timeout -s 9 2 ../source/replace.exe '?[--?' '@%&a'  < ../inputs/temp-test/715.inp.309.1 > ../outputs/t2855
    if diff ../outputs/t2855 ../originals/t2855 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2856) timeout -s 9 2 ../source/replace.exe '?[--?' '@%&a'  < ../inputs/temp-test/716.inp.309.2 > ../outputs/t2856
    if diff ../outputs/t2856 ../originals/t2856 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2857) timeout -s 9 2 ../source/replace.exe '?[--?' '@%&a'  < ../inputs/temp-test/717.inp.309.3 > ../outputs/t2857
    if diff ../outputs/t2857 ../originals/t2857 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2858) timeout -s 9 2 ../source/replace.exe '?[-z]?' ''  < ../inputs/temp-test/813.inp.350.1 > ../outputs/t2858
    if diff ../outputs/t2858 ../originals/t2858 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2859) timeout -s 9 2 ../source/replace.exe '?[-z]?' ''  < ../inputs/temp-test/814.inp.350.2 > ../outputs/t2859
    if diff ../outputs/t2859 ../originals/t2859 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2860) timeout -s 9 2 ../source/replace.exe '?[-z]?-@*-[0-9]--' '@%@&'  < ../inputs/temp-test/2173.inp.919.1 > ../outputs/t2860
    if diff ../outputs/t2860 ../originals/t2860 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2861) timeout -s 9 2 ../source/replace.exe '?[0-9] *[^9-B]@*[^a-c]--[^0-9]' 'b@t'  < ../inputs/temp-test/828.inp.357.1 > ../outputs/t2861
    if diff ../outputs/t2861 ../originals/t2861 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2862) timeout -s 9 2 ../source/replace.exe '?[0-9] *[^9-B]@*[^a-c]--[^0-9]' 'b@t'  < ../inputs/temp-test/829.inp.357.2 > ../outputs/t2862
    if diff ../outputs/t2862 ../originals/t2862 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2863) timeout -s 9 2 ../source/replace.exe '?[0-9]' '&a@%'  < ../inputs/temp-test/2021.inp.858.1 > ../outputs/t2863
    if diff ../outputs/t2863 ../originals/t2863 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2864) timeout -s 9 2 ../source/replace.exe '?[0-9]' '&a@%'  < ../inputs/temp-test/2022.inp.858.2 > ../outputs/t2864
    if diff ../outputs/t2864 ../originals/t2864 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2865) timeout -s 9 2 ../source/replace.exe '?[0-9]' '&a@%'  < ../inputs/temp-test/2023.inp.858.3 > ../outputs/t2865
    if diff ../outputs/t2865 ../originals/t2865 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2866) timeout -s 9 2 ../source/replace.exe '?[0-9]' '@%&a'  < ../inputs/temp-test/287.inp.129.1 > ../outputs/t2866
    if diff ../outputs/t2866 ../originals/t2866 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2867) timeout -s 9 2 ../source/replace.exe '?[0-9]' 'NEW'  < ../inputs/temp-test/342.inp.150.1 > ../outputs/t2867
    if diff ../outputs/t2867 ../originals/t2867 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2868) timeout -s 9 2 ../source/replace.exe '?[0-9]' 'NEW'  < ../inputs/temp-test/343.inp.150.3 > ../outputs/t2868
    if diff ../outputs/t2868 ../originals/t2868 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2869) timeout -s 9 2 ../source/replace.exe '?[0-9]' 'NEW@'  < ../inputs/temp-test/343.inp.150.3 > ../outputs/t2869
    if diff ../outputs/t2869 ../originals/t2869 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2870) timeout -s 9 2 ../source/replace.exe '?[0-9]--*[9-B][a-c[^9-B]' '@%@&'  < ../inputs/temp-test/1812.inp.770.1 > ../outputs/t2870
    if diff ../outputs/t2870 ../originals/t2870 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2871) timeout -s 9 2 ../source/replace.exe '?[0-9]--*[9-B][a-c[^9-B]' '@%@&'  < ../inputs/temp-test/1813.inp.770.2 > ../outputs/t2871
    if diff ../outputs/t2871 ../originals/t2871 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2872) timeout -s 9 2 ../source/replace.exe '?[0-9]-[^a-?[a-]' '@n'  < ../inputs/temp-test/1302.inp.560.1 > ../outputs/t2872
    if diff ../outputs/t2872 ../originals/t2872 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2873) timeout -s 9 2 ../source/replace.exe '?[0-9]-[^a-?[a-]' '@n'  < ../inputs/temp-test/1303.inp.560.2 > ../outputs/t2873
    if diff ../outputs/t2873 ../originals/t2873 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2874) timeout -s 9 2 ../source/replace.exe '?[0-9]@' 'NEW'  < ../inputs/temp-test/342.inp.150.1 > ../outputs/t2874
    if diff ../outputs/t2874 ../originals/t2874 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2875) timeout -s 9 2 ../source/replace.exe '?[0-9]@t**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t2875
    if diff ../outputs/t2875 ../originals/t2875 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2876) timeout -s 9 2 ../source/replace.exe '?[0-9][9-B]-' 'a&'  < ../inputs/temp-test/1972.inp.838.1 > ../outputs/t2876
    if diff ../outputs/t2876 ../originals/t2876 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2877) timeout -s 9 2 ../source/replace.exe '?[0-9][9-B]-' 'a&'  < ../inputs/temp-test/1973.inp.838.2 > ../outputs/t2877
    if diff ../outputs/t2877 ../originals/t2877 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2878) timeout -s 9 2 ../source/replace.exe '?[0-9][^a-c]' '@t'  < ../inputs/temp-test/1983.inp.842.1 > ../outputs/t2878
    if diff ../outputs/t2878 ../originals/t2878 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2879) timeout -s 9 2 ../source/replace.exe '?[0-9][a--][^9-B][0-9] *??$' '@t'  < ../inputs/temp-test/1292.inp.554.6 > ../outputs/t2879
    if diff ../outputs/t2879 ../originals/t2879 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2880) timeout -s 9 2 ../source/replace.exe '?[0-9][a--][^9-B][0-9] *??' '@t'  < ../inputs/temp-test/1290.inp.554.1 > ../outputs/t2880
    if diff ../outputs/t2880 ../originals/t2880 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2881) timeout -s 9 2 ../source/replace.exe '?[0-9][a--][^9-B][0-9] *??' '@t'  < ../inputs/temp-test/1291.inp.554.3 > ../outputs/t2881
    if diff ../outputs/t2881 ../originals/t2881 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2882) timeout -s 9 2 ../source/replace.exe '?[0-9]e' op  < ../inputs/moni/f7.inp > ../outputs/t2882
    if diff ../outputs/t2882 ../originals/t2882 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2883) timeout -s 9 2 ../source/replace.exe '?[0-9]e' op  < ../inputs/moni/f8.inp > ../outputs/t2883
    if diff ../outputs/t2883 ../originals/t2883 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2884) timeout -s 9 2 ../source/replace.exe '?[9-B] ' 'a&'  < ../inputs/temp-test/1959.inp.831.1 > ../outputs/t2884
    if diff ../outputs/t2884 ../originals/t2884 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2885) timeout -s 9 2 ../source/replace.exe '?[9-B]' '@%&a'  < ../inputs/temp-test/1256.inp.539.1 > ../outputs/t2885
    if diff ../outputs/t2885 ../originals/t2885 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2886) timeout -s 9 2 ../source/replace.exe '?[9-B]' '@%@&'  < ../inputs/temp-test/1693.inp.722.1 > ../outputs/t2886
    if diff ../outputs/t2886 ../originals/t2886 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2887) timeout -s 9 2 ../source/replace.exe '?[9-B]' '@n'  < ../inputs/temp-test/1999.inp.849.1 > ../outputs/t2887
    if diff ../outputs/t2887 ../originals/t2887 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2888) timeout -s 9 2 ../source/replace.exe '?[9-B]' 'a&'  < ../inputs/temp-test/271.inp.121.1 > ../outputs/t2888
    if diff ../outputs/t2888 ../originals/t2888 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2889) timeout -s 9 2 ../source/replace.exe '?[9-B]' 'b@t'  < ../inputs/temp-test/2290.inp.970.1 > ../outputs/t2889
    if diff ../outputs/t2889 ../originals/t2889 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2890) timeout -s 9 2 ../source/replace.exe '?[9-B][^a-c]$' '@t'  < ../inputs/temp-test/940.inp.403.6 > ../outputs/t2890
    if diff ../outputs/t2890 ../originals/t2890 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2891) timeout -s 9 2 ../source/replace.exe '?[9-B][^a-c]' '@t'  < ../inputs/temp-test/936.inp.403.1 > ../outputs/t2891
    if diff ../outputs/t2891 ../originals/t2891 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2892) timeout -s 9 2 ../source/replace.exe '?[9-B][^a-c]' '@t'  < ../inputs/temp-test/937.inp.403.2 > ../outputs/t2892
    if diff ../outputs/t2892 ../originals/t2892 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2893) timeout -s 9 2 ../source/replace.exe '?[9-B][^a-c]' '@t'  < ../inputs/temp-test/938.inp.403.3 > ../outputs/t2893
    if diff ../outputs/t2893 ../originals/t2893 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2894) timeout -s 9 2 ../source/replace.exe '?[9-B][a-c]?[9-B][^9-B]-^*?-' '@n'  < ../inputs/temp-test/1507.inp.646.1 > ../outputs/t2894
    if diff ../outputs/t2894 ../originals/t2894 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2895) timeout -s 9 2 ../source/replace.exe '?[9-B][a-c]?[9-B][^9-B]-^*?-' '@n'  < ../inputs/temp-test/1508.inp.646.3 > ../outputs/t2895
    if diff ../outputs/t2895 ../originals/t2895 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2896) timeout -s 9 2 ../source/replace.exe '?[9-B]^a-c]-[a-c]-[^0-9]- *?-^a-]$' 'NEW'  < ../inputs/temp-test/1020.inp.438.6 > ../outputs/t2896
    if diff ../outputs/t2896 ../originals/t2896 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2897) timeout -s 9 2 ../source/replace.exe '?[9-B]^a-c]-[a-c]-[^0-9]- *?-^a-]' 'NEW'  < ../inputs/temp-test/1017.inp.438.1 > ../outputs/t2897
    if diff ../outputs/t2897 ../originals/t2897 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2898) timeout -s 9 2 ../source/replace.exe '?[9-B]^a-c]-[a-c]-[^0-9]- *?-^a-]' 'NEW'  < ../inputs/temp-test/1018.inp.438.2 > ../outputs/t2898
    if diff ../outputs/t2898 ../originals/t2898 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2899) timeout -s 9 2 ../source/replace.exe '?[@@][^0-9][a-c]?-[^0-9]- [^9-B]' 'NEW'  < ../inputs/temp-test/1128.inp.485.1 > ../outputs/t2899
    if diff ../outputs/t2899 ../originals/t2899 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2900) timeout -s 9 2 ../source/replace.exe '?[@n]' 'b@t'  < ../inputs/temp-test/1661.inp.708.1 > ../outputs/t2900
    if diff ../outputs/t2900 ../originals/t2900 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2901) timeout -s 9 2 ../source/replace.exe '?[@t]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t2901
    if diff ../outputs/t2901 ../originals/t2901 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2902) timeout -s 9 2 ../source/replace.exe '?[] ' 'a@nb@tc'  < ../inputs/temp-test/217.inp.97.1 > ../outputs/t2902
    if diff ../outputs/t2902 ../originals/t2902 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2903) timeout -s 9 2 ../source/replace.exe '?[]@*' '@%&a'  < ../inputs/temp-test/532.inp.231.1 > ../outputs/t2903
    if diff ../outputs/t2903 ../originals/t2903 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2904) timeout -s 9 2 ../source/replace.exe '?[][^--z]c[^9-B][^9-B]c*?[9-B]c-' '@t'  < ../inputs/temp-test/530.inp.230.1 > ../outputs/t2904
    if diff ../outputs/t2904 ../originals/t2904 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2905) timeout -s 9 2 ../source/replace.exe '?[][^--z]c[^9-B][^9-B]c*?[9-B]c-' '@t'  < ../inputs/temp-test/531.inp.230.4 > ../outputs/t2905
    if diff ../outputs/t2905 ../originals/t2905 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2906) timeout -s 9 2 ../source/replace.exe '?[^-$' '@t'  < ../inputs/temp-test/1771.inp.754.9 > ../outputs/t2906
    if diff ../outputs/t2906 ../originals/t2906 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2907) timeout -s 9 2 ../source/replace.exe '?[^-' '@t'  < ../inputs/temp-test/1770.inp.754.1 > ../outputs/t2907
    if diff ../outputs/t2907 ../originals/t2907 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2908) timeout -s 9 2 ../source/replace.exe '?[^--z]' ''  < ../inputs/temp-test/2157.inp.913.1 > ../outputs/t2908
    if diff ../outputs/t2908 ../originals/t2908 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2909) timeout -s 9 2 ../source/replace.exe '?[^--z]*$' '@t'  < ../inputs/temp-test/530.inp.230.1 > ../outputs/t2909
    if diff ../outputs/t2909 ../originals/t2909 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2910) timeout -s 9 2 ../source/replace.exe '?[^--z]*' '@t'  < ../inputs/temp-test/530.inp.230.1 > ../outputs/t2910
    if diff ../outputs/t2910 ../originals/t2910 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2911) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B]*$' '@t'  < ../inputs/temp-test/531.inp.230.4 > ../outputs/t2911
    if diff ../outputs/t2911 ../originals/t2911 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2912) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B]*' '@t'  < ../inputs/temp-test/531.inp.230.4 > ../outputs/t2912
    if diff ../outputs/t2912 ../originals/t2912 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2913) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B][^9-B]c*?[9-B]c-'   < ../inputs/temp-test/530.inp.230.1 > ../outputs/t2913
    if diff ../outputs/t2913 ../originals/t2913 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2914) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B][^9-B]c*?[9-B]c-'   < ../inputs/temp-test/531.inp.230.4 > ../outputs/t2914
    if diff ../outputs/t2914 ../originals/t2914 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2915) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B][^9-B]c*?[9-B]c-' '@t'  < ../inputs/temp-test/530.inp.230.1 > ../outputs/t2915
    if diff ../outputs/t2915 ../originals/t2915 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2916) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B][^9-B]c*?[9-B]c-' '@t'  < ../inputs/temp-test/531.inp.230.4 > ../outputs/t2916
    if diff ../outputs/t2916 ../originals/t2916 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2917) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B][^9-B]c?*' '@t'  < ../inputs/temp-test/530.inp.230.1 > ../outputs/t2917
    if diff ../outputs/t2917 ../originals/t2917 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2918) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B][^9-B]c?*' '@t'  < ../inputs/temp-test/531.inp.230.4 > ../outputs/t2918
    if diff ../outputs/t2918 ../originals/t2918 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2919) timeout -s 9 2 ../source/replace.exe '?[^--z]c[^9-B][^9-B]c?**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t2919
    if diff ../outputs/t2919 ../originals/t2919 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2920) timeout -s 9 2 ../source/replace.exe '?[^-z][^--z]?-@[*' '&'  < ../inputs/temp-test/133.inp.62.1 > ../outputs/t2920
    if diff ../outputs/t2920 ../originals/t2920 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2921) timeout -s 9 2 ../source/replace.exe '?[^0-9>-A]' ')Ifp.i9B%j1,0T.zHwp'  < ../inputs/input/ruin.1007 > ../outputs/t2921
    if diff ../outputs/t2921 ../originals/t2921 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2922) timeout -s 9 2 ../source/replace.exe '?[^0-9]' ''  < ../inputs/temp-test/2208.inp.935.1 > ../outputs/t2922
    if diff ../outputs/t2922 ../originals/t2922 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2923) timeout -s 9 2 ../source/replace.exe '?[^0-9]' '@%@&'  < ../inputs/temp-test/1622.inp.690.1 > ../outputs/t2923
    if diff ../outputs/t2923 ../originals/t2923 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2924) timeout -s 9 2 ../source/replace.exe '?[^0-9]' '@%@&'  < ../inputs/temp-test/1623.inp.690.3 > ../outputs/t2924
    if diff ../outputs/t2924 ../originals/t2924 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2925) timeout -s 9 2 ../source/replace.exe '?[^0-9]' '@%@&'  < ../inputs/temp-test/1624.inp.690.4 > ../outputs/t2925
    if diff ../outputs/t2925 ../originals/t2925 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2926) timeout -s 9 2 ../source/replace.exe '?[^0-9]' 'J'  < ../inputs/input/ruin.1332 > ../outputs/t2926
    if diff ../outputs/t2926 ../originals/t2926 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2927) timeout -s 9 2 ../source/replace.exe '?[^0-9]' 'J?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe?Stj%,|9I{FxV*qi!{_(dn*K9`$wo[0-9]NwuJe'  < ../inputs/input/ruin.1332 > ../outputs/t2927
    if diff ../outputs/t2927 ../originals/t2927 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2928) timeout -s 9 2 ../source/replace.exe '?[^0-9]' 'b@t'  < ../inputs/temp-test/2276.inp.965.1 > ../outputs/t2928
    if diff ../outputs/t2928 ../originals/t2928 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2929) timeout -s 9 2 ../source/replace.exe '?[^0-9]' 'b@t'  < ../inputs/temp-test/2277.inp.965.2 > ../outputs/t2929
    if diff ../outputs/t2929 ../originals/t2929 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2930) timeout -s 9 2 ../source/replace.exe '?[^0-9]' 'b@t'  < ../inputs/temp-test/2278.inp.965.3 > ../outputs/t2930
    if diff ../outputs/t2930 ../originals/t2930 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2931) timeout -s 9 2 ../source/replace.exe '?[^0-9]-' '@%&a'  < ../inputs/temp-test/597.inp.257.1 > ../outputs/t2931
    if diff ../outputs/t2931 ../originals/t2931 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2932) timeout -s 9 2 ../source/replace.exe '?[^0-9]-' '@%&a'  < ../inputs/temp-test/598.inp.257.2 > ../outputs/t2932
    if diff ../outputs/t2932 ../originals/t2932 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2933) timeout -s 9 2 ../source/replace.exe '?[^0-9]-*' 'a@nb@tc'  < ../inputs/temp-test/806.inp.346.1 > ../outputs/t2933
    if diff ../outputs/t2933 ../originals/t2933 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2934) timeout -s 9 2 ../source/replace.exe '?[^0-9]?^-]-[^a-c]$' 'NEW'  < ../inputs/temp-test/586.inp.251.9 > ../outputs/t2934
    if diff ../outputs/t2934 ../originals/t2934 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2935) timeout -s 9 2 ../source/replace.exe '?[^0-9]?^-]-[^a-c]' 'NEW'  < ../inputs/temp-test/583.inp.251.1 > ../outputs/t2935
    if diff ../outputs/t2935 ../originals/t2935 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2936) timeout -s 9 2 ../source/replace.exe '?[^0-9]?^-]-[^a-c]' 'NEW'  < ../inputs/temp-test/584.inp.251.3 > ../outputs/t2936
    if diff ../outputs/t2936 ../originals/t2936 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2937) timeout -s 9 2 ../source/replace.exe '?[^0-9]?^-]-[^a-c]' 'NEW'  < ../inputs/temp-test/585.inp.251.4 > ../outputs/t2937
    if diff ../outputs/t2937 ../originals/t2937 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2938) timeout -s 9 2 ../source/replace.exe '?[^9-B]$' 'b@t'  < ../inputs/temp-test/173.inp.77.6 > ../outputs/t2938
    if diff ../outputs/t2938 ../originals/t2938 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2939) timeout -s 9 2 ../source/replace.exe '?[^9-B]%' ''  < ../inputs/temp-test/10.inp.5.1 > ../outputs/t2939
    if diff ../outputs/t2939 ../originals/t2939 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2940) timeout -s 9 2 ../source/replace.exe '?[^9-B]' '&a@%'  < ../inputs/temp-test/377.inp.164.1 > ../outputs/t2940
    if diff ../outputs/t2940 ../originals/t2940 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2941) timeout -s 9 2 ../source/replace.exe '?[^9-B]' '&a@%'  < ../inputs/temp-test/378.inp.164.2 > ../outputs/t2941
    if diff ../outputs/t2941 ../originals/t2941 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2942) timeout -s 9 2 ../source/replace.exe '?[^9-B]' ''  < ../inputs/temp-test/10.inp.5.1 > ../outputs/t2942
    if diff ../outputs/t2942 ../originals/t2942 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2943) timeout -s 9 2 ../source/replace.exe '?[^9-B]' ''  < ../inputs/temp-test/11.inp.5.2 > ../outputs/t2943
    if diff ../outputs/t2943 ../originals/t2943 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2944) timeout -s 9 2 ../source/replace.exe '?[^9-B]' 'a@n'  < ../inputs/temp-test/281.inp.126.1 > ../outputs/t2944
    if diff ../outputs/t2944 ../originals/t2944 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2945) timeout -s 9 2 ../source/replace.exe '?[^9-B]' 'a@n'  < ../inputs/temp-test/282.inp.126.2 > ../outputs/t2945
    if diff ../outputs/t2945 ../originals/t2945 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2946) timeout -s 9 2 ../source/replace.exe '?[^9-B]' 'a@n'  < ../inputs/temp-test/469.inp.205.1 > ../outputs/t2946
    if diff ../outputs/t2946 ../originals/t2946 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2947) timeout -s 9 2 ../source/replace.exe '?[^9-B]' 'a@n'  < ../inputs/temp-test/470.inp.205.2 > ../outputs/t2947
    if diff ../outputs/t2947 ../originals/t2947 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2948) timeout -s 9 2 ../source/replace.exe '?[^9-B]' 'a@nb@tc'  < ../inputs/temp-test/1862.inp.790.1 > ../outputs/t2948
    if diff ../outputs/t2948 ../originals/t2948 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2949) timeout -s 9 2 ../source/replace.exe '?[^9-B]' 'a@nb@tc'  < ../inputs/temp-test/1863.inp.790.3 > ../outputs/t2949
    if diff ../outputs/t2949 ../originals/t2949 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2950) timeout -s 9 2 ../source/replace.exe '?[^9-B]' 'b@t'  < ../inputs/temp-test/171.inp.77.1 > ../outputs/t2950
    if diff ../outputs/t2950 ../originals/t2950 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2951) timeout -s 9 2 ../source/replace.exe '?[^9-B]' 'b@t'  < ../inputs/temp-test/172.inp.77.3 > ../outputs/t2951
    if diff ../outputs/t2951 ../originals/t2951 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2952) timeout -s 9 2 ../source/replace.exe '?[^9-B]-[^0-9]-[9-B]' 'b@t'  < ../inputs/temp-test/267.inp.119.1 > ../outputs/t2952
    if diff ../outputs/t2952 ../originals/t2952 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2953) timeout -s 9 2 ../source/replace.exe '?[^9-B]-[^0-9]-[9-B]' 'b@t'  < ../inputs/temp-test/268.inp.119.2 > ../outputs/t2953
    if diff ../outputs/t2953 ../originals/t2953 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2954) timeout -s 9 2 ../source/replace.exe '?[^9-B]?@**[9-B]-' 'NEW'  < ../inputs/temp-test/86.inp.39.1 > ../outputs/t2954
    if diff ../outputs/t2954 ../originals/t2954 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2955) timeout -s 9 2 ../source/replace.exe '?[^9-B]?@**[9-B]-' 'NEW'  < ../inputs/temp-test/87.inp.39.2 > ../outputs/t2955
    if diff ../outputs/t2955 ../originals/t2955 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2956) timeout -s 9 2 ../source/replace.exe '?[^9-B][9-B][^9-B]' 'a&'  < ../inputs/temp-test/796.inp.343.1 > ../outputs/t2956
    if diff ../outputs/t2956 ../originals/t2956 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2957) timeout -s 9 2 ../source/replace.exe '?[^9-B][9-B][^9-B]' 'a&'  < ../inputs/temp-test/797.inp.343.2 > ../outputs/t2957
    if diff ../outputs/t2957 ../originals/t2957 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2958) timeout -s 9 2 ../source/replace.exe '?[^9-B][9-B][^9-B]' 'a&'  < ../inputs/temp-test/798.inp.343.3 > ../outputs/t2958
    if diff ../outputs/t2958 ../originals/t2958 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2959) timeout -s 9 2 ../source/replace.exe '?[^9-B][^9-B]A$' 'a@n'  < ../inputs/temp-test/1809.inp.768.6 > ../outputs/t2959
    if diff ../outputs/t2959 ../originals/t2959 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2960) timeout -s 9 2 ../source/replace.exe '?[^9-B][^9-B]A' 'a@n'  < ../inputs/temp-test/1805.inp.768.1 > ../outputs/t2960
    if diff ../outputs/t2960 ../originals/t2960 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2961) timeout -s 9 2 ../source/replace.exe '?[^9-B][^9-B]A' 'a@n'  < ../inputs/temp-test/1806.inp.768.2 > ../outputs/t2961
    if diff ../outputs/t2961 ../originals/t2961 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2962) timeout -s 9 2 ../source/replace.exe '?[^9-B][^9-B]A' 'a@n'  < ../inputs/temp-test/1807.inp.768.4 > ../outputs/t2962
    if diff ../outputs/t2962 ../originals/t2962 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2963) timeout -s 9 2 ../source/replace.exe '?[^9-B]a-c]--? ??-- *@[*?' 'a&'  < ../inputs/temp-test/1573.inp.672.1 > ../outputs/t2963
    if diff ../outputs/t2963 ../originals/t2963 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2964) timeout -s 9 2 ../source/replace.exe '?[^9-B]a-c]--? ??-- *@[*?' 'a&'  < ../inputs/temp-test/1574.inp.672.2 > ../outputs/t2964
    if diff ../outputs/t2964 ../originals/t2964 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2965) timeout -s 9 2 ../source/replace.exe '?[^9-B]a-c]--? ??-- *@[*?' 'a&'  < ../inputs/temp-test/1575.inp.672.3 > ../outputs/t2965
    if diff ../outputs/t2965 ../originals/t2965 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2966) timeout -s 9 2 ../source/replace.exe '?[^9-B]a-c]--? ??-- *@[*?' 'a&'  < ../inputs/temp-test/1576.inp.672.4 > ../outputs/t2966
    if diff ../outputs/t2966 ../originals/t2966 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2967) timeout -s 9 2 ../source/replace.exe '?[^@@]' ''  < ../inputs/temp-test/2155.inp.912.1 > ../outputs/t2967
    if diff ../outputs/t2967 ../originals/t2967 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2968) timeout -s 9 2 ../source/replace.exe '?[^@@]' ''  < ../inputs/temp-test/2156.inp.912.3 > ../outputs/t2968
    if diff ../outputs/t2968 ../originals/t2968 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2969) timeout -s 9 2 ../source/replace.exe '?[^@@][0-9]-$' '&'  < ../inputs/temp-test/1195.inp.513.6 > ../outputs/t2969
    if diff ../outputs/t2969 ../originals/t2969 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2970) timeout -s 9 2 ../source/replace.exe '?[^@@][0-9]-' '&'  < ../inputs/temp-test/1192.inp.513.1 > ../outputs/t2970
    if diff ../outputs/t2970 ../originals/t2970 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2971) timeout -s 9 2 ../source/replace.exe '?[^@@][0-9]-' '&'  < ../inputs/temp-test/1193.inp.513.2 > ../outputs/t2971
    if diff ../outputs/t2971 ../originals/t2971 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2972) timeout -s 9 2 ../source/replace.exe '?[^@@][0-9]-' '&'  < ../inputs/temp-test/1194.inp.513.3 > ../outputs/t2972
    if diff ../outputs/t2972 ../originals/t2972 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2973) timeout -s 9 2 ../source/replace.exe '?[^@@][^--z]c-[^0-9][9-B]??' 'a@n'  < ../inputs/temp-test/302.inp.136.1 > ../outputs/t2973
    if diff ../outputs/t2973 ../originals/t2973 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2974) timeout -s 9 2 ../source/replace.exe '?[^@@][^--z]c-[^0-9][9-B]??' 'a@n'  < ../inputs/temp-test/303.inp.136.2 > ../outputs/t2974
    if diff ../outputs/t2974 ../originals/t2974 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2975) timeout -s 9 2 ../source/replace.exe '?[^@@][^--z]c-[^0-9][9-B]??' 'a@n'  < ../inputs/temp-test/304.inp.136.3 > ../outputs/t2975
    if diff ../outputs/t2975 ../originals/t2975 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2976) timeout -s 9 2 ../source/replace.exe '?[^@n]' '@t'  < ../inputs/temp-test/290.inp.131.1 > ../outputs/t2976
    if diff ../outputs/t2976 ../originals/t2976 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2977) timeout -s 9 2 ../source/replace.exe '?[^@n]' '@t'  < ../inputs/temp-test/291.inp.131.2 > ../outputs/t2977
    if diff ../outputs/t2977 ../originals/t2977 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2978) timeout -s 9 2 ../source/replace.exe '?[^@n][^0-9]-@*@*?' 'a&'  < ../inputs/temp-test/269.inp.120.1 > ../outputs/t2978
    if diff ../outputs/t2978 ../originals/t2978 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2979) timeout -s 9 2 ../source/replace.exe '?[^@n][^0-9]-@*@*?' 'a&'  < ../inputs/temp-test/270.inp.120.4 > ../outputs/t2979
    if diff ../outputs/t2979 ../originals/t2979 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2980) timeout -s 9 2 ../source/replace.exe '?[^@n]^[@@][0-9]??-]' 'NEW'  < ../inputs/temp-test/1124.inp.484.1 > ../outputs/t2980
    if diff ../outputs/t2980 ../originals/t2980 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2981) timeout -s 9 2 ../source/replace.exe '?[^@n]^[@@][0-9]??-]' 'NEW'  < ../inputs/temp-test/1125.inp.484.2 > ../outputs/t2981
    if diff ../outputs/t2981 ../originals/t2981 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2982) timeout -s 9 2 ../source/replace.exe '?[^@n]^[@@][0-9]??-]' 'NEW'  < ../inputs/temp-test/1126.inp.484.3 > ../outputs/t2982
    if diff ../outputs/t2982 ../originals/t2982 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2983) timeout -s 9 2 ../source/replace.exe '?[^@t]' 'NEW'  < ../inputs/temp-test/1484.inp.637.1 > ../outputs/t2983
    if diff ../outputs/t2983 ../originals/t2983 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2984) timeout -s 9 2 ../source/replace.exe '?[^Z-a]^_`a]$' '=Wk.f/55+vDk9q)=M@c$J7g4#(A-`^-G!J'  < ../inputs/input/ruin.1940 > ../outputs/t2984
    if diff ../outputs/t2984 ../originals/t2984 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2985) timeout -s 9 2 ../source/replace.exe '?[^Z-a]^_`a]' 'll&TYr{O(v_3"lQIib-9o98U{Cs_a8 cM4lI^%0or5Eu!8QY[J~+#nh<A'  < ../inputs/input/ruin.213 > ../outputs/t2985
    if diff ../outputs/t2985 ../originals/t2985 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2986) timeout -s 9 2 ../source/replace.exe '?[^] ' 'a@nb@tc'  < ../inputs/temp-test/217.inp.97.1 > ../outputs/t2986
    if diff ../outputs/t2986 ../originals/t2986 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2987) timeout -s 9 2 ../source/replace.exe '?[^]@*' '@%&a'  < ../inputs/temp-test/532.inp.231.1 > ../outputs/t2987
    if diff ../outputs/t2987 ../originals/t2987 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2988) timeout -s 9 2 ../source/replace.exe '?[^][^--z]c[^9-B][^9-B]c*?[9-B]c-' '@t'  < ../inputs/temp-test/530.inp.230.1 > ../outputs/t2988
    if diff ../outputs/t2988 ../originals/t2988 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2989) timeout -s 9 2 ../source/replace.exe '?[^][^--z]c[^9-B][^9-B]c*?[9-B]c-' '@t'  < ../inputs/temp-test/531.inp.230.4 > ../outputs/t2989
    if diff ../outputs/t2989 ../originals/t2989 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2990) timeout -s 9 2 ../source/replace.exe '?[^a--]' '@n'  < ../inputs/temp-test/128.inp.60.1 > ../outputs/t2990
    if diff ../outputs/t2990 ../originals/t2990 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2991) timeout -s 9 2 ../source/replace.exe '?[^a--]' '@n'  < ../inputs/temp-test/129.inp.60.2 > ../outputs/t2991
    if diff ../outputs/t2991 ../originals/t2991 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2992) timeout -s 9 2 ../source/replace.exe '?[^a--]' '@n'  < ../inputs/temp-test/130.inp.60.3 > ../outputs/t2992
    if diff ../outputs/t2992 ../originals/t2992 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2993) timeout -s 9 2 ../source/replace.exe '?[^a--]' 'b@t'  < ../inputs/temp-test/1991.inp.846.1 > ../outputs/t2993
    if diff ../outputs/t2993 ../originals/t2993 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2994) timeout -s 9 2 ../source/replace.exe '?[^a--]' 'b@t'  < ../inputs/temp-test/1992.inp.846.2 > ../outputs/t2994
    if diff ../outputs/t2994 ../originals/t2994 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2995) timeout -s 9 2 ../source/replace.exe '?[^a--]' 'b@t'  < ../inputs/temp-test/1993.inp.846.3 > ../outputs/t2995
    if diff ../outputs/t2995 ../originals/t2995 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2996) timeout -s 9 2 ../source/replace.exe '?[^a--b]' '@n'  < ../inputs/temp-test/1052.inp.453.1 > ../outputs/t2996
    if diff ../outputs/t2996 ../originals/t2996 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2997) timeout -s 9 2 ../source/replace.exe '?[^a--b]' '@n'  < ../inputs/temp-test/1053.inp.453.2 > ../outputs/t2997
    if diff ../outputs/t2997 ../originals/t2997 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2998) timeout -s 9 2 ../source/replace.exe '?[^a--b][0-9]A*[9-B]??[^9-B]?-' 'b@t'  < ../inputs/temp-test/1411.inp.606.1 > ../outputs/t2998
    if diff ../outputs/t2998 ../originals/t2998 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p2999) timeout -s 9 2 ../source/replace.exe '?[^a--b][0-9]A*[9-B]??[^9-B]?-' 'b@t'  < ../inputs/temp-test/1412.inp.606.2 > ../outputs/t2999
    if diff ../outputs/t2999 ../originals/t2999 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3000) timeout -s 9 2 ../source/replace.exe '?[^a--b][0-9]A*[9-B]??[^9-B]?-' 'b@t'  < ../inputs/temp-test/1413.inp.606.3 > ../outputs/t3000
    if diff ../outputs/t3000 ../originals/t3000 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3001) timeout -s 9 2 ../source/replace.exe '?[^a-?--*[9-B]?[0-9]a-c]-*' 'a@nb@tc'  < ../inputs/temp-test/1070.inp.460.1 > ../outputs/t3001
    if diff ../outputs/t3001 ../originals/t3001 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3002) timeout -s 9 2 ../source/replace.exe '?[^a-c' '@%@&'  < ../inputs/temp-test/978.inp.421.1 > ../outputs/t3002
    if diff ../outputs/t3002 ../originals/t3002 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3003) timeout -s 9 2 ../source/replace.exe '?[^a-c' '@%@&'  < ../inputs/temp-test/979.inp.421.3 > ../outputs/t3003
    if diff ../outputs/t3003 ../originals/t3003 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3004) timeout -s 9 2 ../source/replace.exe '?[^a-c' '@%@&'  < ../inputs/temp-test/980.inp.421.4 > ../outputs/t3004
    if diff ../outputs/t3004 ../originals/t3004 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3005) timeout -s 9 2 ../source/replace.exe '?[^a-c]$' '@n'  < ../inputs/temp-test/1895.inp.803.6 > ../outputs/t3005
    if diff ../outputs/t3005 ../originals/t3005 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3006) timeout -s 9 2 ../source/replace.exe '?[^a-c]%??[^a-]?[9-B][^9-B][9-B]' ''  < ../inputs/temp-test/2343.inp.995.3 > ../outputs/t3006
    if diff ../outputs/t3006 ../originals/t3006 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3007) timeout -s 9 2 ../source/replace.exe '?[^a-c]' '&'  < ../inputs/temp-test/419.inp.185.1 > ../outputs/t3007
    if diff ../outputs/t3007 ../originals/t3007 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3008) timeout -s 9 2 ../source/replace.exe '?[^a-c]' '&'  < ../inputs/temp-test/420.inp.185.2 > ../outputs/t3008
    if diff ../outputs/t3008 ../originals/t3008 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3009) timeout -s 9 2 ../source/replace.exe '?[^a-c]' '&'  < ../inputs/temp-test/421.inp.185.3 > ../outputs/t3009
    if diff ../outputs/t3009 ../originals/t3009 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3010) timeout -s 9 2 ../source/replace.exe '?[^a-c]' '@n'  < ../inputs/temp-test/1893.inp.803.1 > ../outputs/t3010
    if diff ../outputs/t3010 ../originals/t3010 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3011) timeout -s 9 2 ../source/replace.exe '?[^a-c]' '@n'  < ../inputs/temp-test/1894.inp.803.2 > ../outputs/t3011
    if diff ../outputs/t3011 ../originals/t3011 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3012) timeout -s 9 2 ../source/replace.exe '?[^a-c]- *[9-B]?' '@%@&'  < ../inputs/temp-test/1849.inp.785.1 > ../outputs/t3012
    if diff ../outputs/t3012 ../originals/t3012 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3013) timeout -s 9 2 ../source/replace.exe '?[^a-c]- *[9-B]?' '@%@&'  < ../inputs/temp-test/1850.inp.785.2 > ../outputs/t3013
    if diff ../outputs/t3013 ../originals/t3013 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3014) timeout -s 9 2 ../source/replace.exe '?[^a-c]-^?-[a-c]-?c*?[^9-B]-?' 'NEW'  < ../inputs/temp-test/1585.inp.676.1 > ../outputs/t3014
    if diff ../outputs/t3014 ../originals/t3014 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3015) timeout -s 9 2 ../source/replace.exe '?[^a-c]-^?-[a-c]-?c*?[^9-B]-?' 'NEW'  < ../inputs/temp-test/1586.inp.676.2 > ../outputs/t3015
    if diff ../outputs/t3015 ../originals/t3015 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3016) timeout -s 9 2 ../source/replace.exe '?[^a-c]-^?-[a-c]-?c*?[^9-B]-?' 'NEW'  < ../inputs/temp-test/1587.inp.676.3 > ../outputs/t3016
    if diff ../outputs/t3016 ../originals/t3016 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3017) timeout -s 9 2 ../source/replace.exe '?[^a-c]?%?[^a-]?[9-B][^9-B][9-B]' ''  < ../inputs/temp-test/2341.inp.995.1 > ../outputs/t3017
    if diff ../outputs/t3017 ../originals/t3017 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3018) timeout -s 9 2 ../source/replace.exe '?[^a-c]?%?[^a-]?[9-B][^9-B][9-B]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t3018
    if diff ../outputs/t3018 ../originals/t3018 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3019) timeout -s 9 2 ../source/replace.exe '?[^a-c]??%[^a-]?[9-B][^9-B][9-B]' ''  < ../inputs/temp-test/2342.inp.995.2 > ../outputs/t3019
    if diff ../outputs/t3019 ../originals/t3019 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3020) timeout -s 9 2 ../source/replace.exe '?[^a-c]??%[^a-]?[9-B][^9-B][9-B]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t3020
    if diff ../outputs/t3020 ../originals/t3020 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3021) timeout -s 9 2 ../source/replace.exe '?[^a-c]??[^a-]?[9-B][^9-B][9-B]' ''  < ../inputs/temp-test/2341.inp.995.1 > ../outputs/t3021
    if diff ../outputs/t3021 ../originals/t3021 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3022) timeout -s 9 2 ../source/replace.exe '?[^a-c]??[^a-]?[9-B][^9-B][9-B]' ''  < ../inputs/temp-test/2342.inp.995.2 > ../outputs/t3022
    if diff ../outputs/t3022 ../originals/t3022 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3023) timeout -s 9 2 ../source/replace.exe '?[^a-c]??[^a-]?[9-B][^9-B][9-B]' ''  < ../inputs/temp-test/2343.inp.995.3 > ../outputs/t3023
    if diff ../outputs/t3023 ../originals/t3023 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3024) timeout -s 9 2 ../source/replace.exe '?[^a-c]@[*[^a-c]- *^a-c]^' 'a&'  < ../inputs/temp-test/899.inp.387.1 > ../outputs/t3024
    if diff ../outputs/t3024 ../originals/t3024 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3025) timeout -s 9 2 ../source/replace.exe '?[^a-c]@[*[^a-c]- *^a-c]^' 'a&'  < ../inputs/temp-test/900.inp.387.2 > ../outputs/t3025
    if diff ../outputs/t3025 ../originals/t3025 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3026) timeout -s 9 2 ../source/replace.exe '?[^a-c]@[*[^a-c]- *^a-c]^' 'a&'  < ../inputs/temp-test/901.inp.387.3 > ../outputs/t3026
    if diff ../outputs/t3026 ../originals/t3026 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3027) timeout -s 9 2 ../source/replace.exe '?[^a]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t3027
    if diff ../outputs/t3027 ../originals/t3027 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3028) timeout -s 9 2 ../source/replace.exe '?[^p&y=3[p&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIZYIgTBk0-9]' 'J'  < ../inputs/input/ruin.1332 > ../outputs/t3028
    if diff ../outputs/t3028 ../originals/t3028 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3029) timeout -s 9 2 ../source/replace.exe '?[a-' '&'  < ../inputs/temp-test/1751.inp.744.1 > ../outputs/t3029
    if diff ../outputs/t3029 ../originals/t3029 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3030) timeout -s 9 2 ../source/replace.exe '?[a-' '&'  < ../inputs/temp-test/1752.inp.744.2 > ../outputs/t3030
    if diff ../outputs/t3030 ../originals/t3030 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3031) timeout -s 9 2 ../source/replace.exe '?[a-' '&'  < ../inputs/temp-test/1753.inp.744.4 > ../outputs/t3031
    if diff ../outputs/t3031 ../originals/t3031 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3032) timeout -s 9 2 ../source/replace.exe '?[a--]' '@%@&'  < ../inputs/temp-test/1522.inp.652.1 > ../outputs/t3032
    if diff ../outputs/t3032 ../originals/t3032 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3033) timeout -s 9 2 ../source/replace.exe '?[a--]' '@%@&'  < ../inputs/temp-test/1523.inp.652.3 > ../outputs/t3033
    if diff ../outputs/t3033 ../originals/t3033 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3034) timeout -s 9 2 ../source/replace.exe '?[a--]?[9-B]?[0-9][^a-c]' ''  < ../inputs/temp-test/2018.inp.857.1 > ../outputs/t3034
    if diff ../outputs/t3034 ../originals/t3034 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3035) timeout -s 9 2 ../source/replace.exe '?[a--]?[9-B]?[0-9][^a-c]' ''  < ../inputs/temp-test/2019.inp.857.2 > ../outputs/t3035
    if diff ../outputs/t3035 ../originals/t3035 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3036) timeout -s 9 2 ../source/replace.exe '?[a--]?[9-B]?[0-9][^a-c]' ''  < ../inputs/temp-test/2020.inp.857.3 > ../outputs/t3036
    if diff ../outputs/t3036 ../originals/t3036 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3037) timeout -s 9 2 ../source/replace.exe '?[a--][0-9]--[9-B][-z]?' 'a@nb@tc'  < ../inputs/temp-test/2034.inp.863.1 > ../outputs/t3037
    if diff ../outputs/t3037 ../originals/t3037 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3038) timeout -s 9 2 ../source/replace.exe '?[a--][0-9]--[9-B][-z]?' 'a@nb@tc'  < ../inputs/temp-test/2035.inp.863.2 > ../outputs/t3038
    if diff ../outputs/t3038 ../originals/t3038 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3039) timeout -s 9 2 ../source/replace.exe '?[a--][0-9]--[9-B][-z]?' 'a@nb@tc'  < ../inputs/temp-test/2036.inp.863.3 > ../outputs/t3039
    if diff ../outputs/t3039 ../originals/t3039 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3040) timeout -s 9 2 ../source/replace.exe '?[a--b]@[*[0-9][^a-c]?@*[0-9][- *[^@@][-z][9-B]- *-[a-c]' 'NEW'  < ../inputs/temp-test/1741.inp.741.1 > ../outputs/t3040
    if diff ../outputs/t3040 ../originals/t3040 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3041) timeout -s 9 2 ../source/replace.exe '?[a--b]@[*[0-9][^a-c]?@*[0-9][- *[^@@][-z][9-B]- *-[a-c]' 'NEW'  < ../inputs/temp-test/1742.inp.741.3 > ../outputs/t3041
    if diff ../outputs/t3041 ../originals/t3041 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3042) timeout -s 9 2 ../source/replace.exe '?[a-]' '@t'  < ../inputs/temp-test/2162.inp.915.1 > ../outputs/t3042
    if diff ../outputs/t3042 ../originals/t3042 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3043) timeout -s 9 2 ../source/replace.exe '?[a-]' '@t'  < ../inputs/temp-test/2163.inp.915.2 > ../outputs/t3043
    if diff ../outputs/t3043 ../originals/t3043 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3044) timeout -s 9 2 ../source/replace.exe '?[a-]' '@t'  < ../inputs/temp-test/2164.inp.915.3 > ../outputs/t3044
    if diff ../outputs/t3044 ../originals/t3044 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3045) timeout -s 9 2 ../source/replace.exe '?[a-]@[*?--?^*-@t*-@@*' ''  < ../inputs/temp-test/871.inp.374.1 > ../outputs/t3045
    if diff ../outputs/t3045 ../originals/t3045 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3046) timeout -s 9 2 ../source/replace.exe '?[a-]@[*?--?^*-@t*-@@*' ''  < ../inputs/temp-test/872.inp.374.3 > ../outputs/t3046
    if diff ../outputs/t3046 ../originals/t3046 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3047) timeout -s 9 2 ../source/replace.exe '?[a-b]$**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t3047
    if diff ../outputs/t3047 ../originals/t3047 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3048) timeout -s 9 2 ../source/replace.exe '?[a-c' 'a@n'  < ../inputs/temp-test/769.inp.330.1 > ../outputs/t3048
    if diff ../outputs/t3048 ../originals/t3048 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3049) timeout -s 9 2 ../source/replace.exe '?[a-c-?' 'a@nb@tc'  < ../inputs/temp-test/2198.inp.932.1 > ../outputs/t3049
    if diff ../outputs/t3049 ../originals/t3049 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3050) timeout -s 9 2 ../source/replace.exe '?[a-c-?' 'a@nb@tc'  < ../inputs/temp-test/2199.inp.932.2 > ../outputs/t3050
    if diff ../outputs/t3050 ../originals/t3050 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3051) timeout -s 9 2 ../source/replace.exe '?[a-c-?' 'a@nb@tc'  < ../inputs/temp-test/2200.inp.932.3 > ../outputs/t3051
    if diff ../outputs/t3051 ../originals/t3051 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3052) timeout -s 9 2 ../source/replace.exe '?[a-c]$' '@%@&'  < ../inputs/temp-test/1776.inp.756.6 > ../outputs/t3052
    if diff ../outputs/t3052 ../originals/t3052 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3053) timeout -s 9 2 ../source/replace.exe '?[a-c]' '&a@%'  < ../inputs/temp-test/2166.inp.916.1 > ../outputs/t3053
    if diff ../outputs/t3053 ../originals/t3053 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3054) timeout -s 9 2 ../source/replace.exe '?[a-c]' '&a@%'  < ../inputs/temp-test/2167.inp.916.3 > ../outputs/t3054
    if diff ../outputs/t3054 ../originals/t3054 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3055) timeout -s 9 2 ../source/replace.exe '?[a-c]' '@%@&'  < ../inputs/temp-test/1774.inp.756.1 > ../outputs/t3055
    if diff ../outputs/t3055 ../originals/t3055 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3056) timeout -s 9 2 ../source/replace.exe '?[a-c]' '@%@&'  < ../inputs/temp-test/1775.inp.756.3 > ../outputs/t3056
    if diff ../outputs/t3056 ../originals/t3056 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3057) timeout -s 9 2 ../source/replace.exe '?[a-c]' 'a@n'  < ../inputs/temp-test/1401.inp.601.1 > ../outputs/t3057
    if diff ../outputs/t3057 ../originals/t3057 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3058) timeout -s 9 2 ../source/replace.exe '?[a-c]' 'a@n'  < ../inputs/temp-test/1402.inp.601.3 > ../outputs/t3058
    if diff ../outputs/t3058 ../originals/t3058 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3059) timeout -s 9 2 ../source/replace.exe '?[a-c]' 'b@t'  < ../inputs/temp-test/1374.inp.590.1 > ../outputs/t3059
    if diff ../outputs/t3059 ../originals/t3059 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3060) timeout -s 9 2 ../source/replace.exe '?[a-c]' 'b@t'  < ../inputs/temp-test/1375.inp.590.2 > ../outputs/t3060
    if diff ../outputs/t3060 ../originals/t3060 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3061) timeout -s 9 2 ../source/replace.exe '?[a-c]' 'b@t'  < ../inputs/temp-test/1376.inp.590.4 > ../outputs/t3061
    if diff ../outputs/t3061 ../originals/t3061 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3062) timeout -s 9 2 ../source/replace.exe '?[a-c]@**[a-c]^-]-[-' '@n'  < ../inputs/temp-test/2049.inp.869.1 > ../outputs/t3062
    if diff ../outputs/t3062 ../originals/t3062 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3063) timeout -s 9 2 ../source/replace.exe '?[a-c]@**[a-c]^-]-[-' '@n'  < ../inputs/temp-test/2050.inp.869.2 > ../outputs/t3063
    if diff ../outputs/t3063 ../originals/t3063 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3064) timeout -s 9 2 ../source/replace.exe '?[a-c]@**[a-c]^-]-[-' '@n'  < ../inputs/temp-test/2051.inp.869.3 > ../outputs/t3064
    if diff ../outputs/t3064 ../originals/t3064 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3065) timeout -s 9 2 ../source/replace.exe '?[a-c][^9-B][@n]?[^0-9]@[*' '@%@&'  < ../inputs/temp-test/879.inp.377.1 > ../outputs/t3065
    if diff ../outputs/t3065 ../originals/t3065 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3066) timeout -s 9 2 ../source/replace.exe '?[a-c][^9-B][@n]?[^0-9]@[*' '@%@&'  < ../inputs/temp-test/880.inp.377.2 > ../outputs/t3066
    if diff ../outputs/t3066 ../originals/t3066 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3067) timeout -s 9 2 ../source/replace.exe '?[z-}]' '|90(kN$NAi!EBr,N`fb z$>^0N9vz*r~*nQ'  < ../inputs/input/ruin.1948 > ../outputs/t3067
    if diff ../outputs/t3067 ../originals/t3067 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3068) timeout -s 9 2 ../source/replace.exe '?\ Ynh[' 'q'  < ../inputs/input/ruin.380 > ../outputs/t3068
    if diff ../outputs/t3068 ../originals/t3068 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3069) timeout -s 9 2 ../source/replace.exe '?\' ')NC*%tKb|GGjQi3YBgB"]ME3u<5gkf_ge*1>^@V,l4LjQ#t.Idoo@p<2,j9<*'\''&k}rabG\jnS |:Zd*Nx>3#/"zuTn$+QR\d'\'''  < ../inputs/input/ruin.714 > ../outputs/t3069
    if diff ../outputs/t3069 ../originals/t3069 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3070) timeout -s 9 2 ../source/replace.exe '?\;kn_j.:`F#' 'q'  < ../inputs/input/ruin.973 > ../outputs/t3070
    if diff ../outputs/t3070 ../originals/t3070 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3071) timeout -s 9 2 ../source/replace.exe '?\A0b' 'Z'  < ../inputs/input/ruin.1555 > ../outputs/t3071
    if diff ../outputs/t3071 ../originals/t3071 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3072) timeout -s 9 2 ../source/replace.exe '?\T<:#@@' '2'  < ../inputs/input/ruin.302 > ../outputs/t3072
    if diff ../outputs/t3072 ../originals/t3072 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3073) timeout -s 9 2 ../source/replace.exe '?\U\c-' '+Ts~{n:nQv'\''-zYVa/KpCq27"=/_jA{fR<aHFO%"c-1"'  < ../inputs/input/ruin.867 > ../outputs/t3073
    if diff ../outputs/t3073 ../originals/t3073 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3074) timeout -s 9 2 ../source/replace.exe '?\XK' 'vvy4-prHL@5G04oa\C[&1t2|kzQ2XdVNlgG{X.WlqnnQa(i^da!4HS<qTr5\I&feu*B '  < ../inputs/input/ruin.1016 > ../outputs/t3074
    if diff ../outputs/t3074 ../originals/t3074 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3075) timeout -s 9 2 ../source/replace.exe '?\Y+So' 'w'  < ../inputs/input/ruin.518 > ../outputs/t3075
    if diff ../outputs/t3075 ../originals/t3075 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3076) timeout -s 9 2 ../source/replace.exe '?\z"tEL.. ;9now' 'z'  < ../inputs/input/ruin.429 > ../outputs/t3076
    if diff ../outputs/t3076 ../originals/t3076 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3077) timeout -s 9 2 ../source/replace.exe '?][^0-9][@t[9-B]-[0-@][9-B]-[0-9][^0-9][@t9][^0-9@][9-B]-[0-9][^0-9][@t@][9-B]-[0-9][^0-9][@t]*[@t@][9-B]-*[0-9][^0-9][@][^0-9][@t[9-B]-[0-@][9-B]-[0-9][^0-9][@t9][^0-9@][9-B]-[0-9][^0-9][@t@][9-B]-[0-9][^0-9][@t]*[@t@][9-B]-*[0-9][^0-9][@' 'r'  < ../inputs/input/ruin.319 > ../outputs/t3077
    if diff ../outputs/t3077 ../originals/t3077 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3078) timeout -s 9 2 ../source/replace.exe '?]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,*5rY[0-9]*' 'C'  < ../inputs/input/ruin.1343 > ../outputs/t3078
    if diff ../outputs/t3078 ../originals/t3078 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3079) timeout -s 9 2 ../source/replace.exe '?^' '&'  < ../inputs/temp-test/576.inp.248.1 > ../outputs/t3079
    if diff ../outputs/t3079 ../originals/t3079 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3080) timeout -s 9 2 ../source/replace.exe '?^' '&'  < ../inputs/temp-test/577.inp.248.2 > ../outputs/t3080
    if diff ../outputs/t3080 ../originals/t3080 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3081) timeout -s 9 2 ../source/replace.exe '?^' ''  < ../inputs/temp-test/1886.inp.800.1 > ../outputs/t3081
    if diff ../outputs/t3081 ../originals/t3081 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3082) timeout -s 9 2 ../source/replace.exe '?^' ''  < ../inputs/temp-test/1887.inp.800.2 > ../outputs/t3082
    if diff ../outputs/t3082 ../originals/t3082 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3083) timeout -s 9 2 ../source/replace.exe '?^' '@%&a'  < ../inputs/temp-test/511.inp.223.1 > ../outputs/t3083
    if diff ../outputs/t3083 ../originals/t3083 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3084) timeout -s 9 2 ../source/replace.exe '?^' '@%&a'  < ../inputs/temp-test/512.inp.223.3 > ../outputs/t3084
    if diff ../outputs/t3084 ../originals/t3084 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3085) timeout -s 9 2 ../source/replace.exe '?^' 'NEW'  < ../inputs/temp-test/413.inp.182.1 > ../outputs/t3085
    if diff ../outputs/t3085 ../originals/t3085 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3086) timeout -s 9 2 ../source/replace.exe '?^' 'NEW'  < ../inputs/temp-test/414.inp.182.4 > ../outputs/t3086
    if diff ../outputs/t3086 ../originals/t3086 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3087) timeout -s 9 2 ../source/replace.exe '?^'  < ../inputs/temp-test/511.inp.223.1 > ../outputs/t3087
    if diff ../outputs/t3087 ../originals/t3087 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3088) timeout -s 9 2 ../source/replace.exe '?^*' '&a@%'  < ../inputs/temp-test/974.inp.420.1 > ../outputs/t3088
    if diff ../outputs/t3088 ../originals/t3088 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3089) timeout -s 9 2 ../source/replace.exe '?^*' '&a@%'  < ../inputs/temp-test/975.inp.420.2 > ../outputs/t3089
    if diff ../outputs/t3089 ../originals/t3089 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3090) timeout -s 9 2 ../source/replace.exe '?^*' '&a@%'  < ../inputs/temp-test/976.inp.420.4 > ../outputs/t3090
    if diff ../outputs/t3090 ../originals/t3090 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3091) timeout -s 9 2 ../source/replace.exe '?^*' 'NEW'  < ../inputs/temp-test/159.inp.72.1 > ../outputs/t3091
    if diff ../outputs/t3091 ../originals/t3091 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3092) timeout -s 9 2 ../source/replace.exe '?^*' 'NEW'  < ../inputs/temp-test/160.inp.72.2 > ../outputs/t3092
    if diff ../outputs/t3092 ../originals/t3092 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3093) timeout -s 9 2 ../source/replace.exe '?^*' 'NEW'  < ../inputs/temp-test/161.inp.72.3 > ../outputs/t3093
    if diff ../outputs/t3093 ../originals/t3093 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3094) timeout -s 9 2 ../source/replace.exe '?^*' 'a@n'  < ../inputs/temp-test/1240.inp.533.1 > ../outputs/t3094
    if diff ../outputs/t3094 ../originals/t3094 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3095) timeout -s 9 2 ../source/replace.exe '?^*' 'a@n'  < ../inputs/temp-test/1241.inp.533.2 > ../outputs/t3095
    if diff ../outputs/t3095 ../originals/t3095 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3096) timeout -s 9 2 ../source/replace.exe '?^*' 'a@nb@tc'  < ../inputs/temp-test/1718.inp.732.1 > ../outputs/t3096
    if diff ../outputs/t3096 ../originals/t3096 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3097) timeout -s 9 2 ../source/replace.exe '?^*' 'a@nb@tc'  < ../inputs/temp-test/1719.inp.732.2 > ../outputs/t3097
    if diff ../outputs/t3097 ../originals/t3097 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3098) timeout -s 9 2 ../source/replace.exe '?^*' 'a@nb@tc'  < ../inputs/temp-test/1720.inp.732.3 > ../outputs/t3098
    if diff ../outputs/t3098 ../originals/t3098 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3099) timeout -s 9 2 ../source/replace.exe '?^*-?-[a-c]' '&a@%'  < ../inputs/temp-test/909.inp.392.1 > ../outputs/t3099
    if diff ../outputs/t3099 ../originals/t3099 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3100) timeout -s 9 2 ../source/replace.exe '?^*-?-[a-c]' '&a@%'  < ../inputs/temp-test/910.inp.392.3 > ../outputs/t3100
    if diff ../outputs/t3100 ../originals/t3100 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3101) timeout -s 9 2 ../source/replace.exe '?^-] @**^*' '@%&a'  < ../inputs/temp-test/1319.inp.566.1 > ../outputs/t3101
    if diff ../outputs/t3101 ../originals/t3101 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3102) timeout -s 9 2 ../source/replace.exe '?^-] @**^*' '@%&a'  < ../inputs/temp-test/1320.inp.566.3 > ../outputs/t3102
    if diff ../outputs/t3102 ../originals/t3102 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3103) timeout -s 9 2 ../source/replace.exe '?^-]' 'a@nb@tc'  < ../inputs/temp-test/916.inp.395.1 > ../outputs/t3103
    if diff ../outputs/t3103 ../originals/t3103 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3104) timeout -s 9 2 ../source/replace.exe '?^-][0-9][^9-B][a--]-[9-B][^-^*' 'a&'  < ../inputs/temp-test/1257.inp.540.1 > ../outputs/t3104
    if diff ../outputs/t3104 ../originals/t3104 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3105) timeout -s 9 2 ../source/replace.exe '?^-][0-9][^9-B][a--]-[9-B][^-^*' 'a&'  < ../inputs/temp-test/1258.inp.540.3 > ../outputs/t3105
    if diff ../outputs/t3105 ../originals/t3105 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3106) timeout -s 9 2 ../source/replace.exe '?^?' 'a@n'  < ../inputs/temp-test/106.inp.48.1 > ../outputs/t3106
    if diff ../outputs/t3106 ../originals/t3106 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3107) timeout -s 9 2 ../source/replace.exe '?^?' 'a@n'  < ../inputs/temp-test/107.inp.48.3 > ../outputs/t3107
    if diff ../outputs/t3107 ../originals/t3107 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3108) timeout -s 9 2 ../source/replace.exe '?^?*' '&'  < ../inputs/temp-test/576.inp.248.1 > ../outputs/t3108
    if diff ../outputs/t3108 ../originals/t3108 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3109) timeout -s 9 2 ../source/replace.exe '?^[]' '@%&a'  < ../inputs/temp-test/511.inp.223.1 > ../outputs/t3109
    if diff ../outputs/t3109 ../originals/t3109 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3110) timeout -s 9 2 ../source/replace.exe '?^[]' '@%&a'  < ../inputs/temp-test/512.inp.223.3 > ../outputs/t3110
    if diff ../outputs/t3110 ../originals/t3110 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3111) timeout -s 9 2 ../source/replace.exe '?^[^]' '@%&a'  < ../inputs/temp-test/511.inp.223.1 > ../outputs/t3111
    if diff ../outputs/t3111 ../originals/t3111 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3112) timeout -s 9 2 ../source/replace.exe '?^[^]' '@%&a'  < ../inputs/temp-test/512.inp.223.3 > ../outputs/t3112
    if diff ../outputs/t3112 ../originals/t3112 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3113) timeout -s 9 2 ../source/replace.exe '?^[^]**' 'a'   < ../inputs/moni/f7.inp > ../outputs/t3113
    if diff ../outputs/t3113 ../originals/t3113 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3114) timeout -s 9 2 ../source/replace.exe '?^a-]' '@n'  < ../inputs/temp-test/244.inp.109.1 > ../outputs/t3114
    if diff ../outputs/t3114 ../originals/t3114 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3115) timeout -s 9 2 ../source/replace.exe '?^a-]' '@n'  < ../inputs/temp-test/245.inp.109.2 > ../outputs/t3115
    if diff ../outputs/t3115 ../originals/t3115 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3116) timeout -s 9 2 ../source/replace.exe '?^a-]@[*-[9-B]?$' 'a@n'  < ../inputs/temp-test/740.inp.317.8 > ../outputs/t3116
    if diff ../outputs/t3116 ../originals/t3116 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3117) timeout -s 9 2 ../source/replace.exe '?^a-]@[*-[9-B]?' 'a@n'  < ../inputs/temp-test/738.inp.317.1 > ../outputs/t3117
    if diff ../outputs/t3117 ../originals/t3117 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3118) timeout -s 9 2 ../source/replace.exe '?^a-]@[*-[9-B]?' 'a@n'  < ../inputs/temp-test/739.inp.317.2 > ../outputs/t3118
    if diff ../outputs/t3118 ../originals/t3118 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3119) timeout -s 9 2 ../source/replace.exe '?^a-c][0-9][^a-c][^9-B]-' '&a@%'  < ../inputs/temp-test/488.inp.213.1 > ../outputs/t3119
    if diff ../outputs/t3119 ../originals/t3119 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3120) timeout -s 9 2 ../source/replace.exe '?^a-c][0-9][^a-c][^9-B]-@' '&a@%'  < ../inputs/temp-test/488.inp.213.1 > ../outputs/t3120
    if diff ../outputs/t3120 ../originals/t3120 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3121) timeout -s 9 2 ../source/replace.exe '?^a-c][0-9][^a-c][^9-B]-@***' 'a'  < ../inputs/moni/f7.inp > ../outputs/t3121
    if diff ../outputs/t3121 ../originals/t3121 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3122) timeout -s 9 2 ../source/replace.exe '?a-]' 'a&'  < ../inputs/temp-test/1343.inp.577.1 > ../outputs/t3122
    if diff ../outputs/t3122 ../originals/t3122 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3123) timeout -s 9 2 ../source/replace.exe '?a-]' 'a&'  < ../inputs/temp-test/1344.inp.577.2 > ../outputs/t3123
    if diff ../outputs/t3123 ../originals/t3123 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3124) timeout -s 9 2 ../source/replace.exe '?a-c]' '@%&a'  < ../inputs/temp-test/115.inp.52.1 > ../outputs/t3124
    if diff ../outputs/t3124 ../originals/t3124 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3125) timeout -s 9 2 ../source/replace.exe '?c' 'hQ'  < ../inputs/input/ruin.1939 > ../outputs/t3125
    if diff ../outputs/t3125 ../originals/t3125 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3126) timeout -s 9 2 ../source/replace.exe '?c*' '@n'  < ../inputs/temp-test/349.inp.153.1 > ../outputs/t3126
    if diff ../outputs/t3126 ../originals/t3126 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3127) timeout -s 9 2 ../source/replace.exe '?c*@' '@n'  < ../inputs/temp-test/349.inp.153.1 > ../outputs/t3127
    if diff ../outputs/t3127 ../originals/t3127 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3128) timeout -s 9 2 ../source/replace.exe '?c?%-' '&'  < ../inputs/temp-test/2337.inp.992.1 > ../outputs/t3128
    if diff ../outputs/t3128 ../originals/t3128 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3129) timeout -s 9 2 ../source/replace.exe '?c?-' '&'  < ../inputs/temp-test/2337.inp.992.1 > ../outputs/t3129
    if diff ../outputs/t3129 ../originals/t3129 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3130) timeout -s 9 2 ../source/replace.exe '?c?[-z]??[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/1330.inp.571.1 > ../outputs/t3130
    if diff ../outputs/t3130 ../originals/t3130 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3131) timeout -s 9 2 ../source/replace.exe '?c?[-z]??[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/1331.inp.571.2 > ../outputs/t3131
    if diff ../outputs/t3131 ../originals/t3131 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3132) timeout -s 9 2 ../source/replace.exe '?c?[-z]??[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/1332.inp.571.3 > ../outputs/t3132
    if diff ../outputs/t3132 ../originals/t3132 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3133) timeout -s 9 2 ../source/replace.exe '?d' 'y1[qD'  < ../inputs/input/ruin.1594 > ../outputs/t3133
    if diff ../outputs/t3133 ../originals/t3133 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3134) timeout -s 9 2 ../source/replace.exe '?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?t]*[@t@][9-B]-*[0-9]][@t]*[@t@][9-B]t]*[@t@][9-B]-*[0-9]][?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?t]*[@t@][9-B]-*[0-9]][@t]*[@t@][9-B]t]*[@t@][9-B]-*[0-9]][@t]*[@t@][9-B]ddB]@t]*[@t@][9-B]' '5_edflj&5h8_DCEi.gTlx*L#a)htiLD2@W$74Vc.L'  < ../inputs/input/ruin.325 > ../outputs/t3134
    if diff ../outputs/t3134 ../originals/t3134 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3135) timeout -s 9 2 ../source/replace.exe '?n' 'C'  < ../inputs/input/ruin.1670 > ../outputs/t3135
    if diff ../outputs/t3135 ../originals/t3135 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3136) timeout -s 9 2 ../source/replace.exe '?p&y=3[ZYIgNLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1[0-9]A]TBk?[^0-9]*-*?* *[a' '8l;V'  < ../inputs/input/ruin.1337 > ../outputs/t3136
    if diff ../outputs/t3136 ../originals/t3136 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3137) timeout -s 9 2 ../source/replace.exe '?p&y=3[ZYp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIIgTBk[^9-B]-*?* *[a--' '$'  < ../inputs/input/ruin.1336 > ../outputs/t3137
    if diff ../outputs/t3137 ../originals/t3137 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3138) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c ][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9*]-[^9-B][a-c]?[^0-9]-*[^9-B][a-cYIgTBk' '~'  < ../inputs/input/ruin.1339 > ../outputs/t3138
    if diff ../outputs/t3138 ../originals/t3138 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3139) timeout -s 9 2 ../source/replace.exe '?p&y=3[Zp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIYIgTBk' '>b})}d%:+~EdJc2\! ug7;'  < ../inputs/input/ruin.1335 > ../outputs/t3139
    if diff ../outputs/t3139 ../originals/t3139 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3140) timeout -s 9 2 ../source/replace.exe '?s@t?' '9}(kMj8,~K9.I'  < ../inputs/input/ruin.855 > ../outputs/t3140
    if diff ../outputs/t3140 ../originals/t3140 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3141) timeout -s 9 2 ../source/replace.exe '?{?' '=El&\Ww]-4826L?@ )'\''W!>$'\'';W3DDU& vB%QGt;TIdL-& %kzJ($j5'  < ../inputs/input/ruin.1567 > ../outputs/t3141
    if diff ../outputs/t3141 ../originals/t3141 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3142) timeout -s 9 2 ../source/replace.exe '@ ' 'LYzt2J[^!8*s3wkF(7kj={f1KdN'  < ../inputs/input/ruin.1626 > ../outputs/t3142
    if diff ../outputs/t3142 ../originals/t3142 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3143) timeout -s 9 2 ../source/replace.exe '@ ' 'Y'  < ../inputs/input/ruin.1318 > ../outputs/t3143
    if diff ../outputs/t3143 ../originals/t3143 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3144) timeout -s 9 2 ../source/replace.exe '@ ' 'Z'  < ../inputs/input/ruin.1152 > ../outputs/t3144
    if diff ../outputs/t3144 ../originals/t3144 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3145) timeout -s 9 2 ../source/replace.exe '@!' 'A'  < ../inputs/input/ruin.1546 > ../outputs/t3145
    if diff ../outputs/t3145 ../originals/t3145 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3146) timeout -s 9 2 ../source/replace.exe '@"' '~Ar:2C'  < ../inputs/input/ruin.908 > ../outputs/t3146
    if diff ../outputs/t3146 ../originals/t3146 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3147) timeout -s 9 2 ../source/replace.exe '@"?#' 'J*wVzsbPX&iw, tX4$'  < ../inputs/input/ruin.1957 > ../outputs/t3147
    if diff ../outputs/t3147 ../originals/t3147 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3148) timeout -s 9 2 ../source/replace.exe '@#' '@n67@n67@n'  < ../inputs/moni/f8.inp > ../outputs/t3148
    if diff ../outputs/t3148 ../originals/t3148 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3149) timeout -s 9 2 ../source/replace.exe '@#' 'u-Yif5t-<fI/[&xp!_(>P}(pE'\''6KlTvB#W&0U.D#C0!\hR=[t,_-|{AnRT5kzG]#g}5-|1%u@)^v6\^125_]0%a~J*jd,'  < ../inputs/input/ruin.1544 > ../outputs/t3149
    if diff ../outputs/t3149 ../originals/t3149 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3150) timeout -s 9 2 ../source/replace.exe '@#' 'uQx4*M<}~q7\)}|N)OE]v'  < ../inputs/input/ruin.1095 > ../outputs/t3150
    if diff ../outputs/t3150 ../originals/t3150 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3151) timeout -s 9 2 ../source/replace.exe '@#^' '>*ed'  < ../inputs/input/ruin.1380 > ../outputs/t3151
    if diff ../outputs/t3151 ../originals/t3151 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3152) timeout -s 9 2 ../source/replace.exe '@%[0-9]' 'c'  < ../inputs/moni/f7.inp > ../outputs/t3152
    if diff ../outputs/t3152 ../originals/t3152 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3153) timeout -s 9 2 ../source/replace.exe '@' 'yy'  < ../inputs/moni/f7.inp > ../outputs/t3153
    if diff ../outputs/t3153 ../originals/t3153 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3154) timeout -s 9 2 ../source/replace.exe '@(@n' 'FJ%]J<C\vi'\''nOf*@"$tH7Z ^H{tf7'\''VpPME8 V'  < ../inputs/input/ruin.1376 > ../outputs/t3154
    if diff ../outputs/t3154 ../originals/t3154 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3155) timeout -s 9 2 ../source/replace.exe '@)' '81OA|~%qx8_p(~,NR#K(T@)'  < ../inputs/input/ruin.564 > ../outputs/t3155
    if diff ../outputs/t3155 ../originals/t3155 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3156) timeout -s 9 2 ../source/replace.exe '@)' 'VbA/Ln,%rHuw=~e/MCfA_C=`B/=]2"'\''&]{Gz/-'  < ../inputs/input/ruin.222 > ../outputs/t3156
    if diff ../outputs/t3156 ../originals/t3156 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3157) timeout -s 9 2 ../source/replace.exe '@*$'   < ../inputs/temp-test/198.inp.89.1 > ../outputs/t3157
    if diff ../outputs/t3157 ../originals/t3157 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3158) timeout -s 9 2 ../source/replace.exe '@*$' '@%@&'  < ../inputs/temp-test/1883.inp.798.8 > ../outputs/t3158
    if diff ../outputs/t3158 ../originals/t3158 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3159) timeout -s 9 2 ../source/replace.exe '@*' '&'  < ../inputs/temp-test/1333.inp.572.1 > ../outputs/t3159
    if diff ../outputs/t3159 ../originals/t3159 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3160) timeout -s 9 2 ../source/replace.exe '@*' '&'  < ../inputs/temp-test/1334.inp.572.3 > ../outputs/t3160
    if diff ../outputs/t3160 ../originals/t3160 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3161) timeout -s 9 2 ../source/replace.exe '@*' '@%@&'  < ../inputs/temp-test/1882.inp.798.1 > ../outputs/t3161
    if diff ../outputs/t3161 ../originals/t3161 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3162) timeout -s 9 2 ../source/replace.exe '@*' 'a@nb@tc'  < ../inputs/temp-test/427.inp.188.1 > ../outputs/t3162
    if diff ../outputs/t3162 ../originals/t3162 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3163) timeout -s 9 2 ../source/replace.exe '@*' 'a@nb@tc'  < ../inputs/temp-test/428.inp.188.3 > ../outputs/t3163
    if diff ../outputs/t3163 ../originals/t3163 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3164) timeout -s 9 2 ../source/replace.exe '@**$' 'a@n'  < ../inputs/temp-test/818.inp.352.6 > ../outputs/t3164
    if diff ../outputs/t3164 ../originals/t3164 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3165) timeout -s 9 2 ../source/replace.exe '@**' '&'  < ../inputs/temp-test/2146.inp.909.1 > ../outputs/t3165
    if diff ../outputs/t3165 ../originals/t3165 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3166) timeout -s 9 2 ../source/replace.exe '@**' '&'  < ../inputs/temp-test/2147.inp.909.2 > ../outputs/t3166
    if diff ../outputs/t3166 ../originals/t3166 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3167) timeout -s 9 2 ../source/replace.exe '@**' '@%&a'  < ../inputs/temp-test/1109.inp.477.1 > ../outputs/t3167
    if diff ../outputs/t3167 ../originals/t3167 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3168) timeout -s 9 2 ../source/replace.exe '@**' '@%&a'  < ../inputs/temp-test/1110.inp.477.2 > ../outputs/t3168
    if diff ../outputs/t3168 ../originals/t3168 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3169) timeout -s 9 2 ../source/replace.exe '@**' 'a&'  < ../inputs/temp-test/1338.inp.575.1 > ../outputs/t3169
    if diff ../outputs/t3169 ../originals/t3169 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3170) timeout -s 9 2 ../source/replace.exe '@**' 'a&'  < ../inputs/temp-test/1339.inp.575.3 > ../outputs/t3170
    if diff ../outputs/t3170 ../originals/t3170 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3171) timeout -s 9 2 ../source/replace.exe '@**' 'a@n'  < ../inputs/temp-test/817.inp.352.1 > ../outputs/t3171
    if diff ../outputs/t3171 ../originals/t3171 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3172) timeout -s 9 2 ../source/replace.exe '@**-' '&a@%'  < ../inputs/temp-test/134.inp.63.1 > ../outputs/t3172
    if diff ../outputs/t3172 ../originals/t3172 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3173) timeout -s 9 2 ../source/replace.exe '@**-' '&a@%'  < ../inputs/temp-test/135.inp.63.3 > ../outputs/t3173
    if diff ../outputs/t3173 ../originals/t3173 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3174) timeout -s 9 2 ../source/replace.exe '@**-' '@t'  < ../inputs/temp-test/1490.inp.639.1 > ../outputs/t3174
    if diff ../outputs/t3174 ../originals/t3174 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3175) timeout -s 9 2 ../source/replace.exe '@**-' '@t'  < ../inputs/temp-test/1491.inp.639.2 > ../outputs/t3175
    if diff ../outputs/t3175 ../originals/t3175 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3176) timeout -s 9 2 ../source/replace.exe '@**-' '@t'  < ../inputs/temp-test/1860.inp.789.1 > ../outputs/t3176
    if diff ../outputs/t3176 ../originals/t3176 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3177) timeout -s 9 2 ../source/replace.exe '@**-' '@t'  < ../inputs/temp-test/1861.inp.789.3 > ../outputs/t3177
    if diff ../outputs/t3177 ../originals/t3177 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3178) timeout -s 9 2 ../source/replace.exe '@**--[0-9]?a-c][^-' '&'  < ../inputs/temp-test/278.inp.125.1 > ../outputs/t3178
    if diff ../outputs/t3178 ../originals/t3178 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3179) timeout -s 9 2 ../source/replace.exe '@**--[0-9]?a-c][^-' '&'  < ../inputs/temp-test/279.inp.125.2 > ../outputs/t3179
    if diff ../outputs/t3179 ../originals/t3179 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3180) timeout -s 9 2 ../source/replace.exe '@**?' '&a@%'  < ../inputs/temp-test/2046.inp.868.1 > ../outputs/t3180
    if diff ../outputs/t3180 ../originals/t3180 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3181) timeout -s 9 2 ../source/replace.exe '@**?' '&a@%'  < ../inputs/temp-test/2047.inp.868.2 > ../outputs/t3181
    if diff ../outputs/t3181 ../originals/t3181 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3182) timeout -s 9 2 ../source/replace.exe '@**?' '&a@%'  < ../inputs/temp-test/2048.inp.868.3 > ../outputs/t3182
    if diff ../outputs/t3182 ../originals/t3182 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3183) timeout -s 9 2 ../source/replace.exe '@**?' ''  < ../inputs/temp-test/929.inp.401.1 > ../outputs/t3183
    if diff ../outputs/t3183 ../originals/t3183 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3184) timeout -s 9 2 ../source/replace.exe '@**?' ''  < ../inputs/temp-test/930.inp.401.2 > ../outputs/t3184
    if diff ../outputs/t3184 ../originals/t3184 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3185) timeout -s 9 2 ../source/replace.exe '@**?' ''  < ../inputs/temp-test/931.inp.401.3 > ../outputs/t3185
    if diff ../outputs/t3185 ../originals/t3185 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3186) timeout -s 9 2 ../source/replace.exe '@**?' 'a&'  < ../inputs/temp-test/2037.inp.864.1 > ../outputs/t3186
    if diff ../outputs/t3186 ../originals/t3186 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3187) timeout -s 9 2 ../source/replace.exe '@**?' 'a&'  < ../inputs/temp-test/2038.inp.864.2 > ../outputs/t3187
    if diff ../outputs/t3187 ../originals/t3187 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3188) timeout -s 9 2 ../source/replace.exe '@**?' 'a&'  < ../inputs/temp-test/2039.inp.864.3 > ../outputs/t3188
    if diff ../outputs/t3188 ../originals/t3188 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3189) timeout -s 9 2 ../source/replace.exe '@**?' 'a@n'  < ../inputs/temp-test/867.inp.373.1 > ../outputs/t3189
    if diff ../outputs/t3189 ../originals/t3189 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3190) timeout -s 9 2 ../source/replace.exe '@**?' 'a@n'  < ../inputs/temp-test/868.inp.373.2 > ../outputs/t3190
    if diff ../outputs/t3190 ../originals/t3190 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3191) timeout -s 9 2 ../source/replace.exe '@**?' 'a@n'  < ../inputs/temp-test/869.inp.373.3 > ../outputs/t3191
    if diff ../outputs/t3191 ../originals/t3191 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3192) timeout -s 9 2 ../source/replace.exe '@**?' 'a@n'  < ../inputs/temp-test/870.inp.373.4 > ../outputs/t3192
    if diff ../outputs/t3192 ../originals/t3192 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3193) timeout -s 9 2 ../source/replace.exe '@**?' 'b@t'  < ../inputs/temp-test/2179.inp.922.1 > ../outputs/t3193
    if diff ../outputs/t3193 ../originals/t3193 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3194) timeout -s 9 2 ../source/replace.exe '@**?' 'b@t'  < ../inputs/temp-test/2180.inp.922.2 > ../outputs/t3194
    if diff ../outputs/t3194 ../originals/t3194 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3195) timeout -s 9 2 ../source/replace.exe '@**?' 'b@t'  < ../inputs/temp-test/2181.inp.922.3 > ../outputs/t3195
    if diff ../outputs/t3195 ../originals/t3195 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3196) timeout -s 9 2 ../source/replace.exe '@**[^0-9][9-B]?' '&a@%'  < ../inputs/temp-test/1270.inp.545.1 > ../outputs/t3196
    if diff ../outputs/t3196 ../originals/t3196 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3197) timeout -s 9 2 ../source/replace.exe '@**[^9-B]$' '@t'  < ../inputs/temp-test/1946.inp.826.6 > ../outputs/t3197
    if diff ../outputs/t3197 ../originals/t3197 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3198) timeout -s 9 2 ../source/replace.exe '@**[^9-B]' '@t'  < ../inputs/temp-test/1944.inp.826.1 > ../outputs/t3198
    if diff ../outputs/t3198 ../originals/t3198 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3199) timeout -s 9 2 ../source/replace.exe '@**[^9-B]' '@t'  < ../inputs/temp-test/1945.inp.826.2 > ../outputs/t3199
    if diff ../outputs/t3199 ../originals/t3199 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3200) timeout -s 9 2 ../source/replace.exe '@**[^a-]-*-[-?@** *- ?$' 'a@nb@tc'  < ../inputs/temp-test/2071.inp.877.6 > ../outputs/t3200
    if diff ../outputs/t3200 ../originals/t3200 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3201) timeout -s 9 2 ../source/replace.exe '@**[^a-]-*-[-?@** *- ?' 'a@nb@tc'  < ../inputs/temp-test/2068.inp.877.1 > ../outputs/t3201
    if diff ../outputs/t3201 ../originals/t3201 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3202) timeout -s 9 2 ../source/replace.exe '@**[^a-]-*-[-?@** *- ?' 'a@nb@tc'  < ../inputs/temp-test/2069.inp.877.2 > ../outputs/t3202
    if diff ../outputs/t3202 ../originals/t3202 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3203) timeout -s 9 2 ../source/replace.exe '@**[^a-]-*-[-?@** *- ?' 'a@nb@tc'  < ../inputs/temp-test/2070.inp.877.3 > ../outputs/t3203
    if diff ../outputs/t3203 ../originals/t3203 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3204) timeout -s 9 2 ../source/replace.exe '@**a-c][^@t]-??a-c]?-$' '@%&a'  < ../inputs/temp-test/1565.inp.668.6 > ../outputs/t3204
    if diff ../outputs/t3204 ../originals/t3204 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3205) timeout -s 9 2 ../source/replace.exe '@**a-c][^@t]-??a-c]?-' '@%&a'  < ../inputs/temp-test/1562.inp.668.1 > ../outputs/t3205
    if diff ../outputs/t3205 ../originals/t3205 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3206) timeout -s 9 2 ../source/replace.exe '@**a-c][^@t]-??a-c]?-' '@%&a'  < ../inputs/temp-test/1563.inp.668.2 > ../outputs/t3206
    if diff ../outputs/t3206 ../originals/t3206 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3207) timeout -s 9 2 ../source/replace.exe '@**a-c][^@t]-??a-c]?-' '@%&a'  < ../inputs/temp-test/1564.inp.668.3 > ../outputs/t3207
    if diff ../outputs/t3207 ../originals/t3207 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3208) timeout -s 9 2 ../source/replace.exe '@*-' '&'  < ../inputs/temp-test/225.inp.101.1 > ../outputs/t3208
    if diff ../outputs/t3208 ../originals/t3208 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3209) timeout -s 9 2 ../source/replace.exe '@*-' '&'  < ../inputs/temp-test/226.inp.101.2 > ../outputs/t3209
    if diff ../outputs/t3209 ../originals/t3209 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3210) timeout -s 9 2 ../source/replace.exe '@*-' '&'  < ../inputs/temp-test/227.inp.101.3 > ../outputs/t3210
    if diff ../outputs/t3210 ../originals/t3210 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3211) timeout -s 9 2 ../source/replace.exe '@*-' '@n'  < ../inputs/temp-test/1596.inp.679.1 > ../outputs/t3211
    if diff ../outputs/t3211 ../originals/t3211 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3212) timeout -s 9 2 ../source/replace.exe '@*-' '@n'  < ../inputs/temp-test/1597.inp.679.3 > ../outputs/t3212
    if diff ../outputs/t3212 ../originals/t3212 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3213) timeout -s 9 2 ../source/replace.exe '@*-?[^a-c-[0-9][0-9]@[?[a-?[-' '@%&a'  < ../inputs/temp-test/432.inp.190.1 > ../outputs/t3213
    if diff ../outputs/t3213 ../originals/t3213 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3214) timeout -s 9 2 ../source/replace.exe '@*-?[^a-c-[0-9][0-9]@[?[a-?[-' '@%&a'  < ../inputs/temp-test/433.inp.190.2 > ../outputs/t3214
    if diff ../outputs/t3214 ../originals/t3214 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3215) timeout -s 9 2 ../source/replace.exe '@*-[^0-9]-@[[^a-c] ' 'NEW'  < ../inputs/temp-test/1486.inp.638.1 > ../outputs/t3215
    if diff ../outputs/t3215 ../originals/t3215 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3216) timeout -s 9 2 ../source/replace.exe '@*-[^0-9]-@[[^a-c] ' 'NEW'  < ../inputs/temp-test/1487.inp.638.2 > ../outputs/t3216
    if diff ../outputs/t3216 ../originals/t3216 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3217) timeout -s 9 2 ../source/replace.exe '@*-[^0-9]-@[[^a-c] ' 'NEW'  < ../inputs/temp-test/1488.inp.638.3 > ../outputs/t3217
    if diff ../outputs/t3217 ../originals/t3217 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3218) timeout -s 9 2 ../source/replace.exe '@*?'   < ../inputs/temp-test/198.inp.89.1 > ../outputs/t3218
    if diff ../outputs/t3218 ../originals/t3218 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3219) timeout -s 9 2 ../source/replace.exe '@*?' '&@n'  < ../inputs/temp-test/198.inp.89.1 > ../outputs/t3219
    if diff ../outputs/t3219 ../originals/t3219 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3220) timeout -s 9 2 ../source/replace.exe '@*?' '@%&a'  < ../inputs/temp-test/198.inp.89.1 > ../outputs/t3220
    if diff ../outputs/t3220 ../originals/t3220 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3221) timeout -s 9 2 ../source/replace.exe '@*?'  < ../inputs/temp-test/198.inp.89.1 > ../outputs/t3221
    if diff ../outputs/t3221 ../originals/t3221 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3222) timeout -s 9 2 ../source/replace.exe '@*?[]' '@%&a'  < ../inputs/temp-test/198.inp.89.1 > ../outputs/t3222
    if diff ../outputs/t3222 ../originals/t3222 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3223) timeout -s 9 2 ../source/replace.exe '@*?[^]' '@%&a'  < ../inputs/temp-test/198.inp.89.1 > ../outputs/t3223
    if diff ../outputs/t3223 ../originals/t3223 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3224) timeout -s 9 2 ../source/replace.exe '@*[0-9]??-^*^??@[*' ''  < ../inputs/temp-test/63.inp.27.1 > ../outputs/t3224
    if diff ../outputs/t3224 ../originals/t3224 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3225) timeout -s 9 2 ../source/replace.exe '@*[^0-9]' '&'  < ../inputs/temp-test/1935.inp.823.1 > ../outputs/t3225
    if diff ../outputs/t3225 ../originals/t3225 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3226) timeout -s 9 2 ../source/replace.exe '@*[^0-9]' '&'  < ../inputs/temp-test/1936.inp.823.3 > ../outputs/t3226
    if diff ../outputs/t3226 ../originals/t3226 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3227) timeout -s 9 2 ../source/replace.exe '@*[^0-9]' '@%&a'  < ../inputs/temp-test/888.inp.382.1 > ../outputs/t3227
    if diff ../outputs/t3227 ../originals/t3227 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3228) timeout -s 9 2 ../source/replace.exe '@*[^0-9]' '@%&a'  < ../inputs/temp-test/889.inp.382.2 > ../outputs/t3228
    if diff ../outputs/t3228 ../originals/t3228 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3229) timeout -s 9 2 ../source/replace.exe '@*[^a-c]?- ^a-c]' '&a@%'  < ../inputs/temp-test/2122.inp.900.1 > ../outputs/t3229
    if diff ../outputs/t3229 ../originals/t3229 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3230) timeout -s 9 2 ../source/replace.exe '@*[^a-c]?- ^a-c]' '&a@%'  < ../inputs/temp-test/2123.inp.900.2 > ../outputs/t3230
    if diff ../outputs/t3230 ../originals/t3230 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3231) timeout -s 9 2 ../source/replace.exe '@*[^a-c]?- ^a-c]' '&a@%'  < ../inputs/temp-test/2124.inp.900.3 > ../outputs/t3231
    if diff ../outputs/t3231 ../originals/t3231 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3232) timeout -s 9 2 ../source/replace.exe '@*^a-]' '@n'  < ../inputs/temp-test/2243.inp.951.1 > ../outputs/t3232
    if diff ../outputs/t3232 ../originals/t3232 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3233) timeout -s 9 2 ../source/replace.exe '@+' 'd;'  < ../inputs/input/ruin.1976 > ../outputs/t3233
    if diff ../outputs/t3233 ../originals/t3233 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3234) timeout -s 9 2 ../source/replace.exe '@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}[^0-9]'\''*' 'j'  < ../inputs/input/ruin.1346 > ../outputs/t3234
    if diff ../outputs/t3234 ../originals/t3234 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3235) timeout -s 9 2 ../source/replace.exe '@-' '-'  < ../inputs/input/ruin.1578 > ../outputs/t3235
    if diff ../outputs/t3235 ../originals/t3235 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3236) timeout -s 9 2 ../source/replace.exe '@-' 'R'  < ../inputs/input/ruin.1456 > ../outputs/t3236
    if diff ../outputs/t3236 ../originals/t3236 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3237) timeout -s 9 2 ../source/replace.exe '@-' 'h'  < ../inputs/input/ruin.161 > ../outputs/t3237
    if diff ../outputs/t3237 ../originals/t3237 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3238) timeout -s 9 2 ../source/replace.exe '@/' 'T@cm!x`moJfN/%|*mK7oWn#ZE%z'  < ../inputs/input/ruin.1491 > ../outputs/t3238
    if diff ../outputs/t3238 ../originals/t3238 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3239) timeout -s 9 2 ../source/replace.exe '@3[^Z-a]^_`a]' '_y'  < ../inputs/input/ruin.1748 > ../outputs/t3239
    if diff ../outputs/t3239 ../originals/t3239 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3240) timeout -s 9 2 ../source/replace.exe '@5' '4Q'  < ../inputs/input/ruin.80 > ../outputs/t3240
    if diff ../outputs/t3240 ../originals/t3240 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3241) timeout -s 9 2 ../source/replace.exe '@5' 'V'  < ../inputs/input/ruin.125 > ../outputs/t3241
    if diff ../outputs/t3241 ../originals/t3241 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3242) timeout -s 9 2 ../source/replace.exe '@6' 'K'  < ../inputs/input/ruin.1323 > ../outputs/t3242
    if diff ../outputs/t3242 ../originals/t3242 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3243) timeout -s 9 2 ../source/replace.exe '@6' 'Y~83>~^O_'  < ../inputs/input/ruin.1747 > ../outputs/t3243
    if diff ../outputs/t3243 ../originals/t3243 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3244) timeout -s 9 2 ../source/replace.exe '@8'\''Z' '2xl#kq'  < ../inputs/input/ruin.1419 > ../outputs/t3244
    if diff ../outputs/t3244 ../originals/t3244 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3245) timeout -s 9 2 ../source/replace.exe '@;$' '+W}](~9#6;Go0J- XybH&<\0E$9'  < ../inputs/input/ruin.8 > ../outputs/t3245
    if diff ../outputs/t3245 ../originals/t3245 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3246) timeout -s 9 2 ../source/replace.exe '@;' 'p8-lf,m\V=UixymxlH&eP|nwsDhhN(Hcv4 CV$Gmbi'  < ../inputs/input/ruin.1087 > ../outputs/t3246
    if diff ../outputs/t3246 ../originals/t3246 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3247) timeout -s 9 2 ../source/replace.exe '@=' '`'  < ../inputs/input/ruin.45 > ../outputs/t3247
    if diff ../outputs/t3247 ../originals/t3247 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3248) timeout -s 9 2 ../source/replace.exe '@=*' ':\>jX/&//[~9HI.'\''XsWI!6Hav8e`?^Ut6D;zZpJ*\KB2X5*AcRB}pcAc2>EMpaM,=Ad>a$t>2J{6`5VDe{DRw:Lg>\U]wKK/6Y<q%A8mn]@'  < ../inputs/input/ruin.1174 > ../outputs/t3248
    if diff ../outputs/t3248 ../originals/t3248 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3249) timeout -s 9 2 ../source/replace.exe '@>' 's'  < ../inputs/input/ruin.489 > ../outputs/t3249
    if diff ../outputs/t3249 ../originals/t3249 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3250) timeout -s 9 2 ../source/replace.exe '@@$' '$GBp}{JWTz=SgS`X@>='  < ../inputs/input/ruin.1905 > ../outputs/t3250
    if diff ../outputs/t3250 ../originals/t3250 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3251) timeout -s 9 2 ../source/replace.exe '@@$' '>v}~0g-swC7?z'  < ../inputs/input/ruin.716 > ../outputs/t3251
    if diff ../outputs/t3251 ../originals/t3251 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3252) timeout -s 9 2 ../source/replace.exe '@@$' 'D'  < ../inputs/input/ruin.1943 > ../outputs/t3252
    if diff ../outputs/t3252 ../originals/t3252 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3253) timeout -s 9 2 ../source/replace.exe '@@$' 'O) !V9ey{hoM\gUNi|0JP@&Jj?5|^C9Se2{-V5'  < ../inputs/input/ruin.562 > ../outputs/t3253
    if diff ../outputs/t3253 ../originals/t3253 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3254) timeout -s 9 2 ../source/replace.exe '@@$' 'PBR#i29%`I}+1Y|@Wa.H@G)Vm<-Y\smAI'  < ../inputs/input/ruin.514 > ../outputs/t3254
    if diff ../outputs/t3254 ../originals/t3254 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3255) timeout -s 9 2 ../source/replace.exe '@@$' 'Wm'  < ../inputs/input/ruin.1684 > ../outputs/t3255
    if diff ../outputs/t3255 ../originals/t3255 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3256) timeout -s 9 2 ../source/replace.exe '@@$' '['  < ../inputs/input/ruin.1282 > ../outputs/t3256
    if diff ../outputs/t3256 ../originals/t3256 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3257) timeout -s 9 2 ../source/replace.exe '@@$' ']Jd2(Pk"IOH.'  < ../inputs/input/ruin.1214 > ../outputs/t3257
    if diff ../outputs/t3257 ../originals/t3257 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3258) timeout -s 9 2 ../source/replace.exe '@@$' '`'  < ../inputs/input/ruin.20 > ../outputs/t3258
    if diff ../outputs/t3258 ../originals/t3258 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3259) timeout -s 9 2 ../source/replace.exe '@@$' 'f'  < ../inputs/input/ruin.436 > ../outputs/t3259
    if diff ../outputs/t3259 ../originals/t3259 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3260) timeout -s 9 2 ../source/replace.exe '@@$' 'pe&:zop_%'  < ../inputs/input/ruin.176 > ../outputs/t3260
    if diff ../outputs/t3260 ../originals/t3260 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3261) timeout -s 9 2 ../source/replace.exe '@@$' 'q'  < ../inputs/input/ruin.573 > ../outputs/t3261
    if diff ../outputs/t3261 ../originals/t3261 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3262) timeout -s 9 2 ../source/replace.exe '@@'   < ../inputs/input/ruin.1155 > ../outputs/t3262
    if diff ../outputs/t3262 ../originals/t3262 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3263) timeout -s 9 2 ../source/replace.exe '@@'   < ../inputs/input/ruin.1267 > ../outputs/t3263
    if diff ../outputs/t3263 ../originals/t3263 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3264) timeout -s 9 2 ../source/replace.exe '@@' ' '  < ../inputs/input/ruin.1636 > ../outputs/t3264
    if diff ../outputs/t3264 ../originals/t3264 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3265) timeout -s 9 2 ../source/replace.exe '@@' ' '  < ../inputs/input/ruin.686 > ../outputs/t3265
    if diff ../outputs/t3265 ../originals/t3265 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3266) timeout -s 9 2 ../source/replace.exe '@@' ' /'  < ../inputs/input/ruin.1716 > ../outputs/t3266
    if diff ../outputs/t3266 ../originals/t3266 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3267) timeout -s 9 2 ../source/replace.exe '@@' ' F]~M\ Wz]`M0)y8H?fc7Phqi}@,5rYP"hqRx 1etW9vEs|~'\'' d~'  < ../inputs/input/ruin.150 > ../outputs/t3267
    if diff ../outputs/t3267 ../originals/t3267 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3268) timeout -s 9 2 ../source/replace.exe '@@' ' Hq8<5u8KNy,8KNy,h0_sbVxG=nOfh0_sbVxG=nO8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOffj@{,j17KHl}%a1`PZ!Ur5'\'''  < ../inputs/input/ruin.1038 > ../outputs/t3268
    if diff ../outputs/t3268 ../originals/t3268 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3269) timeout -s 9 2 ../source/replace.exe '@@' ' Hq8<5u8KNy,h0_sbVxG=nOfj@{,j17KHl}%a1`PZ!Ur5'\'''  < ../inputs/input/ruin.1038 > ../outputs/t3269
    if diff ../outputs/t3269 ../originals/t3269 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3270) timeout -s 9 2 ../source/replace.exe '@@' ' eA[pOJ,7}LP=PljrA&m['  < ../inputs/input/ruin.1694 > ../outputs/t3270
    if diff ../outputs/t3270 ../originals/t3270 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3271) timeout -s 9 2 ../source/replace.exe '@@' ' ql3hT_RR%Lv0q{gNA7dFL!iUJk>g$ ~-0ON!BAyv'  < ../inputs/input/ruin.1806 > ../outputs/t3271
    if diff ../outputs/t3271 ../originals/t3271 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3272) timeout -s 9 2 ../source/replace.exe '@@' ' vCcJyA'\''Kn0%'  < ../inputs/input/ruin.409 > ../outputs/t3272
    if diff ../outputs/t3272 ../originals/t3272 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3273) timeout -s 9 2 ../source/replace.exe '@@' '!'  < ../inputs/input/ruin.793 > ../outputs/t3273
    if diff ../outputs/t3273 ../originals/t3273 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3274) timeout -s 9 2 ../source/replace.exe '@@' '!dX:TvVOl,/?nB/ .p(8CF07J&%csQb,NtUE)AX"4&&=Kk"Fc4'  < ../inputs/input/ruin.196 > ../outputs/t3274
    if diff ../outputs/t3274 ../originals/t3274 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3275) timeout -s 9 2 ../source/replace.exe '@@' '!t1D*'\''"z%6'  < ../inputs/input/ruin.1711 > ../outputs/t3275
    if diff ../outputs/t3275 ../originals/t3275 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3276) timeout -s 9 2 ../source/replace.exe '@@' '"%Xq:5!?SA^^.)RRV1-^^t;_'  < ../inputs/input/ruin.606 > ../outputs/t3276
    if diff ../outputs/t3276 ../originals/t3276 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3277) timeout -s 9 2 ../source/replace.exe '@@' '")sV\0['  < ../inputs/input/ruin.482 > ../outputs/t3277
    if diff ../outputs/t3277 ../originals/t3277 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3278) timeout -s 9 2 ../source/replace.exe '@@' '"3<U{'  < ../inputs/input/ruin.41 > ../outputs/t3278
    if diff ../outputs/t3278 ../originals/t3278 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3279) timeout -s 9 2 ../source/replace.exe '@@' '"sk}D$r4U?mR|,'  < ../inputs/input/ruin.542 > ../outputs/t3279
    if diff ../outputs/t3279 ../originals/t3279 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3280) timeout -s 9 2 ../source/replace.exe '@@' '#'  < ../inputs/input/ruin.1116 > ../outputs/t3280
    if diff ../outputs/t3280 ../originals/t3280 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3281) timeout -s 9 2 ../source/replace.exe '@@' '#'  < ../inputs/input/ruin.1615 > ../outputs/t3281
    if diff ../outputs/t3281 ../originals/t3281 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3282) timeout -s 9 2 ../source/replace.exe '@@' '#'  < ../inputs/input/ruin.577 > ../outputs/t3282
    if diff ../outputs/t3282 ../originals/t3282 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3283) timeout -s 9 2 ../source/replace.exe '@@' '$'  < ../inputs/input/ruin.120 > ../outputs/t3283
    if diff ../outputs/t3283 ../originals/t3283 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3284) timeout -s 9 2 ../source/replace.exe '@@' '$'  < ../inputs/input/ruin.188 > ../outputs/t3284
    if diff ../outputs/t3284 ../originals/t3284 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3285) timeout -s 9 2 ../source/replace.exe '@@' '$'\'''  < ../inputs/input/ruin.390 > ../outputs/t3285
    if diff ../outputs/t3285 ../originals/t3285 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3286) timeout -s 9 2 ../source/replace.exe '@@' '%'  < ../inputs/input/ruin.1413 > ../outputs/t3286
    if diff ../outputs/t3286 ../originals/t3286 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3287) timeout -s 9 2 ../source/replace.exe '@@' '%'  < ../inputs/input/ruin.149 > ../outputs/t3287
    if diff ../outputs/t3287 ../originals/t3287 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3288) timeout -s 9 2 ../source/replace.exe '@@' '& +b2m'  < ../inputs/input/ruin.687 > ../outputs/t3288
    if diff ../outputs/t3288 ../originals/t3288 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3289) timeout -s 9 2 ../source/replace.exe '@@' '&'  < ../inputs/input/ruin.1513 > ../outputs/t3289
    if diff ../outputs/t3289 ../originals/t3289 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3290) timeout -s 9 2 ../source/replace.exe '@@' '&'  < ../inputs/input/ruin.370 > ../outputs/t3290
    if diff ../outputs/t3290 ../originals/t3290 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3291) timeout -s 9 2 ../source/replace.exe '@@' '&'  < ../inputs/input/ruin.846 > ../outputs/t3291
    if diff ../outputs/t3291 ../originals/t3291 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3292) timeout -s 9 2 ../source/replace.exe '@@' ''  < ../inputs/input/ruin.139 > ../outputs/t3292
    if diff ../outputs/t3292 ../originals/t3292 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3293) timeout -s 9 2 ../source/replace.exe '@@' ''  < ../inputs/input/ruin.162 > ../outputs/t3293
    if diff ../outputs/t3293 ../originals/t3293 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3294) timeout -s 9 2 ../source/replace.exe '@@' ''  < ../inputs/input/ruin.164 > ../outputs/t3294
    if diff ../outputs/t3294 ../originals/t3294 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3295) timeout -s 9 2 ../source/replace.exe '@@' ''  < ../inputs/input/ruin.1854 > ../outputs/t3295
    if diff ../outputs/t3295 ../originals/t3295 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3296) timeout -s 9 2 ../source/replace.exe '@@' ''  < ../inputs/input/ruin.1900 > ../outputs/t3296
    if diff ../outputs/t3296 ../originals/t3296 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3297) timeout -s 9 2 ../source/replace.exe '@@' ''  < ../inputs/input/ruin.1916 > ../outputs/t3297
    if diff ../outputs/t3297 ../originals/t3297 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3298) timeout -s 9 2 ../source/replace.exe '@@' ''  < ../inputs/input/ruin.438 > ../outputs/t3298
    if diff ../outputs/t3298 ../originals/t3298 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3299) timeout -s 9 2 ../source/replace.exe '@@' ''  < ../inputs/input/ruin.464 > ../outputs/t3299
    if diff ../outputs/t3299 ../originals/t3299 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3300) timeout -s 9 2 ../source/replace.exe '@@' ''\''5.dxDo+'  < ../inputs/input/ruin.1515 > ../outputs/t3300
    if diff ../outputs/t3300 ../originals/t3300 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3301) timeout -s 9 2 ../source/replace.exe '@@' ''\''8>j9I}4)QUOhBL" 5dZjR4'  < ../inputs/input/ruin.1585 > ../outputs/t3301
    if diff ../outputs/t3301 ../originals/t3301 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3302) timeout -s 9 2 ../source/replace.exe '@@' ''\''rtrI}1h*1@x316=8F1Wi(\8ug'  < ../inputs/input/ruin.875 > ../outputs/t3302
    if diff ../outputs/t3302 ../originals/t3302 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3303) timeout -s 9 2 ../source/replace.exe '@@' '('  < ../inputs/input/ruin.1048 > ../outputs/t3303
    if diff ../outputs/t3303 ../originals/t3303 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3304) timeout -s 9 2 ../source/replace.exe '@@' '('  < ../inputs/input/ruin.1560 > ../outputs/t3304
    if diff ../outputs/t3304 ../originals/t3304 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3305) timeout -s 9 2 ../source/replace.exe '@@' '('  < ../inputs/input/ruin.676 > ../outputs/t3305
    if diff ../outputs/t3305 ../originals/t3305 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3306) timeout -s 9 2 ../source/replace.exe '@@' '(o?j~tj7Bh6Rwj`\Vz+SK5cd"fP'  < ../inputs/input/ruin.1892 > ../outputs/t3306
    if diff ../outputs/t3306 ../originals/t3306 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3307) timeout -s 9 2 ../source/replace.exe '@@' ')'  < ../inputs/input/ruin.1547 > ../outputs/t3307
    if diff ../outputs/t3307 ../originals/t3307 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3308) timeout -s 9 2 ../source/replace.exe '@@' ')R6,%8x[%~*u|X\vt&wTaRd|20Ev'\''P'  < ../inputs/input/ruin.33 > ../outputs/t3308
    if diff ../outputs/t3308 ../originals/t3308 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3309) timeout -s 9 2 ../source/replace.exe '@@' '*'  < ../inputs/input/ruin.1525 > ../outputs/t3309
    if diff ../outputs/t3309 ../originals/t3309 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3310) timeout -s 9 2 ../source/replace.exe '@@' '*osp7hY,{a9W&a^b_80b]=AP]j+Sj />k""Ur|HMFY{=7/cW7!37`X'  < ../inputs/input/ruin.599 > ../outputs/t3310
    if diff ../outputs/t3310 ../originals/t3310 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3311) timeout -s 9 2 ../source/replace.exe '@@' '*pv%'  < ../inputs/input/ruin.634 > ../outputs/t3311
    if diff ../outputs/t3311 ../originals/t3311 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3312) timeout -s 9 2 ../source/replace.exe '@@' '*q61|R0fcYH+ZzxA_ '  < ../inputs/input/ruin.797 > ../outputs/t3312
    if diff ../outputs/t3312 ../originals/t3312 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3313) timeout -s 9 2 ../source/replace.exe '@@' '*w`tU@YLlA}c4u,btKqp(!'\''u)e%pb~'  < ../inputs/input/ruin.312 > ../outputs/t3313
    if diff ../outputs/t3313 ../originals/t3313 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3314) timeout -s 9 2 ../source/replace.exe '@@' '+'  < ../inputs/input/ruin.1338 > ../outputs/t3314
    if diff ../outputs/t3314 ../originals/t3314 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3315) timeout -s 9 2 ../source/replace.exe '@@' '+'  < ../inputs/input/ruin.1665 > ../outputs/t3315
    if diff ../outputs/t3315 ../originals/t3315 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3316) timeout -s 9 2 ../source/replace.exe '@@' '+'  < ../inputs/input/ruin.180 > ../outputs/t3316
    if diff ../outputs/t3316 ../originals/t3316 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3317) timeout -s 9 2 ../source/replace.exe '@@' '+'  < ../inputs/input/ruin.2000 > ../outputs/t3317
    if diff ../outputs/t3317 ../originals/t3317 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3318) timeout -s 9 2 ../source/replace.exe '@@' '+'  < ../inputs/input/ruin.708 > ../outputs/t3318
    if diff ../outputs/t3318 ../originals/t3318 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3319) timeout -s 9 2 ../source/replace.exe '@@' '+'  < ../inputs/input/ruin.933 > ../outputs/t3319
    if diff ../outputs/t3319 ../originals/t3319 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3320) timeout -s 9 2 ../source/replace.exe '@@' '+'\''gpw--(=s T&WJK!a)Ca94'  < ../inputs/input/ruin.832 > ../outputs/t3320
    if diff ../outputs/t3320 ../originals/t3320 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3321) timeout -s 9 2 ../source/replace.exe '@@' '+B1j@-aUKh^'  < ../inputs/input/ruin.1102 > ../outputs/t3321
    if diff ../outputs/t3321 ../originals/t3321 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3322) timeout -s 9 2 ../source/replace.exe '@@' '+C=@tD|x.1Gwcu'  < ../inputs/input/ruin.360 > ../outputs/t3322
    if diff ../outputs/t3322 ../originals/t3322 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3323) timeout -s 9 2 ../source/replace.exe '@@' '+L$0nAwTE,?8>=\.)j_?W<"`s<9N LC(tnc|!$gDsG9!<da2D_e#5ehh]mDd_vE9pSi7V!ie^EqeMzAQ[F;'  < ../inputs/input/ruin.1067 > ../outputs/t3323
    if diff ../outputs/t3323 ../originals/t3323 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3324) timeout -s 9 2 ../source/replace.exe '@@' '+[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@[a-c@t*[a-c]^*[^0-9]-[a-c]^*[^0-9]@'  < ../inputs/input/ruin.1338 > ../outputs/t3324
    if diff ../outputs/t3324 ../originals/t3324 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3325) timeout -s 9 2 ../source/replace.exe '@@' '+_he-e]Z\99 4c7!{)aQf:\!'  < ../inputs/input/ruin.1008 > ../outputs/t3325
    if diff ../outputs/t3325 ../originals/t3325 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3326) timeout -s 9 2 ../source/replace.exe '@@' '+tY&c/wyzfFpv'  < ../inputs/input/ruin.343 > ../outputs/t3326
    if diff ../outputs/t3326 ../originals/t3326 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3327) timeout -s 9 2 ../source/replace.exe '@@' ','  < ../inputs/input/ruin.1574 > ../outputs/t3327
    if diff ../outputs/t3327 ../originals/t3327 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3328) timeout -s 9 2 ../source/replace.exe '@@' ',o-'\'' G$8%4u=+op(<['  < ../inputs/input/ruin.238 > ../outputs/t3328
    if diff ../outputs/t3328 ../originals/t3328 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3329) timeout -s 9 2 ../source/replace.exe '@@' '-'  < ../inputs/input/ruin.1101 > ../outputs/t3329
    if diff ../outputs/t3329 ../originals/t3329 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3330) timeout -s 9 2 ../source/replace.exe '@@' '-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-[]aA-GZ-a]*^_('  < ../inputs/input/ruin.1048 > ../outputs/t3330
    if diff ../outputs/t3330 ../originals/t3330 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3331) timeout -s 9 2 ../source/replace.exe '@@' '-}$NG|)ta623`tp&UwIx;Nak[]yQ!LHIP4;%Br1]=J\|%RpVqN*U=98`5'  < ../inputs/input/ruin.1924 > ../outputs/t3331
    if diff ../outputs/t3331 ../originals/t3331 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3332) timeout -s 9 2 ../source/replace.exe '@@' '.'  < ../inputs/input/ruin.631 > ../outputs/t3332
    if diff ../outputs/t3332 ../originals/t3332 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3333) timeout -s 9 2 ../source/replace.exe '@@' '/&!616<!d/}yp"oTD6&j9\Pw8nT\Jsnh[\i>s9/vn.+'\''t'  < ../inputs/input/ruin.11 > ../outputs/t3333
    if diff ../outputs/t3333 ../originals/t3333 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3334) timeout -s 9 2 ../source/replace.exe '@@' '/'  < ../inputs/input/ruin.1022 > ../outputs/t3334
    if diff ../outputs/t3334 ../originals/t3334 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3335) timeout -s 9 2 ../source/replace.exe '@@' '/'  < ../inputs/input/ruin.129 > ../outputs/t3335
    if diff ../outputs/t3335 ../originals/t3335 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3336) timeout -s 9 2 ../source/replace.exe '@@' '/'  < ../inputs/input/ruin.1848 > ../outputs/t3336
    if diff ../outputs/t3336 ../originals/t3336 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3337) timeout -s 9 2 ../source/replace.exe '@@' '/'  < ../inputs/input/ruin.495 > ../outputs/t3337
    if diff ../outputs/t3337 ../originals/t3337 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3338) timeout -s 9 2 ../source/replace.exe '@@' '/6sEWY)qxH!HD%1KqvrFR2$HF_f>{4ZN]'  < ../inputs/input/ruin.121 > ../outputs/t3338
    if diff ../outputs/t3338 ../originals/t3338 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3339) timeout -s 9 2 ../source/replace.exe '@@' '0'  < ../inputs/input/ruin.896 > ../outputs/t3339
    if diff ../outputs/t3339 ../originals/t3339 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3340) timeout -s 9 2 ../source/replace.exe '@@' '07mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpe'  < ../inputs/input/ruin.1061 > ../outputs/t3340
    if diff ../outputs/t3340 ../originals/t3340 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3341) timeout -s 9 2 ../source/replace.exe '@@' '0e'  < ../inputs/input/ruin.1061 > ../outputs/t3341
    if diff ../outputs/t3341 ../originals/t3341 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3342) timeout -s 9 2 ../source/replace.exe '@@' '1"%JX$^ku2<sUsCU+vj&[ q?Nv.wFgwq9!'  < ../inputs/input/ruin.1496 > ../outputs/t3342
    if diff ../outputs/t3342 ../originals/t3342 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3343) timeout -s 9 2 ../source/replace.exe '@@' '1('  < ../inputs/input/ruin.1009 > ../outputs/t3343
    if diff ../outputs/t3343 ../originals/t3343 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3344) timeout -s 9 2 ../source/replace.exe '@@' '1;b*?wOue:=LeChp|Xl[5oGNummHY5C>'  < ../inputs/input/ruin.678 > ../outputs/t3344
    if diff ../outputs/t3344 ../originals/t3344 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3345) timeout -s 9 2 ../source/replace.exe '@@' '1WL1U;05H?Td|ovtm:_+>u63FAZ^pz3d=9iQnoS[&T_T=T5:Ii'  < ../inputs/input/ruin.1921 > ../outputs/t3345
    if diff ../outputs/t3345 ../originals/t3345 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3346) timeout -s 9 2 ../source/replace.exe '@@' '2'  < ../inputs/input/ruin.1209 > ../outputs/t3346
    if diff ../outputs/t3346 ../originals/t3346 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3347) timeout -s 9 2 ../source/replace.exe '@@' '2'  < ../inputs/input/ruin.148 > ../outputs/t3347
    if diff ../outputs/t3347 ../originals/t3347 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3348) timeout -s 9 2 ../source/replace.exe '@@' '2'  < ../inputs/input/ruin.1650 > ../outputs/t3348
    if diff ../outputs/t3348 ../originals/t3348 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3349) timeout -s 9 2 ../source/replace.exe '@@' '2'  < ../inputs/input/ruin.764 > ../outputs/t3349
    if diff ../outputs/t3349 ../originals/t3349 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3350) timeout -s 9 2 ../source/replace.exe '@@' '2'  < ../inputs/input/ruin.773 > ../outputs/t3350
    if diff ../outputs/t3350 ../originals/t3350 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3351) timeout -s 9 2 ../source/replace.exe '@@' '3'  < ../inputs/input/ruin.587 > ../outputs/t3351
    if diff ../outputs/t3351 ../originals/t3351 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3352) timeout -s 9 2 ../source/replace.exe '@@' '3BLytQ69ILh[Q=v@'  < ../inputs/input/ruin.608 > ../outputs/t3352
    if diff ../outputs/t3352 ../originals/t3352 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3353) timeout -s 9 2 ../source/replace.exe '@@' '4'  < ../inputs/input/ruin.1992 > ../outputs/t3353
    if diff ../outputs/t3353 ../originals/t3353 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3354) timeout -s 9 2 ../source/replace.exe '@@' '4'  < ../inputs/input/ruin.64 > ../outputs/t3354
    if diff ../outputs/t3354 ../originals/t3354 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3355) timeout -s 9 2 ../source/replace.exe '@@' '4V_O%];L'  < ../inputs/input/ruin.523 > ../outputs/t3355
    if diff ../outputs/t3355 ../originals/t3355 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3356) timeout -s 9 2 ../source/replace.exe '@@' '5'  < ../inputs/input/ruin.1068 > ../outputs/t3356
    if diff ../outputs/t3356 ../originals/t3356 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3357) timeout -s 9 2 ../source/replace.exe '@@' '5'  < ../inputs/input/ruin.1712 > ../outputs/t3357
    if diff ../outputs/t3357 ../originals/t3357 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3358) timeout -s 9 2 ../source/replace.exe '@@' '5=}m(n~eqHssWTa{"Y?>ZsqxtOGQnjdh_gEY}xsZzV0jtKXn_&qG2I:~w2OXxrgMB>l8d^$ E-|'  < ../inputs/input/ruin.1981 > ../outputs/t3358
    if diff ../outputs/t3358 ../originals/t3358 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3359) timeout -s 9 2 ../source/replace.exe '@@' '6'  < ../inputs/input/ruin.1523 > ../outputs/t3359
    if diff ../outputs/t3359 ../originals/t3359 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3360) timeout -s 9 2 ../source/replace.exe '@@' '6'  < ../inputs/input/ruin.1891 > ../outputs/t3360
    if diff ../outputs/t3360 ../originals/t3360 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3361) timeout -s 9 2 ../source/replace.exe '@@' '6'  < ../inputs/input/ruin.1922 > ../outputs/t3361
    if diff ../outputs/t3361 ../originals/t3361 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3362) timeout -s 9 2 ../source/replace.exe '@@' '7'  < ../inputs/input/ruin.1303 > ../outputs/t3362
    if diff ../outputs/t3362 ../originals/t3362 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3363) timeout -s 9 2 ../source/replace.exe '@@' '7'  < ../inputs/input/ruin.1846 > ../outputs/t3363
    if diff ../outputs/t3363 ../originals/t3363 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3364) timeout -s 9 2 ../source/replace.exe '@@' '78ewmsa'\''3F~3]X`TmS?XC2'\'''  < ../inputs/input/ruin.85 > ../outputs/t3364
    if diff ../outputs/t3364 ../originals/t3364 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3365) timeout -s 9 2 ../source/replace.exe '@@' '7Pv(oq)0t^dvrHkh,e|)8!AK(<=AjeG3l^_'  < ../inputs/input/ruin.893 > ../outputs/t3365
    if diff ../outputs/t3365 ../originals/t3365 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3366) timeout -s 9 2 ../source/replace.exe '@@' '7p'  < ../inputs/input/ruin.53 > ../outputs/t3366
    if diff ../outputs/t3366 ../originals/t3366 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3367) timeout -s 9 2 ../source/replace.exe '@@' '7{%&v{Y:ay!~;a)T8SiF6*,5Z=Kud\M{E+8CT9GxONmm'  < ../inputs/input/ruin.1667 > ../outputs/t3367
    if diff ../outputs/t3367 ../originals/t3367 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3368) timeout -s 9 2 ../source/replace.exe '@@' '7{ek8P_#i5~XKh[kyMY[AhDzY/R2'  < ../inputs/input/ruin.1394 > ../outputs/t3368
    if diff ../outputs/t3368 ../originals/t3368 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3369) timeout -s 9 2 ../source/replace.exe '@@' '8'  < ../inputs/input/ruin.1695 > ../outputs/t3369
    if diff ../outputs/t3369 ../originals/t3369 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3370) timeout -s 9 2 ../source/replace.exe '@@' '8'  < ../inputs/input/ruin.1901 > ../outputs/t3370
    if diff ../outputs/t3370 ../originals/t3370 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3371) timeout -s 9 2 ../source/replace.exe '@@' '8Kn0{lOL:63C(`zF>U{e=G$53y'  < ../inputs/input/ruin.851 > ../outputs/t3371
    if diff ../outputs/t3371 ../originals/t3371 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3372) timeout -s 9 2 ../source/replace.exe '@@' '9'  < ../inputs/input/ruin.1542 > ../outputs/t3372
    if diff ../outputs/t3372 ../originals/t3372 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3373) timeout -s 9 2 ../source/replace.exe '@@' '9'  < ../inputs/input/ruin.186 > ../outputs/t3373
    if diff ../outputs/t3373 ../originals/t3373 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3374) timeout -s 9 2 ../source/replace.exe '@@' '9E{rn2?m(T@]A=ZX+qguf}Om/HMp3,'  < ../inputs/input/ruin.1959 > ../outputs/t3374
    if diff ../outputs/t3374 ../originals/t3374 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3375) timeout -s 9 2 ../source/replace.exe '@@' '9fzx91%af \'\''jgI$V|BL(X sN@?F8AXgoas/%p'  < ../inputs/input/ruin.1543 > ../outputs/t3375
    if diff ../outputs/t3375 ../originals/t3375 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3376) timeout -s 9 2 ../source/replace.exe '@@' ':'  < ../inputs/input/ruin.1049 > ../outputs/t3376
    if diff ../outputs/t3376 ../originals/t3376 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3377) timeout -s 9 2 ../source/replace.exe '@@' ':'  < ../inputs/input/ruin.1917 > ../outputs/t3377
    if diff ../outputs/t3377 ../originals/t3377 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3378) timeout -s 9 2 ../source/replace.exe '@@' ':'  < ../inputs/input/ruin.430 > ../outputs/t3378
    if diff ../outputs/t3378 ../originals/t3378 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3379) timeout -s 9 2 ../source/replace.exe '@@' ':-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ*-a]^_-aA-GZ-a]^_-aA-GZ-a]^_'  < ../inputs/input/ruin.1049 > ../outputs/t3379
    if diff ../outputs/t3379 ../originals/t3379 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3380) timeout -s 9 2 ../source/replace.exe '@@' ':AXq~ z+rj0BX0dT}k58H6_%'  < ../inputs/input/ruin.1438 > ../outputs/t3380
    if diff ../outputs/t3380 ../originals/t3380 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3381) timeout -s 9 2 ../source/replace.exe '@@' ';'  < ../inputs/input/ruin.1155 > ../outputs/t3381
    if diff ../outputs/t3381 ../originals/t3381 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3382) timeout -s 9 2 ../source/replace.exe '@@' ';'  < ../inputs/input/ruin.177 > ../outputs/t3382
    if diff ../outputs/t3382 ../originals/t3382 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3383) timeout -s 9 2 ../source/replace.exe '@@' ';'  < ../inputs/input/ruin.427 > ../outputs/t3383
    if diff ../outputs/t3383 ../originals/t3383 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3384) timeout -s 9 2 ../source/replace.exe '@@' ';.St7,*,FY'\''e2 #PQt_JAdEVyBorNLKtG4,nKOUCw{Tr/J2d]Omr-PWjk+'  < ../inputs/input/ruin.98 > ../outputs/t3384
    if diff ../outputs/t3384 ../originals/t3384 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3385) timeout -s 9 2 ../source/replace.exe '@@' ';cnGb$sku_0Cwd6'  < ../inputs/input/ruin.341 > ../outputs/t3385
    if diff ../outputs/t3385 ../originals/t3385 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3386) timeout -s 9 2 ../source/replace.exe '@@' ';pJ<?F=Dxa?\754QF'  < ../inputs/input/ruin.1756 > ../outputs/t3386
    if diff ../outputs/t3386 ../originals/t3386 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3387) timeout -s 9 2 ../source/replace.exe '@@' '<'  < ../inputs/input/ruin.1005 > ../outputs/t3387
    if diff ../outputs/t3387 ../originals/t3387 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3388) timeout -s 9 2 ../source/replace.exe '@@' '<'  < ../inputs/input/ruin.1316 > ../outputs/t3388
    if diff ../outputs/t3388 ../originals/t3388 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3389) timeout -s 9 2 ../source/replace.exe '@@' '<'  < ../inputs/input/ruin.1461 > ../outputs/t3389
    if diff ../outputs/t3389 ../originals/t3389 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3390) timeout -s 9 2 ../source/replace.exe '@@' '<'  < ../inputs/input/ruin.1545 > ../outputs/t3390
    if diff ../outputs/t3390 ../originals/t3390 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3391) timeout -s 9 2 ../source/replace.exe '@@' '<'  < ../inputs/input/ruin.239 > ../outputs/t3391
    if diff ../outputs/t3391 ../originals/t3391 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3392) timeout -s 9 2 ../source/replace.exe '@@' '<<s'\''ykL-eK+T'  < ../inputs/input/ruin.1771 > ../outputs/t3392
    if diff ../outputs/t3392 ../originals/t3392 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3393) timeout -s 9 2 ../source/replace.exe '@@' '<T'  < ../inputs/input/ruin.1455 > ../outputs/t3393
    if diff ../outputs/t3393 ../originals/t3393 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3394) timeout -s 9 2 ../source/replace.exe '@@' '<aeDJVcc:%wK*e9vLi71Y'  < ../inputs/input/ruin.1781 > ../outputs/t3394
    if diff ../outputs/t3394 ../originals/t3394 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3395) timeout -s 9 2 ../source/replace.exe '@@' '<c!'  < ../inputs/input/ruin.1179 > ../outputs/t3395
    if diff ../outputs/t3395 ../originals/t3395 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3396) timeout -s 9 2 ../source/replace.exe '@@' '<kl(cA m(Y`(5*I,G:CY+*n+)%En[Gl<:18Y9j$*V`$NJ}$;'  < ../inputs/input/ruin.1149 > ../outputs/t3396
    if diff ../outputs/t3396 ../originals/t3396 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3397) timeout -s 9 2 ../source/replace.exe '@@' '<u2<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs]r/0cjs'\''`'  < ../inputs/input/ruin.1047 > ../outputs/t3397
    if diff ../outputs/t3397 ../originals/t3397 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3398) timeout -s 9 2 ../source/replace.exe '@@' '<u2]r/0cjs'\''`'  < ../inputs/input/ruin.1047 > ../outputs/t3398
    if diff ../outputs/t3398 ../originals/t3398 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3399) timeout -s 9 2 ../source/replace.exe '@@' '='  < ../inputs/input/ruin.1882 > ../outputs/t3399
    if diff ../outputs/t3399 ../originals/t3399 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3400) timeout -s 9 2 ../source/replace.exe '@@' '='  < ../inputs/input/ruin.252 > ../outputs/t3400
    if diff ../outputs/t3400 ../originals/t3400 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3401) timeout -s 9 2 ../source/replace.exe '@@' '='  < ../inputs/input/ruin.664 > ../outputs/t3401
    if diff ../outputs/t3401 ../originals/t3401 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3402) timeout -s 9 2 ../source/replace.exe '@@' '=0b?deU>R%+|'  < ../inputs/input/ruin.192 > ../outputs/t3402
    if diff ../outputs/t3402 ../originals/t3402 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3403) timeout -s 9 2 ../source/replace.exe '@@' '>'  < ../inputs/input/ruin.1304 > ../outputs/t3403
    if diff ../outputs/t3403 ../originals/t3403 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3404) timeout -s 9 2 ../source/replace.exe '@@' '>TdQN{'  < ../inputs/input/ruin.362 > ../outputs/t3404
    if diff ../outputs/t3404 ../originals/t3404 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3405) timeout -s 9 2 ../source/replace.exe '@@' '>f'  < ../inputs/input/ruin.892 > ../outputs/t3405
    if diff ../outputs/t3405 ../originals/t3405 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3406) timeout -s 9 2 ../source/replace.exe '@@' '?'  < ../inputs/input/ruin.1127 > ../outputs/t3406
    if diff ../outputs/t3406 ../originals/t3406 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3407) timeout -s 9 2 ../source/replace.exe '@@' '?'  < ../inputs/input/ruin.649 > ../outputs/t3407
    if diff ../outputs/t3407 ../originals/t3407 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3408) timeout -s 9 2 ../source/replace.exe '@@' '?+'  < ../inputs/input/ruin.1397 > ../outputs/t3408
    if diff ../outputs/t3408 ../originals/t3408 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3409) timeout -s 9 2 ../source/replace.exe '@@' '@%5i%WdPe=U{3rY>R'\''EL$Mdy:Qrxi_{?'  < ../inputs/input/ruin.1739 > ../outputs/t3409
    if diff ../outputs/t3409 ../originals/t3409 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3410) timeout -s 9 2 ../source/replace.exe '@@' '@'  < ../inputs/input/ruin.175 > ../outputs/t3410
    if diff ../outputs/t3410 ../originals/t3410 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3411) timeout -s 9 2 ../source/replace.exe '@@' '@?JRm_9'  < ../inputs/input/ruin.550 > ../outputs/t3411
    if diff ../outputs/t3411 ../originals/t3411 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3412) timeout -s 9 2 ../source/replace.exe '@@' '@`CUC~C,?o:8E|f?3unMs?t#2b'  < ../inputs/input/ruin.870 > ../outputs/t3412
    if diff ../outputs/t3412 ../originals/t3412 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3413) timeout -s 9 2 ../source/replace.exe '@@' 'A$coJ-5Zw<>TQ[kxxEuNHcPly\'  < ../inputs/input/ruin.1858 > ../outputs/t3413
    if diff ../outputs/t3413 ../originals/t3413 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3414) timeout -s 9 2 ../source/replace.exe '@@' 'Azy);2Sc&A?(cD~7xuuFC`L7'  < ../inputs/input/ruin.1139 > ../outputs/t3414
    if diff ../outputs/t3414 ../originals/t3414 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3415) timeout -s 9 2 ../source/replace.exe '@@' 'B'  < ../inputs/input/ruin.1368 > ../outputs/t3415
    if diff ../outputs/t3415 ../originals/t3415 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3416) timeout -s 9 2 ../source/replace.exe '@@' 'B'  < ../inputs/input/ruin.1439 > ../outputs/t3416
    if diff ../outputs/t3416 ../originals/t3416 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3417) timeout -s 9 2 ../source/replace.exe '@@' 'B<'  < ../inputs/input/ruin.1363 > ../outputs/t3417
    if diff ../outputs/t3417 ../originals/t3417 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3418) timeout -s 9 2 ../source/replace.exe '@@' 'BBWIUEb}'  < ../inputs/input/ruin.1655 > ../outputs/t3418
    if diff ../outputs/t3418 ../originals/t3418 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3419) timeout -s 9 2 ../source/replace.exe '@@' 'Bn[E#7FzkrT]aFS#Q+f 10GtF?_'  < ../inputs/input/ruin.97 > ../outputs/t3419
    if diff ../outputs/t3419 ../originals/t3419 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3420) timeout -s 9 2 ../source/replace.exe '@@' 'B|n]$]<1fqRl]Hg!'  < ../inputs/input/ruin.915 > ../outputs/t3420
    if diff ../outputs/t3420 ../originals/t3420 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3421) timeout -s 9 2 ../source/replace.exe '@@' 'C7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mps2S11T]8KHwx~kv1uQJ*#%bdM,!Lt5'  < ../inputs/input/ruin.1062 > ../outputs/t3421
    if diff ../outputs/t3421 ../originals/t3421 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3422) timeout -s 9 2 ../source/replace.exe '@@' 'C^S+RY)_\a|PHKS5n~SFU?b'  < ../inputs/input/ruin.1714 > ../outputs/t3422
    if diff ../outputs/t3422 ../originals/t3422 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3423) timeout -s 9 2 ../source/replace.exe '@@' 'Cq_c#\FHg\Kr?>3*!m/A*_3}{7j1U3TsP)_smq|%~P-OCQ9`6-MO<k4"SN'\''n80N4Y> q^ZY{W5_7'  < ../inputs/input/ruin.1435 > ../outputs/t3423
    if diff ../outputs/t3423 ../originals/t3423 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3424) timeout -s 9 2 ../source/replace.exe '@@' 'Cs2S11T]8KHwx~kv1uQJ*#%bdM,!Lt5'  < ../inputs/input/ruin.1062 > ../outputs/t3424
    if diff ../outputs/t3424 ../originals/t3424 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3425) timeout -s 9 2 ../source/replace.exe '@@' 'D'  < ../inputs/input/ruin.1690 > ../outputs/t3425
    if diff ../outputs/t3425 ../originals/t3425 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3426) timeout -s 9 2 ../source/replace.exe '@@' 'D'  < ../inputs/input/ruin.246 > ../outputs/t3426
    if diff ../outputs/t3426 ../originals/t3426 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3427) timeout -s 9 2 ../source/replace.exe '@@' 'DXrcj(\#39@'  < ../inputs/input/ruin.215 > ../outputs/t3427
    if diff ../outputs/t3427 ../originals/t3427 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3428) timeout -s 9 2 ../source/replace.exe '@@' 'E!*gXlM6RC\lG'  < ../inputs/input/ruin.34 > ../outputs/t3428
    if diff ../outputs/t3428 ../originals/t3428 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3429) timeout -s 9 2 ../source/replace.exe '@@' 'E9p\6X[t<jnR3{*3PQSno!);('  < ../inputs/input/ruin.1256 > ../outputs/t3429
    if diff ../outputs/t3429 ../originals/t3429 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3430) timeout -s 9 2 ../source/replace.exe '@@' 'ELw~`C@PQ)'  < ../inputs/input/ruin.1722 > ../outputs/t3430
    if diff ../outputs/t3430 ../originals/t3430 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3431) timeout -s 9 2 ../source/replace.exe '@@' 'EjK?X#{Ur>oN|wXPT$BQRg:T$~BH;PLmx ?08~{Ig0Ze7`.|(kzu3o_s/"5"5\k1ylh)q;!<1>w$C1qd'  < ../inputs/input/ruin.265 > ../outputs/t3431
    if diff ../outputs/t3431 ../originals/t3431 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3432) timeout -s 9 2 ../source/replace.exe '@@' 'Etz|'  < ../inputs/input/ruin.667 > ../outputs/t3432
    if diff ../outputs/t3432 ../originals/t3432 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3433) timeout -s 9 2 ../source/replace.exe '@@' 'F'  < ../inputs/input/ruin.802 > ../outputs/t3433
    if diff ../outputs/t3433 ../originals/t3433 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3434) timeout -s 9 2 ../source/replace.exe '@@' 'G'  < ../inputs/input/ruin.397 > ../outputs/t3434
    if diff ../outputs/t3434 ../originals/t3434 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3435) timeout -s 9 2 ../source/replace.exe '@@' 'G_'  < ../inputs/input/ruin.1779 > ../outputs/t3435
    if diff ../outputs/t3435 ../originals/t3435 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3436) timeout -s 9 2 ../source/replace.exe '@@' 'G`$$:VB%$M[$ErHos~U]`5+'  < ../inputs/input/ruin.379 > ../outputs/t3436
    if diff ../outputs/t3436 ../originals/t3436 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3437) timeout -s 9 2 ../source/replace.exe '@@' 'H&'  < ../inputs/input/ruin.1074 > ../outputs/t3437
    if diff ../outputs/t3437 ../originals/t3437 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3438) timeout -s 9 2 ../source/replace.exe '@@' 'H4uOP@dgu<-LyyKn+[L@'  < ../inputs/input/ruin.682 > ../outputs/t3438
    if diff ../outputs/t3438 ../originals/t3438 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3439) timeout -s 9 2 ../source/replace.exe '@@' 'HI;TdGuR1D8'  < ../inputs/input/ruin.1935 > ../outputs/t3439
    if diff ../outputs/t3439 ../originals/t3439 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3440) timeout -s 9 2 ../source/replace.exe '@@' 'HP;~lm[ DxA!90Db}UH/ZEruRC'  < ../inputs/input/ruin.1487 > ../outputs/t3440
    if diff ../outputs/t3440 ../originals/t3440 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3441) timeout -s 9 2 ../source/replace.exe '@@' 'Hb'  < ../inputs/input/ruin.273 > ../outputs/t3441
    if diff ../outputs/t3441 ../originals/t3441 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3442) timeout -s 9 2 ../source/replace.exe '@@' 'I'  < ../inputs/input/ruin.1306 > ../outputs/t3442
    if diff ../outputs/t3442 ../originals/t3442 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3443) timeout -s 9 2 ../source/replace.exe '@@' 'I\/As)Z}7*%*i>17(z_L'  < ../inputs/input/ruin.559 > ../outputs/t3443
    if diff ../outputs/t3443 ../originals/t3443 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3444) timeout -s 9 2 ../source/replace.exe '@@' 'In9JjnCwGVggl=k&wnK}7ke)zG>.>[Bvgi;4W'  < ../inputs/input/ruin.249 > ../outputs/t3444
    if diff ../outputs/t3444 ../originals/t3444 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3445) timeout -s 9 2 ../source/replace.exe '@@' 'J'  < ../inputs/input/ruin.117 > ../outputs/t3445
    if diff ../outputs/t3445 ../originals/t3445 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3446) timeout -s 9 2 ../source/replace.exe '@@' 'K7+%7`\*l.EL,'  < ../inputs/input/ruin.1657 > ../outputs/t3446
    if diff ../outputs/t3446 ../originals/t3446 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3447) timeout -s 9 2 ../source/replace.exe '@@' 'KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@e'  < ../inputs/input/ruin.1036 > ../outputs/t3447
    if diff ../outputs/t3447 ../originals/t3447 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3448) timeout -s 9 2 ../source/replace.exe '@@' 'L$0Ky;c.R1F>Tw"W:^'  < ../inputs/input/ruin.225 > ../outputs/t3448
    if diff ../outputs/t3448 ../originals/t3448 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3449) timeout -s 9 2 ../source/replace.exe '@@' 'L'  < ../inputs/input/ruin.1203 > ../outputs/t3449
    if diff ../outputs/t3449 ../originals/t3449 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3450) timeout -s 9 2 ../source/replace.exe '@@' 'L'  < ../inputs/input/ruin.689 > ../outputs/t3450
    if diff ../outputs/t3450 ../originals/t3450 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3451) timeout -s 9 2 ../source/replace.exe '@@' 'L'  < ../inputs/input/ruin.720 > ../outputs/t3451
    if diff ../outputs/t3451 ../originals/t3451 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3452) timeout -s 9 2 ../source/replace.exe '@@' 'LFmqS#J=6aq\=6iN(T_?#?RzO y5ZA2'\''zX%~4b!nf$}Nmg'\'''  < ../inputs/input/ruin.207 > ../outputs/t3452
    if diff ../outputs/t3452 ../originals/t3452 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3453) timeout -s 9 2 ../source/replace.exe '@@' 'LTkhRoY X0O>]PcG'  < ../inputs/input/ruin.950 > ../outputs/t3453
    if diff ../outputs/t3453 ../originals/t3453 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3454) timeout -s 9 2 ../source/replace.exe '@@' 'Lt2GEbuGo,qE01mO6yS"\V'  < ../inputs/input/ruin.1700 > ../outputs/t3454
    if diff ../outputs/t3454 ../originals/t3454 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3455) timeout -s 9 2 ../source/replace.exe '@@' 'N!'  < ../inputs/input/ruin.546 > ../outputs/t3455
    if diff ../outputs/t3455 ../originals/t3455 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3456) timeout -s 9 2 ../source/replace.exe '@@' 'N'  < ../inputs/input/ruin.137 > ../outputs/t3456
    if diff ../outputs/t3456 ../originals/t3456 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3457) timeout -s 9 2 ../source/replace.exe '@@' 'N'  < ../inputs/input/ruin.737 > ../outputs/t3457
    if diff ../outputs/t3457 ../originals/t3457 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3458) timeout -s 9 2 ../source/replace.exe '@@' 'NGN4ij?opj(>9`>.1rUs0vJ{7?'  < ../inputs/input/ruin.1575 > ../outputs/t3458
    if diff ../outputs/t3458 ../originals/t3458 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3459) timeout -s 9 2 ../source/replace.exe '@@' 'NGyC?;*O3Y+25aQIdV'  < ../inputs/input/ruin.909 > ../outputs/t3459
    if diff ../outputs/t3459 ../originals/t3459 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3460) timeout -s 9 2 ../source/replace.exe '@@' 'NaZ'  < ../inputs/input/ruin.1588 > ../outputs/t3460
    if diff ../outputs/t3460 ../originals/t3460 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3461) timeout -s 9 2 ../source/replace.exe '@@' 'O8(CoPrxFq+.ZM|WW+0YtwT[\iP85^ ('  < ../inputs/input/ruin.975 > ../outputs/t3461
    if diff ../outputs/t3461 ../originals/t3461 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3462) timeout -s 9 2 ../source/replace.exe '@@' 'OE<W=ZndLYQd%p}lN|>'  < ../inputs/input/ruin.1796 > ../outputs/t3462
    if diff ../outputs/t3462 ../originals/t3462 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3463) timeout -s 9 2 ../source/replace.exe '@@' 'Of?,N@rdX*]]Px\#0)K[1C'  < ../inputs/input/ruin.1793 > ../outputs/t3463
    if diff ../outputs/t3463 ../originals/t3463 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3464) timeout -s 9 2 ../source/replace.exe '@@' 'P"zPgA08HQ_'\''1"'\''3_WC+.cmt3Rh^:'  < ../inputs/input/ruin.1408 > ../outputs/t3464
    if diff ../outputs/t3464 ../originals/t3464 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3465) timeout -s 9 2 ../source/replace.exe '@@' 'P'  < ../inputs/input/ruin.1745 > ../outputs/t3465
    if diff ../outputs/t3465 ../originals/t3465 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3466) timeout -s 9 2 ../source/replace.exe '@@' 'P:g"14" j0^]'\'':DK70 \o4AP}[z~>lxPCCM9m*\BwO%d!'  < ../inputs/input/ruin.1559 > ../outputs/t3466
    if diff ../outputs/t3466 ../originals/t3466 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3467) timeout -s 9 2 ../source/replace.exe '@@' 'P`G\'  < ../inputs/input/ruin.917 > ../outputs/t3467
    if diff ../outputs/t3467 ../originals/t3467 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3468) timeout -s 9 2 ../source/replace.exe '@@' 'Po[uSP.I_y!>nh:I7T"u$=>:mwq+5Q-(%'  < ../inputs/input/ruin.958 > ../outputs/t3468
    if diff ../outputs/t3468 ../originals/t3468 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3469) timeout -s 9 2 ../source/replace.exe '@@' 'Q0GMm0#K!hHA~y! iDG`*sh0I@'  < ../inputs/input/ruin.547 > ../outputs/t3469
    if diff ../outputs/t3469 ../originals/t3469 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3470) timeout -s 9 2 ../source/replace.exe '@@' 'QZ}nu?<N_m}]**y62k2AXk9'  < ../inputs/input/ruin.1286 > ../outputs/t3470
    if diff ../outputs/t3470 ../originals/t3470 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3471) timeout -s 9 2 ../source/replace.exe '@@' 'R-Q;*rnq'  < ../inputs/input/ruin.805 > ../outputs/t3471
    if diff ../outputs/t3471 ../originals/t3471 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3472) timeout -s 9 2 ../source/replace.exe '@@' 'Rz!7iD,x8DBW^[[bVr+@ZMKp+m"4.Rh?;:t>.={ZY~m'  < ../inputs/input/ruin.331 > ../outputs/t3472
    if diff ../outputs/t3472 ../originals/t3472 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3473) timeout -s 9 2 ../source/replace.exe '@@' 'S1G=SPJxh*Gd}R$vSwz{HEo.N'  < ../inputs/input/ruin.1190 > ../outputs/t3473
    if diff ../outputs/t3473 ../originals/t3473 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3474) timeout -s 9 2 ../source/replace.exe '@@' 'Sqn}f'  < ../inputs/input/ruin.1947 > ../outputs/t3474
    if diff ../outputs/t3474 ../originals/t3474 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3475) timeout -s 9 2 ../source/replace.exe '@@' 'T'  < ../inputs/input/ruin.1330 > ../outputs/t3475
    if diff ../outputs/t3475 ../originals/t3475 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3476) timeout -s 9 2 ../source/replace.exe '@@' 'T?^S|}'\''!\>bF'\''5T'  < ../inputs/input/ruin.1250 > ../outputs/t3476
    if diff ../outputs/t3476 ../originals/t3476 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3477) timeout -s 9 2 ../source/replace.exe '@@' 'TLE8-~GaWCbc;@/F@l`'  < ../inputs/input/ruin.1896 > ../outputs/t3477
    if diff ../outputs/t3477 ../originals/t3477 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3478) timeout -s 9 2 ../source/replace.exe '@@' 'TQ$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?Q$$7 E(2%8Q"fiw^tLQ$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?Wk2\)>Wg( 6h8z$?Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?Q$$7 E(2%8Q"fiw^tLWk2\)>Wg( 6h8z$?[*[0-9]*@0-9](*'  < ../inputs/input/ruin.1330 > ../outputs/t3478
    if diff ../outputs/t3478 ../originals/t3478 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3479) timeout -s 9 2 ../source/replace.exe '@@' 'TbjIYx|Qb}}TKt5QS<'  < ../inputs/input/ruin.1187 > ../outputs/t3479
    if diff ../outputs/t3479 ../originals/t3479 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3480) timeout -s 9 2 ../source/replace.exe '@@' 'U'  < ../inputs/input/ruin.1742 > ../outputs/t3480
    if diff ../outputs/t3480 ../originals/t3480 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3481) timeout -s 9 2 ../source/replace.exe '@@' 'U'  < ../inputs/input/ruin.652 > ../outputs/t3481
    if diff ../outputs/t3481 ../originals/t3481 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3482) timeout -s 9 2 ../source/replace.exe '@@' 'UYO1pYxIn73gID*+`{/f6 /NAhY;g+G#-QVuqKSuP2}FO!q'  < ../inputs/input/ruin.669 > ../outputs/t3482
    if diff ../outputs/t3482 ../originals/t3482 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3483) timeout -s 9 2 ../source/replace.exe '@@' 'V'  < ../inputs/input/ruin.778 > ../outputs/t3483
    if diff ../outputs/t3483 ../originals/t3483 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3484) timeout -s 9 2 ../source/replace.exe '@@' 'V8X['  < ../inputs/input/ruin.721 > ../outputs/t3484
    if diff ../outputs/t3484 ../originals/t3484 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3485) timeout -s 9 2 ../source/replace.exe '@@' 'V\-oNf0a>?5'  < ../inputs/input/ruin.1291 > ../outputs/t3485
    if diff ../outputs/t3485 ../originals/t3485 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3486) timeout -s 9 2 ../source/replace.exe '@@' 'W'  < ../inputs/input/ruin.1384 > ../outputs/t3486
    if diff ../outputs/t3486 ../originals/t3486 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3487) timeout -s 9 2 ../source/replace.exe '@@' 'W'  < ../inputs/input/ruin.925 > ../outputs/t3487
    if diff ../outputs/t3487 ../originals/t3487 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3488) timeout -s 9 2 ../source/replace.exe '@@' 'W*B'\''=WR-U}+3n UE1`uj#w3nOzt,'  < ../inputs/input/ruin.941 > ../outputs/t3488
    if diff ../outputs/t3488 ../originals/t3488 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3489) timeout -s 9 2 ../source/replace.exe '@@' 'WJfW@~bR70@TPOC>W^rlP4YMsOx}sZH)<N"whTH\!JP'  < ../inputs/input/ruin.1681 > ../outputs/t3489
    if diff ../outputs/t3489 ../originals/t3489 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3490) timeout -s 9 2 ../source/replace.exe '@@' 'X5,D~^}Uezv[(n?i4@udSpRjK)2)hOy!D9DM{ROIR>6:p.9k`w@|'  < ../inputs/input/ruin.1549 > ../outputs/t3490
    if diff ../outputs/t3490 ../originals/t3490 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3491) timeout -s 9 2 ../source/replace.exe '@@' 'Xz'  < ../inputs/input/ruin.1863 > ../outputs/t3491
    if diff ../outputs/t3491 ../originals/t3491 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3492) timeout -s 9 2 ../source/replace.exe '@@' 'Y'  < ../inputs/input/ruin.1211 > ../outputs/t3492
    if diff ../outputs/t3492 ../originals/t3492 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3493) timeout -s 9 2 ../source/replace.exe '@@' 'YCoe'  < ../inputs/input/ruin.1246 > ../outputs/t3493
    if diff ../outputs/t3493 ../originals/t3493 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3494) timeout -s 9 2 ../source/replace.exe '@@' 'YRBzjkTk&^o]x&mr;k'  < ../inputs/input/ruin.126 > ../outputs/t3494
    if diff ../outputs/t3494 ../originals/t3494 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3495) timeout -s 9 2 ../source/replace.exe '@@' 'Y~3WQ^TDf.W]8c@LJ`*H2xp]e8-106jkG3TMg+;,1I;3-'  < ../inputs/input/ruin.1583 > ../outputs/t3495
    if diff ../outputs/t3495 ../originals/t3495 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3496) timeout -s 9 2 ../source/replace.exe '@@' 'Z'  < ../inputs/input/ruin.732 > ../outputs/t3496
    if diff ../outputs/t3496 ../originals/t3496 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3497) timeout -s 9 2 ../source/replace.exe '@@' '['\''o[}k")5^ZB0Q`x/^Di>;o%m2R@$B'  < ../inputs/input/ruin.37 > ../outputs/t3497
    if diff ../outputs/t3497 ../originals/t3497 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3498) timeout -s 9 2 ../source/replace.exe '@@' '[5K_$J[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!Ur[8o>B'\''+shEe>eT4x )#X}](v'\''=1Gx2W&!UrsD[0-9]*[a-b]'  < ../inputs/input/ruin.1329 > ../outputs/t3498
    if diff ../outputs/t3498 ../originals/t3498 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3499) timeout -s 9 2 ../source/replace.exe '@@' '[5K_$JsD'  < ../inputs/input/ruin.1329 > ../outputs/t3499
    if diff ../outputs/t3499 ../originals/t3499 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3500) timeout -s 9 2 ../source/replace.exe '@@' '[jJ3"kdXY?.O _q-kqD7^;wzC{m@'  < ../inputs/input/ruin.352 > ../outputs/t3500
    if diff ../outputs/t3500 ../originals/t3500 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3501) timeout -s 9 2 ../source/replace.exe '@@' '\"8rH'  < ../inputs/input/ruin.483 > ../outputs/t3501
    if diff ../outputs/t3501 ../originals/t3501 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3502) timeout -s 9 2 ../source/replace.exe '@@' '\Qch=P"+VUY>@V35oj['  < ../inputs/input/ruin.1447 > ../outputs/t3502
    if diff ../outputs/t3502 ../originals/t3502 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3503) timeout -s 9 2 ../source/replace.exe '@@' '\xc'  < ../inputs/input/ruin.86 > ../outputs/t3503
    if diff ../outputs/t3503 ../originals/t3503 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3504) timeout -s 9 2 ../source/replace.exe '@@' ']'  < ../inputs/input/ruin.1597 > ../outputs/t3504
    if diff ../outputs/t3504 ../originals/t3504 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3505) timeout -s 9 2 ../source/replace.exe '@@' ']A;Z'  < ../inputs/input/ruin.916 > ../outputs/t3505
    if diff ../outputs/t3505 ../originals/t3505 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3506) timeout -s 9 2 ../source/replace.exe '@@' '^'  < ../inputs/input/ruin.1150 > ../outputs/t3506
    if diff ../outputs/t3506 ../originals/t3506 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3507) timeout -s 9 2 ../source/replace.exe '@@' '^'  < ../inputs/input/ruin.1710 > ../outputs/t3507
    if diff ../outputs/t3507 ../originals/t3507 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3508) timeout -s 9 2 ../source/replace.exe '@@' '_'  < ../inputs/input/ruin.442 > ../outputs/t3508
    if diff ../outputs/t3508 ../originals/t3508 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3509) timeout -s 9 2 ../source/replace.exe '@@' '_'  < ../inputs/input/ruin.964 > ../outputs/t3509
    if diff ../outputs/t3509 ../originals/t3509 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3510) timeout -s 9 2 ../source/replace.exe '@@' '_)yu\4xy*BO>-TK${EHB'  < ../inputs/input/ruin.728 > ../outputs/t3510
    if diff ../outputs/t3510 ../originals/t3510 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3511) timeout -s 9 2 ../source/replace.exe '@@' '_AtlH$9q>kcWc*%x:UL}T5bDIP~oV&p,uD-r'\''RKFZ~<nkYi}'  < ../inputs/input/ruin.621 > ../outputs/t3511
    if diff ../outputs/t3511 ../originals/t3511 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3512) timeout -s 9 2 ../source/replace.exe '@@' '_Y}LC6.Z_G:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JGbw.3gyV:Q0er!>'  < ../inputs/input/ruin.1041 > ../outputs/t3512
    if diff ../outputs/t3512 ../originals/t3512 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3513) timeout -s 9 2 ../source/replace.exe '@@' '_Y}LC6.Z_Gbw.3gyV:Q0er!>'  < ../inputs/input/ruin.1041 > ../outputs/t3513
    if diff ../outputs/t3513 ../originals/t3513 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3514) timeout -s 9 2 ../source/replace.exe '@@' '__v[0r+_odTj'\''e>-[`,Qc9/rT'  < ../inputs/input/ruin.989 > ../outputs/t3514
    if diff ../outputs/t3514 ../originals/t3514 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3515) timeout -s 9 2 ../source/replace.exe '@@' '`'  < ../inputs/input/ruin.1213 > ../outputs/t3515
    if diff ../outputs/t3515 ../originals/t3515 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3516) timeout -s 9 2 ../source/replace.exe '@@' '`'  < ../inputs/input/ruin.1963 > ../outputs/t3516
    if diff ../outputs/t3516 ../originals/t3516 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3517) timeout -s 9 2 ../source/replace.exe '@@' '`'  < ../inputs/input/ruin.850 > ../outputs/t3517
    if diff ../outputs/t3517 ../originals/t3517 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3518) timeout -s 9 2 ../source/replace.exe '@@' '`'  < ../inputs/input/ruin.992 > ../outputs/t3518
    if diff ../outputs/t3518 ../originals/t3518 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3519) timeout -s 9 2 ../source/replace.exe '@@' 'a'  < ../inputs/input/ruin.1215 > ../outputs/t3519
    if diff ../outputs/t3519 ../originals/t3519 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3520) timeout -s 9 2 ../source/replace.exe '@@' 'a'  < ../inputs/input/ruin.1259 > ../outputs/t3520
    if diff ../outputs/t3520 ../originals/t3520 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3521) timeout -s 9 2 ../source/replace.exe '@@' 'a'  < ../inputs/input/ruin.84 > ../outputs/t3521
    if diff ../outputs/t3521 ../originals/t3521 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3522) timeout -s 9 2 ../source/replace.exe '@@' 'a0v,-tcE^\x'  < ../inputs/input/ruin.1761 > ../outputs/t3522
    if diff ../outputs/t3522 ../originals/t3522 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3523) timeout -s 9 2 ../source/replace.exe '@@' 'b'  < ../inputs/input/ruin.1078 > ../outputs/t3523
    if diff ../outputs/t3523 ../originals/t3523 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3524) timeout -s 9 2 ../source/replace.exe '@@' 'c'  < ../inputs/input/ruin.235 > ../outputs/t3524
    if diff ../outputs/t3524 ../originals/t3524 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3525) timeout -s 9 2 ../source/replace.exe '@@' 'c^C0V'  < ../inputs/input/ruin.771 > ../outputs/t3525
    if diff ../outputs/t3525 ../originals/t3525 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3526) timeout -s 9 2 ../source/replace.exe '@@' 'dR1!L@k(&/ZgsZs,*d\'  < ../inputs/input/ruin.367 > ../outputs/t3526
    if diff ../outputs/t3526 ../originals/t3526 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3527) timeout -s 9 2 ../source/replace.exe '@@' 'e!gTC@po-K"lq@{;#4Pt:in1 p.!+` ]dLa5'  < ../inputs/input/ruin.297 > ../outputs/t3527
    if diff ../outputs/t3527 ../originals/t3527 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3528) timeout -s 9 2 ../source/replace.exe '@@' 'e'  < ../inputs/input/ruin.1036 > ../outputs/t3528
    if diff ../outputs/t3528 ../originals/t3528 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3529) timeout -s 9 2 ../source/replace.exe '@@' 'e'  < ../inputs/input/ruin.323 > ../outputs/t3529
    if diff ../outputs/t3529 ../originals/t3529 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3530) timeout -s 9 2 ../source/replace.exe '@@' 'e;o1qYfx@'  < ../inputs/input/ruin.661 > ../outputs/t3530
    if diff ../outputs/t3530 ../originals/t3530 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3531) timeout -s 9 2 ../source/replace.exe '@@' 'eT@aR6@4AoERO"scF)a"dqsE)GaEU$d~$U<<zIU>P>V,&'  < ../inputs/input/ruin.1183 > ../outputs/t3531
    if diff ../outputs/t3531 ../originals/t3531 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3532) timeout -s 9 2 ../source/replace.exe '@@' 'e^O;EJ5?6DU!Sw"B%ah'\''m*lY_`a'  < ../inputs/input/ruin.1598 > ../outputs/t3532
    if diff ../outputs/t3532 ../originals/t3532 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3533) timeout -s 9 2 ../source/replace.exe '@@' 'ej5i-U/6Q5@m>TzI{D/Y`Z#2'  < ../inputs/input/ruin.52 > ../outputs/t3533
    if diff ../outputs/t3533 ../originals/t3533 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3534) timeout -s 9 2 ../source/replace.exe '@@' 'f'  < ../inputs/input/ruin.1000 > ../outputs/t3534
    if diff ../outputs/t3534 ../originals/t3534 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3535) timeout -s 9 2 ../source/replace.exe '@@' 'f'  < ../inputs/input/ruin.789 > ../outputs/t3535
    if diff ../outputs/t3535 ../originals/t3535 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3536) timeout -s 9 2 ../source/replace.exe '@@' 'f+PSsiDSRQ/*(D(Bq:LX?JXpsZ A1JT]-^Y!wA%ms'  < ../inputs/input/ruin.848 > ../outputs/t3536
    if diff ../outputs/t3536 ../originals/t3536 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3537) timeout -s 9 2 ../source/replace.exe '@@' 'f?P&IzJ":,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8CcZ'  < ../inputs/input/ruin.82 > ../outputs/t3537
    if diff ../outputs/t3537 ../originals/t3537 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3538) timeout -s 9 2 ../source/replace.exe '@@' 'f?P&IzJ":,V00zS8|LFd{fgr(z@L5ZE{\?7<iFeAt8CcZ'  < ../inputs/input/ruin.82 > ../outputs/t3538
    if diff ../outputs/t3538 ../originals/t3538 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3539) timeout -s 9 2 ../source/replace.exe '@@' 'fO$hc9Vunm^fRBx+3N{{!urM]pAS@xFpr'\'''\''Bs7{E6dX`JP-d'  < ../inputs/input/ruin.1147 > ../outputs/t3539
    if diff ../outputs/t3539 ../originals/t3539 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3540) timeout -s 9 2 ../source/replace.exe '@@' 'fQ`{IB:H3a=WSdme}w6|h!vb$*%!K;Y* R-b3=Mi1glBYW>x]t<h'  < ../inputs/input/ruin.1792 > ../outputs/t3540
    if diff ../outputs/t3540 ../originals/t3540 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3541) timeout -s 9 2 ../source/replace.exe '@@' 'g'  < ../inputs/input/ruin.1773 > ../outputs/t3541
    if diff ../outputs/t3541 ../originals/t3541 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3542) timeout -s 9 2 ../source/replace.exe '@@' 'g9`YM,ozyUxQqpQAHH/sK++]'  < ../inputs/input/ruin.205 > ../outputs/t3542
    if diff ../outputs/t3542 ../originals/t3542 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3543) timeout -s 9 2 ../source/replace.exe '@@' 'gM4Iz9`JS5`'\''ZhDPT'  < ../inputs/input/ruin.1151 > ../outputs/t3543
    if diff ../outputs/t3543 ../originals/t3543 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3544) timeout -s 9 2 ../source/replace.exe '@@' 'gV8;%IAhxp(4]=AqH&'\''feFXY&8>^:%j,(\'  < ../inputs/input/ruin.1311 > ../outputs/t3544
    if diff ../outputs/t3544 ../originals/t3544 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3545) timeout -s 9 2 ../source/replace.exe '@@' 'h'  < ../inputs/input/ruin.1129 > ../outputs/t3545
    if diff ../outputs/t3545 ../originals/t3545 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3546) timeout -s 9 2 ../source/replace.exe '@@' 'h'  < ../inputs/input/ruin.1223 > ../outputs/t3546
    if diff ../outputs/t3546 ../originals/t3546 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3547) timeout -s 9 2 ../source/replace.exe '@@' 'hAh7G[Wy'  < ../inputs/input/ruin.807 > ../outputs/t3547
    if diff ../outputs/t3547 ../originals/t3547 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3548) timeout -s 9 2 ../source/replace.exe '@@' 'i'  < ../inputs/input/ruin.509 > ../outputs/t3548
    if diff ../outputs/t3548 ../originals/t3548 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3549) timeout -s 9 2 ../source/replace.exe '@@' 'i3&YEy?NDqT |ye3E+7WmBD#X-J4KI'  < ../inputs/input/ruin.422 > ../outputs/t3549
    if diff ../outputs/t3549 ../originals/t3549 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3550) timeout -s 9 2 ../source/replace.exe '@@' 'j'  < ../inputs/input/ruin.1276 > ../outputs/t3550
    if diff ../outputs/t3550 ../originals/t3550 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3551) timeout -s 9 2 ../source/replace.exe '@@' 'j'  < ../inputs/input/ruin.1719 > ../outputs/t3551
    if diff ../outputs/t3551 ../originals/t3551 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3552) timeout -s 9 2 ../source/replace.exe '@@' 'j'  < ../inputs/input/ruin.424 > ../outputs/t3552
    if diff ../outputs/t3552 ../originals/t3552 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3553) timeout -s 9 2 ../source/replace.exe '@@' 'j'  < ../inputs/input/ruin.904 > ../outputs/t3553
    if diff ../outputs/t3553 ../originals/t3553 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3554) timeout -s 9 2 ../source/replace.exe '@@' 'j'  < ../inputs/input/ruin.996 > ../outputs/t3554
    if diff ../outputs/t3554 ../originals/t3554 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3555) timeout -s 9 2 ../source/replace.exe '@@' 'j'\''lp`]]b|XBOU+;%Z&7~pp;7VFA83x(zkK{%9."'  < ../inputs/input/ruin.1218 > ../outputs/t3555
    if diff ../outputs/t3555 ../originals/t3555 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3556) timeout -s 9 2 ../source/replace.exe '@@' 'j6A?tQQCI+w[(+e0(\M2l'  < ../inputs/input/ruin.1530 > ../outputs/t3556
    if diff ../outputs/t3556 ../originals/t3556 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3557) timeout -s 9 2 ../source/replace.exe '@@' 'j?'  < ../inputs/input/ruin.1855 > ../outputs/t3557
    if diff ../outputs/t3557 ../originals/t3557 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3558) timeout -s 9 2 ../source/replace.exe '@@' 'jjlqOhlK})+YNyJREVn`'  < ../inputs/input/ruin.1483 > ../outputs/t3558
    if diff ../outputs/t3558 ../originals/t3558 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3559) timeout -s 9 2 ../source/replace.exe '@@' 'k'  < ../inputs/input/ruin.1772 > ../outputs/t3559
    if diff ../outputs/t3559 ../originals/t3559 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3560) timeout -s 9 2 ../source/replace.exe '@@' 'k'  < ../inputs/input/ruin.68 > ../outputs/t3560
    if diff ../outputs/t3560 ../originals/t3560 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3561) timeout -s 9 2 ../source/replace.exe '@@' 'k8lIP/^lq^1Y+fyL*]:A/&$>QU&rMLju9)gZJn7t0L'  < ../inputs/input/ruin.852 > ../outputs/t3561
    if diff ../outputs/t3561 ../originals/t3561 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3562) timeout -s 9 2 ../source/replace.exe '@@' 'k90v&+GhOb?3^)t8w^5eB 8n+w|c,}dnl|/9zv:amXVHU<2LtF/'  < ../inputs/input/ruin.1673 > ../outputs/t3562
    if diff ../outputs/t3562 ../originals/t3562 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3563) timeout -s 9 2 ../source/replace.exe '@@' 'k`px>G$3CtAt8QtV'\''95t'  < ../inputs/input/ruin.1568 > ../outputs/t3563
    if diff ../outputs/t3563 ../originals/t3563 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3564) timeout -s 9 2 ../source/replace.exe '@@' 'kj{>|jBXaQi+U6Z,?.Z2zf!z,54K};>F^h1W &6!-jfKY=;7dzK5&Jd;`@%"a_5E'  < ../inputs/input/ruin.492 > ../outputs/t3564
    if diff ../outputs/t3564 ../originals/t3564 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3565) timeout -s 9 2 ../source/replace.exe '@@' 'l'  < ../inputs/input/ruin.1148 > ../outputs/t3565
    if diff ../outputs/t3565 ../originals/t3565 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3566) timeout -s 9 2 ../source/replace.exe '@@' 'l'  < ../inputs/input/ruin.1421 > ../outputs/t3566
    if diff ../outputs/t3566 ../originals/t3566 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3567) timeout -s 9 2 ../source/replace.exe '@@' 'lZ'  < ../inputs/input/ruin.383 > ../outputs/t3567
    if diff ../outputs/t3567 ../originals/t3567 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3568) timeout -s 9 2 ../source/replace.exe '@@' 'm'  < ../inputs/input/ruin.1181 > ../outputs/t3568
    if diff ../outputs/t3568 ../originals/t3568 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3569) timeout -s 9 2 ../source/replace.exe '@@' 'm'  < ../inputs/input/ruin.1738 > ../outputs/t3569
    if diff ../outputs/t3569 ../originals/t3569 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3570) timeout -s 9 2 ../source/replace.exe '@@' 'mmca'\''y]fF 5 '  < ../inputs/input/ruin.200 > ../outputs/t3570
    if diff ../outputs/t3570 ../originals/t3570 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3571) timeout -s 9 2 ../source/replace.exe '@@' 'n'  < ../inputs/input/ruin.795 > ../outputs/t3571
    if diff ../outputs/t3571 ../originals/t3571 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3572) timeout -s 9 2 ../source/replace.exe '@@' 'nZQNac5[{EJpLJrR>H7DDaGqvR'  < ../inputs/input/ruin.912 > ../outputs/t3572
    if diff ../outputs/t3572 ../originals/t3572 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3573) timeout -s 9 2 ../source/replace.exe '@@' 'nj*'  < ../inputs/input/ruin.565 > ../outputs/t3573
    if diff ../outputs/t3573 ../originals/t3573 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3574) timeout -s 9 2 ../source/replace.exe '@@' 'o'  < ../inputs/input/ruin.1479 > ../outputs/t3574
    if diff ../outputs/t3574 ../originals/t3574 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3575) timeout -s 9 2 ../source/replace.exe '@@' 'p<'  < ../inputs/input/ruin.1510 > ../outputs/t3575
    if diff ../outputs/t3575 ../originals/t3575 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3576) timeout -s 9 2 ../source/replace.exe '@@' 'pJAr(P$X'  < ../inputs/input/ruin.1426 > ../outputs/t3576
    if diff ../outputs/t3576 ../originals/t3576 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3577) timeout -s 9 2 ../source/replace.exe '@@' 'pTk>mo0}9UV`\akAM'  < ../inputs/input/ruin.488 > ../outputs/t3577
    if diff ../outputs/t3577 ../originals/t3577 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3578) timeout -s 9 2 ../source/replace.exe '@@' 'pUDenGaV4uuTBp'  < ../inputs/input/ruin.707 > ../outputs/t3578
    if diff ../outputs/t3578 ../originals/t3578 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3579) timeout -s 9 2 ../source/replace.exe '@@' 'q'  < ../inputs/input/ruin.322 > ../outputs/t3579
    if diff ../outputs/t3579 ../originals/t3579 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3580) timeout -s 9 2 ../source/replace.exe '@@' 'q'  < ../inputs/input/ruin.610 > ../outputs/t3580
    if diff ../outputs/t3580 ../originals/t3580 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3581) timeout -s 9 2 ../source/replace.exe '@@' 'q'  < ../inputs/input/ruin.650 > ../outputs/t3581
    if diff ../outputs/t3581 ../originals/t3581 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3582) timeout -s 9 2 ../source/replace.exe '@@' 'r'  < ../inputs/input/ruin.1985 > ../outputs/t3582
    if diff ../outputs/t3582 ../originals/t3582 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3583) timeout -s 9 2 ../source/replace.exe '@@' 'r'  < ../inputs/input/ruin.602 > ../outputs/t3583
    if diff ../outputs/t3583 ../originals/t3583 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3584) timeout -s 9 2 ../source/replace.exe '@@' 'r'  < ../inputs/input/ruin.938 > ../outputs/t3584
    if diff ../outputs/t3584 ../originals/t3584 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3585) timeout -s 9 2 ../source/replace.exe '@@' 'r(e <\Q$X[8Qn-^g9\yaGf=`ipV'  < ../inputs/input/ruin.1514 > ../outputs/t3585
    if diff ../outputs/t3585 ../originals/t3585 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3586) timeout -s 9 2 ../source/replace.exe '@@' 'rf[8:ZbgT%q{\_J^E@u3)IuxENZ~"v'  < ../inputs/input/ruin.1584 > ../outputs/t3586
    if diff ../outputs/t3586 ../originals/t3586 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3587) timeout -s 9 2 ../source/replace.exe '@@' 'rnQ0W'  < ../inputs/input/ruin.1766 > ../outputs/t3587
    if diff ../outputs/t3587 ../originals/t3587 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3588) timeout -s 9 2 ../source/replace.exe '@@' 's'  < ../inputs/input/ruin.157 > ../outputs/t3588
    if diff ../outputs/t3588 ../originals/t3588 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3589) timeout -s 9 2 ../source/replace.exe '@@' 's'  < ../inputs/input/ruin.1875 > ../outputs/t3589
    if diff ../outputs/t3589 ../originals/t3589 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3590) timeout -s 9 2 ../source/replace.exe '@@' 's+jsq+sqp33oy|>sXt&.w<(EJ[$_J'  < ../inputs/input/ruin.579 > ../outputs/t3590
    if diff ../outputs/t3590 ../originals/t3590 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3591) timeout -s 9 2 ../source/replace.exe '@@' 'sF1w_ggvWylg>yMc]h,D)_+_$r4m\$Vh '  < ../inputs/input/ruin.55 > ../outputs/t3591
    if diff ../outputs/t3591 ../originals/t3591 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3592) timeout -s 9 2 ../source/replace.exe '@@' 't+b%Ev`=tGgLKIdrp'  < ../inputs/input/ruin.1596 > ../outputs/t3592
    if diff ../outputs/t3592 ../originals/t3592 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3593) timeout -s 9 2 ../source/replace.exe '@@' 'tW'  < ../inputs/input/ruin.1247 > ../outputs/t3593
    if diff ../outputs/t3593 ../originals/t3593 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3594) timeout -s 9 2 ../source/replace.exe '@@' 'u]KpAv6)cN.l7mY\p?:,SP|'  < ../inputs/input/ruin.1053 > ../outputs/t3594
    if diff ../outputs/t3594 ../originals/t3594 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3595) timeout -s 9 2 ../source/replace.exe '@@' 'v'  < ../inputs/input/ruin.1046 > ../outputs/t3595
    if diff ../outputs/t3595 ../originals/t3595 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3596) timeout -s 9 2 ../source/replace.exe '@@' 'v'  < ../inputs/input/ruin.1674 > ../outputs/t3596
    if diff ../outputs/t3596 ../originals/t3596 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3597) timeout -s 9 2 ../source/replace.exe '@@' 'v'  < ../inputs/input/ruin.254 > ../outputs/t3597
    if diff ../outputs/t3597 ../originals/t3597 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3598) timeout -s 9 2 ../source/replace.exe '@@' 'v;b=dV4;]ygerT'  < ../inputs/input/ruin.818 > ../outputs/t3598
    if diff ../outputs/t3598 ../originals/t3598 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3599) timeout -s 9 2 ../source/replace.exe '@@' 'v<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs'  < ../inputs/input/ruin.1046 > ../outputs/t3599
    if diff ../outputs/t3599 ../originals/t3599 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3600) timeout -s 9 2 ../source/replace.exe '@@' 'vDAI-/lT.qya'  < ../inputs/input/ruin.359 > ../outputs/t3600
    if diff ../outputs/t3600 ../originals/t3600 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3601) timeout -s 9 2 ../source/replace.exe '@@' 'vZ`=_1/f&:WSB'\''.)vc&tN%d}Vf2%=]b>s/rYKaS]"F0l(W~#Ps#9FZYYdaNVl.wdL.'  < ../inputs/input/ruin.1267 > ../outputs/t3601
    if diff ../outputs/t3601 ../originals/t3601 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3602) timeout -s 9 2 ../source/replace.exe '@@' 'wr'  < ../inputs/input/ruin.1340 > ../outputs/t3602
    if diff ../outputs/t3602 ../originals/t3602 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3603) timeout -s 9 2 ../source/replace.exe '@@' 'x'  < ../inputs/input/ruin.1315 > ../outputs/t3603
    if diff ../outputs/t3603 ../originals/t3603 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3604) timeout -s 9 2 ../source/replace.exe '@@' 'x-4pr$|OeG~}/59%x9n9muL1?V>i)'  < ../inputs/input/ruin.1656 > ../outputs/t3604
    if diff ../outputs/t3604 ../originals/t3604 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3605) timeout -s 9 2 ../source/replace.exe '@@' 'xN(q} B`^qJME0vUM3iTnc\w\'  < ../inputs/input/ruin.593 > ../outputs/t3605
    if diff ../outputs/t3605 ../originals/t3605 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3606) timeout -s 9 2 ../source/replace.exe '@@' 'y'  < ../inputs/input/ruin.1059 > ../outputs/t3606
    if diff ../outputs/t3606 ../originals/t3606 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3607) timeout -s 9 2 ../source/replace.exe '@@' 'y'\''O;wCB`/IC#tko'\''ztR%D)S}WK}htv'\''CdX[k69[r'  < ../inputs/input/ruin.1754 > ../outputs/t3607
    if diff ../outputs/t3607 ../originals/t3607 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3608) timeout -s 9 2 ../source/replace.exe '@@' 'y7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp'  < ../inputs/input/ruin.1059 > ../outputs/t3608
    if diff ../outputs/t3608 ../originals/t3608 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3609) timeout -s 9 2 ../source/replace.exe '@@' 'z'  < ../inputs/input/ruin.62 > ../outputs/t3609
    if diff ../outputs/t3609 ../originals/t3609 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3610) timeout -s 9 2 ../source/replace.exe '@@' '{/ cC;3\[1Xjlmdn*[4(hG8'  < ../inputs/input/ruin.1881 > ../outputs/t3610
    if diff ../outputs/t3610 ../originals/t3610 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3611) timeout -s 9 2 ../source/replace.exe '@@' '{h[2n=I&4%W9N^8K.k1(0n)Pus1!i|hF&S&%_X61v<D8!JQGc)U1>Q05\&=r v8'  < ../inputs/input/ruin.1378 > ../outputs/t3611
    if diff ../outputs/t3611 ../originals/t3611 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3612) timeout -s 9 2 ../source/replace.exe '@@' '|'  < ../inputs/input/ruin.315 > ../outputs/t3612
    if diff ../outputs/t3612 ../originals/t3612 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3613) timeout -s 9 2 ../source/replace.exe '@@' '|9d|RN?*4< I:m63#['  < ../inputs/input/ruin.883 > ../outputs/t3613
    if diff ../outputs/t3613 ../originals/t3613 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3614) timeout -s 9 2 ../source/replace.exe '@@' '|=}'  < ../inputs/input/ruin.353 > ../outputs/t3614
    if diff ../outputs/t3614 ../originals/t3614 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3615) timeout -s 9 2 ../source/replace.exe '@@' '|lf=?(vz<r0o_RA10&UVxvVk`*VTC%}VlIEoG7] '  < ../inputs/input/ruin.1953 > ../outputs/t3615
    if diff ../outputs/t3615 ../originals/t3615 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3616) timeout -s 9 2 ../source/replace.exe '@@' '}&5EvYBv%T2.bCUUMp7hd>P/EBX&~26D?2z|YJ)Ql ERswc'  < ../inputs/input/ruin.1741 > ../outputs/t3616
    if diff ../outputs/t3616 ../originals/t3616 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3617) timeout -s 9 2 ../source/replace.exe '@@' '}t'  < ../inputs/input/ruin.578 > ../outputs/t3617
    if diff ../outputs/t3617 ../originals/t3617 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3618) timeout -s 9 2 ../source/replace.exe '@@'\''93QTn'   < ../inputs/input/ruin.1264 > ../outputs/t3618
    if diff ../outputs/t3618 ../originals/t3618 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3619) timeout -s 9 2 ../source/replace.exe '@@'\''93QTn' 'O*9 p]M4:=D71<S{~2V6mPa'  < ../inputs/input/ruin.1264 > ../outputs/t3619
    if diff ../outputs/t3619 ../originals/t3619 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3620) timeout -s 9 2 ../source/replace.exe '@@'\''@n' 'mF%'  < ../inputs/input/ruin.1541 > ../outputs/t3620
    if diff ../outputs/t3620 ../originals/t3620 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3621) timeout -s 9 2 ../source/replace.exe '@@'\''B9z^p-f]Eq/' 'SH{S$QV0"e<bz-[(*Z9Q'  < ../inputs/input/ruin.635 > ../outputs/t3621
    if diff ../outputs/t3621 ../originals/t3621 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3622) timeout -s 9 2 ../source/replace.exe '@@'\''B9z^p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9Q' 'SH{S$QV0"e<b[0-9]--*[^a-c][0-9]--*[^a-c][0-9]--*[^a-c][0-9]--*[^a-c]z-[(*Z9Q'  < ../inputs/input/ruin.635 > ../outputs/t3622
    if diff ../outputs/t3622 ../originals/t3622 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3623) timeout -s 9 2 ../source/replace.exe '@@'\''F$S9yt4Q=q' 'Nkto_//y?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe"'  < ../inputs/input/ruin.1997 > ../outputs/t3623
    if diff ../outputs/t3623 ../originals/t3623 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3624) timeout -s 9 2 ../source/replace.exe '@@'\''F$S9yt4Q=q*$' 'Nkto_//y?Stj%,|9I{FxV*qi!{_(dn*K9`$woNwuJe"'  < ../inputs/input/ruin.1997 > ../outputs/t3624
    if diff ../outputs/t3624 ../originals/t3624 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3625) timeout -s 9 2 ../source/replace.exe '@@'\''Z(T[TC' '<'  < ../inputs/input/ruin.1079 > ../outputs/t3625
    if diff ../outputs/t3625 ../originals/t3625 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3626) timeout -s 9 2 ../source/replace.exe '@@'\''_h' 'C'  < ../inputs/input/ruin.1379 > ../outputs/t3626
    if diff ../outputs/t3626 ../originals/t3626 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3627) timeout -s 9 2 ../source/replace.exe '@@'\''j?' 'l'  < ../inputs/input/ruin.307 > ../outputs/t3627
    if diff ../outputs/t3627 ../originals/t3627 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3628) timeout -s 9 2 ../source/replace.exe '@@)' '6wTwyN~#+^?38P>|WqutbRgK3V[{^{qDMM*E*6PJw?A<oo?&udbM.8/9{3H@;uQ-okq.3o#U+wFAV'  < ../inputs/input/ruin.158 > ../outputs/t3628
    if diff ../outputs/t3628 ../originals/t3628 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3629) timeout -s 9 2 ../source/replace.exe '@@*$' '#'  < ../inputs/input/ruin.1116 > ../outputs/t3629
    if diff ../outputs/t3629 ../originals/t3629 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3630) timeout -s 9 2 ../source/replace.exe '@@*$' '+'  < ../inputs/input/ruin.2000 > ../outputs/t3630
    if diff ../outputs/t3630 ../originals/t3630 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3631) timeout -s 9 2 ../source/replace.exe '@@*$' '4'  < ../inputs/input/ruin.1992 > ../outputs/t3631
    if diff ../outputs/t3631 ../originals/t3631 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3632) timeout -s 9 2 ../source/replace.exe '@@*$' 'E9p\6X[t<jnR3{*3PQSno!);('  < ../inputs/input/ruin.1256 > ../outputs/t3632
    if diff ../outputs/t3632 ../originals/t3632 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3633) timeout -s 9 2 ../source/replace.exe '@@*$' 'T/'  < ../inputs/input/ruin.1109 > ../outputs/t3633
    if diff ../outputs/t3633 ../originals/t3633 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3634) timeout -s 9 2 ../source/replace.exe '@@*$' 'T?^S|}'\''!\>bF'\''5T'  < ../inputs/input/ruin.1250 > ../outputs/t3634
    if diff ../outputs/t3634 ../originals/t3634 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3635) timeout -s 9 2 ../source/replace.exe '@@*$' 'YCoe'  < ../inputs/input/ruin.1246 > ../outputs/t3635
    if diff ../outputs/t3635 ../originals/t3635 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3636) timeout -s 9 2 ../source/replace.exe '@@*$' 'tW'  < ../inputs/input/ruin.1247 > ../outputs/t3636
    if diff ../outputs/t3636 ../originals/t3636 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3637) timeout -s 9 2 ../source/replace.exe '@@*' ''  < ../inputs/input/ruin.1132 > ../outputs/t3637
    if diff ../outputs/t3637 ../originals/t3637 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3638) timeout -s 9 2 ../source/replace.exe '@@*' ';Jq'  < ../inputs/input/ruin.1645 > ../outputs/t3638
    if diff ../outputs/t3638 ../originals/t3638 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3639) timeout -s 9 2 ../source/replace.exe '@@*' '>(jLZz>>Lg~n<xr62=%!LO#hy}{eo>9D_'  < ../inputs/input/ruin.800 > ../outputs/t3639
    if diff ../outputs/t3639 ../originals/t3639 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3640) timeout -s 9 2 ../source/replace.exe '@@*' '}7Qy)}SI'\''nw#bVsE+<-OwA.8oYuwKHLNr4bFf'  < ../inputs/input/ruin.1621 > ../outputs/t3640
    if diff ../outputs/t3640 ../originals/t3640 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3641) timeout -s 9 2 ../source/replace.exe '@@*'\'',^P&Sh6@@' '(&S8w;8MY'  < ../inputs/input/ruin.1119 > ../outputs/t3641
    if diff ../outputs/t3641 ../originals/t3641 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3642) timeout -s 9 2 ../source/replace.exe '@@*'\'*$',^P&Sh6@@' '(&S8w;8MY'  < ../inputs/input/ruin.1119 > ../outputs/t3642
    if diff ../outputs/t3642 ../originals/t3642 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3643) timeout -s 9 2 ../source/replace.exe '@@**' '9Jwr6Whlet5:nulL=82){._jluPvUdHD}&'  < ../inputs/input/ruin.333 > ../outputs/t3643
    if diff ../outputs/t3643 ../originals/t3643 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3644) timeout -s 9 2 ../source/replace.exe '@@**' 'DR'\''R'\''$x@7uS2EbR[H/q4ml^<1S(?&U_L~_m#^MaWM;'  < ../inputs/input/ruin.981 > ../outputs/t3644
    if diff ../outputs/t3644 ../originals/t3644 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3645) timeout -s 9 2 ../source/replace.exe '@@*?' 'a&'  < ../inputs/temp-test/437.inp.192.1 > ../outputs/t3645
    if diff ../outputs/t3645 ../originals/t3645 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3646) timeout -s 9 2 ../source/replace.exe '@@*?' 'a&'  < ../inputs/temp-test/438.inp.192.3 > ../outputs/t3646
    if diff ../outputs/t3646 ../originals/t3646 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3647) timeout -s 9 2 ../source/replace.exe '@@*?' 'cAcJGn".:*uPb165}4{qxaW\2**HeQ^HrbNvka bpOeC/DmG)u\8bwF'  < ../inputs/input/ruin.560 > ../outputs/t3647
    if diff ../outputs/t3647 ../originals/t3647 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3648) timeout -s 9 2 ../source/replace.exe '@@*@n' 'H&b'  < ../inputs/input/ruin.273 > ../outputs/t3648
    if diff ../outputs/t3648 ../originals/t3648 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3649) timeout -s 9 2 ../source/replace.exe '@@*[0-9]' '&'  < ../inputs/temp-test/623.inp.269.1 > ../outputs/t3649
    if diff ../outputs/t3649 ../originals/t3649 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3650) timeout -s 9 2 ../source/replace.exe '@@*[0-9]' '&'  < ../inputs/temp-test/624.inp.269.2 > ../outputs/t3650
    if diff ../outputs/t3650 ../originals/t3650 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3651) timeout -s 9 2 ../source/replace.exe '@@*[0-9]' '&'  < ../inputs/temp-test/625.inp.269.3 > ../outputs/t3651
    if diff ../outputs/t3651 ../originals/t3651 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3652) timeout -s 9 2 ../source/replace.exe '@@*[0-9]?--??' 'a&'  < ../inputs/temp-test/1505.inp.645.1 > ../outputs/t3652
    if diff ../outputs/t3652 ../originals/t3652 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3653) timeout -s 9 2 ../source/replace.exe '@@*[0-9]?--??' 'a&'  < ../inputs/temp-test/1506.inp.645.4 > ../outputs/t3653
    if diff ../outputs/t3653 ../originals/t3653 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3654) timeout -s 9 2 ../source/replace.exe '@@*[9-B]?[^0-9][a-?$' 'a@n'  < ../inputs/temp-test/2207.inp.934.6 > ../outputs/t3654
    if diff ../outputs/t3654 ../originals/t3654 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3655) timeout -s 9 2 ../source/replace.exe '@@*[9-B]?[^0-9][a-?' 'a@n'  < ../inputs/temp-test/2205.inp.934.1 > ../outputs/t3655
    if diff ../outputs/t3655 ../originals/t3655 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3656) timeout -s 9 2 ../source/replace.exe '@@*[9-B]?[^0-9][a-?' 'a@n'  < ../inputs/temp-test/2206.inp.934.2 > ../outputs/t3656
    if diff ../outputs/t3656 ../originals/t3656 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3657) timeout -s 9 2 ../source/replace.exe '@@*[^9-B] *-c*[-$' '&a@%'  < ../inputs/temp-test/1496.inp.641.6 > ../outputs/t3657
    if diff ../outputs/t3657 ../originals/t3657 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3658) timeout -s 9 2 ../source/replace.exe '@@*[^9-B] *-c*[-' '&a@%'  < ../inputs/temp-test/1494.inp.641.1 > ../outputs/t3658
    if diff ../outputs/t3658 ../originals/t3658 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3659) timeout -s 9 2 ../source/replace.exe '@@*[^9-B] *-c*[-' '&a@%'  < ../inputs/temp-test/1495.inp.641.2 > ../outputs/t3659
    if diff ../outputs/t3659 ../originals/t3659 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3660) timeout -s 9 2 ../source/replace.exe '@@*[^a-]?-^*' '&'  < ../inputs/temp-test/2283.inp.967.1 > ../outputs/t3660
    if diff ../outputs/t3660 ../originals/t3660 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3661) timeout -s 9 2 ../source/replace.exe '@@*[^a-]?-^*' '&'  < ../inputs/temp-test/2284.inp.967.3 > ../outputs/t3661
    if diff ../outputs/t3661 ../originals/t3661 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3662) timeout -s 9 2 ../source/replace.exe '@@*[^a-]?-^*' '&'  < ../inputs/temp-test/2285.inp.967.4 > ../outputs/t3662
    if diff ../outputs/t3662 ../originals/t3662 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3663) timeout -s 9 2 ../source/replace.exe '@@*[^j]' '2'  < ../inputs/input/ruin.544 > ../outputs/t3663
    if diff ../outputs/t3663 ../originals/t3663 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3664) timeout -s 9 2 ../source/replace.exe '@@-$' 'a@nb@tc'  < ../inputs/temp-test/1160.inp.499.9 > ../outputs/t3664
    if diff ../outputs/t3664 ../originals/t3664 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3665) timeout -s 9 2 ../source/replace.exe '@@-' '&a@%'  < ../inputs/temp-test/412.inp.181.1 > ../outputs/t3665
    if diff ../outputs/t3665 ../originals/t3665 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3666) timeout -s 9 2 ../source/replace.exe '@@-' '@%&a'  < ../inputs/temp-test/455.inp.199.1 > ../outputs/t3666
    if diff ../outputs/t3666 ../originals/t3666 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3667) timeout -s 9 2 ../source/replace.exe '@@-' '@%&a'  < ../inputs/temp-test/456.inp.199.3 > ../outputs/t3667
    if diff ../outputs/t3667 ../originals/t3667 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3668) timeout -s 9 2 ../source/replace.exe '@@-' '@{Pu@]R]'  < ../inputs/input/ruin.790 > ../outputs/t3668
    if diff ../outputs/t3668 ../originals/t3668 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3669) timeout -s 9 2 ../source/replace.exe '@@-' 'a@nb@tc'  < ../inputs/temp-test/1158.inp.499.1 > ../outputs/t3669
    if diff ../outputs/t3669 ../originals/t3669 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3670) timeout -s 9 2 ../source/replace.exe '@@-' 'a@nb@tc'  < ../inputs/temp-test/1159.inp.499.2 > ../outputs/t3670
    if diff ../outputs/t3670 ../originals/t3670 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3671) timeout -s 9 2 ../source/replace.exe '@@-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*-[^9-B][^0-9]?*' 'wr'  < ../inputs/input/ruin.1340 > ../outputs/t3671
    if diff ../outputs/t3671 ../originals/t3671 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3672) timeout -s 9 2 ../source/replace.exe '@@4['\'']\~s' 'T'  < ../inputs/input/ruin.537 > ../outputs/t3672
    if diff ../outputs/t3672 ../originals/t3672 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3673) timeout -s 9 2 ../source/replace.exe '@@:@@' '{a)^[TRRKd]?/7S% SUK1Pu^#_}^E#IZW`i1e>[YZ:Mr~G'  < ../inputs/input/ruin.446 > ../outputs/t3673
    if diff ../outputs/t3673 ../originals/t3673 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3674) timeout -s 9 2 ../source/replace.exe '@@?$' 'T/'  < ../inputs/input/ruin.1109 > ../outputs/t3674
    if diff ../outputs/t3674 ../originals/t3674 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3675) timeout -s 9 2 ../source/replace.exe '@@?' ')V@/g0LQ"#siS2K8F0=m'  < ../inputs/input/ruin.113 > ../outputs/t3675
    if diff ../outputs/t3675 ../originals/t3675 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3676) timeout -s 9 2 ../source/replace.exe '@@?' '0&,p^#I}6fi.kmr6K)xdK(M'\''7Iz}z:3QIG0mEil6xX{(5CsNr(r'  < ../inputs/input/ruin.527 > ../outputs/t3676
    if diff ../outputs/t3676 ../originals/t3676 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3677) timeout -s 9 2 ../source/replace.exe '@@?' '6`*o-'  < ../inputs/input/ruin.1387 > ../outputs/t3677
    if diff ../outputs/t3677 ../originals/t3677 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3678) timeout -s 9 2 ../source/replace.exe '@@?' '7'  < ../inputs/input/ruin.498 > ../outputs/t3678
    if diff ../outputs/t3678 ../originals/t3678 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3679) timeout -s 9 2 ../source/replace.exe '@@?' '<0,s xFuv2Dp'  < ../inputs/input/ruin.1810 > ../outputs/t3679
    if diff ../outputs/t3679 ../originals/t3679 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3680) timeout -s 9 2 ../source/replace.exe '@@?' 'WL+gd/H[UWU$h}N[i;#5Qc)X+oU8&I)M-b/F9J! '\''"'\''C'  < ../inputs/input/ruin.914 > ../outputs/t3680
    if diff ../outputs/t3680 ../originals/t3680 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3681) timeout -s 9 2 ../source/replace.exe '@@?' 'gUGalF#O'  < ../inputs/input/ruin.963 > ../outputs/t3681
    if diff ../outputs/t3681 ../originals/t3681 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3682) timeout -s 9 2 ../source/replace.exe '@@?' 'xZ@G7` /`/o))1@@NO? k5&m<#YcQg)OGD<ORel>4MD'  < ../inputs/input/ruin.569 > ../outputs/t3682
    if diff ../outputs/t3682 ../originals/t3682 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3683) timeout -s 9 2 ../source/replace.exe '@@?*' '#'  < ../inputs/input/ruin.1615 > ../outputs/t3683
    if diff ../outputs/t3683 ../originals/t3683 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3684) timeout -s 9 2 ../source/replace.exe '@@?*' 'I'  < ../inputs/input/ruin.1485 > ../outputs/t3684
    if diff ../outputs/t3684 ../originals/t3684 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3685) timeout -s 9 2 ../source/replace.exe '@@?*' ']'  < ../inputs/input/ruin.1597 > ../outputs/t3685
    if diff ../outputs/t3685 ../originals/t3685 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3686) timeout -s 9 2 ../source/replace.exe '@@?*' 'e^O;EJ5?6DU!Sw"B%ah'\''m*lY_`a'  < ../inputs/input/ruin.1598 > ../outputs/t3686
    if diff ../outputs/t3686 ../originals/t3686 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3687) timeout -s 9 2 ../source/replace.exe '@@?*' 't+b%Ev`=tGgLKIdrp'  < ../inputs/input/ruin.1596 > ../outputs/t3687
    if diff ../outputs/t3687 ../originals/t3687 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3688) timeout -s 9 2 ../source/replace.exe '@@?*' '}7Qy)}SI'\''nw#bVsE+<-OwA.8oYuwKHLNr4bFf'  < ../inputs/input/ruin.1621 > ../outputs/t3688
    if diff ../outputs/t3688 ../originals/t3688 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3689) timeout -s 9 2 ../source/replace.exe '@@?A$' 'K'  < ../inputs/input/ruin.1609 > ../outputs/t3689
    if diff ../outputs/t3689 ../originals/t3689 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3690) timeout -s 9 2 ../source/replace.exe '@@?A$?*' 'K'  < ../inputs/input/ruin.1609 > ../outputs/t3690
    if diff ../outputs/t3690 ../originals/t3690 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3691) timeout -s 9 2 ../source/replace.exe '@@?[^c-a$]' 't'  < ../inputs/input/ruin.416 > ../outputs/t3691
    if diff ../outputs/t3691 ../originals/t3691 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3692) timeout -s 9 2 ../source/replace.exe '@@?w$' '7'  < ../inputs/input/ruin.314 > ../outputs/t3692
    if diff ../outputs/t3692 ../originals/t3692 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3693) timeout -s 9 2 ../source/replace.exe '@@@!' '5]y50ks{!u}xF93w}f[;WP4&Q4[=4'  < ../inputs/input/ruin.73 > ../outputs/t3693
    if diff ../outputs/t3693 ../originals/t3693 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3694) timeout -s 9 2 ../source/replace.exe '@@@/@@[0-9]' 'o'  < ../inputs/input/ruin.284 > ../outputs/t3694
    if diff ../outputs/t3694 ../originals/t3694 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3695) timeout -s 9 2 ../source/replace.exe '@@@2*' 'NU'  < ../inputs/input/ruin.567 > ../outputs/t3695
    if diff ../outputs/t3695 ../originals/t3695 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3696) timeout -s 9 2 ../source/replace.exe '@@@@$' '+'  < ../inputs/input/ruin.786 > ../outputs/t3696
    if diff ../outputs/t3696 ../originals/t3696 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3697) timeout -s 9 2 ../source/replace.exe '@@@@$' 'IvJL"!Kh[JX'\''_wS|r+Z(:B7<xtHS@p38c|cC#}/j#FpjA>;BuZf09%h1jMyFu'  < ../inputs/input/ruin.1928 > ../outputs/t3697
    if diff ../outputs/t3697 ../originals/t3697 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3698) timeout -s 9 2 ../source/replace.exe '@@@@' '!+f(~L|L^Uc6wf5)pmPAJjC6yX}^=`D&MGl@W'  < ../inputs/input/ruin.1920 > ../outputs/t3698
    if diff ../outputs/t3698 ../originals/t3698 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3699) timeout -s 9 2 ../source/replace.exe '@@@@' '='  < ../inputs/input/ruin.910 > ../outputs/t3699
    if diff ../outputs/t3699 ../originals/t3699 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3700) timeout -s 9 2 ../source/replace.exe '@@@@' 'F*)H: O}u'  < ../inputs/input/ruin.1092 > ../outputs/t3700
    if diff ../outputs/t3700 ../originals/t3700 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3701) timeout -s 9 2 ../source/replace.exe '@@@@' 'L'  < ../inputs/input/ruin.389 > ../outputs/t3701
    if diff ../outputs/t3701 ../originals/t3701 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3702) timeout -s 9 2 ../source/replace.exe '@@@@' 'L'  < ../inputs/input/ruin.407 > ../outputs/t3702
    if diff ../outputs/t3702 ../originals/t3702 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3703) timeout -s 9 2 ../source/replace.exe '@@@@' 'T'  < ../inputs/input/ruin.181 > ../outputs/t3703
    if diff ../outputs/t3703 ../originals/t3703 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3704) timeout -s 9 2 ../source/replace.exe '@@@@' 'T'  < ../inputs/input/ruin.885 > ../outputs/t3704
    if diff ../outputs/t3704 ../originals/t3704 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3705) timeout -s 9 2 ../source/replace.exe '@@@@' '[V]s~wXx-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^-[^a-c][0-9]@[[0-9]*[^0-9]*-[^a-c]@n*^[^M3af'  < ../inputs/input/ruin.1342 > ../outputs/t3705
    if diff ../outputs/t3705 ../originals/t3705 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3706) timeout -s 9 2 ../source/replace.exe '@@@@' '[V]s~wXxM3af'  < ../inputs/input/ruin.1342 > ../outputs/t3706
    if diff ../outputs/t3706 ../originals/t3706 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3707) timeout -s 9 2 ../source/replace.exe '@@@@' ']~;WpJ>rM%DNS/`+N@R\=W'\''7q((@!7pb&v"'  < ../inputs/input/ruin.184 > ../outputs/t3707
    if diff ../outputs/t3707 ../originals/t3707 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3708) timeout -s 9 2 ../source/replace.exe '@@@@' 'iQh&l$RTw@>}2m/i}Jua'\''w_1'\''z1`b&Q9cU'  < ../inputs/input/ruin.351 > ../outputs/t3708
    if diff ../outputs/t3708 ../originals/t3708 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3709) timeout -s 9 2 ../source/replace.exe '@@@@' '|J/3~Opz]2uqtMS\~E'  < ../inputs/input/ruin.803 > ../outputs/t3709
    if diff ../outputs/t3709 ../originals/t3709 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3710) timeout -s 9 2 ../source/replace.exe '@@@@?' 'w2OuzZ7S6'  < ../inputs/input/ruin.929 > ../outputs/t3710
    if diff ../outputs/t3710 ../originals/t3710 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3711) timeout -s 9 2 ../source/replace.exe '@@@@S' 'BZvBw]7~=NB4MK@b'  < ../inputs/input/ruin.1143 > ../outputs/t3711
    if diff ../outputs/t3711 ../originals/t3711 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3712) timeout -s 9 2 ../source/replace.exe '@@@@\G$H.|M' 'y&'  < ../inputs/input/ruin.672 > ../outputs/t3712
    if diff ../outputs/t3712 ../originals/t3712 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3713) timeout -s 9 2 ../source/replace.exe '@@@`' '3"'  < ../inputs/input/ruin.1824 > ../outputs/t3713
    if diff ../outputs/t3713 ../originals/t3713 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3714) timeout -s 9 2 ../source/replace.exe '@@@n' '60&<9:5*f8GULK>.:&6r]A'  < ../inputs/input/ruin.1321 > ../outputs/t3714
    if diff ../outputs/t3714 ../originals/t3714 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3715) timeout -s 9 2 ../source/replace.exe '@@@n' ';&.St7,*,FY'\''e2 #PQt_JAdEVyBorNLKtG4,nKOUCw{Tr/J2d]Omr-PWjk+'  < ../inputs/input/ruin.98 > ../outputs/t3715
    if diff ../outputs/t3715 ../originals/t3715 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3716) timeout -s 9 2 ../source/replace.exe '@@F' 'f[6_8'  < ../inputs/input/ruin.1138 > ../outputs/t3716
    if diff ../outputs/t3716 ../originals/t3716 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3717) timeout -s 9 2 ../source/replace.exe '@@J*' '('  < ../inputs/input/ruin.1467 > ../outputs/t3717
    if diff ../outputs/t3717 ../originals/t3717 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3718) timeout -s 9 2 ../source/replace.exe '@@[0-9]*o[0-9]' '$'  < ../inputs/input/ruin.566 > ../outputs/t3718
    if diff ../outputs/t3718 ../originals/t3718 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3719) timeout -s 9 2 ../source/replace.exe '@@[>-A]' '%o9j&*k~kjfdI'  < ../inputs/input/ruin.1080 > ../outputs/t3719
    if diff ../outputs/t3719 ../originals/t3719 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3720) timeout -s 9 2 ../source/replace.exe '@@[A-G]$' 'O'  < ../inputs/input/ruin.614 > ../outputs/t3720
    if diff ../outputs/t3720 ../originals/t3720 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3721) timeout -s 9 2 ../source/replace.exe '@@[A-Gz-}<]' 'I'  < ../inputs/input/ruin.609 > ../outputs/t3721
    if diff ../outputs/t3721 ../originals/t3721 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3722) timeout -s 9 2 ../source/replace.exe '@@[^--z]' 'NEW'  < ../inputs/temp-test/2125.inp.901.1 > ../outputs/t3722
    if diff ../outputs/t3722 ../originals/t3722 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3723) timeout -s 9 2 ../source/replace.exe '@@[^--z]' 'NEW'  < ../inputs/temp-test/2126.inp.901.3 > ../outputs/t3723
    if diff ../outputs/t3723 ../originals/t3723 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3724) timeout -s 9 2 ../source/replace.exe '@@[^--z]' 'NEW'  < ../inputs/temp-test/2127.inp.901.4 > ../outputs/t3724
    if diff ../outputs/t3724 ../originals/t3724 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3725) timeout -s 9 2 ../source/replace.exe '@@[^0-9]' '@n'  < ../inputs/temp-test/1087.inp.468.1 > ../outputs/t3725
    if diff ../outputs/t3725 ../originals/t3725 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3726) timeout -s 9 2 ../source/replace.exe '@@[^0-9]' '@n'  < ../inputs/temp-test/1088.inp.468.3 > ../outputs/t3726
    if diff ../outputs/t3726 ../originals/t3726 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3727) timeout -s 9 2 ../source/replace.exe '@@[^A-Gn0-9]' 'A)T537M`;~`g'  < ../inputs/input/ruin.1519 > ../outputs/t3727
    if diff ../outputs/t3727 ../originals/t3727 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3728) timeout -s 9 2 ../source/replace.exe '@@[^l]' 'c'  < ../inputs/input/ruin.1453 > ../outputs/t3728
    if diff ../outputs/t3728 ../originals/t3728 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3729) timeout -s 9 2 ../source/replace.exe '@@[a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9]' 'e'  < ../inputs/input/ruin.323 > ../outputs/t3729
    if diff ../outputs/t3729 ../originals/t3729 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3730) timeout -s 9 2 ../source/replace.exe '@@[a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c*[0-9][a-c]-?-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*[0-9]' 'q'  < ../inputs/input/ruin.322 > ../outputs/t3730
    if diff ../outputs/t3730 ../originals/t3730 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3731) timeout -s 9 2 ../source/replace.exe '@@[z-}]'   < ../inputs/input/ruin.1263 > ../outputs/t3731
    if diff ../outputs/t3731 ../originals/t3731 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3732) timeout -s 9 2 ../source/replace.exe '@@[z-}]' '/s_ziY.ZkrBEgFC4_(F^|T`jH`t@hJl,j=#7sJ}'  < ../inputs/input/ruin.1263 > ../outputs/t3732
    if diff ../outputs/t3732 ../originals/t3732 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3733) timeout -s 9 2 ../source/replace.exe '@@\)' '4I'  < ../inputs/input/ruin.1063 > ../outputs/t3733
    if diff ../outputs/t3733 ../originals/t3733 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3734) timeout -s 9 2 ../source/replace.exe '@@\)' '7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mpAv6)cN.l7mp4I'  < ../inputs/input/ruin.1063 > ../outputs/t3734
    if diff ../outputs/t3734 ../originals/t3734 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3735) timeout -s 9 2 ../source/replace.exe '@@\EO' 'KH-J?'\''`M!B=/fD`}s=H@.K]'  < ../inputs/input/ruin.346 > ../outputs/t3735
    if diff ../outputs/t3735 ../originals/t3735 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3736) timeout -s 9 2 ../source/replace.exe '@@]' 'ueNxiCI$-'  < ../inputs/input/ruin.1687 > ../outputs/t3736
    if diff ../outputs/t3736 ../originals/t3736 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3737) timeout -s 9 2 ../source/replace.exe '@@^a-c]' '@%@&'  < ../inputs/temp-test/185.inp.83.1 > ../outputs/t3737
    if diff ../outputs/t3737 ../originals/t3737 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3738) timeout -s 9 2 ../source/replace.exe '@@`' 'm'  < ../inputs/input/ruin.734 > ../outputs/t3738
    if diff ../outputs/t3738 ../originals/t3738 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3739) timeout -s 9 2 ../source/replace.exe '@@o'\''D@z@@?' 'D*Cx2,Ha$<h|]}{:Vf C/To4Vds0QNM+LTtC%Q1{""W'  < ../inputs/input/ruin.437 > ../outputs/t3739
    if diff ../outputs/t3739 ../originals/t3739 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3740) timeout -s 9 2 ../source/replace.exe '@@p&y=3[ZNLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{HC<5S)0ft3+1A]NLF]{H*[0-9]*C<5S)0ft3+1A]YIgTBk-*?* *[a' '+'  < ../inputs/input/ruin.1338 > ../outputs/t3740
    if diff ../outputs/t3740 ../originals/t3740 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3741) timeout -s 9 2 ../source/replace.exe '@@p&y=3[ZYIgp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYIp&y=3[ZYITBk' 'T'  < ../inputs/input/ruin.1330 > ../outputs/t3741
    if diff ../outputs/t3741 ../originals/t3741 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3742) timeout -s 9 2 ../source/replace.exe '@@s' '3'  < ../inputs/input/ruin.605 > ../outputs/t3742
    if diff ../outputs/t3742 ../originals/t3742 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3743) timeout -s 9 2 ../source/replace.exe '@A$' 'Vm3P(j&"*S[r19i9]}TqvX%/B[p^JXe_'  < ../inputs/input/ruin.66 > ../outputs/t3743
    if diff ../outputs/t3743 ../originals/t3743 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3744) timeout -s 9 2 ../source/replace.exe '@C' 'z'  < ../inputs/input/ruin.1125 > ../outputs/t3744
    if diff ../outputs/t3744 ../originals/t3744 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3745) timeout -s 9 2 ../source/replace.exe '@D' '.'  < ../inputs/input/ruin.1169 > ../outputs/t3745
    if diff ../outputs/t3745 ../originals/t3745 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3746) timeout -s 9 2 ../source/replace.exe '@E' 'PLvh0lN%L2%?&GW#2VGQ>D,<~.4l,[<Z;xbv|!y'  < ../inputs/input/ruin.245 > ../outputs/t3746
    if diff ../outputs/t3746 ../originals/t3746 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3747) timeout -s 9 2 ../source/replace.exe '@J' 'K'  < ../inputs/input/ruin.465 > ../outputs/t3747
    if diff ../outputs/t3747 ../originals/t3747 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3748) timeout -s 9 2 ../source/replace.exe '@J' 'rTRJy`3lY]0ky'  < ../inputs/input/ruin.1895 > ../outputs/t3748
    if diff ../outputs/t3748 ../originals/t3748 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3749) timeout -s 9 2 ../source/replace.exe '@P' 'XUd+.8r\'  < ../inputs/input/ruin.1606 > ../outputs/t3749
    if diff ../outputs/t3749 ../originals/t3749 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3750) timeout -s 9 2 ../source/replace.exe '@P?*' 'XUd+.8r\'  < ../inputs/input/ruin.1606 > ../outputs/t3750
    if diff ../outputs/t3750 ../originals/t3750 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3751) timeout -s 9 2 ../source/replace.exe '@R' '^'  < ../inputs/input/ruin.208 > ../outputs/t3751
    if diff ../outputs/t3751 ../originals/t3751 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3752) timeout -s 9 2 ../source/replace.exe '@T' '}'  < ../inputs/input/ruin.1233 > ../outputs/t3752
    if diff ../outputs/t3752 ../originals/t3752 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3753) timeout -s 9 2 ../source/replace.exe '@X' 'j'  < ../inputs/input/ruin.972 > ../outputs/t3753
    if diff ../outputs/t3753 ../originals/t3753 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3754) timeout -s 9 2 ../source/replace.exe '@Y' 'n"F;S+\) buv"j('  < ../inputs/input/ruin.1908 > ../outputs/t3754
    if diff ../outputs/t3754 ../originals/t3754 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3755) timeout -s 9 2 ../source/replace.exe '@Y' 'uY.rul7yx-pu2#3MGnr'\'''  < ../inputs/input/ruin.889 > ../outputs/t3755
    if diff ../outputs/t3755 ../originals/t3755 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3756) timeout -s 9 2 ../source/replace.exe '@Z' 'q'  < ../inputs/input/ruin.1194 > ../outputs/t3756
    if diff ../outputs/t3756 ../originals/t3756 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3757) timeout -s 9 2 ../source/replace.exe '@[' '@%@&'  < ../inputs/temp-test/2286.inp.968.1 > ../outputs/t3757
    if diff ../outputs/t3757 ../originals/t3757 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3758) timeout -s 9 2 ../source/replace.exe '@[' '@%@&'  < ../inputs/temp-test/2287.inp.968.3 > ../outputs/t3758
    if diff ../outputs/t3758 ../originals/t3758 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3759) timeout -s 9 2 ../source/replace.exe '@[' '@t'  < ../inputs/temp-test/1463.inp.627.1 > ../outputs/t3759
    if diff ../outputs/t3759 ../originals/t3759 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3760) timeout -s 9 2 ../source/replace.exe '@[' '@t'  < ../inputs/temp-test/1464.inp.627.2 > ../outputs/t3760
    if diff ../outputs/t3760 ../originals/t3760 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3761) timeout -s 9 2 ../source/replace.exe '@[' 'a@nb@tc'  < ../inputs/temp-test/1095.inp.472.1 > ../outputs/t3761
    if diff ../outputs/t3761 ../originals/t3761 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3762) timeout -s 9 2 ../source/replace.exe '@[' 'a@nb@tc'  < ../inputs/temp-test/1096.inp.472.2 > ../outputs/t3762
    if diff ../outputs/t3762 ../originals/t3762 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3763) timeout -s 9 2 ../source/replace.exe '@[' 'a@nb@tc'  < ../inputs/temp-test/1097.inp.472.3 > ../outputs/t3763
    if diff ../outputs/t3763 ../originals/t3763 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3764) timeout -s 9 2 ../source/replace.exe '@[*' ''  < ../inputs/temp-test/2203.inp.933.1 > ../outputs/t3764
    if diff ../outputs/t3764 ../originals/t3764 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3765) timeout -s 9 2 ../source/replace.exe '@[*' ''  < ../inputs/temp-test/2204.inp.933.3 > ../outputs/t3765
    if diff ../outputs/t3765 ../originals/t3765 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3766) timeout -s 9 2 ../source/replace.exe '@[*' 'NEW'  < ../inputs/temp-test/673.inp.293.1 > ../outputs/t3766
    if diff ../outputs/t3766 ../originals/t3766 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3767) timeout -s 9 2 ../source/replace.exe '@[*' 'NEW'  < ../inputs/temp-test/674.inp.293.2 > ../outputs/t3767
    if diff ../outputs/t3767 ../originals/t3767 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3768) timeout -s 9 2 ../source/replace.exe '@[*' 'NEW'  < ../inputs/temp-test/675.inp.293.3 > ../outputs/t3768
    if diff ../outputs/t3768 ../originals/t3768 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3769) timeout -s 9 2 ../source/replace.exe '@[*-$%' ''  < ../inputs/temp-test/2331.inp.988.6 > ../outputs/t3769
    if diff ../outputs/t3769 ../originals/t3769 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3770) timeout -s 9 2 ../source/replace.exe '@[*-$' ''  < ../inputs/temp-test/2331.inp.988.6 > ../outputs/t3770
    if diff ../outputs/t3770 ../originals/t3770 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3771) timeout -s 9 2 ../source/replace.exe '@[*-%' ''  < ../inputs/temp-test/2330.inp.988.4 > ../outputs/t3771
    if diff ../outputs/t3771 ../originals/t3771 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3772) timeout -s 9 2 ../source/replace.exe '@[*-' ''  < ../inputs/temp-test/2327.inp.988.1 > ../outputs/t3772
    if diff ../outputs/t3772 ../originals/t3772 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3773) timeout -s 9 2 ../source/replace.exe '@[*-' ''  < ../inputs/temp-test/2328.inp.988.2 > ../outputs/t3773
    if diff ../outputs/t3773 ../originals/t3773 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3774) timeout -s 9 2 ../source/replace.exe '@[*-' ''  < ../inputs/temp-test/2329.inp.988.3 > ../outputs/t3774
    if diff ../outputs/t3774 ../originals/t3774 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3775) timeout -s 9 2 ../source/replace.exe '@[*-' ''  < ../inputs/temp-test/2330.inp.988.4 > ../outputs/t3775
    if diff ../outputs/t3775 ../originals/t3775 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3776) timeout -s 9 2 ../source/replace.exe '@[*-?[a-c$'   < ../inputs/temp-test/210.inp.93.8 > ../outputs/t3776
    if diff ../outputs/t3776 ../originals/t3776 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3777) timeout -s 9 2 ../source/replace.exe '@[*-?[a-c$' 'a@nb@tc'  < ../inputs/temp-test/210.inp.93.8 > ../outputs/t3777
    if diff ../outputs/t3777 ../originals/t3777 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3778) timeout -s 9 2 ../source/replace.exe '@[*-?[a-c'   < ../inputs/temp-test/208.inp.93.2 > ../outputs/t3778
    if diff ../outputs/t3778 ../originals/t3778 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3779) timeout -s 9 2 ../source/replace.exe '@[*-?[a-c'   < ../inputs/temp-test/209.inp.93.3 > ../outputs/t3779
    if diff ../outputs/t3779 ../originals/t3779 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3780) timeout -s 9 2 ../source/replace.exe '@[*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/207.inp.93.1 > ../outputs/t3780
    if diff ../outputs/t3780 ../originals/t3780 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3781) timeout -s 9 2 ../source/replace.exe '@[*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/208.inp.93.2 > ../outputs/t3781
    if diff ../outputs/t3781 ../originals/t3781 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3782) timeout -s 9 2 ../source/replace.exe '@[*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/209.inp.93.3 > ../outputs/t3782
    if diff ../outputs/t3782 ../originals/t3782 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3783) timeout -s 9 2 ../source/replace.exe '@[*?' 'a@n'  < ../inputs/temp-test/2189.inp.927.1 > ../outputs/t3783
    if diff ../outputs/t3783 ../originals/t3783 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3784) timeout -s 9 2 ../source/replace.exe '@[*?' 'a@n'  < ../inputs/temp-test/2190.inp.927.2 > ../outputs/t3784
    if diff ../outputs/t3784 ../originals/t3784 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3785) timeout -s 9 2 ../source/replace.exe '@[*[0-9]' ''  < ../inputs/temp-test/2132.inp.903.1 > ../outputs/t3785
    if diff ../outputs/t3785 ../originals/t3785 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3786) timeout -s 9 2 ../source/replace.exe '@[*[0-9]' ''  < ../inputs/temp-test/2133.inp.903.2 > ../outputs/t3786
    if diff ../outputs/t3786 ../originals/t3786 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3787) timeout -s 9 2 ../source/replace.exe '@[*[0-9]' ''  < ../inputs/temp-test/2134.inp.903.3 > ../outputs/t3787
    if diff ../outputs/t3787 ../originals/t3787 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3788) timeout -s 9 2 ../source/replace.exe '@[*[9-B]' '&'  < ../inputs/temp-test/491.inp.215.1 > ../outputs/t3788
    if diff ../outputs/t3788 ../originals/t3788 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3789) timeout -s 9 2 ../source/replace.exe '@[*[9-B]?-[a-c]?@**[9-B][-z][^9-B]@@' '@%@&'  < ../inputs/temp-test/471.inp.206.1 > ../outputs/t3789
    if diff ../outputs/t3789 ../originals/t3789 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3790) timeout -s 9 2 ../source/replace.exe '@[*[9-B]?-[a-c]?@**[9-B][-z][^9-B]@@' '@%@&'  < ../inputs/temp-test/472.inp.206.2 > ../outputs/t3790
    if diff ../outputs/t3790 ../originals/t3790 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3791) timeout -s 9 2 ../source/replace.exe '@[*[9-B]?-[a-c]?@**[9-B][-z][^9-B]@@' '@%@&'  < ../inputs/temp-test/473.inp.206.3 > ../outputs/t3791
    if diff ../outputs/t3791 ../originals/t3791 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3792) timeout -s 9 2 ../source/replace.exe '@[*[9-B]@' '&@'  < ../inputs/temp-test/491.inp.215.1 > ../outputs/t3792
    if diff ../outputs/t3792 ../originals/t3792 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3793) timeout -s 9 2 ../source/replace.exe '@[*[9-B][0-9]?' '&'  < ../inputs/temp-test/1358.inp.583.1 > ../outputs/t3793
    if diff ../outputs/t3793 ../originals/t3793 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3794) timeout -s 9 2 ../source/replace.exe '@[*[9-B][0-9]?' '&'  < ../inputs/temp-test/1359.inp.583.2 > ../outputs/t3794
    if diff ../outputs/t3794 ../originals/t3794 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3795) timeout -s 9 2 ../source/replace.exe '@[*[9-B][0-9]?' '&'  < ../inputs/temp-test/1360.inp.583.4 > ../outputs/t3795
    if diff ../outputs/t3795 ../originals/t3795 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3796) timeout -s 9 2 ../source/replace.exe '@[*[^9-B]' 'a@nb@tc'  < ../inputs/temp-test/2113.inp.896.1 > ../outputs/t3796
    if diff ../outputs/t3796 ../originals/t3796 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3797) timeout -s 9 2 ../source/replace.exe '@[*[^9-B]' 'a@nb@tc'  < ../inputs/temp-test/2114.inp.896.2 > ../outputs/t3797
    if diff ../outputs/t3797 ../originals/t3797 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3798) timeout -s 9 2 ../source/replace.exe '@[*[^9-B][^a-c?' 'NEW'  < ../inputs/temp-test/474.inp.207.1 > ../outputs/t3798
    if diff ../outputs/t3798 ../originals/t3798 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3799) timeout -s 9 2 ../source/replace.exe '@[*[^9-B][^a-c?' 'NEW'  < ../inputs/temp-test/475.inp.207.2 > ../outputs/t3799
    if diff ../outputs/t3799 ../originals/t3799 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3800) timeout -s 9 2 ../source/replace.exe '@[*[a-]' '@%@&'  < ../inputs/temp-test/1600.inp.681.1 > ../outputs/t3800
    if diff ../outputs/t3800 ../originals/t3800 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3801) timeout -s 9 2 ../source/replace.exe '@[*[a-]' '@%@&'  < ../inputs/temp-test/1601.inp.681.2 > ../outputs/t3801
    if diff ../outputs/t3801 ../originals/t3801 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3802) timeout -s 9 2 ../source/replace.exe '@[*[a-]' '@%@&'  < ../inputs/temp-test/1602.inp.681.3 > ../outputs/t3802
    if diff ../outputs/t3802 ../originals/t3802 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3803) timeout -s 9 2 ../source/replace.exe '@[*[a-c]' 'NEW'  < ../inputs/temp-test/1370.inp.588.1 > ../outputs/t3803
    if diff ../outputs/t3803 ../originals/t3803 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3804) timeout -s 9 2 ../source/replace.exe '@[*[a-c]' 'NEW'  < ../inputs/temp-test/1371.inp.588.2 > ../outputs/t3804
    if diff ../outputs/t3804 ../originals/t3804 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3805) timeout -s 9 2 ../source/replace.exe '@[?[^9-B]-[a-[^0-9][9-B]?' '@t'  < ../inputs/temp-test/1762.inp.750.1 > ../outputs/t3805
    if diff ../outputs/t3805 ../originals/t3805 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3806) timeout -s 9 2 ../source/replace.exe '@[?[^9-B]-[a-[^0-9][9-B]?' '@t'  < ../inputs/temp-test/1763.inp.750.2 > ../outputs/t3806
    if diff ../outputs/t3806 ../originals/t3806 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3807) timeout -s 9 2 ../source/replace.exe '@[?[^a-c]?[^0-9]-[^9-B][a-c]' '@%@&'  < ../inputs/temp-test/1356.inp.582.1 > ../outputs/t3807
    if diff ../outputs/t3807 ../originals/t3807 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3808) timeout -s 9 2 ../source/replace.exe '@[?[^a-c]?[^0-9]-[^9-B][a-c]' '@%@&'  < ../inputs/temp-test/1357.inp.582.3 > ../outputs/t3808
    if diff ../outputs/t3808 ../originals/t3808 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3809) timeout -s 9 2 ../source/replace.exe '@[A*[9-B]^[0-9]$' '@%&a'  < ../inputs/temp-test/1513.inp.647.6 > ../outputs/t3809
    if diff ../outputs/t3809 ../originals/t3809 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3810) timeout -s 9 2 ../source/replace.exe '@[A*[9-B]^[0-9]' '@%&a'  < ../inputs/temp-test/1509.inp.647.1 > ../outputs/t3810
    if diff ../outputs/t3810 ../originals/t3810 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3811) timeout -s 9 2 ../source/replace.exe '@[A*[9-B]^[0-9]' '@%&a'  < ../inputs/temp-test/1510.inp.647.2 > ../outputs/t3811
    if diff ../outputs/t3811 ../originals/t3811 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3812) timeout -s 9 2 ../source/replace.exe '@[A*[9-B]^[0-9]' '@%&a'  < ../inputs/temp-test/1511.inp.647.3 > ../outputs/t3812
    if diff ../outputs/t3812 ../originals/t3812 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3813) timeout -s 9 2 ../source/replace.exe '@[A*[9-B]^[0-9]' '@%&a'  < ../inputs/temp-test/1512.inp.647.4 > ../outputs/t3813
    if diff ../outputs/t3813 ../originals/t3813 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3814) timeout -s 9 2 ../source/replace.exe '@[[0-9]' '&'  < ../inputs/temp-test/1180.inp.509.1 > ../outputs/t3814
    if diff ../outputs/t3814 ../originals/t3814 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3815) timeout -s 9 2 ../source/replace.exe '@[[0-9]' '&'  < ../inputs/temp-test/1181.inp.509.2 > ../outputs/t3815
    if diff ../outputs/t3815 ../originals/t3815 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3816) timeout -s 9 2 ../source/replace.exe '@[[0-9]' '&'  < ../inputs/temp-test/1182.inp.509.3 > ../outputs/t3816
    if diff ../outputs/t3816 ../originals/t3816 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3817) timeout -s 9 2 ../source/replace.exe '@[[0-9]' ''  < ../inputs/temp-test/2225.inp.944.1 > ../outputs/t3817
    if diff ../outputs/t3817 ../originals/t3817 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3818) timeout -s 9 2 ../source/replace.exe '@[[0-9]' ''  < ../inputs/temp-test/2226.inp.944.2 > ../outputs/t3818
    if diff ../outputs/t3818 ../originals/t3818 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3819) timeout -s 9 2 ../source/replace.exe '@[[0-9]' ''  < ../inputs/temp-test/2227.inp.944.3 > ../outputs/t3819
    if diff ../outputs/t3819 ../originals/t3819 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3820) timeout -s 9 2 ../source/replace.exe '@[[0-9]' 'NEW'  < ../inputs/temp-test/720.inp.311.1 > ../outputs/t3820
    if diff ../outputs/t3820 ../originals/t3820 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3821) timeout -s 9 2 ../source/replace.exe '@[[0-9]' 'NEW'  < ../inputs/temp-test/721.inp.311.2 > ../outputs/t3821
    if diff ../outputs/t3821 ../originals/t3821 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3822) timeout -s 9 2 ../source/replace.exe '@[[9-B]-' '@%&a'  < ../inputs/temp-test/1021.inp.439.1 > ../outputs/t3822
    if diff ../outputs/t3822 ../originals/t3822 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3823) timeout -s 9 2 ../source/replace.exe '@[[9-B]-' '@%&a'  < ../inputs/temp-test/1022.inp.439.2 > ../outputs/t3823
    if diff ../outputs/t3823 ../originals/t3823 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3824) timeout -s 9 2 ../source/replace.exe '@[[9-B]^[^9-B]' 'NEW'  < ../inputs/temp-test/812.inp.349.1 > ../outputs/t3824
    if diff ../outputs/t3824 ../originals/t3824 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3825) timeout -s 9 2 ../source/replace.exe '@[[^0-9]' '@%&a'  < ../inputs/temp-test/947.inp.408.1 > ../outputs/t3825
    if diff ../outputs/t3825 ../originals/t3825 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3826) timeout -s 9 2 ../source/replace.exe '@[[^0-9]' '@%&a'  < ../inputs/temp-test/948.inp.408.3 > ../outputs/t3826
    if diff ../outputs/t3826 ../originals/t3826 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3827) timeout -s 9 2 ../source/replace.exe '@[[^0-9]*' 'a@nb@tc'  < ../inputs/temp-test/131.inp.61.1 > ../outputs/t3827
    if diff ../outputs/t3827 ../originals/t3827 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3828) timeout -s 9 2 ../source/replace.exe '@[[^0-9]*' 'a@nb@tc'  < ../inputs/temp-test/132.inp.61.4 > ../outputs/t3828
    if diff ../outputs/t3828 ../originals/t3828 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3829) timeout -s 9 2 ../source/replace.exe '@[[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B]' '[[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B][[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B][[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B][[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B]a&'  < ../inputs/temp-test/2266.inp.961.1 > ../outputs/t3829
    if diff ../outputs/t3829 ../originals/t3829 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3830) timeout -s 9 2 ../source/replace.exe '@[[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B]' 'a&'  < ../inputs/temp-test/2266.inp.961.1 > ../outputs/t3830
    if diff ../outputs/t3830 ../originals/t3830 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3831) timeout -s 9 2 ../source/replace.exe '@[[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B]' 'a&'  < ../inputs/temp-test/2267.inp.961.2 > ../outputs/t3831
    if diff ../outputs/t3831 ../originals/t3831 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3832) timeout -s 9 2 ../source/replace.exe '@[[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B]' 'a&'  < ../inputs/temp-test/2268.inp.961.4 > ../outputs/t3832
    if diff ../outputs/t3832 ../originals/t3832 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3833) timeout -s 9 2 ../source/replace.exe '@[[^a-c]' 'a@n'  < ../inputs/temp-test/771.inp.331.1 > ../outputs/t3833
    if diff ../outputs/t3833 ../originals/t3833 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3834) timeout -s 9 2 ../source/replace.exe '@[[^a-c]' 'a@n'  < ../inputs/temp-test/772.inp.331.2 > ../outputs/t3834
    if diff ../outputs/t3834 ../originals/t3834 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3835) timeout -s 9 2 ../source/replace.exe '@[[a-c]-*-' '&a@%'  < ../inputs/temp-test/2323.inp.986.1 > ../outputs/t3835
    if diff ../outputs/t3835 ../originals/t3835 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3836) timeout -s 9 2 ../source/replace.exe '@[[a-c]-*-' '&a@%'  < ../inputs/temp-test/2324.inp.986.2 > ../outputs/t3836
    if diff ../outputs/t3836 ../originals/t3836 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3837) timeout -s 9 2 ../source/replace.exe '@[][*-?[a-c$' 'a@nb@tc'  < ../inputs/temp-test/210.inp.93.8 > ../outputs/t3837
    if diff ../outputs/t3837 ../originals/t3837 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3838) timeout -s 9 2 ../source/replace.exe '@[][*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/208.inp.93.2 > ../outputs/t3838
    if diff ../outputs/t3838 ../originals/t3838 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3839) timeout -s 9 2 ../source/replace.exe '@[][*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/209.inp.93.3 > ../outputs/t3839
    if diff ../outputs/t3839 ../originals/t3839 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3840) timeout -s 9 2 ../source/replace.exe '@[][*-?[a-c[]' 'a@nb@tc'  < ../inputs/temp-test/207.inp.93.1 > ../outputs/t3840
    if diff ../outputs/t3840 ../originals/t3840 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3841) timeout -s 9 2 ../source/replace.exe '@[^][*-?[a-c$' 'a@nb@tc'  < ../inputs/temp-test/210.inp.93.8 > ../outputs/t3841
    if diff ../outputs/t3841 ../originals/t3841 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3842) timeout -s 9 2 ../source/replace.exe '@[^][*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/208.inp.93.2 > ../outputs/t3842
    if diff ../outputs/t3842 ../originals/t3842 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3843) timeout -s 9 2 ../source/replace.exe '@[^][*-?[a-c' 'a@nb@tc'  < ../inputs/temp-test/209.inp.93.3 > ../outputs/t3843
    if diff ../outputs/t3843 ../originals/t3843 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3844) timeout -s 9 2 ../source/replace.exe '@[^][*-?[a-c[^]' 'a@nb@tc'  < ../inputs/temp-test/207.inp.93.1 > ../outputs/t3844
    if diff ../outputs/t3844 ../originals/t3844 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3845) timeout -s 9 2 ../source/replace.exe '@\' 'g-]cUd4^Cl)"wkYz'  < ../inputs/input/ruin.1638 > ../outputs/t3845
    if diff ../outputs/t3845 ../originals/t3845 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3846) timeout -s 9 2 ../source/replace.exe '@]' '($;X"X$F-uMG+`"5<X"'  < ../inputs/input/ruin.1430 > ../outputs/t3846
    if diff ../outputs/t3846 ../originals/t3846 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3847) timeout -s 9 2 ../source/replace.exe '@^?(@}' 'f'  < ../inputs/input/ruin.1680 > ../outputs/t3847
    if diff ../outputs/t3847 ../originals/t3847 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3848) timeout -s 9 2 ../source/replace.exe '@`' 'pQH;uJ,{RTf,E`X>gP;MGaei$HG}'  < ../inputs/input/ruin.945 > ../outputs/t3848
    if diff ../outputs/t3848 ../originals/t3848 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3849) timeout -s 9 2 ../source/replace.exe '@a' 'mZ1ng>k-x4voh3._i>_;0G|/C$'  < ../inputs/input/ruin.365 > ../outputs/t3849
    if diff ../outputs/t3849 ../originals/t3849 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3850) timeout -s 9 2 ../source/replace.exe '@a\|?' '?YH_'\''.XVn$Je"$z5vh%5F`nJNn|ft'  < ../inputs/input/ruin.575 > ../outputs/t3850
    if diff ../outputs/t3850 ../originals/t3850 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3851) timeout -s 9 2 ../source/replace.exe '@ddN@n' 'fg~4&[LmRA3o6:cW<[RU@3H*M;Z:.;y'\'',gC?= VPAFmAF'\'':1)z3<<'  < ../inputs/input/ruin.377 > ../outputs/t3851
    if diff ../outputs/t3851 ../originals/t3851 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3852) timeout -s 9 2 ../source/replace.exe '@e' 'O'  < ../inputs/input/ruin.12 > ../outputs/t3852
    if diff ../outputs/t3852 ../originals/t3852 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3853) timeout -s 9 2 ../source/replace.exe '@g' 'w|'  < ../inputs/input/ruin.1201 > ../outputs/t3853
    if diff ../outputs/t3853 ../originals/t3853 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3854) timeout -s 9 2 ../source/replace.exe '@h' 'w0Yj|`l`AYgv{KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@KNy,h0_sbVxG=nOfj@M<#KAouk'  < ../inputs/input/ruin.1035 > ../outputs/t3854
    if diff ../outputs/t3854 ../originals/t3854 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3855) timeout -s 9 2 ../source/replace.exe '@h' 'w0Yj|`l`AYgv{M<#KAouk'  < ../inputs/input/ruin.1035 > ../outputs/t3855
    if diff ../outputs/t3855 ../originals/t3855 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3856) timeout -s 9 2 ../source/replace.exe '@i' 'j'  < ../inputs/input/ruin.1668 > ../outputs/t3856
    if diff ../outputs/t3856 ../originals/t3856 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3857) timeout -s 9 2 ../source/replace.exe '@l' 'A)y'  < ../inputs/input/ruin.1820 > ../outputs/t3857
    if diff ../outputs/t3857 ../originals/t3857 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3858) timeout -s 9 2 ../source/replace.exe '@l' 'PSP`1vR+aC$I8'\''9UeO_Y'\''_nJ<FtcIi}. ,av4,XPyZ7BT#(B9{S=c--i.'  < ../inputs/input/ruin.1105 > ../outputs/t3858
    if diff ../outputs/t3858 ../originals/t3858 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3859) timeout -s 9 2 ../source/replace.exe '@l' 'RhZj~cW}'  < ../inputs/input/ruin.1478 > ../outputs/t3859
    if diff ../outputs/t3859 ../originals/t3859 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3860) timeout -s 9 2 ../source/replace.exe '@l*$' 'PSP`1vR+aC$I8'\''9UeO_Y'\''_nJ<FtcIi}. ,av4,XPyZ7BT#(B9{S=c--i.'  < ../inputs/input/ruin.1105 > ../outputs/t3860
    if diff ../outputs/t3860 ../originals/t3860 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3861) timeout -s 9 2 ../source/replace.exe '@m[^z-}]' 'Iz'  < ../inputs/input/ruin.1474 > ../outputs/t3861
    if diff ../outputs/t3861 ../originals/t3861 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3862) timeout -s 9 2 ../source/replace.exe '@n$' '$'  < ../inputs/input/ruin.1678 > ../outputs/t3862
    if diff ../outputs/t3862 ../originals/t3862 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3863) timeout -s 9 2 ../source/replace.exe '@n$' '&b0:'  < ../inputs/input/ruin.1020 > ../outputs/t3863
    if diff ../outputs/t3863 ../originals/t3863 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3864) timeout -s 9 2 ../source/replace.exe '@n$' '-[&b0:'  < ../inputs/input/ruin.1020 > ../outputs/t3864
    if diff ../outputs/t3864 ../originals/t3864 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3865) timeout -s 9 2 ../source/replace.exe '@n$' 'G4`w-b'  < ../inputs/input/ruin.1929 > ../outputs/t3865
    if diff ../outputs/t3865 ../originals/t3865 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3866) timeout -s 9 2 ../source/replace.exe '@n'   < ../inputs/input/ruin.1157 > ../outputs/t3866
    if diff ../outputs/t3866 ../originals/t3866 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3867) timeout -s 9 2 ../source/replace.exe '@n'   < ../inputs/input/ruin.1268 > ../outputs/t3867
    if diff ../outputs/t3867 ../originals/t3867 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3868) timeout -s 9 2 ../source/replace.exe '@n' '!'  < ../inputs/input/ruin.145 > ../outputs/t3868
    if diff ../outputs/t3868 ../originals/t3868 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3869) timeout -s 9 2 ../source/replace.exe '@n' '"'  < ../inputs/input/ruin.954 > ../outputs/t3869
    if diff ../outputs/t3869 ../originals/t3869 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3870) timeout -s 9 2 ../source/replace.exe '@n' '$!9jSkl)bEK'\''coE)Yz)\'\''9Qk(>mPE'  < ../inputs/input/ruin.1441 > ../outputs/t3870
    if diff ../outputs/t3870 ../originals/t3870 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3871) timeout -s 9 2 ../source/replace.exe '@n' '%:gPY.>,2#'  < ../inputs/input/ruin.1275 > ../outputs/t3871
    if diff ../outputs/t3871 ../originals/t3871 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3872) timeout -s 9 2 ../source/replace.exe '@n' '& '  < ../inputs/input/ruin.1192 > ../outputs/t3872
    if diff ../outputs/t3872 ../originals/t3872 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3873) timeout -s 9 2 ../source/replace.exe '@n' '&"w4yF;^%V{=[g" GQ!^)U'\''6G+5J[ejzJ=>IXG>MUU*;c:LUh'\''sz` ;i)-cxBKFwk%b`+L'  < ../inputs/input/ruin.1189 > ../outputs/t3873
    if diff ../outputs/t3873 ../originals/t3873 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3874) timeout -s 9 2 ../source/replace.exe '@n' '&#8|G=x$)8Bi3&]|}0Ei%$sGmY={x{8WXO(B='  < ../inputs/input/ruin.1197 > ../outputs/t3874
    if diff ../outputs/t3874 ../originals/t3874 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3875) timeout -s 9 2 ../source/replace.exe '@n' '&'  < ../inputs/temp-test/1025.inp.441.1 > ../outputs/t3875
    if diff ../outputs/t3875 ../originals/t3875 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3876) timeout -s 9 2 ../source/replace.exe '@n' '&'  < ../inputs/temp-test/329.inp.146.1 > ../outputs/t3876
    if diff ../outputs/t3876 ../originals/t3876 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3877) timeout -s 9 2 ../source/replace.exe '@n' '&'  < ../inputs/temp-test/332.inp.146.4 > ../outputs/t3877
    if diff ../outputs/t3877 ../originals/t3877 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3878) timeout -s 9 2 ../source/replace.exe '@n' '&(Qk '  < ../inputs/input/ruin.1205 > ../outputs/t3878
    if diff ../outputs/t3878 ../originals/t3878 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3879) timeout -s 9 2 ../source/replace.exe '@n' '&*'  < ../inputs/input/ruin.1360 > ../outputs/t3879
    if diff ../outputs/t3879 ../originals/t3879 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3880) timeout -s 9 2 ../source/replace.exe '@n' '&.St7,*,FY'\''e2 #PQt_JAdEVyBorNLKtG4,nKOUCw{Tr/J2d]Omr-PWjk+'  < ../inputs/input/ruin.98 > ../outputs/t3880
    if diff ../outputs/t3880 ../originals/t3880 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3881) timeout -s 9 2 ../source/replace.exe '@n' '&/=VXw>%)rWz0.ROqC>THDqQ^Hr+jB~x]S(cp}#'  < ../inputs/input/ruin.1204 > ../outputs/t3881
    if diff ../outputs/t3881 ../originals/t3881 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3882) timeout -s 9 2 ../source/replace.exe '@n' '&16|L'  < ../inputs/input/ruin.270 > ../outputs/t3882
    if diff ../outputs/t3882 ../originals/t3882 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3883) timeout -s 9 2 ../source/replace.exe '@n' '&4'  < ../inputs/input/ruin.281 > ../outputs/t3883
    if diff ../outputs/t3883 ../originals/t3883 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3884) timeout -s 9 2 ../source/replace.exe '@n' '&5.'  < ../inputs/input/ruin.1186 > ../outputs/t3884
    if diff ../outputs/t3884 ../originals/t3884 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3885) timeout -s 9 2 ../source/replace.exe '@n' '&5D$6:)'\''!!WaohoC<DMt/ns5zA:0vzT p?PADhjzrF.e*NbJLCd;0Sr/.Ja+?2sn-MP+uf6)IZet;aI!3=TH7?$d_6t)!l=Wfh37`[%\<5'  < ../inputs/input/ruin.1200 > ../outputs/t3885
    if diff ../outputs/t3885 ../originals/t3885 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3886) timeout -s 9 2 ../source/replace.exe '@n' '&6'  < ../inputs/input/ruin.284 > ../outputs/t3886
    if diff ../outputs/t3886 ../originals/t3886 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3887) timeout -s 9 2 ../source/replace.exe '@n' '&7KOgdHVS~e*RbgQ>M{]|d'  < ../inputs/input/ruin.1195 > ../outputs/t3887
    if diff ../outputs/t3887 ../originals/t3887 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3888) timeout -s 9 2 ../source/replace.exe '@n' '&8sdW9T'  < ../inputs/input/ruin.1065 > ../outputs/t3888
    if diff ../outputs/t3888 ../originals/t3888 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3889) timeout -s 9 2 ../source/replace.exe '@n' '&:an"OMpY#Ei1WdZ>`'  < ../inputs/input/ruin.1277 > ../outputs/t3889
    if diff ../outputs/t3889 ../originals/t3889 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3890) timeout -s 9 2 ../source/replace.exe '@n' '&<9:5*f8GULK>.:&6r]A'  < ../inputs/input/ruin.1321 > ../outputs/t3890
    if diff ../outputs/t3890 ../originals/t3890 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3891) timeout -s 9 2 ../source/replace.exe '@n' '&<N#2/*K)n'  < ../inputs/input/ruin.1182 > ../outputs/t3891
    if diff ../outputs/t3891 ../originals/t3891 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3892) timeout -s 9 2 ../source/replace.exe '@n' '&<N#N4zMu+/?$@,"oa`nt=1CL!g3y*(k((w!.4aPc>wSP2w2'  < ../inputs/input/ruin.487 > ../outputs/t3892
    if diff ../outputs/t3892 ../originals/t3892 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3893) timeout -s 9 2 ../source/replace.exe '@n' '&<c!'  < ../inputs/input/ruin.1179 > ../outputs/t3893
    if diff ../outputs/t3893 ../originals/t3893 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3894) timeout -s 9 2 ../source/replace.exe '@n' '&=:zD+0/]VKClfA;8d-(~bTN"m'  < ../inputs/input/ruin.1086 > ../outputs/t3894
    if diff ../outputs/t3894 ../originals/t3894 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3895) timeout -s 9 2 ../source/replace.exe '@n' '&?[0-9]'  < ../inputs/input/ruin.1377 > ../outputs/t3895
    if diff ../outputs/t3895 ../originals/t3895 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3896) timeout -s 9 2 ../source/replace.exe '@n' '&@@'  < ../inputs/input/ruin.1352 > ../outputs/t3896
    if diff ../outputs/t3896 ../originals/t3896 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3897) timeout -s 9 2 ../source/replace.exe '@n' '&@n'  < ../inputs/input/ruin.1340 > ../outputs/t3897
    if diff ../outputs/t3897 ../originals/t3897 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3898) timeout -s 9 2 ../source/replace.exe '@n' '&@n@n'  < ../inputs/input/ruin.1364 > ../outputs/t3898
    if diff ../outputs/t3898 ../originals/t3898 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3899) timeout -s 9 2 ../source/replace.exe '@n' '&@t'  < ../inputs/input/ruin.13 > ../outputs/t3899
    if diff ../outputs/t3899 ../originals/t3899 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3900) timeout -s 9 2 ../source/replace.exe '@n' '&@t@t'  < ../inputs/input/ruin.1376 > ../outputs/t3900
    if diff ../outputs/t3900 ../originals/t3900 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3901) timeout -s 9 2 ../source/replace.exe '@n' '&@t@t'  < ../inputs/input/ruin.617 > ../outputs/t3901
    if diff ../outputs/t3901 ../originals/t3901 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3902) timeout -s 9 2 ../source/replace.exe '@n' '&@t@t@t'  < ../inputs/input/ruin.460 > ../outputs/t3902
    if diff ../outputs/t3902 ../originals/t3902 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3903) timeout -s 9 2 ../source/replace.exe '@n' '&A'  < ../inputs/input/ruin.293 > ../outputs/t3903
    if diff ../outputs/t3903 ../originals/t3903 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3904) timeout -s 9 2 ../source/replace.exe '@n' '&D'  < ../inputs/input/ruin.1199 > ../outputs/t3904
    if diff ../outputs/t3904 ../originals/t3904 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3905) timeout -s 9 2 ../source/replace.exe '@n' '&E'  < ../inputs/input/ruin.1184 > ../outputs/t3905
    if diff ../outputs/t3905 ../originals/t3905 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3906) timeout -s 9 2 ../source/replace.exe '@n' '&L'  < ../inputs/input/ruin.1203 > ../outputs/t3906
    if diff ../outputs/t3906 ../originals/t3906 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3907) timeout -s 9 2 ../source/replace.exe '@n' '&L'  < ../inputs/input/ruin.274 > ../outputs/t3907
    if diff ../outputs/t3907 ../originals/t3907 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3908) timeout -s 9 2 ../source/replace.exe '@n' '&M'  < ../inputs/input/ruin.1185 > ../outputs/t3908
    if diff ../outputs/t3908 ../originals/t3908 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3909) timeout -s 9 2 ../source/replace.exe '@n' '&U'  < ../inputs/input/ruin.1193 > ../outputs/t3909
    if diff ../outputs/t3909 ../originals/t3909 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3910) timeout -s 9 2 ../source/replace.exe '@n' '&XW&%JwE}YEQ"vBljIYg}l'  < ../inputs/input/ruin.494 > ../outputs/t3910
    if diff ../outputs/t3910 ../originals/t3910 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3911) timeout -s 9 2 ../source/replace.exe '@n' '&[0-9]'  < ../inputs/input/ruin.1221 > ../outputs/t3911
    if diff ../outputs/t3911 ../originals/t3911 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3912) timeout -s 9 2 ../source/replace.exe '@n' '&[0-9]'  < ../inputs/input/ruin.138 > ../outputs/t3912
    if diff ../outputs/t3912 ../originals/t3912 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3913) timeout -s 9 2 ../source/replace.exe '@n' '&[LmRA3o6:cW<[RU@3H*M;Z:.;y'\'',gC?= VPAFmAF'\'':1)z3<<'  < ../inputs/input/ruin.377 > ../outputs/t3913
    if diff ../outputs/t3913 ../originals/t3913 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3914) timeout -s 9 2 ../source/replace.exe '@n' '&\/Jo n3Hj!!XA\!!Z;'\''k#\pku:-g*G ;iMw3]'  < ../inputs/input/ruin.1191 > ../outputs/t3914
    if diff ../outputs/t3914 ../originals/t3914 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3915) timeout -s 9 2 ../source/replace.exe '@n' '&_W$'  < ../inputs/input/ruin.1198 > ../outputs/t3915
    if diff ../outputs/t3915 ../originals/t3915 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3916) timeout -s 9 2 ../source/replace.exe '@n' '&`'  < ../inputs/input/ruin.1158 > ../outputs/t3916
    if diff ../outputs/t3916 ../originals/t3916 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3917) timeout -s 9 2 ../source/replace.exe '@n' '&`'  < ../inputs/input/ruin.278 > ../outputs/t3917
    if diff ../outputs/t3917 ../originals/t3917 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3918) timeout -s 9 2 ../source/replace.exe '@n' '&a@%'  < ../inputs/temp-test/1498.inp.642.1 > ../outputs/t3918
    if diff ../outputs/t3918 ../originals/t3918 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3919) timeout -s 9 2 ../source/replace.exe '@n' '&a@%'  < ../inputs/temp-test/1499.inp.642.2 > ../outputs/t3919
    if diff ../outputs/t3919 ../originals/t3919 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3920) timeout -s 9 2 ../source/replace.exe '@n' '&b'  < ../inputs/input/ruin.273 > ../outputs/t3920
    if diff ../outputs/t3920 ../originals/t3920 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3921) timeout -s 9 2 ../source/replace.exe '@n' '&b0:'  < ../inputs/input/ruin.1020 > ../outputs/t3921
    if diff ../outputs/t3921 ../originals/t3921 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3922) timeout -s 9 2 ../source/replace.exe '@n' '&e'  < ../inputs/input/ruin.280 > ../outputs/t3922
    if diff ../outputs/t3922 ../originals/t3922 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3923) timeout -s 9 2 ../source/replace.exe '@n' '&f$BLCD}tiigf@3'  < ../inputs/input/ruin.553 > ../outputs/t3923
    if diff ../outputs/t3923 ../originals/t3923 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3924) timeout -s 9 2 ../source/replace.exe '@n' '&h'  < ../inputs/input/ruin.288 > ../outputs/t3924
    if diff ../outputs/t3924 ../originals/t3924 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3925) timeout -s 9 2 ../source/replace.exe '@n' '&i+'\''s OXxRu~W2bMVQrfx+GT$4>}5J5XNph:`xe! zY'  < ../inputs/input/ruin.275 > ../outputs/t3925
    if diff ../outputs/t3925 ../originals/t3925 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3926) timeout -s 9 2 ../source/replace.exe '@n' '&lk'  < ../inputs/input/ruin.277 > ../outputs/t3926
    if diff ../outputs/t3926 ../originals/t3926 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3927) timeout -s 9 2 ../source/replace.exe '@n' '&o n3Hj!!XA\!!Z;'\''k#\pku:-g*G ;iMw3]'  < ../inputs/input/ruin.1191 > ../outputs/t3927
    if diff ../outputs/t3927 ../originals/t3927 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3928) timeout -s 9 2 ../source/replace.exe '@n' '&p'  < ../inputs/input/ruin.276 > ../outputs/t3928
    if diff ../outputs/t3928 ../originals/t3928 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3929) timeout -s 9 2 ../source/replace.exe '@n' '&q'  < ../inputs/input/ruin.1194 > ../outputs/t3929
    if diff ../outputs/t3929 ../originals/t3929 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3930) timeout -s 9 2 ../source/replace.exe '@n' '&q'  < ../inputs/input/ruin.539 > ../outputs/t3930
    if diff ../outputs/t3930 ../originals/t3930 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3931) timeout -s 9 2 ../source/replace.exe '@n' '&u>`Y~4'\''!d;?[6eMR*)X+D>xU%AUWv8y$.jdQ@jBn='\''(J8f,KIL4L'  < ../inputs/input/ruin.285 > ../outputs/t3931
    if diff ../outputs/t3931 ../originals/t3931 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3932) timeout -s 9 2 ../source/replace.exe '@n' '&u@@LZ'  < ../inputs/input/ruin.1188 > ../outputs/t3932
    if diff ../outputs/t3932 ../originals/t3932 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3933) timeout -s 9 2 ../source/replace.exe '@n' '&w|'  < ../inputs/input/ruin.1201 > ../outputs/t3933
    if diff ../outputs/t3933 ../originals/t3933 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3934) timeout -s 9 2 ../source/replace.exe '@n' '&xUW$3UOKEX2a@El#=-t[^R%"'  < ../inputs/input/ruin.290 > ../outputs/t3934
    if diff ../outputs/t3934 ../originals/t3934 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3935) timeout -s 9 2 ../source/replace.exe '@n' '&y#k-llLWk'  < ../inputs/input/ruin.279 > ../outputs/t3935
    if diff ../outputs/t3935 ../originals/t3935 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3936) timeout -s 9 2 ../source/replace.exe '@n' ''  < ../inputs/input/ruin.269 > ../outputs/t3936
    if diff ../outputs/t3936 ../originals/t3936 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3937) timeout -s 9 2 ../source/replace.exe '@n' ''  < ../inputs/input/ruin.831 > ../outputs/t3937
    if diff ../outputs/t3937 ../originals/t3937 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3938) timeout -s 9 2 ../source/replace.exe '@n' ''\''Y8_V~GP,no<Nwn1&d2*Mi^j4.Fx*Fb&sC#;9okUMY`</KdUj2(MQo'  < ../inputs/input/ruin.376 > ../outputs/t3938
    if diff ../outputs/t3938 ../originals/t3938 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3939) timeout -s 9 2 ../source/replace.exe '@n' '( $V0B&16|L'  < ../inputs/input/ruin.270 > ../outputs/t3939
    if diff ../outputs/t3939 ../originals/t3939 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3940) timeout -s 9 2 ../source/replace.exe '@n' '('  < ../inputs/input/ruin.1970 > ../outputs/t3940
    if diff ../outputs/t3940 ../originals/t3940 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3941) timeout -s 9 2 ../source/replace.exe '@n' ')clYn/q$'  < ../inputs/input/ruin.1688 > ../outputs/t3941
    if diff ../outputs/t3941 ../originals/t3941 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3942) timeout -s 9 2 ../source/replace.exe '@n' '*U&:an"OMpY#Ei1WdZ>`'  < ../inputs/input/ruin.1277 > ../outputs/t3942
    if diff ../outputs/t3942 ../originals/t3942 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3943) timeout -s 9 2 ../source/replace.exe '@n' '-[&b0:'  < ../inputs/input/ruin.1020 > ../outputs/t3943
    if diff ../outputs/t3943 ../originals/t3943 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3944) timeout -s 9 2 ../source/replace.exe '@n' '.'  < ../inputs/input/ruin.1999 > ../outputs/t3944
    if diff ../outputs/t3944 ../originals/t3944 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3945) timeout -s 9 2 ../source/replace.exe '@n' '.^&u>`Y~4'\''!d;?[6eMR*)X+D>xU%AUWv8y$.jdQ@jBn='\''(J8f,KIL4L'  < ../inputs/input/ruin.285 > ../outputs/t3945
    if diff ../outputs/t3945 ../originals/t3945 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3946) timeout -s 9 2 ../source/replace.exe '@n' '/&q'  < ../inputs/input/ruin.539 > ../outputs/t3946
    if diff ../outputs/t3946 ../originals/t3946 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3947) timeout -s 9 2 ../source/replace.exe '@n' '0'  < ../inputs/input/ruin.779 > ../outputs/t3947
    if diff ../outputs/t3947 ../originals/t3947 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3948) timeout -s 9 2 ../source/replace.exe '@n' '1gF=&n$u]g/C}w8N6'  < ../inputs/input/ruin.1207 > ../outputs/t3948
    if diff ../outputs/t3948 ../originals/t3948 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3949) timeout -s 9 2 ../source/replace.exe '@n' '1no9B60hA0-+uTMrfp/uzB4.|#*H+7q3Qy@/YT"b2b5['  < ../inputs/input/ruin.1268 > ../outputs/t3949
    if diff ../outputs/t3949 ../originals/t3949 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3950) timeout -s 9 2 ../source/replace.exe '@n' '2BEj`7d>hbD&m?T;b)0;'  < ../inputs/input/ruin.1803 > ../outputs/t3950
    if diff ../outputs/t3950 ../originals/t3950 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3951) timeout -s 9 2 ../source/replace.exe '@n' '2k|h=&-kA{I^m)l>oO{G'  < ../inputs/input/ruin.1029 > ../outputs/t3951
    if diff ../outputs/t3951 ../originals/t3951 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3952) timeout -s 9 2 ../source/replace.exe '@n' '2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G'  < ../inputs/input/ruin.1029 > ../outputs/t3952
    if diff ../outputs/t3952 ../originals/t3952 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3953) timeout -s 9 2 ../source/replace.exe '@n' '3&4'  < ../inputs/input/ruin.281 > ../outputs/t3953
    if diff ../outputs/t3953 ../originals/t3953 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3954) timeout -s 9 2 ../source/replace.exe '@n' '373Vm*EWixkNRI/J1'  < ../inputs/input/ruin.1270 > ../outputs/t3954
    if diff ../outputs/t3954 ../originals/t3954 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3955) timeout -s 9 2 ../source/replace.exe '@n' '4 '  < ../inputs/input/ruin.251 > ../outputs/t3955
    if diff ../outputs/t3955 ../originals/t3955 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3956) timeout -s 9 2 ../source/replace.exe '@n' '60&<9:5*f8GULK>.:&6r]A'  < ../inputs/input/ruin.1321 > ../outputs/t3956
    if diff ../outputs/t3956 ../originals/t3956 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3957) timeout -s 9 2 ../source/replace.exe '@n' '7KOgdHVS~e*RbgQ>M{]|d'  < ../inputs/input/ruin.1195 > ../outputs/t3957
    if diff ../outputs/t3957 ../originals/t3957 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3958) timeout -s 9 2 ../source/replace.exe '@n' '8,%wu%Hm=zS'  < ../inputs/input/ruin.1070 > ../outputs/t3958
    if diff ../outputs/t3958 ../originals/t3958 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3959) timeout -s 9 2 ../source/replace.exe '@n' '9&@t@t'  < ../inputs/input/ruin.617 > ../outputs/t3959
    if diff ../outputs/t3959 ../originals/t3959 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3960) timeout -s 9 2 ../source/replace.exe '@n' '98l&xUW$3UOKEX2a@El#=-t[^R%"'  < ../inputs/input/ruin.290 > ../outputs/t3960
    if diff ../outputs/t3960 ../originals/t3960 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3961) timeout -s 9 2 ../source/replace.exe '@n' ':'  < ../inputs/input/ruin.1828 > ../outputs/t3961
    if diff ../outputs/t3961 ../originals/t3961 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3962) timeout -s 9 2 ../source/replace.exe '@n' ':(4lCfr['  < ../inputs/input/ruin.1012 > ../outputs/t3962
    if diff ../outputs/t3962 ../originals/t3962 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3963) timeout -s 9 2 ../source/replace.exe '@n' ';&.St7,*,FY'\''e2 #PQt_JAdEVyBorNLKtG4,nKOUCw{Tr/J2d]Omr-PWjk+'  < ../inputs/input/ruin.98 > ../outputs/t3963
    if diff ../outputs/t3963 ../originals/t3963 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3964) timeout -s 9 2 ../source/replace.exe '@n' ';S&=:zD+0/]VKClfA;8d-(~bTN"m'  < ../inputs/input/ruin.1086 > ../outputs/t3964
    if diff ../outputs/t3964 ../originals/t3964 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3965) timeout -s 9 2 ../source/replace.exe '@n' ';S=:zD+0/]VKClfA;8d-(~bTN"m'  < ../inputs/input/ruin.1086 > ../outputs/t3965
    if diff ../outputs/t3965 ../originals/t3965 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3966) timeout -s 9 2 ../source/replace.exe '@n' ';g&.}:{js8R^#VPXDq2$?H7JEik*Lg_}N\ I(T"'  < ../inputs/input/ruin.1180 > ../outputs/t3966
    if diff ../outputs/t3966 ../originals/t3966 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3967) timeout -s 9 2 ../source/replace.exe '@n' '<'  < ../inputs/input/ruin.902 > ../outputs/t3967
    if diff ../outputs/t3967 ../originals/t3967 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3968) timeout -s 9 2 ../source/replace.exe '@n' '<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjs<u2]r/0cjsO'  < ../inputs/input/ruin.1045 > ../outputs/t3968
    if diff ../outputs/t3968 ../originals/t3968 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3969) timeout -s 9 2 ../source/replace.exe '@n' '=&lk'  < ../inputs/input/ruin.277 > ../outputs/t3969
    if diff ../outputs/t3969 ../originals/t3969 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3970) timeout -s 9 2 ../source/replace.exe '@n' '?&<N#N4zMu+/?$@,"oa`nt=1CL!g3y*(k((w!.4aPc>wSP2w2'  < ../inputs/input/ruin.487 > ../outputs/t3970
    if diff ../outputs/t3970 ../originals/t3970 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3971) timeout -s 9 2 ../source/replace.exe '@n' '?<N#N4zMu+/?$@,"oa`nt=1CL!g3y*(k((w!.4aPc>wSP2w2'  < ../inputs/input/ruin.487 > ../outputs/t3971
    if diff ../outputs/t3971 ../originals/t3971 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3972) timeout -s 9 2 ../source/replace.exe '@n' '@$Gd4I<bvLOk~I[u6ZJBh.'  < ../inputs/input/ruin.1637 > ../outputs/t3972
    if diff ../outputs/t3972 ../originals/t3972 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3973) timeout -s 9 2 ../source/replace.exe '@n' '@nS&1GvSwz{HEo.N'  < ../inputs/input/ruin.1190 > ../outputs/t3973
    if diff ../outputs/t3973 ../originals/t3973 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3974) timeout -s 9 2 ../source/replace.exe '@n' '@t@t&k*Lg_}N\ I(T"'  < ../inputs/input/ruin.1180 > ../outputs/t3974
    if diff ../outputs/t3974 ../originals/t3974 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3975) timeout -s 9 2 ../source/replace.exe '@n' '@{3y4ujD#rXanr\k6Ue_wmnt@Z#,%+({h'  < ../inputs/input/ruin.1014 > ../outputs/t3975
    if diff ../outputs/t3975 ../originals/t3975 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3976) timeout -s 9 2 ../source/replace.exe '@n' 'BVm'  < ../inputs/input/ruin.1894 > ../outputs/t3976
    if diff ../outputs/t3976 ../originals/t3976 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3977) timeout -s 9 2 ../source/replace.exe '@n' 'D&'  < ../inputs/input/ruin.1196 > ../outputs/t3977
    if diff ../outputs/t3977 ../originals/t3977 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3978) timeout -s 9 2 ../source/replace.exe '@n' 'E&'  < ../inputs/input/ruin.1184 > ../outputs/t3978
    if diff ../outputs/t3978 ../originals/t3978 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3979) timeout -s 9 2 ../source/replace.exe '@n' 'F'  < ../inputs/input/ruin.1157 > ../outputs/t3979
    if diff ../outputs/t3979 ../originals/t3979 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3980) timeout -s 9 2 ../source/replace.exe '@n' 'F]"8`#tLmW1FGw`iK4QO;MuiQ4{%R:h2`^Ndy W4p?5Yd9N%7tp~'  < ../inputs/input/ruin.154 > ../outputs/t3980
    if diff ../outputs/t3980 ../originals/t3980 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3981) timeout -s 9 2 ../source/replace.exe '@n' 'H&'  < ../inputs/input/ruin.1206 > ../outputs/t3981
    if diff ../outputs/t3981 ../originals/t3981 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3982) timeout -s 9 2 ../source/replace.exe '@n' 'H&@t@t@t'  < ../inputs/input/ruin.460 > ../outputs/t3982
    if diff ../outputs/t3982 ../originals/t3982 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3983) timeout -s 9 2 ../source/replace.exe '@n' 'H&b'  < ../inputs/input/ruin.273 > ../outputs/t3983
    if diff ../outputs/t3983 ../originals/t3983 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3984) timeout -s 9 2 ../source/replace.exe '@n' 'KO#|1)uX@Dy>+3j`g)D_SM "=l!3{n2g<y'  < ../inputs/input/ruin.612 > ../outputs/t3984
    if diff ../outputs/t3984 ../originals/t3984 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3985) timeout -s 9 2 ../source/replace.exe '@n' 'L=&XW&%JwE}YEQ"vBljIYg}l'  < ../inputs/input/ruin.494 > ../outputs/t3985
    if diff ../outputs/t3985 ../originals/t3985 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3986) timeout -s 9 2 ../source/replace.exe '@n' 'LK@d-'\'':KkM_v8WWuE!S'  < ../inputs/input/ruin.51 > ../outputs/t3986
    if diff ../outputs/t3986 ../originals/t3986 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3987) timeout -s 9 2 ../source/replace.exe '@n' 'M&'  < ../inputs/input/ruin.1185 > ../outputs/t3987
    if diff ../outputs/t3987 ../originals/t3987 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3988) timeout -s 9 2 ../source/replace.exe '@n' 'M'  < ../inputs/input/ruin.613 > ../outputs/t3988
    if diff ../outputs/t3988 ../originals/t3988 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3989) timeout -s 9 2 ../source/replace.exe '@n' 'N&A'  < ../inputs/input/ruin.293 > ../outputs/t3989
    if diff ../outputs/t3989 ../originals/t3989 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3990) timeout -s 9 2 ../source/replace.exe '@n' 'O'  < ../inputs/input/ruin.1045 > ../outputs/t3990
    if diff ../outputs/t3990 ../originals/t3990 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3991) timeout -s 9 2 ../source/replace.exe '@n' 'P&p'  < ../inputs/input/ruin.276 > ../outputs/t3991
    if diff ../outputs/t3991 ../originals/t3991 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3992) timeout -s 9 2 ../source/replace.exe '@n' 'P'  < ../inputs/input/ruin.276 > ../outputs/t3992
    if diff ../outputs/t3992 ../originals/t3992 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3993) timeout -s 9 2 ../source/replace.exe '@n' 'R9@ g]NIAErVbSSr=~G~@`ju?Q~]HAWjufdNY6.k}s'  < ../inputs/input/ruin.823 > ../outputs/t3993
    if diff ../outputs/t3993 ../originals/t3993 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3994) timeout -s 9 2 ../source/replace.exe '@n' 'S&1G=SPJxh*Gd}R$vSwz{HEo.N'  < ../inputs/input/ruin.1190 > ../outputs/t3994
    if diff ../outputs/t3994 ../originals/t3994 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3995) timeout -s 9 2 ../source/replace.exe '@n' 'S1G=&SPJxh*Gd}R$vSwz{HEo.N'  < ../inputs/input/ruin.1190 > ../outputs/t3995
    if diff ../outputs/t3995 ../originals/t3995 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3996) timeout -s 9 2 ../source/replace.exe '@n' 'TbjIYx|Q&}}TKt5QS<'  < ../inputs/input/ruin.1187 > ../outputs/t3996
    if diff ../outputs/t3996 ../originals/t3996 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3997) timeout -s 9 2 ../source/replace.exe '@n' 'TbjIYx|Qb}}&TKt5QS<'  < ../inputs/input/ruin.1187 > ../outputs/t3997
    if diff ../outputs/t3997 ../originals/t3997 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3998) timeout -s 9 2 ../source/replace.exe '@n' 'U&'  < ../inputs/input/ruin.1193 > ../outputs/t3998
    if diff ../outputs/t3998 ../originals/t3998 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p3999) timeout -s 9 2 ../source/replace.exe '@n' 'VmO1MS/z/7-!)sG#\ Pl|1`0$B*e'  < ../inputs/input/ruin.337 > ../outputs/t3999
    if diff ../outputs/t3999 ../originals/t3999 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4000) timeout -s 9 2 ../source/replace.exe '@n' 'X'  < ../inputs/input/ruin.321 > ../outputs/t4000
    if diff ../outputs/t4000 ../originals/t4000 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4001) timeout -s 9 2 ../source/replace.exe '@n' 'Yb`=<aVf_kx\zxE!_^(2{XTG#'  < ../inputs/input/ruin.256 > ../outputs/t4001
    if diff ../outputs/t4001 ../originals/t4001 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4002) timeout -s 9 2 ../source/replace.exe '@n' '[0-9]&&[a-z]'  < ../inputs/input/ruin.144 > ../outputs/t4002
    if diff ../outputs/t4002 ../originals/t4002 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4003) timeout -s 9 2 ../source/replace.exe '@n' '[0-9]&[a-z]'  < ../inputs/input/ruin.144 > ../outputs/t4003
    if diff ../outputs/t4003 ../originals/t4003 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4004) timeout -s 9 2 ../source/replace.exe '@n' '[0-9]@t@n@@TbjIYx|Q&}}TKt5QS<'  < ../inputs/input/ruin.1187 > ../outputs/t4004
    if diff ../outputs/t4004 ../originals/t4004 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4005) timeout -s 9 2 ../source/replace.exe '@n' '[^2-9]!&{HEo.N'  < ../inputs/input/ruin.1190 > ../outputs/t4005
    if diff ../outputs/t4005 ../originals/t4005 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4006) timeout -s 9 2 ../source/replace.exe '@n' '\/J&o n3Hj!!XA\!!Z;'\''k#\pku:-g*G ;iMw3]'  < ../inputs/input/ruin.1191 > ../outputs/t4006
    if diff ../outputs/t4006 ../originals/t4006 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4007) timeout -s 9 2 ../source/replace.exe '@n' '\/Jo n3Hj!!XA\!!Z;'\''k#\pku:-g*G ;iMw3]&'  < ../inputs/input/ruin.1191 > ../outputs/t4007
    if diff ../outputs/t4007 ../originals/t4007 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4008) timeout -s 9 2 ../source/replace.exe '@n' '^K'  < ../inputs/input/ruin.1774 > ../outputs/t4008
    if diff ../outputs/t4008 ../originals/t4008 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4009) timeout -s 9 2 ../source/replace.exe '@n' '`&`'  < ../inputs/input/ruin.278 > ../outputs/t4009
    if diff ../outputs/t4009 ../originals/t4009 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4010) timeout -s 9 2 ../source/replace.exe '@n' 'a&'  < ../inputs/temp-test/329.inp.146.1 > ../outputs/t4010
    if diff ../outputs/t4010 ../originals/t4010 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4011) timeout -s 9 2 ../source/replace.exe '@n' 'a&'  < ../inputs/temp-test/332.inp.146.4 > ../outputs/t4011
    if diff ../outputs/t4011 ../originals/t4011 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4012) timeout -s 9 2 ../source/replace.exe '@n' 'a&L'  < ../inputs/input/ruin.274 > ../outputs/t4012
    if diff ../outputs/t4012 ../originals/t4012 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4013) timeout -s 9 2 ../source/replace.exe '@n' 'a&`'  < ../inputs/input/ruin.1158 > ../outputs/t4013
    if diff ../outputs/t4013 ../originals/t4013 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4014) timeout -s 9 2 ../source/replace.exe '@n' 'a&y#k-llLWk'  < ../inputs/input/ruin.279 > ../outputs/t4014
    if diff ../outputs/t4014 ../originals/t4014 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4015) timeout -s 9 2 ../source/replace.exe '@n' 'a'  < ../inputs/input/ruin.210 > ../outputs/t4015
    if diff ../outputs/t4015 ../originals/t4015 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4016) timeout -s 9 2 ../source/replace.exe '@n' 'cfP M%;7}!g8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf8KNy,h0_sbVxG=nOf^yda^u5]__z&`%FlMJ7'  < ../inputs/input/ruin.1039 > ../outputs/t4016
    if diff ../outputs/t4016 ../originals/t4016 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4017) timeout -s 9 2 ../source/replace.exe '@n' 'cfP M%;7}!g^yda^u5]__z&`%FlMJ7'  < ../inputs/input/ruin.1039 > ../outputs/t4017
    if diff ../outputs/t4017 ../originals/t4017 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4018) timeout -s 9 2 ../source/replace.exe '@n' 'd & '\''Ts/gEB(0=$(}A.AVje3x'  < ../inputs/input/ruin.1202 > ../outputs/t4018
    if diff ../outputs/t4018 ../originals/t4018 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4019) timeout -s 9 2 ../source/replace.exe '@n' 'd'  < ../inputs/input/ruin.326 > ../outputs/t4019
    if diff ../outputs/t4019 ../originals/t4019 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4020) timeout -s 9 2 ../source/replace.exe '@n' 'eT@aR6@4AoERO"scF)a"dqsE)GaEU$d~$U<<zIU>P>V,&'  < ../inputs/input/ruin.1183 > ../outputs/t4020
    if diff ../outputs/t4020 ../originals/t4020 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4021) timeout -s 9 2 ../source/replace.exe '@n' 'fg~4&[LmRA3o6:cW<[RU@3H*M;Z:.;y'\'',gC?= VPAFmAF'\'':1)z3<<'  < ../inputs/input/ruin.377 > ../outputs/t4021
    if diff ../outputs/t4021 ../originals/t4021 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4022) timeout -s 9 2 ../source/replace.exe '@n' 'g&h'  < ../inputs/input/ruin.288 > ../outputs/t4022
    if diff ../outputs/t4022 ../originals/t4022 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4023) timeout -s 9 2 ../source/replace.exe '@n' 'gt3%!lio[y2P9x'  < ../inputs/input/ruin.806 > ../outputs/t4023
    if diff ../outputs/t4023 ../originals/t4023 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4024) timeout -s 9 2 ../source/replace.exe '@n' 'h&[0-9]'  < ../inputs/input/ruin.1221 > ../outputs/t4024
    if diff ../outputs/t4024 ../originals/t4024 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4025) timeout -s 9 2 ../source/replace.exe '@n' 'h'  < ../inputs/input/ruin.826 > ../outputs/t4025
    if diff ../outputs/t4025 ../originals/t4025 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4026) timeout -s 9 2 ../source/replace.exe '@n' 'i&'  < ../inputs/input/ruin.1178 > ../outputs/t4026
    if diff ../outputs/t4026 ../originals/t4026 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4027) timeout -s 9 2 ../source/replace.exe '@n' 'i&@@[^6-9]'  < ../inputs/input/ruin.1178 > ../outputs/t4027
    if diff ../outputs/t4027 ../originals/t4027 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4028) timeout -s 9 2 ../source/replace.exe '@n' 'k#\pku:-g*G [0-9]@t@@;iMw3]&'  < ../inputs/input/ruin.1191 > ../outputs/t4028
    if diff ../outputs/t4028 ../originals/t4028 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4029) timeout -s 9 2 ../source/replace.exe '@n' 'k&e'  < ../inputs/input/ruin.280 > ../outputs/t4029
    if diff ../outputs/t4029 ../originals/t4029 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4030) timeout -s 9 2 ../source/replace.exe '@n' 'lQ]IzWyseh>aL@l}lF'  < ../inputs/input/ruin.230 > ../outputs/t4030
    if diff ../outputs/t4030 ../originals/t4030 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4031) timeout -s 9 2 ../source/replace.exe '@n' 'm&'  < ../inputs/input/ruin.1181 > ../outputs/t4031
    if diff ../outputs/t4031 ../originals/t4031 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4032) timeout -s 9 2 ../source/replace.exe '@n' 'm'  < ../inputs/input/ruin.1026 > ../outputs/t4032
    if diff ../outputs/t4032 ../originals/t4032 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4033) timeout -s 9 2 ../source/replace.exe '@n' 'meEqXG~#(1!P1'  < ../inputs/input/ruin.726 > ../outputs/t4033
    if diff ../outputs/t4033 ../originals/t4033 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4034) timeout -s 9 2 ../source/replace.exe '@n' 'n&f$BLCD}tiigf@3'  < ../inputs/input/ruin.553 > ../outputs/t4034
    if diff ../outputs/t4034 ../originals/t4034 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4035) timeout -s 9 2 ../source/replace.exe '@n' 'o&6'  < ../inputs/input/ruin.284 > ../outputs/t4035
    if diff ../outputs/t4035 ../originals/t4035 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4036) timeout -s 9 2 ../source/replace.exe '@n' 'q&'  < ../inputs/input/ruin.1194 > ../outputs/t4036
    if diff ../outputs/t4036 ../originals/t4036 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4037) timeout -s 9 2 ../source/replace.exe '@n' 'q*@n&+ovX g    [0-98]'  < ../inputs/input/ruin.144 > ../outputs/t4037
    if diff ../outputs/t4037 ../originals/t4037 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4038) timeout -s 9 2 ../source/replace.exe '@n' 'q*PRdtw$&+ovX guAeILM7M'  < ../inputs/input/ruin.144 > ../outputs/t4038
    if diff ../outputs/t4038 ../originals/t4038 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4039) timeout -s 9 2 ../source/replace.exe '@n' 'r5'  < ../inputs/input/ruin.1177 > ../outputs/t4039
    if diff ../outputs/t4039 ../originals/t4039 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4040) timeout -s 9 2 ../source/replace.exe '@n' 'tqyi460w^}~C$R<'  < ../inputs/input/ruin.943 > ../outputs/t4040
    if diff ../outputs/t4040 ../originals/t4040 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4041) timeout -s 9 2 ../source/replace.exe '@n' 'u>{%9; ?S3&u@@LZ'  < ../inputs/input/ruin.1188 > ../outputs/t4041
    if diff ../outputs/t4041 ../originals/t4041 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4042) timeout -s 9 2 ../source/replace.exe '@n' 'vwGsq%:a<(5`c[h6 W;I[sk;'\''2{+~!jW/n'  < ../inputs/input/ruin.1372 > ../outputs/t4042
    if diff ../outputs/t4042 ../originals/t4042 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4043) timeout -s 9 2 ../source/replace.exe '@n' 'w'  < ../inputs/input/ruin.7 > ../outputs/t4043
    if diff ../outputs/t4043 ../originals/t4043 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4044) timeout -s 9 2 ../source/replace.exe '@n' 'y$Z1<[1_6wHLcYZnEoC/JY$%O0tKDCdx>(9"'  < ../inputs/input/ruin.710 > ../outputs/t4044
    if diff ../outputs/t4044 ../originals/t4044 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4045) timeout -s 9 2 ../source/replace.exe '@n' 'y&8sdW9T'  < ../inputs/input/ruin.1065 > ../outputs/t4045
    if diff ../outputs/t4045 ../originals/t4045 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4046) timeout -s 9 2 ../source/replace.exe '@n' '{G8'  < ../inputs/input/ruin.32 > ../outputs/t4046
    if diff ../outputs/t4046 ../originals/t4046 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4047) timeout -s 9 2 ../source/replace.exe '@n' '|M&i+'\''s OXxRu~W2bMVQrfx+GT$4>}5J5XNph:`xe! zY'  < ../inputs/input/ruin.275 > ../outputs/t4047
    if diff ../outputs/t4047 ../originals/t4047 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4048) timeout -s 9 2 ../source/replace.exe '@n'\''[^z-}]' '='  < ../inputs/input/ruin.277 > ../outputs/t4048
    if diff ../outputs/t4048 ../originals/t4048 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4049) timeout -s 9 2 ../source/replace.exe '@n*$' '.'  < ../inputs/input/ruin.1999 > ../outputs/t4049
    if diff ../outputs/t4049 ../originals/t4049 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4050) timeout -s 9 2 ../source/replace.exe '@n*$' 'R,35{f9=L?~on%ox#y{V'  < ../inputs/input/ruin.1511 > ../outputs/t4050
    if diff ../outputs/t4050 ../originals/t4050 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4051) timeout -s 9 2 ../source/replace.exe '@n*' 'B(=9uHKrS'  < ../inputs/input/ruin.106 > ../outputs/t4051
    if diff ../outputs/t4051 ../originals/t4051 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4052) timeout -s 9 2 ../source/replace.exe '@n*' 'a@nb@tc'  < ../inputs/temp-test/747.inp.320.1 > ../outputs/t4052
    if diff ../outputs/t4052 ../originals/t4052 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4053) timeout -s 9 2 ../source/replace.exe '@n**' 'GbrNP(q!N'  < ../inputs/input/ruin.27 > ../outputs/t4053
    if diff ../outputs/t4053 ../originals/t4053 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4054) timeout -s 9 2 ../source/replace.exe '@n*-@*@@*[a-c[0-9][^a-][^9-B]--[^--z]' 'a@n'  < ../inputs/temp-test/2220.inp.941.1 > ../outputs/t4054
    if diff ../outputs/t4054 ../originals/t4054 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4055) timeout -s 9 2 ../source/replace.exe '@n*-@*@@*[a-c[0-9][^a-][^9-B]--[^--z]' 'a@n'  < ../inputs/temp-test/2221.inp.941.2 > ../outputs/t4055
    if diff ../outputs/t4055 ../originals/t4055 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4056) timeout -s 9 2 ../source/replace.exe '@n*-@*@@*[a-c[0-9][^a-][^9-B]--[^--z]' 'a@n'  < ../inputs/temp-test/2222.inp.941.3 > ../outputs/t4056
    if diff ../outputs/t4056 ../originals/t4056 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4057) timeout -s 9 2 ../source/replace.exe '@n*[0-9]' '&a@%'  < ../inputs/temp-test/2211.inp.937.1 > ../outputs/t4057
    if diff ../outputs/t4057 ../originals/t4057 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4058) timeout -s 9 2 ../source/replace.exe '@n*[0-9]' '&a@%'  < ../inputs/temp-test/2212.inp.937.2 > ../outputs/t4058
    if diff ../outputs/t4058 ../originals/t4058 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4059) timeout -s 9 2 ../source/replace.exe '@n*[^0-9]?--[^a--@*' '@t'  < ../inputs/temp-test/1062.inp.457.1 > ../outputs/t4059
    if diff ../outputs/t4059 ../originals/t4059 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4060) timeout -s 9 2 ../source/replace.exe '@n*[^0-9]?--[^a--@*' '@t'  < ../inputs/temp-test/1063.inp.457.2 > ../outputs/t4060
    if diff ../outputs/t4060 ../originals/t4060 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4061) timeout -s 9 2 ../source/replace.exe '@n*[^0-9]?--[^a--@*' '@t'  < ../inputs/temp-test/1064.inp.457.3 > ../outputs/t4061
    if diff ../outputs/t4061 ../originals/t4061 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4062) timeout -s 9 2 ../source/replace.exe '@n*[^a-c]$' 'b@t'  < ../inputs/temp-test/1921.inp.816.9 > ../outputs/t4062
    if diff ../outputs/t4062 ../originals/t4062 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4063) timeout -s 9 2 ../source/replace.exe '@n*[^a-c]' 'b@t'  < ../inputs/temp-test/1920.inp.816.1 > ../outputs/t4063
    if diff ../outputs/t4063 ../originals/t4063 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4064) timeout -s 9 2 ../source/replace.exe '@n?' 'NEW'  < ../inputs/temp-test/614.inp.265.1 > ../outputs/t4064
    if diff ../outputs/t4064 ../originals/t4064 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4065) timeout -s 9 2 ../source/replace.exe '@n?' 'NEW'  < ../inputs/temp-test/615.inp.265.3 > ../outputs/t4065
    if diff ../outputs/t4065 ../originals/t4065 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4066) timeout -s 9 2 ../source/replace.exe '@n?' 'NEW'  < ../inputs/temp-test/616.inp.265.4 > ../outputs/t4066
    if diff ../outputs/t4066 ../originals/t4066 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4067) timeout -s 9 2 ../source/replace.exe '@n?' '_'  < ../inputs/input/ruin.991 > ../outputs/t4067
    if diff ../outputs/t4067 ../originals/t4067 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4068) timeout -s 9 2 ../source/replace.exe '@n?' 'a@n'  < ../inputs/temp-test/2259.inp.958.1 > ../outputs/t4068
    if diff ../outputs/t4068 ../originals/t4068 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4069) timeout -s 9 2 ../source/replace.exe '@n?' 'a@n'  < ../inputs/temp-test/2260.inp.958.2 > ../outputs/t4069
    if diff ../outputs/t4069 ../originals/t4069 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4070) timeout -s 9 2 ../source/replace.exe '@n?' 'a@n'  < ../inputs/temp-test/2261.inp.958.3 > ../outputs/t4070
    if diff ../outputs/t4070 ../originals/t4070 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4071) timeout -s 9 2 ../source/replace.exe '@n?' 'yy'  < ../inputs/moni/f7.inp > ../outputs/t4071
    if diff ../outputs/t4071 ../originals/t4071 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4072) timeout -s 9 2 ../source/replace.exe '@n@@$' ''\'''  < ../inputs/input/ruin.1374 > ../outputs/t4072
    if diff ../outputs/t4072 ../originals/t4072 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4073) timeout -s 9 2 ../source/replace.exe '@n@@' '_/vHv[\~S6P)'  < ../inputs/input/ruin.1354 > ../outputs/t4073
    if diff ../outputs/t4073 ../originals/t4073 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4074) timeout -s 9 2 ../source/replace.exe '@n@@;@@' '60<9:5*f8GULK>.:&6r]A'  < ../inputs/input/ruin.1321 > ../outputs/t4074
    if diff ../outputs/t4074 ../originals/t4074 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4075) timeout -s 9 2 ../source/replace.exe '@n@@?' '09xj8*p{[Tk=E|P~H.Ge{Py<Z'  < ../inputs/input/ruin.35 > ../outputs/t4075
    if diff ../outputs/t4075 ../originals/t4075 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4076) timeout -s 9 2 ../source/replace.exe '@nPhqi}@,5rY]~M\ Wz]`M0)y8H?@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?t]*[@t@][9-B]-*[0-9]][@t]*[@t@][9-B]t]*[@t@][9-B]-*[0-9]][?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0' 'd'  < ../inputs/input/ruin.326 > ../outputs/t4076
    if diff ../outputs/t4076 ../originals/t4076 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4077) timeout -s 9 2 ../source/replace.exe '@n[>-AH]' 'x'  < ../inputs/input/ruin.1019 > ../outputs/t4077
    if diff ../outputs/t4077 ../originals/t4077 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4078) timeout -s 9 2 ../source/replace.exe '@n[^c-a]' ')V|'  < ../inputs/input/ruin.445 > ../outputs/t4078
    if diff ../outputs/t4078 ../originals/t4078 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4079) timeout -s 9 2 ../source/replace.exe '@n[a-c]' 'a@nb@tc'  < ../inputs/temp-test/954.inp.411.1 > ../outputs/t4079
    if diff ../outputs/t4079 ../originals/t4079 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4080) timeout -s 9 2 ../source/replace.exe '@n[a-c]' 'a@nb@tc'  < ../inputs/temp-test/955.inp.411.3 > ../outputs/t4080
    if diff ../outputs/t4080 ../originals/t4080 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4081) timeout -s 9 2 ../source/replace.exe '@n[a-z][0-9]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4081
    if diff ../outputs/t4081 ../originals/t4081 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4082) timeout -s 9 2 ../source/replace.exe '@n[c-a]' 'H)R{PA:4}IkCZ\9NA$V@if]b]lcL*](B]-#S'  < ../inputs/input/ruin.94 > ../outputs/t4082
    if diff ../outputs/t4082 ../originals/t4082 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4083) timeout -s 9 2 ../source/replace.exe '@n][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9]][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9]' 'X'  < ../inputs/input/ruin.321 > ../outputs/t4083
    if diff ../outputs/t4083 ../originals/t4083 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4084) timeout -s 9 2 ../source/replace.exe '@o' ''  < ../inputs/input/ruin.928 > ../outputs/t4084
    if diff ../outputs/t4084 ../originals/t4084 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4085) timeout -s 9 2 ../source/replace.exe '@p' 'l)I#$SnVq^6"2XS{#Gu`w'  < ../inputs/input/ruin.1512 > ../outputs/t4085
    if diff ../outputs/t4085 ../originals/t4085 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4086) timeout -s 9 2 ../source/replace.exe '@r@@' 'n<Hq8Z%6sxa'  < ../inputs/input/ruin.959 > ../outputs/t4086
    if diff ../outputs/t4086 ../originals/t4086 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4087) timeout -s 9 2 ../source/replace.exe '@t$' ')Y Tr\&_%MYI-Hvz!p];s'  < ../inputs/input/ruin.1764 > ../outputs/t4087
    if diff ../outputs/t4087 ../originals/t4087 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4088) timeout -s 9 2 ../source/replace.exe '@t$' '@%@&'  < ../inputs/temp-test/682.inp.296.9 > ../outputs/t4088
    if diff ../outputs/t4088 ../originals/t4088 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4089) timeout -s 9 2 ../source/replace.exe '@t$' 'VQ7UIU&=z]J 3BvzQd+'\''%P\]iuS{Q)nzE'  < ../inputs/input/ruin.1 > ../outputs/t4089
    if diff ../outputs/t4089 ../originals/t4089 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4090) timeout -s 9 2 ../source/replace.exe '@t' ' {'  < ../inputs/input/ruin.1418 > ../outputs/t4090
    if diff ../outputs/t4090 ../originals/t4090 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4091) timeout -s 9 2 ../source/replace.exe '@t' '"Q'  < ../inputs/input/ruin.110 > ../outputs/t4091
    if diff ../outputs/t4091 ../originals/t4091 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4092) timeout -s 9 2 ../source/replace.exe '@t' '$ybvgd HC9i)raWA*pH8#5auxQ\y'\''+Gxa3qV|vWk'  < ../inputs/input/ruin.822 > ../outputs/t4092
    if diff ../outputs/t4092 ../originals/t4092 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4093) timeout -s 9 2 ../source/replace.exe '@t' ''  < ../inputs/input/ruin.968 > ../outputs/t4093
    if diff ../outputs/t4093 ../originals/t4093 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4094) timeout -s 9 2 ../source/replace.exe '@t' ''  < ../inputs/temp-test/266.inp.118.1 > ../outputs/t4094
    if diff ../outputs/t4094 ../originals/t4094 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4095) timeout -s 9 2 ../source/replace.exe '@t' ''\'''  < ../inputs/input/ruin.874 > ../outputs/t4095
    if diff ../outputs/t4095 ../originals/t4095 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4096) timeout -s 9 2 ../source/replace.exe '@t' '.'  < ../inputs/input/ruin.1244 > ../outputs/t4096
    if diff ../outputs/t4096 ../originals/t4096 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4097) timeout -s 9 2 ../source/replace.exe '@t' '/q'  < ../inputs/input/ruin.539 > ../outputs/t4097
    if diff ../outputs/t4097 ../originals/t4097 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4098) timeout -s 9 2 ../source/replace.exe '@t' '0'  < ../inputs/input/ruin.1465 > ../outputs/t4098
    if diff ../outputs/t4098 ../originals/t4098 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4099) timeout -s 9 2 ../source/replace.exe '@t' '0S-'  < ../inputs/input/ruin.1103 > ../outputs/t4099
    if diff ../outputs/t4099 ../originals/t4099 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4100) timeout -s 9 2 ../source/replace.exe '@t' '4_'  < ../inputs/input/ruin.70 > ../outputs/t4100
    if diff ../outputs/t4100 ../originals/t4100 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4101) timeout -s 9 2 ../source/replace.exe '@t' '@%@&'  < ../inputs/temp-test/681.inp.296.1 > ../outputs/t4101
    if diff ../outputs/t4101 ../originals/t4101 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4102) timeout -s 9 2 ../source/replace.exe '@t' 'J'  < ../inputs/input/ruin.93 > ../outputs/t4102
    if diff ../outputs/t4102 ../originals/t4102 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4103) timeout -s 9 2 ../source/replace.exe '@t' 'W&1c:QJf($UO~?u(`y H..L/?~3(*qLpVqz0I$\;u='  < ../inputs/input/ruin.895 > ../outputs/t4103
    if diff ../outputs/t4103 ../originals/t4103 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4104) timeout -s 9 2 ../source/replace.exe '@t' 'YJ$cMOTGZkYU_qL"&a `#c;9Hlainkh$H|%pPBg)No ~wdIY>*09OY-Xw=sD]6FI'  < ../inputs/input/ruin.919 > ../outputs/t4104
    if diff ../outputs/t4104 ../originals/t4104 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4105) timeout -s 9 2 ../source/replace.exe '@t' '['  < ../inputs/input/ruin.570 > ../outputs/t4105
    if diff ../outputs/t4105 ../originals/t4105 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4106) timeout -s 9 2 ../source/replace.exe '@t' '\dsn|a; |+['  < ../inputs/input/ruin.1564 > ../outputs/t4106
    if diff ../outputs/t4106 ../originals/t4106 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4107) timeout -s 9 2 ../source/replace.exe '@t' 'a'  < ../inputs/input/ruin.1230 > ../outputs/t4107
    if diff ../outputs/t4107 ../originals/t4107 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4108) timeout -s 9 2 ../source/replace.exe '@t' 'awRjE|M*3XDH%k!OG%su\7'\''h:r@xuKZ%'  < ../inputs/input/ruin.1400 > ../outputs/t4108
    if diff ../outputs/t4108 ../originals/t4108 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4109) timeout -s 9 2 ../source/replace.exe '@t' 't'  < ../inputs/input/ruin.942 > ../outputs/t4109
    if diff ../outputs/t4109 ../originals/t4109 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4110) timeout -s 9 2 ../source/replace.exe '@t' 'xDC'  < ../inputs/input/ruin.156 > ../outputs/t4110
    if diff ../outputs/t4110 ../originals/t4110 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4111) timeout -s 9 2 ../source/replace.exe '@t' '}'  < ../inputs/input/ruin.937 > ../outputs/t4111
    if diff ../outputs/t4111 ../originals/t4111 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4112) timeout -s 9 2 ../source/replace.exe '@t'\''lm@GD@@' 'Y>qrcPjB9#V'  < ../inputs/input/ruin.1682 > ../outputs/t4112
    if diff ../outputs/t4112 ../originals/t4112 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4113) timeout -s 9 2 ../source/replace.exe '@t*$' '.'  < ../inputs/input/ruin.1244 > ../outputs/t4113
    if diff ../outputs/t4113 ../originals/t4113 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4114) timeout -s 9 2 ../source/replace.exe '@t*- *?[^a--]-c*?$' '&'  < ../inputs/temp-test/1730.inp.735.8 > ../outputs/t4114
    if diff ../outputs/t4114 ../originals/t4114 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4115) timeout -s 9 2 ../source/replace.exe '@t*- *?[^a--]-c*?' '&'  < ../inputs/temp-test/1727.inp.735.1 > ../outputs/t4115
    if diff ../outputs/t4115 ../originals/t4115 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4116) timeout -s 9 2 ../source/replace.exe '@t*- *?[^a--]-c*?' '&'  < ../inputs/temp-test/1728.inp.735.2 > ../outputs/t4116
    if diff ../outputs/t4116 ../originals/t4116 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4117) timeout -s 9 2 ../source/replace.exe '@t*- *?[^a--]-c*?' '&'  < ../inputs/temp-test/1729.inp.735.3 > ../outputs/t4117
    if diff ../outputs/t4117 ../originals/t4117 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4118) timeout -s 9 2 ../source/replace.exe '@t*-@[*-*-' '&a@%'  < ../inputs/temp-test/1633.inp.695.1 > ../outputs/t4118
    if diff ../outputs/t4118 ../originals/t4118 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4119) timeout -s 9 2 ../source/replace.exe '@t*-@[*-*-' '&a@%'  < ../inputs/temp-test/1634.inp.695.3 > ../outputs/t4119
    if diff ../outputs/t4119 ../originals/t4119 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4120) timeout -s 9 2 ../source/replace.exe '@t*?' '@%&a'  < ../inputs/temp-test/1170.inp.504.1 > ../outputs/t4120
    if diff ../outputs/t4120 ../originals/t4120 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4121) timeout -s 9 2 ../source/replace.exe '@t*?' '@%&a'  < ../inputs/temp-test/1171.inp.504.2 > ../outputs/t4121
    if diff ../outputs/t4121 ../originals/t4121 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4122) timeout -s 9 2 ../source/replace.exe '@t*?' 'a@nb@tc'  < ../inputs/temp-test/121.inp.57.1 > ../outputs/t4122
    if diff ../outputs/t4122 ../originals/t4122 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4123) timeout -s 9 2 ../source/replace.exe '@t*?' 'a@nb@tc'  < ../inputs/temp-test/122.inp.57.2 > ../outputs/t4123
    if diff ../outputs/t4123 ../originals/t4123 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4124) timeout -s 9 2 ../source/replace.exe '@t*?' 'a@nb@tc'  < ../inputs/temp-test/123.inp.57.3 > ../outputs/t4124
    if diff ../outputs/t4124 ../originals/t4124 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4125) timeout -s 9 2 ../source/replace.exe '@t*[^--z][^0-9]?[^a-c]-' '&'  < ../inputs/temp-test/2223.inp.942.1 > ../outputs/t4125
    if diff ../outputs/t4125 ../originals/t4125 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4126) timeout -s 9 2 ../source/replace.exe '@t?' 'yy'  < ../inputs/moni/f7.inp > ../outputs/t4126
    if diff ../outputs/t4126 ../originals/t4126 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4127) timeout -s 9 2 ../source/replace.exe '@t@n' '/&q'  < ../inputs/input/ruin.539 > ../outputs/t4127
    if diff ../outputs/t4127 ../originals/t4127 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4128) timeout -s 9 2 ../source/replace.exe '@t@n**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4128
    if diff ../outputs/t4128 ../originals/t4128 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4129) timeout -s 9 2 ../source/replace.exe '@t@t**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4129
    if diff ../outputs/t4129 ../originals/t4129 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4130) timeout -s 9 2 ../source/replace.exe '@t[^0-9]' '8:,4]/)V7{X`&WCS"*eV#CiLR?Ey@wNa&*]Cm=?qNu/|~.wD'  < ../inputs/input/ruin.668 > ../outputs/t4130
    if diff ../outputs/t4130 ../originals/t4130 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4131) timeout -s 9 2 ../source/replace.exe '@t[_-z][^9-B]--@**?-' 'a@nb@tc'  < ../inputs/temp-test/702.inp.304.1 > ../outputs/t4131
    if diff ../outputs/t4131 ../originals/t4131 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4132) timeout -s 9 2 ../source/replace.exe '@t[_-z][^9-B]--@**?-' 'a@nb@tc'  < ../inputs/temp-test/703.inp.304.2 > ../outputs/t4132
    if diff ../outputs/t4132 ../originals/t4132 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4133) timeout -s 9 2 ../source/replace.exe '@t[a-z]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4133
    if diff ../outputs/t4133 ../originals/t4133 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4134) timeout -s 9 2 ../source/replace.exe '@ta[0-9]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4134
    if diff ../outputs/t4134 ../originals/t4134 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4135) timeout -s 9 2 ../source/replace.exe '@v' '['  < ../inputs/input/ruin.660 > ../outputs/t4135
    if diff ../outputs/t4135 ../originals/t4135 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4136) timeout -s 9 2 ../source/replace.exe '@v' 'uQhw$/lp,W6|T.kU[ali/|!:*<'\'''\''fd*qm0L}CmT^_<F@A5_P]'\''%P$nTZ'  < ../inputs/input/ruin.1131 > ../outputs/t4136
    if diff ../outputs/t4136 ../originals/t4136 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4137) timeout -s 9 2 ../source/replace.exe '@wT\W[tlZ@@' 'F'  < ../inputs/input/ruin.1811 > ../outputs/t4137
    if diff ../outputs/t4137 ../originals/t4137 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4138) timeout -s 9 2 ../source/replace.exe '@x' 'E2[HVM]HQd4'\''S'  < ../inputs/input/ruin.940 > ../outputs/t4138
    if diff ../outputs/t4138 ../originals/t4138 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4139) timeout -s 9 2 ../source/replace.exe '@z' '&DA%CzwMgf6f9r4:>q"borRtcvj@,P$7J Iatw|%n<DK-a,n'  < ../inputs/input/ruin.876 > ../outputs/t4139
    if diff ../outputs/t4139 ../originals/t4139 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4140) timeout -s 9 2 ../source/replace.exe '@z' '/'  < ../inputs/input/ruin.491 > ../outputs/t4140
    if diff ../outputs/t4140 ../originals/t4140 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4141) timeout -s 9 2 ../source/replace.exe '@|' ''\'''  < ../inputs/input/ruin.1305 > ../outputs/t4141
    if diff ../outputs/t4141 ../originals/t4141 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4142) timeout -s 9 2 ../source/replace.exe '@|' 'E)m'  < ../inputs/input/ruin.1373 > ../outputs/t4142
    if diff ../outputs/t4142 ../originals/t4142 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4143) timeout -s 9 2 ../source/replace.exe '@|' 'n'  < ../inputs/input/ruin.1691 > ../outputs/t4143
    if diff ../outputs/t4143 ../originals/t4143 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4144) timeout -s 9 2 ../source/replace.exe 'A' '9'  < ../inputs/input/ruin.214 > ../outputs/t4144
    if diff ../outputs/t4144 ../originals/t4144 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4145) timeout -s 9 2 ../source/replace.exe 'A' 'KT=b'  < ../inputs/input/ruin.655 > ../outputs/t4145
    if diff ../outputs/t4145 ../originals/t4145 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4146) timeout -s 9 2 ../source/replace.exe 'A' 'U~4'  < ../inputs/input/ruin.1451 > ../outputs/t4146
    if diff ../outputs/t4146 ../originals/t4146 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4147) timeout -s 9 2 ../source/replace.exe 'A*[9-B]' 'a&'  < ../inputs/temp-test/1415.inp.607.1 > ../outputs/t4147
    if diff ../outputs/t4147 ../originals/t4147 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4148) timeout -s 9 2 ../source/replace.exe 'A*[9-B]' 'a&'  < ../inputs/temp-test/1416.inp.607.3 > ../outputs/t4148
    if diff ../outputs/t4148 ../originals/t4148 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4149) timeout -s 9 2 ../source/replace.exe 'A*[^0-9]*' '@%@&'  < ../inputs/temp-test/35.inp.15.1 > ../outputs/t4149
    if diff ../outputs/t4149 ../originals/t4149 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4150) timeout -s 9 2 ../source/replace.exe 'A-' 'a@n'  < ../inputs/temp-test/1435.inp.616.1 > ../outputs/t4150
    if diff ../outputs/t4150 ../originals/t4150 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4151) timeout -s 9 2 ../source/replace.exe 'A-' 'a@n'  < ../inputs/temp-test/1436.inp.616.2 > ../outputs/t4151
    if diff ../outputs/t4151 ../originals/t4151 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4152) timeout -s 9 2 ../source/replace.exe 'A-' 'a@nb@tc'  < ../inputs/temp-test/981.inp.422.1 > ../outputs/t4152
    if diff ../outputs/t4152 ../originals/t4152 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4153) timeout -s 9 2 ../source/replace.exe 'A-' 'a@nb@tc'  < ../inputs/temp-test/982.inp.422.2 > ../outputs/t4153
    if diff ../outputs/t4153 ../originals/t4153 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4154) timeout -s 9 2 ../source/replace.exe 'A?' 'NEW'  < ../inputs/temp-test/1092.inp.471.1 > ../outputs/t4154
    if diff ../outputs/t4154 ../originals/t4154 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4155) timeout -s 9 2 ../source/replace.exe 'A?' 'NEW'  < ../inputs/temp-test/1093.inp.471.2 > ../outputs/t4155
    if diff ../outputs/t4155 ../originals/t4155 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4156) timeout -s 9 2 ../source/replace.exe 'A?' 'NEW'  < ../inputs/temp-test/1094.inp.471.4 > ../outputs/t4156
    if diff ../outputs/t4156 ../originals/t4156 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4157) timeout -s 9 2 ../source/replace.exe 'A?' 'n|G:]y;Zm{7<\G:]y;Zm{7<\33O~h_J33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_Jp'  < ../inputs/input/ruin.1043 > ../outputs/t4157
    if diff ../outputs/t4157 ../originals/t4157 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4158) timeout -s 9 2 ../source/replace.exe 'A?' 'n|p'  < ../inputs/input/ruin.1043 > ../outputs/t4158
    if diff ../outputs/t4158 ../originals/t4158 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4159) timeout -s 9 2 ../source/replace.exe 'A[0-9]?@**[a-c][^0-9]' '@%&a'  < ../inputs/temp-test/669.inp.292.1 > ../outputs/t4159
    if diff ../outputs/t4159 ../originals/t4159 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4160) timeout -s 9 2 ../source/replace.exe 'A[0-9]?@**[a-c][^0-9]' '@%&a'  < ../inputs/temp-test/670.inp.292.2 > ../outputs/t4160
    if diff ../outputs/t4160 ../originals/t4160 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4161) timeout -s 9 2 ../source/replace.exe 'A[0-9]?@**[a-c][^0-9]' '@%&a'  < ../inputs/temp-test/671.inp.292.3 > ../outputs/t4161
    if diff ../outputs/t4161 ../originals/t4161 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4162) timeout -s 9 2 ../source/replace.exe 'A[9-B]@*[9-B]---*-[_-z]-[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/985.inp.425.1 > ../outputs/t4162
    if diff ../outputs/t4162 ../originals/t4162 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4163) timeout -s 9 2 ../source/replace.exe 'A[9-B]@*[9-B]---*-[_-z]-[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/986.inp.425.2 > ../outputs/t4163
    if diff ../outputs/t4163 ../originals/t4163 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4164) timeout -s 9 2 ../source/replace.exe 'A[9-B]@*[9-B]---*-[_-z]-[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/987.inp.425.3 > ../outputs/t4164
    if diff ../outputs/t4164 ../originals/t4164 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4165) timeout -s 9 2 ../source/replace.exe 'A[9-B]@*[9-B]---*-[_-z]-[^0-9]' 'a@nb@tc'  < ../inputs/temp-test/988.inp.425.4 > ../outputs/t4165
    if diff ../outputs/t4165 ../originals/t4165 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4166) timeout -s 9 2 ../source/replace.exe 'A[^0-9]' '&'  < ../inputs/temp-test/443.inp.194.1 > ../outputs/t4166
    if diff ../outputs/t4166 ../originals/t4166 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4167) timeout -s 9 2 ../source/replace.exe 'A[^0-9]' '&'  < ../inputs/temp-test/444.inp.194.2 > ../outputs/t4167
    if diff ../outputs/t4167 ../originals/t4167 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4168) timeout -s 9 2 ../source/replace.exe 'A[^a-c[0-9]@[*' '&a@%'  < ../inputs/temp-test/589.inp.253.1 > ../outputs/t4168
    if diff ../outputs/t4168 ../originals/t4168 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4169) timeout -s 9 2 ../source/replace.exe 'A[^a-c[0-9]@[*' '&a@%'  < ../inputs/temp-test/590.inp.253.2 > ../outputs/t4169
    if diff ../outputs/t4169 ../originals/t4169 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4170) timeout -s 9 2 ../source/replace.exe 'A[^a-c[0-9]@[*' '&a@%'  < ../inputs/temp-test/591.inp.253.3 > ../outputs/t4170
    if diff ../outputs/t4170 ../originals/t4170 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4171) timeout -s 9 2 ../source/replace.exe 'A[a-c]' '&'  < ../inputs/temp-test/787.inp.339.1 > ../outputs/t4171
    if diff ../outputs/t4171 ../originals/t4171 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4172) timeout -s 9 2 ../source/replace.exe 'A[a-c]' '&'  < ../inputs/temp-test/788.inp.339.2 > ../outputs/t4172
    if diff ../outputs/t4172 ../originals/t4172 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4173) timeout -s 9 2 ../source/replace.exe 'AyxAyxg=po%]]@lhZe,xFP.{F:@m}I)|?,WAyxg=po%]]@lhZe,xFP.{F:@m}I)|?,WAyxg=po%]]@lhZe,xFP.{F:@m}I)|?,Wg=po%]]@lhZe,xFP.{F:@m}I)|?,W-[^0-9]*' 'a'  < ../inputs/moni/f8.inp > ../outputs/t4173
    if diff ../outputs/t4173 ../originals/t4173 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4174) timeout -s 9 2 ../source/replace.exe 'B' 'Jp=p0sA?1'  < ../inputs/input/ruin.189 > ../outputs/t4174
    if diff ../outputs/t4174 ../originals/t4174 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4175) timeout -s 9 2 ../source/replace.exe 'B*' 'LOBA3nKpK'  < ../inputs/input/ruin.1540 > ../outputs/t4175
    if diff ../outputs/t4175 ../originals/t4175 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4176) timeout -s 9 2 ../source/replace.exe 'B@n' 'L/'  < ../inputs/input/ruin.1402 > ../outputs/t4176
    if diff ../outputs/t4176 ../originals/t4176 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4177) timeout -s 9 2 ../source/replace.exe 'C' '*KzXwIk7N2H\tMB0cSIU)2'  < ../inputs/input/ruin.261 > ../outputs/t4177
    if diff ../outputs/t4177 ../originals/t4177 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4178) timeout -s 9 2 ../source/replace.exe 'C' '/;ou%4-Wm7YQOcwuoq~qeI4u{J-'  < ../inputs/input/ruin.1794 > ../outputs/t4178
    if diff ../outputs/t4178 ../originals/t4178 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4179) timeout -s 9 2 ../source/replace.exe 'C' 'A@,)aS'  < ../inputs/input/ruin.255 > ../outputs/t4179
    if diff ../outputs/t4179 ../originals/t4179 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4180) timeout -s 9 2 ../source/replace.exe 'C' 'yel.mN.aMcN'  < ../inputs/input/ruin.141 > ../outputs/t4180
    if diff ../outputs/t4180 ../originals/t4180 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4181) timeout -s 9 2 ../source/replace.exe 'C' '|'  < ../inputs/input/ruin.263 > ../outputs/t4181
    if diff ../outputs/t4181 ../originals/t4181 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4182) timeout -s 9 2 ../source/replace.exe 'C*' '\'  < ../inputs/input/ruin.1504 > ../outputs/t4182
    if diff ../outputs/t4182 ../originals/t4182 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4183) timeout -s 9 2 ../source/replace.exe 'D' '%0,*G^75(j/ZwU5liE,jWQ((cq::$.B SGUhf% uN'  < ../inputs/input/ruin.1654 > ../outputs/t4183
    if diff ../outputs/t4183 ../originals/t4183 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4184) timeout -s 9 2 ../source/replace.exe 'D' '4'  < ../inputs/input/ruin.1266 > ../outputs/t4184
    if diff ../outputs/t4184 ../originals/t4184 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4185) timeout -s 9 2 ../source/replace.exe 'D' 'EI3"JSr"Wv1YW:m,fR@cfETz#.'\'''\'')fO#'  < ../inputs/input/ruin.717 > ../outputs/t4185
    if diff ../outputs/t4185 ../originals/t4185 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4186) timeout -s 9 2 ../source/replace.exe 'D' 'W"Kax!`^75zx?2@p4;(PY(a+_a)5rq*!x\i]-?+2Z"^b7b*0*ucQ}Pb )zRL24-Rc iB'  < ../inputs/input/ruin.920 > ../outputs/t4186
    if diff ../outputs/t4186 ../originals/t4186 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4187) timeout -s 9 2 ../source/replace.exe 'D'  < ../inputs/input/ruin.1266 > ../outputs/t4187
    if diff ../outputs/t4187 ../originals/t4187 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4188) timeout -s 9 2 ../source/replace.exe 'D*@@*' '~'  < ../inputs/input/ruin.1524 > ../outputs/t4188
    if diff ../outputs/t4188 ../originals/t4188 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4189) timeout -s 9 2 ../source/replace.exe 'D?' 'EI3"JSr"Wv1YW:m,fR@cfETz#.'\'''\'')fO#'  < ../inputs/input/ruin.717 > ../outputs/t4189
    if diff ../outputs/t4189 ../originals/t4189 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4190) timeout -s 9 2 ../source/replace.exe 'E@n' '0'  < ../inputs/input/ruin.313 > ../outputs/t4190
    if diff ../outputs/t4190 ../originals/t4190 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4191) timeout -s 9 2 ../source/replace.exe 'EW-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*EW-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*EW-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*EW-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*EW-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*EW-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*EW-?-c*[0-9][a-c]-?A-?-c*[0-9][a-c]-?A-?-c*' 'l[*U(0T7mn'  < ../inputs/input/ruin.1352 > ../outputs/t4191
    if diff ../outputs/t4191 ../originals/t4191 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4192) timeout -s 9 2 ../source/replace.exe 'EW-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?A-?-cEW-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?A-?-cEW-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?A-?-cEW-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?A-?-cEW-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?A-?-cEW-?-c[0-9][a-c]-?A-?-c[0-9][a-c]-?A-?-cEW-?-c0-9][a-c]-?A-?-c[0-9][a-c]-?A-?-c[0-9]*' 'l[*U(0T7mn'  < ../inputs/input/ruin.1352 > ../outputs/t4192
    if diff ../outputs/t4192 ../originals/t4192 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4193) timeout -s 9 2 ../source/replace.exe 'EW-[0-9][^0-9][@t][^@][9-B]-[0-9][^0-9][@t0-9]@@]@][9-B]-[0-9][^0-9][@t@][9-B]-[0-9][^0-9][@t@][9-B]-[0-9][^0-9][@t[9-B]-[0-@][9-B]-[0-9][^0-9][@t9][^0-9@][9-B]-[0-9][^0-9][@t@][9-B]-[0-9][^0-9][@t]*[@t@][9-B]-*[0-9][^0-9][@t' ''  < ../inputs/moni/f8.inp > ../outputs/t4193
    if diff ../outputs/t4193 ../originals/t4193 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4194) timeout -s 9 2 ../source/replace.exe 'F' 'O'  < ../inputs/input/ruin.1425 > ../outputs/t4194
    if diff ../outputs/t4194 ../originals/t4194 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4195) timeout -s 9 2 ../source/replace.exe 'F' 'WX<&l^t0+KUz-hc#38V(a+S5F w|V~[]SX-XF-1fiksa['  < ../inputs/input/ruin.620 > ../outputs/t4195
    if diff ../outputs/t4195 ../originals/t4195 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4196) timeout -s 9 2 ../source/replace.exe 'F' 'b'  < ../inputs/input/ruin.1271 > ../outputs/t4196
    if diff ../outputs/t4196 ../originals/t4196 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4197) timeout -s 9 2 ../source/replace.exe 'F*$' '[SnK:ScY3|gj)p9qF'  < ../inputs/input/ruin.1107 > ../outputs/t4197
    if diff ../outputs/t4197 ../originals/t4197 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4198) timeout -s 9 2 ../source/replace.exe 'G' '4N9'  < ../inputs/input/ruin.656 > ../outputs/t4198
    if diff ../outputs/t4198 ../originals/t4198 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4199) timeout -s 9 2 ../source/replace.exe 'G' '@TG<!e"F'  < ../inputs/input/ruin.814 > ../outputs/t4199
    if diff ../outputs/t4199 ../originals/t4199 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4200) timeout -s 9 2 ../source/replace.exe 'H' 'j-8m$"la'  < ../inputs/input/ruin.272 > ../outputs/t4200
    if diff ../outputs/t4200 ../originals/t4200 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4201) timeout -s 9 2 ../source/replace.exe 'H8WstZ' 'B'  < ../inputs/input/ruin.808 > ../outputs/t4201
    if diff ../outputs/t4201 ../originals/t4201 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4202) timeout -s 9 2 ../source/replace.exe 'K' 'C'  < ../inputs/input/ruin.1006 > ../outputs/t4202
    if diff ../outputs/t4202 ../originals/t4202 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4203) timeout -s 9 2 ../source/replace.exe 'K' '~yV0-:222<W/.gu!m4(Uzh;q{+F?H13VV=3'  < ../inputs/input/ruin.262 > ../outputs/t4203
    if diff ../outputs/t4203 ../originals/t4203 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4204) timeout -s 9 2 ../source/replace.exe 'L' '3'  < ../inputs/input/ruin.1662 > ../outputs/t4204
    if diff ../outputs/t4204 ../originals/t4204 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4205) timeout -s 9 2 ../source/replace.exe 'L' '\'  < ../inputs/input/ruin.54 > ../outputs/t4205
    if diff ../outputs/t4205 ../originals/t4205 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4206) timeout -s 9 2 ../source/replace.exe 'L' '|}HL'  < ../inputs/input/ruin.1345 > ../outputs/t4206
    if diff ../outputs/t4206 ../originals/t4206 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4207) timeout -s 9 2 ../source/replace.exe 'L]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY[0-9]*' '|}HL'  < ../inputs/input/ruin.1345 > ../outputs/t4207
    if diff ../outputs/t4207 ../originals/t4207 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4208) timeout -s 9 2 ../source/replace.exe 'M' 'Cj"P[Am~9?yD6$!CL]i35p`"R"/.6A*Y6b8#y)#}^"'  < ../inputs/input/ruin.467 > ../outputs/t4208
    if diff ../outputs/t4208 ../originals/t4208 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4209) timeout -s 9 2 ../source/replace.exe 'M' 'D'  < ../inputs/input/ruin.1199 > ../outputs/t4209
    if diff ../outputs/t4209 ../originals/t4209 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4210) timeout -s 9 2 ../source/replace.exe 'M' 'kE]3,iYi}HxHv$4g_4Un8pHk&TFT([dkb^2'  < ../inputs/input/ruin.840 > ../outputs/t4210
    if diff ../outputs/t4210 ../originals/t4210 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4211) timeout -s 9 2 ../source/replace.exe 'M' 'sizo5Mt^V>)QHSUlI}Zgpr(C.59OiQ;R>StQx95)ab]'  < ../inputs/input/ruin.193 > ../outputs/t4211
    if diff ../outputs/t4211 ../originals/t4211 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4212) timeout -s 9 2 ../source/replace.exe 'M' 'tx'\''%~x55x9M '  < ../inputs/input/ruin.1763 > ../outputs/t4212
    if diff ../outputs/t4212 ../originals/t4212 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4213) timeout -s 9 2 ../source/replace.exe 'N' '6Ws|xIfoO~JSwkEPBr8s/VE '  < ../inputs/input/ruin.1112 > ../outputs/t4213
    if diff ../outputs/t4213 ../originals/t4213 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4214) timeout -s 9 2 ../source/replace.exe 'N' '=$(4a6[U'  < ../inputs/input/ruin.423 > ../outputs/t4214
    if diff ../outputs/t4214 ../originals/t4214 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4215) timeout -s 9 2 ../source/replace.exe 'N' '`d+gs"uyr#OV+nf@.:.%V.?GP'  < ../inputs/input/ruin.1991 > ../outputs/t4215
    if diff ../outputs/t4215 ../originals/t4215 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4216) timeout -s 9 2 ../source/replace.exe 'N*$' '6Ws|xIfoO~JSwkEPBr8s/VE '  < ../inputs/input/ruin.1112 > ../outputs/t4216
    if diff ../outputs/t4216 ../originals/t4216 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4217) timeout -s 9 2 ../source/replace.exe 'N*$' '`d+gs"uyr#OV+nf@.:.%V.?GP'  < ../inputs/input/ruin.1991 > ../outputs/t4217
    if diff ../outputs/t4217 ../originals/t4217 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4218) timeout -s 9 2 ../source/replace.exe 'NEWNEW-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0[^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t4218
    if diff ../outputs/t4218 ../originals/t4218 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4219) timeout -s 9 2 ../source/replace.exe 'NEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEW-[^0-9][0-9]A@@*' 'NEW'  < ../inputs/temp-test/1584.inp.675.1 > ../outputs/t4219
    if diff ../outputs/t4219 ../originals/t4219 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4220) timeout -s 9 2 ../source/replace.exe 'NEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEW-[^0-9][0-9]A@@*[^0-9][9-B]@@[^a-c]--[0-9][9-B][^a-]' 'NEW'  < ../inputs/temp-test/1584.inp.675.1 > ../outputs/t4220
    if diff ../outputs/t4220 ../originals/t4220 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4221) timeout -s 9 2 ../source/replace.exe 'NEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEWNEW-[a-b]@A*' 'NEW'  < ../inputs/temp-test/1584.inp.675.1 > ../outputs/t4221
    if diff ../outputs/t4221 ../originals/t4221 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4222) timeout -s 9 2 ../source/replace.exe 'O' 'y'  < ../inputs/input/ruin.1367 > ../outputs/t4222
    if diff ../outputs/t4222 ../originals/t4222 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4223) timeout -s 9 2 ../source/replace.exe 'O' 'yxk&IcrOvB79'  < ../inputs/input/ruin.1324 > ../outputs/t4223
    if diff ../outputs/t4223 ../originals/t4223 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4224) timeout -s 9 2 ../source/replace.exe 'P' '#uy6z!;7!5}BP}j(]y|jFd!P8'  < ../inputs/input/ruin.530 > ../outputs/t4224
    if diff ../outputs/t4224 ../originals/t4224 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4225) timeout -s 9 2 ../source/replace.exe 'P' ')9'\''8k3|Ny$1(){7:uAh@|7_0P==NHS+k*aGI.Ii)Jo'  < ../inputs/input/ruin.1260 > ../outputs/t4225
    if diff ../outputs/t4225 ../originals/t4225 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4226) timeout -s 9 2 ../source/replace.exe 'P' '8dnIaK~FIW<<Q;Z7/e'  < ../inputs/input/ruin.709 > ../outputs/t4226
    if diff ../outputs/t4226 ../originals/t4226 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4227) timeout -s 9 2 ../source/replace.exe 'P' 'C%^&1c)TylhX%4~p?xve1crIe>QYS'  < ../inputs/input/ruin.1819 > ../outputs/t4227
    if diff ../outputs/t4227 ../originals/t4227 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4228) timeout -s 9 2 ../source/replace.exe 'P' 'H'  < ../inputs/input/ruin.1444 > ../outputs/t4228
    if diff ../outputs/t4228 ../originals/t4228 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4229) timeout -s 9 2 ../source/replace.exe 'Q' '['  < ../inputs/input/ruin.1505 > ../outputs/t4229
    if diff ../outputs/t4229 ../originals/t4229 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4230) timeout -s 9 2 ../source/replace.exe 'Q' 'a3ZF0Vxb'\''Lv@Ok8KPvf'  < ../inputs/input/ruin.699 > ../outputs/t4230
    if diff ../outputs/t4230 ../originals/t4230 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4231) timeout -s 9 2 ../source/replace.exe 'Q' 'wNqDw*g-Fd<<T<2_s<p7'  < ../inputs/input/ruin.535 > ../outputs/t4231
    if diff ../outputs/t4231 ../originals/t4231 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4232) timeout -s 9 2 ../source/replace.exe 'Q'\''A%ON,r[^Q]' ''  < ../inputs/input/ruin.1604 > ../outputs/t4232
    if diff ../outputs/t4232 ../originals/t4232 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4233) timeout -s 9 2 ../source/replace.exe 'Q?*'\''A%ON,r[^Q]' ''  < ../inputs/input/ruin.1604 > ../outputs/t4233
    if diff ../outputs/t4233 ../originals/t4233 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4234) timeout -s 9 2 ../source/replace.exe 'R' ' wMNQ]FT4jT:<n~RM@!U'  < ../inputs/input/ruin.540 > ../outputs/t4234
    if diff ../outputs/t4234 ../originals/t4234 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4235) timeout -s 9 2 ../source/replace.exe 'R' '.UxpVIk4j5.x#~A_?tJgxk(iJog'  < ../inputs/input/ruin.1469 > ../outputs/t4235
    if diff ../outputs/t4235 ../originals/t4235 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4236) timeout -s 9 2 ../source/replace.exe 'R' ';'  < ../inputs/input/ruin.1925 > ../outputs/t4236
    if diff ../outputs/t4236 ../originals/t4236 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4237) timeout -s 9 2 ../source/replace.exe 'R' '=IM'  < ../inputs/input/ruin.30 > ../outputs/t4237
    if diff ../outputs/t4237 ../originals/t4237 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4238) timeout -s 9 2 ../source/replace.exe 'S$' ',;38fvdrW+/RE#MD&O/^AZjdQz2X4GAE'  < ../inputs/input/ruin.102 > ../outputs/t4238
    if diff ../outputs/t4238 ../originals/t4238 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4239) timeout -s 9 2 ../source/replace.exe 'S' ')B.>,{|a%= :,/e]SAZV~B;$SmeJsO^(vS.D?5N%tI4~'  < ../inputs/input/ruin.1646 > ../outputs/t4239
    if diff ../outputs/t4239 ../originals/t4239 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4240) timeout -s 9 2 ../source/replace.exe 'S' '*q2"V]-tl5iK"z^gn'  < ../inputs/input/ruin.1004 > ../outputs/t4240
    if diff ../outputs/t4240 ../originals/t4240 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4241) timeout -s 9 2 ../source/replace.exe 'S' 'Mu4y5Jmglv#)'  < ../inputs/input/ruin.768 > ../outputs/t4241
    if diff ../outputs/t4241 ../originals/t4241 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4242) timeout -s 9 2 ../source/replace.exe 'S' 'b8SsJNUimj[N?#ok`'  < ../inputs/input/ruin.1021 > ../outputs/t4242
    if diff ../outputs/t4242 ../originals/t4242 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4243) timeout -s 9 2 ../source/replace.exe 'T' '*O'  < ../inputs/input/ruin.1603 > ../outputs/t4243
    if diff ../outputs/t4243 ../originals/t4243 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4244) timeout -s 9 2 ../source/replace.exe 'T?*' '*O'  < ../inputs/input/ruin.1603 > ../outputs/t4244
    if diff ../outputs/t4244 ../originals/t4244 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4245) timeout -s 9 2 ../source/replace.exe 'T@@' '.b'  < ../inputs/input/ruin.361 > ../outputs/t4245
    if diff ../outputs/t4245 ../originals/t4245 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4246) timeout -s 9 2 ../source/replace.exe 'T@@' 'n'  < ../inputs/input/ruin.854 > ../outputs/t4246
    if diff ../outputs/t4246 ../originals/t4246 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4247) timeout -s 9 2 ../source/replace.exe 'U' ''  < ../inputs/input/ruin.1571 > ../outputs/t4247
    if diff ../outputs/t4247 ../originals/t4247 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4248) timeout -s 9 2 ../source/replace.exe 'U' 'J'  < ../inputs/input/ruin.99 > ../outputs/t4248
    if diff ../outputs/t4248 ../originals/t4248 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4249) timeout -s 9 2 ../source/replace.exe 'U' 'f'  < ../inputs/input/ruin.798 > ../outputs/t4249
    if diff ../outputs/t4249 ../originals/t4249 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4250) timeout -s 9 2 ../source/replace.exe 'V' '#'  < ../inputs/input/ruin.1851 > ../outputs/t4250
    if diff ../outputs/t4250 ../originals/t4250 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4251) timeout -s 9 2 ../source/replace.exe 'V' '>'\''q'  < ../inputs/input/ruin.1273 > ../outputs/t4251
    if diff ../outputs/t4251 ../originals/t4251 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4252) timeout -s 9 2 ../source/replace.exe 'V' 'o'  < ../inputs/input/ruin.107 > ../outputs/t4252
    if diff ../outputs/t4252 ../originals/t4252 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4253) timeout -s 9 2 ../source/replace.exe 'V' 'x'  < ../inputs/input/ruin.863 > ../outputs/t4253
    if diff ../outputs/t4253 ../originals/t4253 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4254) timeout -s 9 2 ../source/replace.exe 'W$' '7'  < ../inputs/input/ruin.1302 > ../outputs/t4254
    if diff ../outputs/t4254 ../originals/t4254 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4255) timeout -s 9 2 ../source/replace.exe 'W' '4'  < ../inputs/input/ruin.1931 > ../outputs/t4255
    if diff ../outputs/t4255 ../originals/t4255 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4256) timeout -s 9 2 ../source/replace.exe 'W' 'W='  < ../inputs/input/ruin.999 > ../outputs/t4256
    if diff ../outputs/t4256 ../originals/t4256 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4257) timeout -s 9 2 ../source/replace.exe 'W' 'cCeuNv}}<pw83QZL=[v%D!jP]z[`?=f9b?1A'  < ../inputs/input/ruin.24 > ../outputs/t4257
    if diff ../outputs/t4257 ../originals/t4257 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4258) timeout -s 9 2 ../source/replace.exe 'W' 'es'  < ../inputs/input/ruin.712 > ../outputs/t4258
    if diff ../outputs/t4258 ../originals/t4258 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4259) timeout -s 9 2 ../source/replace.exe 'WF@@' 'r'  < ../inputs/input/ruin.1450 > ../outputs/t4259
    if diff ../outputs/t4259 ../originals/t4259 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4260) timeout -s 9 2 ../source/replace.exe 'X' '"'  < ../inputs/input/ruin.1765 > ../outputs/t4260
    if diff ../outputs/t4260 ../originals/t4260 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4261) timeout -s 9 2 ../source/replace.exe 'X' '6?@UBgSAstKhS|SHH*nQ#bN4t}}E6X%KVg9Q.21Hl7[ot[r`rE %IheDivd`\b7dfg^'\''^Ysr=zRchgkQLx{aoU@`'  < ../inputs/input/ruin.431 > ../outputs/t4261
    if diff ../outputs/t4261 ../originals/t4261 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4262) timeout -s 9 2 ../source/replace.exe 'X' '}'  < ../inputs/input/ruin.1753 > ../outputs/t4262
    if diff ../outputs/t4262 ../originals/t4262 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4263) timeout -s 9 2 ../source/replace.exe 'X[>-A]\Mb%-N@@*' '4'  < ../inputs/input/ruin.1808 > ../outputs/t4263
    if diff ../outputs/t4263 ../originals/t4263 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4264) timeout -s 9 2 ../source/replace.exe 'X[A-G]' '_'  < ../inputs/input/ruin.604 > ../outputs/t4264
    if diff ../outputs/t4264 ../originals/t4264 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4265) timeout -s 9 2 ../source/replace.exe 'Y$' '$]'  < ../inputs/input/ruin.691 > ../outputs/t4265
    if diff ../outputs/t4265 ../originals/t4265 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4266) timeout -s 9 2 ../source/replace.exe 'Y' ''  < ../inputs/input/ruin.1988 > ../outputs/t4266
    if diff ../outputs/t4266 ../originals/t4266 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4267) timeout -s 9 2 ../source/replace.exe 'Y' ')}&>hBN)HZF_obPasG*I4tso.>?+2Vcp'  < ../inputs/input/ruin.1405 > ../outputs/t4267
    if diff ../outputs/t4267 ../originals/t4267 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4268) timeout -s 9 2 ../source/replace.exe 'Y' 'pW0qy>=,KL"X@t<=mT(@/+]>BxhOE&FMUU'  < ../inputs/input/ruin.1481 > ../outputs/t4268
    if diff ../outputs/t4268 ../originals/t4268 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4269) timeout -s 9 2 ../source/replace.exe 'YN[^)0-9]' '<KVDSFwGr=)<pMBhEhiwPgVy@F'  < ../inputs/input/ruin.1495 > ../outputs/t4269
    if diff ../outputs/t4269 ../originals/t4269 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4270) timeout -s 9 2 ../source/replace.exe 'Z' '!'  < ../inputs/input/ruin.1085 > ../outputs/t4270
    if diff ../outputs/t4270 ../originals/t4270 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4271) timeout -s 9 2 ../source/replace.exe 'Z' 'QHJV7!Ty3gBtmt_(NOk;73R>j*\Hq.B?RLmD$3y]%ay(M! '  < ../inputs/input/ruin.1154 > ../outputs/t4271
    if diff ../outputs/t4271 ../originals/t4271 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4272) timeout -s 9 2 ../source/replace.exe 'Z' 'k$HcHD(tVs}`VS'  < ../inputs/input/ruin.1141 > ../outputs/t4272
    if diff ../outputs/t4272 ../originals/t4272 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4273) timeout -s 9 2 ../source/replace.exe 'Z' 'k'  < ../inputs/input/ruin.1936 > ../outputs/t4273
    if diff ../outputs/t4273 ../originals/t4273 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4274) timeout -s 9 2 ../source/replace.exe 'Z'  < ../inputs/input/ruin.1154 > ../outputs/t4274
    if diff ../outputs/t4274 ../originals/t4274 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4275) timeout -s 9 2 ../source/replace.exe '[ ]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4275
    if diff ../outputs/t4275 ../originals/t4275 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4276) timeout -s 9 2 ../source/replace.exe '[!]*\@@' 'X'\'',id`ucU?Bhj!aeGJ~qW=F*9LTRouw#I-quWg}}wkR8Cwfff{{JGSTC2v7(*^3wSqSn{{\Jx9r8a'  < ../inputs/input/ruin.130 > ../outputs/t4276
    if diff ../outputs/t4276 ../originals/t4276 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4277) timeout -s 9 2 ../source/replace.exe '[%a-c[9-B]c*^-[0-9]-^*?@[-[^a-c]?' 'b@t'  < ../inputs/temp-test/2345.inp.996.2 > ../outputs/t4277
    if diff ../outputs/t4277 ../originals/t4277 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4278) timeout -s 9 2 ../source/replace.exe '[)]' 'o'  < ../inputs/input/ruin.1965 > ../outputs/t4278
    if diff ../outputs/t4278 ../originals/t4278 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4279) timeout -s 9 2 ../source/replace.exe '[*]' 'k0x@zTL"t{3F#Ha7~@k+:!hc]OtZ~i}h?rr}'  < ../inputs/input/ruin.596 > ../outputs/t4279
    if diff ../outputs/t4279 ../originals/t4279 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4280) timeout -s 9 2 ../source/replace.exe '[-?' '@n'  < ../inputs/temp-test/81.inp.36.1 > ../outputs/t4280
    if diff ../outputs/t4280 ../originals/t4280 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4281) timeout -s 9 2 ../source/replace.exe '[-?' '@n'  < ../inputs/temp-test/82.inp.36.3 > ../outputs/t4281
    if diff ../outputs/t4281 ../originals/t4281 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4282) timeout -s 9 2 ../source/replace.exe '[-?-]?-?^-][0-9][_-z]?' 'NEW'  < ../inputs/temp-test/959.inp.413.1 > ../outputs/t4282
    if diff ../outputs/t4282 ../originals/t4282 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4283) timeout -s 9 2 ../source/replace.exe '[-?-]?-?^-][0-9][_-z]?' 'NEW'  < ../inputs/temp-test/960.inp.413.3 > ../outputs/t4283
    if diff ../outputs/t4283 ../originals/t4283 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4284) timeout -s 9 2 ../source/replace.exe '[-^?[9-B][^a-][9-B]-[-??--@t' 'a&'  < ../inputs/temp-test/403.inp.176.1 > ../outputs/t4284
    if diff ../outputs/t4284 ../originals/t4284 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4285) timeout -s 9 2 ../source/replace.exe '[-z]?' 'a&'  < ../inputs/temp-test/652.inp.283.1 > ../outputs/t4285
    if diff ../outputs/t4285 ../originals/t4285 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4286) timeout -s 9 2 ../source/replace.exe '[-z][^--z]' 'a&'  < ../inputs/temp-test/1089.inp.469.1 > ../outputs/t4286
    if diff ../outputs/t4286 ../originals/t4286 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4287) timeout -s 9 2 ../source/replace.exe '[-z][^--z]' 'a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&a&'  < ../inputs/temp-test/1089.inp.469.1 > ../outputs/t4287
    if diff ../outputs/t4287 ../originals/t4287 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4288) timeout -s 9 2 ../source/replace.exe '[-z][^0-9]' '@%&a'  < ../inputs/temp-test/1901.inp.806.1 > ../outputs/t4288
    if diff ../outputs/t4288 ../originals/t4288 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4289) timeout -s 9 2 ../source/replace.exe '[-z][^0-9]' '@%&a'  < ../inputs/temp-test/1902.inp.806.2 > ../outputs/t4289
    if diff ../outputs/t4289 ../originals/t4289 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4290) timeout -s 9 2 ../source/replace.exe '[-z][^9-B]?--[^9-B]-[^9-B][^9-B]-?@[' '@n'  < ../inputs/temp-test/2095.inp.888.1 > ../outputs/t4290
    if diff ../outputs/t4290 ../originals/t4290 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4291) timeout -s 9 2 ../source/replace.exe '[0-9@[@%^2]*?' 'c'  < ../inputs/moni/f7.inp > ../outputs/t4291
    if diff ../outputs/t4291 ../originals/t4291 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4292) timeout -s 9 2 ../source/replace.exe '[0-9@[^2]*' 'c'  < ../inputs/moni/f7.inp > ../outputs/t4292
    if diff ../outputs/t4292 ../originals/t4292 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4293) timeout -s 9 2 ../source/replace.exe '[0-9A-G]' '$g!HB8cbI<,U1Q7<r%tEEDC['\''N?'  < ../inputs/input/ruin.1516 > ../outputs/t4293
    if diff ../outputs/t4293 ../originals/t4293 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4294) timeout -s 9 2 ../source/replace.exe '[0-9Z-a]^_`a]' 'a'  < ../inputs/input/ruin.713 > ../outputs/t4294
    if diff ../outputs/t4294 ../originals/t4294 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4295) timeout -s 9 2 ../source/replace.exe '[0-9] *?@[*[0-9]?' '&'  < ../inputs/temp-test/1647.inp.702.1 > ../outputs/t4295
    if diff ../outputs/t4295 ../originals/t4295 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4296) timeout -s 9 2 ../source/replace.exe '[0-9] [^@@]?A??[^@n]@@' '@%&a'  < ../inputs/temp-test/1621.inp.689.1 > ../outputs/t4296
    if diff ../outputs/t4296 ../originals/t4296 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4297) timeout -s 9 2 ../source/replace.exe '[0-9]%?' '@t'  < ../inputs/temp-test/2339.inp.994.1 > ../outputs/t4297
    if diff ../outputs/t4297 ../originals/t4297 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4298) timeout -s 9 2 ../source/replace.exe '[0-9]%?' '@t'  < ../inputs/temp-test/2340.inp.994.3 > ../outputs/t4298
    if diff ../outputs/t4298 ../originals/t4298 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4299) timeout -s 9 2 ../source/replace.exe '[0-9]' '&@n'  < ../inputs/temp-test/698.inp.302.1 > ../outputs/t4299
    if diff ../outputs/t4299 ../originals/t4299 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4300) timeout -s 9 2 ../source/replace.exe '[0-9]' '&@n'  < ../inputs/temp-test/699.inp.302.3 > ../outputs/t4300
    if diff ../outputs/t4300 ../originals/t4300 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4301) timeout -s 9 2 ../source/replace.exe '[0-9]' '&a@%'  < ../inputs/temp-test/592.inp.254.1 > ../outputs/t4301
    if diff ../outputs/t4301 ../originals/t4301 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4302) timeout -s 9 2 ../source/replace.exe '[0-9]' '&a@%'  < ../inputs/temp-test/593.inp.254.2 > ../outputs/t4302
    if diff ../outputs/t4302 ../originals/t4302 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4303) timeout -s 9 2 ../source/replace.exe '[0-9]' '9'  < ../inputs/input/ruin.617 > ../outputs/t4303
    if diff ../outputs/t4303 ../originals/t4303 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4304) timeout -s 9 2 ../source/replace.exe '[0-9]' '@%&a'  < ../inputs/temp-test/1478.inp.634.1 > ../outputs/t4304
    if diff ../outputs/t4304 ../originals/t4304 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4305) timeout -s 9 2 ../source/replace.exe '[0-9]' '@%&a'  < ../inputs/temp-test/1479.inp.634.2 > ../outputs/t4305
    if diff ../outputs/t4305 ../originals/t4305 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4306) timeout -s 9 2 ../source/replace.exe '[0-9]' '@%@&'  < ../inputs/temp-test/1065.inp.458.1 > ../outputs/t4306
    if diff ../outputs/t4306 ../originals/t4306 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4307) timeout -s 9 2 ../source/replace.exe '[0-9]' '@%@&'  < ../inputs/temp-test/1066.inp.458.2 > ../outputs/t4307
    if diff ../outputs/t4307 ../originals/t4307 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4308) timeout -s 9 2 ../source/replace.exe '[0-9]' '@%@&'  < ../inputs/temp-test/1067.inp.458.3 > ../outputs/t4308
    if diff ../outputs/t4308 ../originals/t4308 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4309) timeout -s 9 2 ../source/replace.exe '[0-9]' '@'  < ../inputs/input/ruin.1254 > ../outputs/t4309
    if diff ../outputs/t4309 ../originals/t4309 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4310) timeout -s 9 2 ../source/replace.exe '[0-9]' '@9ad|W{5Opa?mnxf=Jhe>u5Dh\*W:.1Q*tSCyX79o5v;D91S\@,R:mmfL'  < ../inputs/input/ruin.267 > ../outputs/t4310
    if diff ../outputs/t4310 ../originals/t4310 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4311) timeout -s 9 2 ../source/replace.exe '[0-9]' '@t'  < ../inputs/temp-test/2302.inp.978.1 > ../outputs/t4311
    if diff ../outputs/t4311 ../originals/t4311 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4312) timeout -s 9 2 ../source/replace.exe '[0-9]' '@t'  < ../inputs/temp-test/2303.inp.978.2 > ../outputs/t4312
    if diff ../outputs/t4312 ../originals/t4312 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4313) timeout -s 9 2 ../source/replace.exe '[0-9]' 'D'  < ../inputs/input/ruin.1443 > ../outputs/t4313
    if diff ../outputs/t4313 ../originals/t4313 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4314) timeout -s 9 2 ../source/replace.exe '[0-9]' 'G'  < ../inputs/input/ruin.57 > ../outputs/t4314
    if diff ../outputs/t4314 ../originals/t4314 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4315) timeout -s 9 2 ../source/replace.exe '[0-9]' 'L3n1<EN|F8u?><i{'  < ../inputs/input/ruin.891 > ../outputs/t4315
    if diff ../outputs/t4315 ../originals/t4315 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4316) timeout -s 9 2 ../source/replace.exe '[0-9]' 'NEW'  < ../inputs/temp-test/849.inp.365.1 > ../outputs/t4316
    if diff ../outputs/t4316 ../originals/t4316 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4317) timeout -s 9 2 ../source/replace.exe '[0-9]' 'NEW'  < ../inputs/temp-test/850.inp.365.2 > ../outputs/t4317
    if diff ../outputs/t4317 ../originals/t4317 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4318) timeout -s 9 2 ../source/replace.exe '[0-9]' 'SryF'  < ../inputs/input/ruin.1576 > ../outputs/t4318
    if diff ../outputs/t4318 ../originals/t4318 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4319) timeout -s 9 2 ../source/replace.exe '[0-9]' 'TeqP2iu]R?wiH?0?xlG9pCy?y9'  < ../inputs/input/ruin.1392 > ../outputs/t4319
    if diff ../outputs/t4319 ../originals/t4319 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4320) timeout -s 9 2 ../source/replace.exe '[0-9]' 'V9U,`[95h_,<BuOOS)?:@yaM3"l5/vWQv242)yJ],?_[&49@y>|;ahg7Hd:wja'  < ../inputs/input/ruin.1499 > ../outputs/t4320
    if diff ../outputs/t4320 ../originals/t4320 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4321) timeout -s 9 2 ../source/replace.exe '[0-9]' 'X'  < ../inputs/input/ruin.1759 > ../outputs/t4321
    if diff ../outputs/t4321 ../originals/t4321 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4322) timeout -s 9 2 ../source/replace.exe '[0-9]' '[[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B][[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B][[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B][[^9-B][_-z]c^a-]^*-?[^0-9]-[^9-B]a&'  < ../inputs/temp-test/2266.inp.961.1 > ../outputs/t4322
    if diff ../outputs/t4322 ../originals/t4322 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4323) timeout -s 9 2 ../source/replace.exe '[0-9]' '`+/Xl'  < ../inputs/input/ruin.303 > ../outputs/t4323
    if diff ../outputs/t4323 ../originals/t4323 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4324) timeout -s 9 2 ../source/replace.exe '[0-9]' 'a@nb@tc'  < ../inputs/temp-test/1348.inp.579.1 > ../outputs/t4324
    if diff ../outputs/t4324 ../originals/t4324 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4325) timeout -s 9 2 ../source/replace.exe '[0-9]' 'a@nb@tc'  < ../inputs/temp-test/1349.inp.579.2 > ../outputs/t4325
    if diff ../outputs/t4325 ../originals/t4325 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4326) timeout -s 9 2 ../source/replace.exe '[0-9]' 'a@nb@tc'  < ../inputs/temp-test/1350.inp.579.3 > ../outputs/t4326
    if diff ../outputs/t4326 ../originals/t4326 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4327) timeout -s 9 2 ../source/replace.exe '[0-9]' 'aM9n8"47mFoC> PGpU!,U'  < ../inputs/input/ruin.1294 > ../outputs/t4327
    if diff ../outputs/t4327 ../originals/t4327 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4328) timeout -s 9 2 ../source/replace.exe '[0-9]*$' '@'  < ../inputs/input/ruin.1254 > ../outputs/t4328
    if diff ../outputs/t4328 ../originals/t4328 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4329) timeout -s 9 2 ../source/replace.exe '[0-9]*' '&@n'  < ../inputs/moni/f8.inp > ../outputs/t4329
    if diff ../outputs/t4329 ../originals/t4329 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4330) timeout -s 9 2 ../source/replace.exe '[0-9]*' ''  < ../inputs/temp-test/157.inp.71.1 > ../outputs/t4330
    if diff ../outputs/t4330 ../originals/t4330 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4331) timeout -s 9 2 ../source/replace.exe '[0-9]*' ''  < ../inputs/temp-test/158.inp.71.2 > ../outputs/t4331
    if diff ../outputs/t4331 ../originals/t4331 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4332) timeout -s 9 2 ../source/replace.exe '[0-9]-' '&'  < ../inputs/temp-test/145.inp.67.1 > ../outputs/t4332
    if diff ../outputs/t4332 ../originals/t4332 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4333) timeout -s 9 2 ../source/replace.exe '[0-9]-' '&'  < ../inputs/temp-test/146.inp.67.2 > ../outputs/t4333
    if diff ../outputs/t4333 ../originals/t4333 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4334) timeout -s 9 2 ../source/replace.exe '[0-9]-' ''  < ../inputs/temp-test/118.inp.55.1 > ../outputs/t4334
    if diff ../outputs/t4334 ../originals/t4334 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4335) timeout -s 9 2 ../source/replace.exe '[0-9]-' '@%@&'  < ../inputs/temp-test/1166.inp.502.1 > ../outputs/t4335
    if diff ../outputs/t4335 ../originals/t4335 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4336) timeout -s 9 2 ../source/replace.exe '[0-9]-' '@%@&'  < ../inputs/temp-test/1167.inp.502.3 > ../outputs/t4336
    if diff ../outputs/t4336 ../originals/t4336 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4337) timeout -s 9 2 ../source/replace.exe '[0-9]-' 'a@n'  < ../inputs/temp-test/1619.inp.688.1 > ../outputs/t4337
    if diff ../outputs/t4337 ../originals/t4337 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4338) timeout -s 9 2 ../source/replace.exe '[0-9]-' 'a@n'  < ../inputs/temp-test/1620.inp.688.3 > ../outputs/t4338
    if diff ../outputs/t4338 ../originals/t4338 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4339) timeout -s 9 2 ../source/replace.exe '[0-9]-' 'a@nb@tc'  < ../inputs/temp-test/1029.inp.443.1 > ../outputs/t4339
    if diff ../outputs/t4339 ../originals/t4339 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4340) timeout -s 9 2 ../source/replace.exe '[0-9]-' 'a@nb@tc'  < ../inputs/temp-test/1030.inp.443.2 > ../outputs/t4340
    if diff ../outputs/t4340 ../originals/t4340 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4341) timeout -s 9 2 ../source/replace.exe '[0-9]-' 'a@nb@tc'  < ../inputs/temp-test/1031.inp.443.3 > ../outputs/t4341
    if diff ../outputs/t4341 ../originals/t4341 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4342) timeout -s 9 2 ../source/replace.exe '[0-9]-' 'a@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tca@nb@tc'  < ../inputs/temp-test/1029.inp.443.1 > ../outputs/t4342
    if diff ../outputs/t4342 ../originals/t4342 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4343) timeout -s 9 2 ../source/replace.exe '[0-9]--*[^a-c]' '&a@%'  < ../inputs/temp-test/152.inp.69.1 > ../outputs/t4343
    if diff ../outputs/t4343 ../originals/t4343 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4344) timeout -s 9 2 ../source/replace.exe '[0-9]--*[^a-c]' '&a@%'  < ../inputs/temp-test/153.inp.69.2 > ../outputs/t4344
    if diff ../outputs/t4344 ../originals/t4344 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4345) timeout -s 9 2 ../source/replace.exe '[0-9]--*[^a-c]' '&a@%'  < ../inputs/temp-test/154.inp.69.3 > ../outputs/t4345
    if diff ../outputs/t4345 ../originals/t4345 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4346) timeout -s 9 2 ../source/replace.exe '[0-9]-?-?[a-c][^9-B]@[*-' '&'  < ../inputs/temp-test/409.inp.179.1 > ../outputs/t4346
    if diff ../outputs/t4346 ../originals/t4346 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4347) timeout -s 9 2 ../source/replace.exe '[0-9]-[9-B]?-[9-B]^-]?' 'NEW'  < ../inputs/temp-test/1669.inp.712.1 > ../outputs/t4347
    if diff ../outputs/t4347 ../originals/t4347 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4348) timeout -s 9 2 ../source/replace.exe '[0-9]-[9-B]?-[9-B]^-]?' 'NEW'  < ../inputs/temp-test/1670.inp.712.2 > ../outputs/t4348
    if diff ../outputs/t4348 ../originals/t4348 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4349) timeout -s 9 2 ../source/replace.exe '[0-9]-[9-B]?-[9-B]^-]?' 'NEW'  < ../inputs/temp-test/1671.inp.712.4 > ../outputs/t4349
    if diff ../outputs/t4349 ../originals/t4349 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4350) timeout -s 9 2 ../source/replace.exe '[0-9]?' '&'  < ../inputs/temp-test/1865.inp.792.1 > ../outputs/t4350
    if diff ../outputs/t4350 ../originals/t4350 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4351) timeout -s 9 2 ../source/replace.exe '[0-9]?' '&'  < ../inputs/temp-test/1866.inp.792.2 > ../outputs/t4351
    if diff ../outputs/t4351 ../originals/t4351 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4352) timeout -s 9 2 ../source/replace.exe '[0-9]?' '&'  < ../inputs/temp-test/1867.inp.792.3 > ../outputs/t4352
    if diff ../outputs/t4352 ../originals/t4352 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4353) timeout -s 9 2 ../source/replace.exe '[0-9]?' '&a@%'  < ../inputs/temp-test/752.inp.323.1 > ../outputs/t4353
    if diff ../outputs/t4353 ../originals/t4353 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4354) timeout -s 9 2 ../source/replace.exe '[0-9]?' '&a@%'  < ../inputs/temp-test/753.inp.323.2 > ../outputs/t4354
    if diff ../outputs/t4354 ../originals/t4354 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4355) timeout -s 9 2 ../source/replace.exe '[0-9]?' '&a@%'  < ../inputs/temp-test/754.inp.323.3 > ../outputs/t4355
    if diff ../outputs/t4355 ../originals/t4355 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4356) timeout -s 9 2 ../source/replace.exe '[0-9]?' '@%@&'  < ../inputs/temp-test/698.inp.302.1 > ../outputs/t4356
    if diff ../outputs/t4356 ../originals/t4356 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4357) timeout -s 9 2 ../source/replace.exe '[0-9]?' '@%@&'  < ../inputs/temp-test/699.inp.302.3 > ../outputs/t4357
    if diff ../outputs/t4357 ../originals/t4357 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4358) timeout -s 9 2 ../source/replace.exe '[0-9]?' '@t'  < ../inputs/temp-test/1046.inp.451.1 > ../outputs/t4358
    if diff ../outputs/t4358 ../originals/t4358 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4359) timeout -s 9 2 ../source/replace.exe '[0-9]?' '@t'  < ../inputs/temp-test/1047.inp.451.2 > ../outputs/t4359
    if diff ../outputs/t4359 ../originals/t4359 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4360) timeout -s 9 2 ../source/replace.exe '[0-9]?' '@t'  < ../inputs/temp-test/2339.inp.994.1 > ../outputs/t4360
    if diff ../outputs/t4360 ../originals/t4360 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4361) timeout -s 9 2 ../source/replace.exe '[0-9]?' '@t'  < ../inputs/temp-test/2340.inp.994.3 > ../outputs/t4361
    if diff ../outputs/t4361 ../originals/t4361 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4362) timeout -s 9 2 ../source/replace.exe '[0-9]?' 'NEW'  < ../inputs/temp-test/919.inp.397.1 > ../outputs/t4362
    if diff ../outputs/t4362 ../originals/t4362 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4363) timeout -s 9 2 ../source/replace.exe '[0-9]?' 'NEW'  < ../inputs/temp-test/920.inp.397.3 > ../outputs/t4363
    if diff ../outputs/t4363 ../originals/t4363 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4364) timeout -s 9 2 ../source/replace.exe '[0-9]?' 'NEW'  < ../inputs/temp-test/921.inp.397.4 > ../outputs/t4364
    if diff ../outputs/t4364 ../originals/t4364 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4365) timeout -s 9 2 ../source/replace.exe '[0-9]?' 'a&'  < ../inputs/temp-test/2040.inp.865.1 > ../outputs/t4365
    if diff ../outputs/t4365 ../originals/t4365 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4366) timeout -s 9 2 ../source/replace.exe '[0-9]?' 'a@nb@tc'  < ../inputs/temp-test/1365.inp.586.1 > ../outputs/t4366
    if diff ../outputs/t4366 ../originals/t4366 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4367) timeout -s 9 2 ../source/replace.exe '[0-9]?' 'a@nb@tc'  < ../inputs/temp-test/1366.inp.586.2 > ../outputs/t4367
    if diff ../outputs/t4367 ../originals/t4367 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4368) timeout -s 9 2 ../source/replace.exe '[0-9]?-[a-]@[*' '@%&a'  < ../inputs/temp-test/1231.inp.528.1 > ../outputs/t4368
    if diff ../outputs/t4368 ../originals/t4368 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4369) timeout -s 9 2 ../source/replace.exe '[0-9]?-[a-]@[*' '@%&a'  < ../inputs/temp-test/1232.inp.528.2 > ../outputs/t4369
    if diff ../outputs/t4369 ../originals/t4369 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4370) timeout -s 9 2 ../source/replace.exe '[0-9]??@@-[a--]-' '@%&a'  < ../inputs/temp-test/1532.inp.656.1 > ../outputs/t4370
    if diff ../outputs/t4370 ../originals/t4370 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4371) timeout -s 9 2 ../source/replace.exe '[0-9]??@@-[a--]-' '@%&a'  < ../inputs/temp-test/1533.inp.656.2 > ../outputs/t4371
    if diff ../outputs/t4371 ../originals/t4371 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4372) timeout -s 9 2 ../source/replace.exe '[0-9]??@@-[a--]-' '@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a@%&a'  < ../inputs/temp-test/1532.inp.656.1 > ../outputs/t4372
    if diff ../outputs/t4372 ../originals/t4372 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4373) timeout -s 9 2 ../source/replace.exe '[0-9]?[^0-9]@[-[9-B]-[^0-9]-[^9-B]' ''  < ../inputs/temp-test/983.inp.423.1 > ../outputs/t4373
    if diff ../outputs/t4373 ../originals/t4373 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4374) timeout -s 9 2 ../source/replace.exe '[0-9]?^[^0-9]?-[^0-9]c[^a--]-[0-9][^9-B]@n[^0-9][9-B]?' '@n'  < ../inputs/temp-test/1629.inp.693.1 > ../outputs/t4374
    if diff ../outputs/t4374 ../originals/t4374 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4375) timeout -s 9 2 ../source/replace.exe '[0-9]@$' 'c'  < ../inputs/moni/f7.inp > ../outputs/t4375
    if diff ../outputs/t4375 ../originals/t4375 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4376) timeout -s 9 2 ../source/replace.exe '[0-9]@*' '&'  < ../inputs/temp-test/1114.inp.479.1 > ../outputs/t4376
    if diff ../outputs/t4376 ../originals/t4376 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4377) timeout -s 9 2 ../source/replace.exe '[0-9]@*' '&'  < ../inputs/temp-test/1115.inp.479.3 > ../outputs/t4377
    if diff ../outputs/t4377 ../originals/t4377 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4378) timeout -s 9 2 ../source/replace.exe '[0-9]@*' '&'  < ../inputs/temp-test/1116.inp.479.4 > ../outputs/t4378
    if diff ../outputs/t4378 ../originals/t4378 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4379) timeout -s 9 2 ../source/replace.exe '[0-9]@*' '&'  < ../inputs/temp-test/1296.inp.556.1 > ../outputs/t4379
    if diff ../outputs/t4379 ../originals/t4379 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4380) timeout -s 9 2 ../source/replace.exe '[0-9]@*' 'a@n'  < ../inputs/temp-test/298.inp.134.1 > ../outputs/t4380
    if diff ../outputs/t4380 ../originals/t4380 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4381) timeout -s 9 2 ../source/replace.exe '[0-9]@*' 'a@n'  < ../inputs/temp-test/299.inp.134.2 > ../outputs/t4381
    if diff ../outputs/t4381 ../originals/t4381 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4382) timeout -s 9 2 ../source/replace.exe '[0-9]@*' 'a@n'  < ../inputs/temp-test/300.inp.134.3 > ../outputs/t4382
    if diff ../outputs/t4382 ../originals/t4382 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4383) timeout -s 9 2 ../source/replace.exe '[0-9]@*^-]$' '@n'  < ../inputs/temp-test/1474.inp.632.8 > ../outputs/t4383
    if diff ../outputs/t4383 ../originals/t4383 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4384) timeout -s 9 2 ../source/replace.exe '[0-9]@*^-]' '@n'  < ../inputs/temp-test/1473.inp.632.1 > ../outputs/t4384
    if diff ../outputs/t4384 ../originals/t4384 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4385) timeout -s 9 2 ../source/replace.exe '[0-9]@@' '@%&a'  < ../inputs/temp-test/1694.inp.723.1 > ../outputs/t4385
    if diff ../outputs/t4385 ../originals/t4385 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4386) timeout -s 9 2 ../source/replace.exe '[0-9]@@' '@%&a'  < ../inputs/temp-test/1695.inp.723.2 > ../outputs/t4386
    if diff ../outputs/t4386 ../originals/t4386 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4387) timeout -s 9 2 ../source/replace.exe '[0-9]@[*' '@n'  < ../inputs/temp-test/843.inp.362.1 > ../outputs/t4387
    if diff ../outputs/t4387 ../originals/t4387 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4388) timeout -s 9 2 ../source/replace.exe '[0-9]@n' '9&@t@t'  < ../inputs/input/ruin.617 > ../outputs/t4388
    if diff ../outputs/t4388 ../originals/t4388 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4389) timeout -s 9 2 ../source/replace.exe '[0-9]@n' 'k&e'  < ../inputs/input/ruin.280 > ../outputs/t4389
    if diff ../outputs/t4389 ../originals/t4389 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4390) timeout -s 9 2 ../source/replace.exe '[0-9]@n' 'o&6'  < ../inputs/input/ruin.284 > ../outputs/t4390
    if diff ../outputs/t4390 ../originals/t4390 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4391) timeout -s 9 2 ../source/replace.exe '[0-9]A*@n?-?^*-' ''  < ../inputs/temp-test/1947.inp.827.1 > ../outputs/t4391
    if diff ../outputs/t4391 ../originals/t4391 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4392) timeout -s 9 2 ../source/replace.exe '[0-9]A*@n?-?^*-' ''  < ../inputs/temp-test/1948.inp.827.2 > ../outputs/t4392
    if diff ../outputs/t4392 ../originals/t4392 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4393) timeout -s 9 2 ../source/replace.exe '[0-9]A*@n?-?^*-' ''  < ../inputs/temp-test/1949.inp.827.3 > ../outputs/t4393
    if diff ../outputs/t4393 ../originals/t4393 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4394) timeout -s 9 2 ../source/replace.exe '[0-9]A*@n?-?^*-' ''  < ../inputs/temp-test/1950.inp.827.4 > ../outputs/t4394
    if diff ../outputs/t4394 ../originals/t4394 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4395) timeout -s 9 2 ../source/replace.exe '[0-9][^-' '@%@&'  < ../inputs/temp-test/324.inp.144.1 > ../outputs/t4395
    if diff ../outputs/t4395 ../originals/t4395 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4396) timeout -s 9 2 ../source/replace.exe '[0-9][^-' '@%@&'  < ../inputs/temp-test/325.inp.144.2 > ../outputs/t4396
    if diff ../outputs/t4396 ../originals/t4396 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4397) timeout -s 9 2 ../source/replace.exe '[0-9][^0-9]' '&'  < ../inputs/temp-test/564.inp.243.1 > ../outputs/t4397
    if diff ../outputs/t4397 ../originals/t4397 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4398) timeout -s 9 2 ../source/replace.exe '[0-9][^0-9]' '&'  < ../inputs/temp-test/565.inp.243.3 > ../outputs/t4398
    if diff ../outputs/t4398 ../originals/t4398 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4399) timeout -s 9 2 ../source/replace.exe '[0-9][^0-9]-[^-' 'a@nb@tc'  < ../inputs/temp-test/1636.inp.697.1 > ../outputs/t4399
    if diff ../outputs/t4399 ../originals/t4399 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4400) timeout -s 9 2 ../source/replace.exe '[0-9][^0-9]-[^-' 'a@nb@tc'  < ../inputs/temp-test/1637.inp.697.3 > ../outputs/t4400
    if diff ../outputs/t4400 ../originals/t4400 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4401) timeout -s 9 2 ../source/replace.exe '[0-9][^9-B]' 'NEW'  < ../inputs/temp-test/1552.inp.664.1 > ../outputs/t4401
    if diff ../outputs/t4401 ../originals/t4401 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4402) timeout -s 9 2 ../source/replace.exe '[0-9][^9-B]?A*?[a-c]?[0-9][^9-B]-' ''  < ../inputs/temp-test/928.inp.400.1 > ../outputs/t4402
    if diff ../outputs/t4402 ../originals/t4402 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4403) timeout -s 9 2 ../source/replace.exe '[0-9][^9-B][@t][^a-c]' '@%&a'  < ../inputs/temp-test/1038.inp.447.1 > ../outputs/t4403
    if diff ../outputs/t4403 ../originals/t4403 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4404) timeout -s 9 2 ../source/replace.exe '[0-9][^9-B][@t][^a-c]' '@%&a'  < ../inputs/temp-test/1039.inp.447.3 > ../outputs/t4404
    if diff ../outputs/t4404 ../originals/t4404 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4405) timeout -s 9 2 ../source/replace.exe '[0-9]^-?-^*' '&a@%'  < ../inputs/temp-test/1313.inp.564.1 > ../outputs/t4405
    if diff ../outputs/t4405 ../originals/t4405 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4406) timeout -s 9 2 ../source/replace.exe '[0-9]^-?-^*' '&a@%'  < ../inputs/temp-test/1314.inp.564.2 > ../outputs/t4406
    if diff ../outputs/t4406 ../originals/t4406 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4407) timeout -s 9 2 ../source/replace.exe '[0-9]^-?-^*' '&a@%'  < ../inputs/temp-test/1315.inp.564.3 > ../outputs/t4407
    if diff ../outputs/t4407 ../originals/t4407 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4408) timeout -s 9 2 ../source/replace.exe '[0-9]^-?-^*' '&a@%'  < ../inputs/temp-test/1316.inp.564.4 > ../outputs/t4408
    if diff ../outputs/t4408 ../originals/t4408 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4409) timeout -s 9 2 ../source/replace.exe '[0-9]c*@*[a-c]-[0-9][^0-9]@*' 'b@t'  < ../inputs/temp-test/791.inp.341.1 > ../outputs/t4409
    if diff ../outputs/t4409 ../originals/t4409 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4410) timeout -s 9 2 ../source/replace.exe '[0-9]c*@*[a-c]-[0-9][^0-9]@*' 'b@t'  < ../inputs/temp-test/792.inp.341.2 > ../outputs/t4410
    if diff ../outputs/t4410 ../originals/t4410 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4411) timeout -s 9 2 ../source/replace.exe '[0-9]c*@*[a-c]-[0-9][^0-9]@*' 'b@t'  < ../inputs/temp-test/793.inp.341.3 > ../outputs/t4411
    if diff ../outputs/t4411 ../originals/t4411 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4412) timeout -s 9 2 ../source/replace.exe '[0-9^4]*' 5  < ../inputs/moni/f7.inp > ../outputs/t4412
    if diff ../outputs/t4412 ../originals/t4412 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4413) timeout -s 9 2 ../source/replace.exe '[0-9c-a]' 'vm&LgryRJI2?C95<5\^'  < ../inputs/input/ruin.490 > ../outputs/t4413
    if diff ../outputs/t4413 ../originals/t4413 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4414) timeout -s 9 2 ../source/replace.exe '[0-9z-}>-A]\@@?' '4'  < ../inputs/input/ruin.813 > ../outputs/t4414
    if diff ../outputs/t4414 ../originals/t4414 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4415) timeout -s 9 2 ../source/replace.exe '[0-9z-}]' 'WOMZMg'  < ../inputs/input/ruin.1746 > ../outputs/t4415
    if diff ../outputs/t4415 ../originals/t4415 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4416) timeout -s 9 2 ../source/replace.exe '[1-' 'yy'  < ../inputs/moni/f7.inp > ../outputs/t4416
    if diff ../outputs/t4416 ../originals/t4416 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4417) timeout -s 9 2 ../source/replace.exe '[1-9]%' '@t67@t67@n'  < ../inputs/moni/f8.inp > ../outputs/t4417
    if diff ../outputs/t4417 ../originals/t4417 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4418) timeout -s 9 2 ../source/replace.exe '[1-9]@t**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4418
    if diff ../outputs/t4418 ../originals/t4418 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4419) timeout -s 9 2 ../source/replace.exe '[1-9][1-9]' 6666666  < ../inputs/moni/f5.inp > ../outputs/t4419
    if diff ../outputs/t4419 ../originals/t4419 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4420) timeout -s 9 2 ../source/replace.exe '[1-@n]' '@-1'  < ../inputs/moni/f7.inp > ../outputs/t4420
    if diff ../outputs/t4420 ../originals/t4420 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4421) timeout -s 9 2 ../source/replace.exe '[1]' '5D$6:)'\''!!WaohoC<DMt/ns5zA:0vzT p?PADhjzrF.e*NbJLCd;0Sr/.Ja+?2sn-MP+uf6)IZet;aI!3=TH7?$d_6t)!l=Wfh37`[%\<5'  < ../inputs/input/ruin.1200 > ../outputs/t4421
    if diff ../outputs/t4421 ../originals/t4421 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4422) timeout -s 9 2 ../source/replace.exe '[5]' 'D9c@\|.|ljJv/2]Sw+F<JU5{,Y`;B'  < ../inputs/input/ruin.295 > ../outputs/t4422
    if diff ../outputs/t4422 ../originals/t4422 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4423) timeout -s 9 2 ../source/replace.exe '[7-9]ab**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4423
    if diff ../outputs/t4423 ../originals/t4423 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4424) timeout -s 9 2 ../source/replace.exe '[7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]7KOgdHVS~e*RbgQ>M{]^0-9]?[a-c] [^0-9]?[a-c]-[a--b]?^a-c]' '&'   < ../inputs/temp-test/1268.inp.544.1 > ../outputs/t4424
    if diff ../outputs/t4424 ../originals/t4424 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4425) timeout -s 9 2 ../source/replace.exe '[9-B] *-[^9-B]---*' 'NEW'  < ../inputs/temp-test/457.inp.200.1 > ../outputs/t4425
    if diff ../outputs/t4425 ../originals/t4425 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4426) timeout -s 9 2 ../source/replace.exe '[9-B]$' '&'  < ../inputs/temp-test/2306.inp.979.6 > ../outputs/t4426
    if diff ../outputs/t4426 ../originals/t4426 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4427) timeout -s 9 2 ../source/replace.exe '[9-B]$' '&'  < ../inputs/temp-test/2308.inp.979.8 > ../outputs/t4427
    if diff ../outputs/t4427 ../originals/t4427 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4428) timeout -s 9 2 ../source/replace.exe '[9-B]$' 'NEW'  < ../inputs/temp-test/1804.inp.767.8 > ../outputs/t4428
    if diff ../outputs/t4428 ../originals/t4428 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4429) timeout -s 9 2 ../source/replace.exe '[9-B]%-' 'a@nb@tc'  < ../inputs/temp-test/2334.inp.990.1 > ../outputs/t4429
    if diff ../outputs/t4429 ../originals/t4429 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4430) timeout -s 9 2 ../source/replace.exe '[9-B]%-' 'a@nb@tc'  < ../inputs/temp-test/2335.inp.990.3 > ../outputs/t4430
    if diff ../outputs/t4430 ../originals/t4430 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4431) timeout -s 9 2 ../source/replace.exe '[9-B]%?' '@t'  < ../inputs/temp-test/2338.inp.993.1 > ../outputs/t4431
    if diff ../outputs/t4431 ../originals/t4431 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4432) timeout -s 9 2 ../source/replace.exe '[9-B]%A-?[^a--]?' '&'  < ../inputs/temp-test/2356.inp.1000.1 > ../outputs/t4432
    if diff ../outputs/t4432 ../originals/t4432 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4433) timeout -s 9 2 ../source/replace.exe '[9-B]%[^a--b][^9-B]@**[9-B]-' '&a@%'  < ../inputs/temp-test/27.inp.12.1 > ../outputs/t4433
    if diff ../outputs/t4433 ../originals/t4433 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4434) timeout -s 9 2 ../source/replace.exe '[9-B]' '&'  < ../inputs/temp-test/2304.inp.979.1 > ../outputs/t4434
    if diff ../outputs/t4434 ../originals/t4434 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4435) timeout -s 9 2 ../source/replace.exe '[9-B]' '&'  < ../inputs/temp-test/2305.inp.979.2 > ../outputs/t4435
    if diff ../outputs/t4435 ../originals/t4435 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4436) timeout -s 9 2 ../source/replace.exe '[9-B]' 'NEW'  < ../inputs/temp-test/1803.inp.767.1 > ../outputs/t4436
    if diff ../outputs/t4436 ../originals/t4436 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4437) timeout -s 9 2 ../source/replace.exe '[9-B]' 'NEW'  < ../inputs/temp-test/2216.inp.939.1 > ../outputs/t4437
    if diff ../outputs/t4437 ../originals/t4437 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4438) timeout -s 9 2 ../source/replace.exe '[9-B]' 'NEW'  < ../inputs/temp-test/2217.inp.939.3 > ../outputs/t4438
    if diff ../outputs/t4438 ../originals/t4438 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4439) timeout -s 9 2 ../source/replace.exe '[9-B]' 'NEW'  < ../inputs/temp-test/2218.inp.939.4 > ../outputs/t4439
    if diff ../outputs/t4439 ../originals/t4439 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4440) timeout -s 9 2 ../source/replace.exe '[9-B]' 'a&'  < ../inputs/temp-test/2104.inp.892.1 > ../outputs/t4440
    if diff ../outputs/t4440 ../originals/t4440 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4441) timeout -s 9 2 ../source/replace.exe '[9-B]' 'a&'  < ../inputs/temp-test/2105.inp.892.3 > ../outputs/t4441
    if diff ../outputs/t4441 ../originals/t4441 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4442) timeout -s 9 2 ../source/replace.exe '[9-B]' 'a@nb@tc'  < ../inputs/temp-test/1220.inp.524.1 > ../outputs/t4442
    if diff ../outputs/t4442 ../originals/t4442 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4443) timeout -s 9 2 ../source/replace.exe '[9-B]' 'b@t'  < ../inputs/temp-test/949.inp.409.1 > ../outputs/t4443
    if diff ../outputs/t4443 ../originals/t4443 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4444) timeout -s 9 2 ../source/replace.exe '[9-B]' 'b@t'  < ../inputs/temp-test/950.inp.409.2 > ../outputs/t4444
    if diff ../outputs/t4444 ../originals/t4444 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4445) timeout -s 9 2 ../source/replace.exe '[9-B]* ' '&a@%'  < ../inputs/temp-test/30.inp.13.1 > ../outputs/t4445
    if diff ../outputs/t4445 ../originals/t4445 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4446) timeout -s 9 2 ../source/replace.exe '[9-B]* ' '&a@%'  < ../inputs/temp-test/31.inp.13.3 > ../outputs/t4446
    if diff ../outputs/t4446 ../originals/t4446 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4447) timeout -s 9 2 ../source/replace.exe '[9-B]- *-^a-] *' 'NEW'  < ../inputs/temp-test/848.inp.364.1 > ../outputs/t4447
    if diff ../outputs/t4447 ../originals/t4447 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4448) timeout -s 9 2 ../source/replace.exe '[9-B]-' '&'  < ../inputs/temp-test/1903.inp.807.1 > ../outputs/t4448
    if diff ../outputs/t4448 ../originals/t4448 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4449) timeout -s 9 2 ../source/replace.exe '[9-B]-' '&'  < ../inputs/temp-test/1904.inp.807.3 > ../outputs/t4449
    if diff ../outputs/t4449 ../originals/t4449 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4450) timeout -s 9 2 ../source/replace.exe '[9-B]-' ''  < ../inputs/temp-test/1924.inp.818.1 > ../outputs/t4450
    if diff ../outputs/t4450 ../originals/t4450 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4451) timeout -s 9 2 ../source/replace.exe '[9-B]-' ''  < ../inputs/temp-test/1925.inp.818.2 > ../outputs/t4451
    if diff ../outputs/t4451 ../originals/t4451 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4452) timeout -s 9 2 ../source/replace.exe '[9-B]-' ''  < ../inputs/temp-test/732.inp.315.1 > ../outputs/t4452
    if diff ../outputs/t4452 ../originals/t4452 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4453) timeout -s 9 2 ../source/replace.exe '[9-B]-' ''  < ../inputs/temp-test/733.inp.315.3 > ../outputs/t4453
    if diff ../outputs/t4453 ../originals/t4453 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4454) timeout -s 9 2 ../source/replace.exe '[9-B]-' '@%&a'  < ../inputs/temp-test/1150.inp.495.1 > ../outputs/t4454
    if diff ../outputs/t4454 ../originals/t4454 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4455) timeout -s 9 2 ../source/replace.exe '[9-B]-' '@%&a'  < ../inputs/temp-test/1151.inp.495.3 > ../outputs/t4455
    if diff ../outputs/t4455 ../originals/t4455 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4456) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'NEW'  < ../inputs/temp-test/1233.inp.529.1 > ../outputs/t4456
    if diff ../outputs/t4456 ../originals/t4456 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4457) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'NEW'  < ../inputs/temp-test/1234.inp.529.3 > ../outputs/t4457
    if diff ../outputs/t4457 ../originals/t4457 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4458) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'NEW'  < ../inputs/temp-test/1418.inp.609.1 > ../outputs/t4458
    if diff ../outputs/t4458 ../originals/t4458 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4459) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'NEW'  < ../inputs/temp-test/1419.inp.609.2 > ../outputs/t4459
    if diff ../outputs/t4459 ../originals/t4459 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4460) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'NEW'  < ../inputs/temp-test/1452.inp.623.1 > ../outputs/t4460
    if diff ../outputs/t4460 ../originals/t4460 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4461) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'NEW'  < ../inputs/temp-test/1453.inp.623.2 > ../outputs/t4461
    if diff ../outputs/t4461 ../originals/t4461 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4462) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'NEW'  < ../inputs/temp-test/1454.inp.623.3 > ../outputs/t4462
    if diff ../outputs/t4462 ../originals/t4462 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4463) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'a&'  < ../inputs/temp-test/283.inp.127.1 > ../outputs/t4463
    if diff ../outputs/t4463 ../originals/t4463 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4464) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'a&'  < ../inputs/temp-test/284.inp.127.2 > ../outputs/t4464
    if diff ../outputs/t4464 ../originals/t4464 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4465) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'a&'  < ../inputs/temp-test/285.inp.127.3 > ../outputs/t4465
    if diff ../outputs/t4465 ../originals/t4465 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4466) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'a@nb@tc'  < ../inputs/temp-test/2334.inp.990.1 > ../outputs/t4466
    if diff ../outputs/t4466 ../originals/t4466 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4467) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'a@nb@tc'  < ../inputs/temp-test/2335.inp.990.3 > ../outputs/t4467
    if diff ../outputs/t4467 ../originals/t4467 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4468) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'b@t'  < ../inputs/temp-test/1734.inp.738.1 > ../outputs/t4468
    if diff ../outputs/t4468 ../originals/t4468 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4469) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'b@t'  < ../inputs/temp-test/1735.inp.738.2 > ../outputs/t4469
    if diff ../outputs/t4469 ../originals/t4469 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4470) timeout -s 9 2 ../source/replace.exe '[9-B]-' 'b@t'  < ../inputs/temp-test/1736.inp.738.3 > ../outputs/t4470
    if diff ../outputs/t4470 ../originals/t4470 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4471) timeout -s 9 2 ../source/replace.exe '[9-B]-*@[*? *$' '&a@%'  < ../inputs/temp-test/1199.inp.514.8 > ../outputs/t4471
    if diff ../outputs/t4471 ../originals/t4471 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4472) timeout -s 9 2 ../source/replace.exe '[9-B]-*@[*? *' '&a@%'  < ../inputs/temp-test/1196.inp.514.1 > ../outputs/t4472
    if diff ../outputs/t4472 ../originals/t4472 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4473) timeout -s 9 2 ../source/replace.exe '[9-B]-*@[*? *' '&a@%'  < ../inputs/temp-test/1197.inp.514.2 > ../outputs/t4473
    if diff ../outputs/t4473 ../originals/t4473 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4474) timeout -s 9 2 ../source/replace.exe '[9-B]-*@[*? *' '&a@%'  < ../inputs/temp-test/1198.inp.514.3 > ../outputs/t4474
    if diff ../outputs/t4474 ../originals/t4474 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4475) timeout -s 9 2 ../source/replace.exe '[9-B]-*[^0-9]?' '&'  < ../inputs/temp-test/1997.inp.848.1 > ../outputs/t4475
    if diff ../outputs/t4475 ../originals/t4475 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4476) timeout -s 9 2 ../source/replace.exe '[9-B]-*[^0-9]?' '&'  < ../inputs/temp-test/1998.inp.848.4 > ../outputs/t4476
    if diff ../outputs/t4476 ../originals/t4476 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4477) timeout -s 9 2 ../source/replace.exe '[9-B]--?[^-z]-[0-9][^a-c]$' 'b@t'  < ../inputs/temp-test/2085.inp.883.6 > ../outputs/t4477
    if diff ../outputs/t4477 ../originals/t4477 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4478) timeout -s 9 2 ../source/replace.exe '[9-B]--?[^-z]-[0-9][^a-c]$' 'b@t'  < ../inputs/temp-test/2086.inp.883.8 > ../outputs/t4478
    if diff ../outputs/t4478 ../originals/t4478 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4479) timeout -s 9 2 ../source/replace.exe '[9-B]--?[^-z]-[0-9][^a-c]' 'b@t'  < ../inputs/temp-test/2083.inp.883.1 > ../outputs/t4479
    if diff ../outputs/t4479 ../originals/t4479 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4480) timeout -s 9 2 ../source/replace.exe '[9-B]--?[^-z]-[0-9][^a-c]' 'b@t'  < ../inputs/temp-test/2084.inp.883.2 > ../outputs/t4480
    if diff ../outputs/t4480 ../originals/t4480 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4481) timeout -s 9 2 ../source/replace.exe '[9-B]-?-' 'a@nb@tc'  < ../inputs/temp-test/445.inp.195.1 > ../outputs/t4481
    if diff ../outputs/t4481 ../originals/t4481 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4482) timeout -s 9 2 ../source/replace.exe '[9-B]-?-' 'a@nb@tc'  < ../inputs/temp-test/446.inp.195.2 > ../outputs/t4482
    if diff ../outputs/t4482 ../originals/t4482 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4483) timeout -s 9 2 ../source/replace.exe '[9-B]-??[0-9]@t?[^a-c]?' 'a&'  < ../inputs/temp-test/2325.inp.987.1 > ../outputs/t4483
    if diff ../outputs/t4483 ../originals/t4483 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4484) timeout -s 9 2 ../source/replace.exe '[9-B]-??[0-9]@t?[^a-c]?' 'a&'  < ../inputs/temp-test/2326.inp.987.2 > ../outputs/t4484
    if diff ../outputs/t4484 ../originals/t4484 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4485) timeout -s 9 2 ../source/replace.exe '[9-B]-A[^0-9]-@*' '@%@&'  < ../inputs/temp-test/1673.inp.713.1 > ../outputs/t4485
    if diff ../outputs/t4485 ../originals/t4485 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4486) timeout -s 9 2 ../source/replace.exe '[9-B]-[-z]?[@t]?[^a-c]' 'a&'  < ../inputs/temp-test/2017.inp.856.1 > ../outputs/t4486
    if diff ../outputs/t4486 ../originals/t4486 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4487) timeout -s 9 2 ../source/replace.exe '[9-B]?' '&a@%'  < ../inputs/temp-test/2044.inp.867.1 > ../outputs/t4487
    if diff ../outputs/t4487 ../originals/t4487 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4488) timeout -s 9 2 ../source/replace.exe '[9-B]?' '@%&a'  < ../inputs/temp-test/1801.inp.766.1 > ../outputs/t4488
    if diff ../outputs/t4488 ../originals/t4488 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4489) timeout -s 9 2 ../source/replace.exe '[9-B]?' '@%&a'  < ../inputs/temp-test/1802.inp.766.3 > ../outputs/t4489
    if diff ../outputs/t4489 ../originals/t4489 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4490) timeout -s 9 2 ../source/replace.exe '[9-B]?' '@%&a'  < ../inputs/temp-test/799.inp.344.1 > ../outputs/t4490
    if diff ../outputs/t4490 ../originals/t4490 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4491) timeout -s 9 2 ../source/replace.exe '[9-B]?' '@%&a'  < ../inputs/temp-test/800.inp.344.3 > ../outputs/t4491
    if diff ../outputs/t4491 ../originals/t4491 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4492) timeout -s 9 2 ../source/replace.exe '[9-B]?' '@%@&'  < ../inputs/temp-test/1625.inp.691.1 > ../outputs/t4492
    if diff ../outputs/t4492 ../originals/t4492 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4493) timeout -s 9 2 ../source/replace.exe '[9-B]?' '@%@&'  < ../inputs/temp-test/1626.inp.691.2 > ../outputs/t4493
    if diff ../outputs/t4493 ../originals/t4493 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4494) timeout -s 9 2 ../source/replace.exe '[9-B]?' '@%@&'  < ../inputs/temp-test/1627.inp.691.3 > ../outputs/t4494
    if diff ../outputs/t4494 ../originals/t4494 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4495) timeout -s 9 2 ../source/replace.exe '[9-B]?' '@t'  < ../inputs/temp-test/2338.inp.993.1 > ../outputs/t4495
    if diff ../outputs/t4495 ../originals/t4495 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4496) timeout -s 9 2 ../source/replace.exe '[9-B]?' 'NEW'  < ../inputs/temp-test/1689.inp.720.1 > ../outputs/t4496
    if diff ../outputs/t4496 ../originals/t4496 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4497) timeout -s 9 2 ../source/replace.exe '[9-B]?' 'NEW'  < ../inputs/temp-test/1690.inp.720.2 > ../outputs/t4497
    if diff ../outputs/t4497 ../originals/t4497 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4498) timeout -s 9 2 ../source/replace.exe '[9-B]?-@[*[^9-B]-@tc*a-]' '@n'  < ../inputs/temp-test/1534.inp.657.1 > ../outputs/t4498
    if diff ../outputs/t4498 ../originals/t4498 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4499) timeout -s 9 2 ../source/replace.exe '[9-B]?-@[*[^9-B]-@tc*a-]' '@n'  < ../inputs/temp-test/1535.inp.657.2 > ../outputs/t4499
    if diff ../outputs/t4499 ../originals/t4499 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4500) timeout -s 9 2 ../source/replace.exe '[9-B]??^?^-]' '@t'  < ../inputs/temp-test/84.inp.38.1 > ../outputs/t4500
    if diff ../outputs/t4500 ../originals/t4500 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4501) timeout -s 9 2 ../source/replace.exe '[9-B]??^?^-]' '@t'  < ../inputs/temp-test/85.inp.38.3 > ../outputs/t4501
    if diff ../outputs/t4501 ../originals/t4501 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4502) timeout -s 9 2 ../source/replace.exe '[9-B]@*' '&'  < ../inputs/temp-test/540.inp.234.1 > ../outputs/t4502
    if diff ../outputs/t4502 ../originals/t4502 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4503) timeout -s 9 2 ../source/replace.exe '[9-B]@*' '&'  < ../inputs/temp-test/541.inp.234.2 > ../outputs/t4503
    if diff ../outputs/t4503 ../originals/t4503 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4504) timeout -s 9 2 ../source/replace.exe '[9-B]@**?^@@-' '@%&a'  < ../inputs/temp-test/904.inp.389.1 > ../outputs/t4504
    if diff ../outputs/t4504 ../originals/t4504 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4505) timeout -s 9 2 ../source/replace.exe '[9-B]@**?^@@-' '@%&a'  < ../inputs/temp-test/905.inp.389.3 > ../outputs/t4505
    if diff ../outputs/t4505 ../originals/t4505 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4506) timeout -s 9 2 ../source/replace.exe '[9-B]@@' 'a&'  < ../inputs/temp-test/119.inp.56.1 > ../outputs/t4506
    if diff ../outputs/t4506 ../originals/t4506 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4507) timeout -s 9 2 ../source/replace.exe '[9-B]@@' 'a&'  < ../inputs/temp-test/120.inp.56.3 > ../outputs/t4507
    if diff ../outputs/t4507 ../originals/t4507 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4508) timeout -s 9 2 ../source/replace.exe '[9-B]@[?[9-B]-[@n][^a-c[0-9]?@@*[0-9]' '&'  < ../inputs/temp-test/1524.inp.653.1 > ../outputs/t4508
    if diff ../outputs/t4508 ../originals/t4508 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4509) timeout -s 9 2 ../source/replace.exe '[9-B]@[?[9-B]-[@n][^a-c[0-9]?@@*[0-9]' '&'  < ../inputs/temp-test/1525.inp.653.2 > ../outputs/t4509
    if diff ../outputs/t4509 ../originals/t4509 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4510) timeout -s 9 2 ../source/replace.exe '[9-B]@[c*-??-' '@%&a'  < ../inputs/temp-test/1007.inp.433.1 > ../outputs/t4510
    if diff ../outputs/t4510 ../originals/t4510 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4511) timeout -s 9 2 ../source/replace.exe '[9-B]@[c*-??-' '@%&a'  < ../inputs/temp-test/1008.inp.433.3 > ../outputs/t4511
    if diff ../outputs/t4511 ../originals/t4511 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4512) timeout -s 9 2 ../source/replace.exe '[9-B]A-%?[^a--]?' '&'  < ../inputs/temp-test/2357.inp.1000.2 > ../outputs/t4512
    if diff ../outputs/t4512 ../originals/t4512 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4513) timeout -s 9 2 ../source/replace.exe '[9-B]A-?%[^a--]?' '&'  < ../inputs/temp-test/2358.inp.1000.3 > ../outputs/t4513
    if diff ../outputs/t4513 ../originals/t4513 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4514) timeout -s 9 2 ../source/replace.exe '[9-B]A-?[^a--]?' '&'  < ../inputs/temp-test/2356.inp.1000.1 > ../outputs/t4514
    if diff ../outputs/t4514 ../originals/t4514 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4515) timeout -s 9 2 ../source/replace.exe '[9-B]A-?[^a--]?' '&'  < ../inputs/temp-test/2357.inp.1000.2 > ../outputs/t4515
    if diff ../outputs/t4515 ../originals/t4515 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4516) timeout -s 9 2 ../source/replace.exe '[9-B]A-?[^a--]?' '&'  < ../inputs/temp-test/2358.inp.1000.3 > ../outputs/t4516
    if diff ../outputs/t4516 ../originals/t4516 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4517) timeout -s 9 2 ../source/replace.exe '[9-B][9-B]?[^a-c]a-c]' '&'  < ../inputs/temp-test/2232.inp.946.1 > ../outputs/t4517
    if diff ../outputs/t4517 ../originals/t4517 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4518) timeout -s 9 2 ../source/replace.exe '[9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B][9-B]' 'b@t'  < ../inputs/temp-test/949.inp.409.1 > ../outputs/t4518
    if diff ../outputs/t4518 ../originals/t4518 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4519) timeout -s 9 2 ../source/replace.exe '[9-B][^-' 'a&'  < ../inputs/temp-test/2224.inp.943.1 > ../outputs/t4519
    if diff ../outputs/t4519 ../originals/t4519 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4520) timeout -s 9 2 ../source/replace.exe '[9-B][^0-9]' '@%&a'  < ../inputs/temp-test/794.inp.342.1 > ../outputs/t4520
    if diff ../outputs/t4520 ../originals/t4520 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4521) timeout -s 9 2 ../source/replace.exe '[9-B][^0-9]' '@%&a'  < ../inputs/temp-test/795.inp.342.3 > ../outputs/t4521
    if diff ../outputs/t4521 ../originals/t4521 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4522) timeout -s 9 2 ../source/replace.exe '[9-B][^0-9]??[9-B]^*-[^a-c]' ''  < ../inputs/temp-test/594.inp.255.1 > ../outputs/t4522
    if diff ../outputs/t4522 ../originals/t4522 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4523) timeout -s 9 2 ../source/replace.exe '[9-B][^0-9]@[?[a-c[^0-9][_-z]-?@[' 'b@t'  < ../inputs/temp-test/700.inp.303.1 > ../outputs/t4523
    if diff ../outputs/t4523 ../originals/t4523 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4524) timeout -s 9 2 ../source/replace.exe '[9-B][^0-9]@[?[a-c[^0-9][_-z]-?@[' 'b@t'  < ../inputs/temp-test/701.inp.303.2 > ../outputs/t4524
    if diff ../outputs/t4524 ../originals/t4524 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4525) timeout -s 9 2 ../source/replace.exe '[9-B][^9-B]@t*?' '@t'  < ../inputs/temp-test/1301.inp.559.1 > ../outputs/t4525
    if diff ../outputs/t4525 ../originals/t4525 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4526) timeout -s 9 2 ../source/replace.exe '[9-B][^9-B][0-9]' '&@n'  < ../inputs/temp-test/643.inp.278.1 > ../outputs/t4526
    if diff ../outputs/t4526 ../originals/t4526 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4527) timeout -s 9 2 ../source/replace.exe '[9-B][^9-B][0-9]' '&@n[a-z]'  < ../inputs/temp-test/643.inp.278.1 > ../outputs/t4527
    if diff ../outputs/t4527 ../originals/t4527 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4528) timeout -s 9 2 ../source/replace.exe '[9-B][^9-B][0-9]' '@n'  < ../inputs/temp-test/643.inp.278.1 > ../outputs/t4528
    if diff ../outputs/t4528 ../originals/t4528 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4529) timeout -s 9 2 ../source/replace.exe '[9-B][^a--]' 'a@nb@tc'  < ../inputs/temp-test/1353.inp.581.1 > ../outputs/t4529
    if diff ../outputs/t4529 ../originals/t4529 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4530) timeout -s 9 2 ../source/replace.exe '[9-B][^a--]' 'a@nb@tc'  < ../inputs/temp-test/1354.inp.581.3 > ../outputs/t4530
    if diff ../outputs/t4530 ../originals/t4530 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4531) timeout -s 9 2 ../source/replace.exe '[9-B][^a--][^@n]-' '@%@&'  < ../inputs/temp-test/2144.inp.908.1 > ../outputs/t4531
    if diff ../outputs/t4531 ../originals/t4531 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4532) timeout -s 9 2 ../source/replace.exe '[9-B][^a--][^@n]-' '@%@&'  < ../inputs/temp-test/2145.inp.908.2 > ../outputs/t4532
    if diff ../outputs/t4532 ../originals/t4532 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4533) timeout -s 9 2 ../source/replace.exe '[9-B][^a--b]%[^9-B]@**[9-B]-' '&a@%'  < ../inputs/temp-test/28.inp.12.3 > ../outputs/t4533
    if diff ../outputs/t4533 ../originals/t4533 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4534) timeout -s 9 2 ../source/replace.exe '[9-B][^a--b]%[^9-B]@**[9-B]-' '&a@%'  < ../inputs/temp-test/29.inp.12.4 > ../outputs/t4534
    if diff ../outputs/t4534 ../originals/t4534 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4535) timeout -s 9 2 ../source/replace.exe '[9-B][^a--b][^9-B]@**[9-B]-' '&a@%'  < ../inputs/temp-test/27.inp.12.1 > ../outputs/t4535
    if diff ../outputs/t4535 ../originals/t4535 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4536) timeout -s 9 2 ../source/replace.exe '[9-B][^a--b][^9-B]@**[9-B]-' '&a@%'  < ../inputs/temp-test/28.inp.12.3 > ../outputs/t4536
    if diff ../outputs/t4536 ../originals/t4536 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4537) timeout -s 9 2 ../source/replace.exe '[9-B][^a--b][^9-B]@**[9-B]-' '&a@%'  < ../inputs/temp-test/29.inp.12.4 > ../outputs/t4537
    if diff ../outputs/t4537 ../originals/t4537 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4538) timeout -s 9 2 ../source/replace.exe '[9-B][^a-c]' '@%&a'  < ../inputs/temp-test/917.inp.396.1 > ../outputs/t4538
    if diff ../outputs/t4538 ../originals/t4538 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4539) timeout -s 9 2 ../source/replace.exe '[9-B][^a-c]' '@%&a'  < ../inputs/temp-test/918.inp.396.3 > ../outputs/t4539
    if diff ../outputs/t4539 ../originals/t4539 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4540) timeout -s 9 2 ../source/replace.exe '[9-B][^a-c]' '@%@&'  < ../inputs/temp-test/2089.inp.885.1 > ../outputs/t4540
    if diff ../outputs/t4540 ../originals/t4540 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4541) timeout -s 9 2 ../source/replace.exe '[9-B][^a-c]' '@%@&'  < ../inputs/temp-test/2090.inp.885.2 > ../outputs/t4541
    if diff ../outputs/t4541 ../originals/t4541 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4542) timeout -s 9 2 ../source/replace.exe '[9-B][^a-c]' '@t'  < ../inputs/temp-test/390.inp.170.1 > ../outputs/t4542
    if diff ../outputs/t4542 ../originals/t4542 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4543) timeout -s 9 2 ../source/replace.exe '[9-B][^a-c]?*' '@t'  < ../inputs/temp-test/390.inp.170.1 > ../outputs/t4543
    if diff ../outputs/t4543 ../originals/t4543 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4544) timeout -s 9 2 ../source/replace.exe '[9-B]^$' 'NEW'  < ../inputs/temp-test/757.inp.324.6 > ../outputs/t4544
    if diff ../outputs/t4544 ../originals/t4544 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4545) timeout -s 9 2 ../source/replace.exe '[9-B]^' 'NEW'  < ../inputs/temp-test/755.inp.324.1 > ../outputs/t4545
    if diff ../outputs/t4545 ../originals/t4545 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4546) timeout -s 9 2 ../source/replace.exe '[9-B]^' 'NEW'  < ../inputs/temp-test/756.inp.324.2 > ../outputs/t4546
    if diff ../outputs/t4546 ../originals/t4546 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4547) timeout -s 9 2 ../source/replace.exe '[9-B]c$' 'a@n'  < ../inputs/temp-test/495.inp.216.6 > ../outputs/t4547
    if diff ../outputs/t4547 ../originals/t4547 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4548) timeout -s 9 2 ../source/replace.exe '[9-B]c' 'a@n'  < ../inputs/temp-test/493.inp.216.1 > ../outputs/t4548
    if diff ../outputs/t4548 ../originals/t4548 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4549) timeout -s 9 2 ../source/replace.exe '[9-B]c' 'a@n'  < ../inputs/temp-test/494.inp.216.3 > ../outputs/t4549
    if diff ../outputs/t4549 ../originals/t4549 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4550) timeout -s 9 2 ../source/replace.exe '[9-B]c*$' '@%@&'  < ../inputs/temp-test/1715.inp.730.6 > ../outputs/t4550
    if diff ../outputs/t4550 ../originals/t4550 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4551) timeout -s 9 2 ../source/replace.exe '[9-B]c*' '@%@&'  < ../inputs/temp-test/1712.inp.730.1 > ../outputs/t4551
    if diff ../outputs/t4551 ../originals/t4551 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4552) timeout -s 9 2 ../source/replace.exe '[9-B]c*' '@%@&'  < ../inputs/temp-test/1713.inp.730.2 > ../outputs/t4552
    if diff ../outputs/t4552 ../originals/t4552 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4553) timeout -s 9 2 ../source/replace.exe '[9-B]c*' '@%@&'  < ../inputs/temp-test/1714.inp.730.3 > ../outputs/t4553
    if diff ../outputs/t4553 ../originals/t4553 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4554) timeout -s 9 2 ../source/replace.exe '[9-B]c*' 'NEW'  < ../inputs/temp-test/2112.inp.895.1 > ../outputs/t4554
    if diff ../outputs/t4554 ../originals/t4554 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4555) timeout -s 9 2 ../source/replace.exe '[9-B]c*?@[*-? ' '&'  < ../inputs/temp-test/434.inp.191.1 > ../outputs/t4555
    if diff ../outputs/t4555 ../originals/t4555 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4556) timeout -s 9 2 ../source/replace.exe '[9-B]c*?@[*-? ' '&'  < ../inputs/temp-test/435.inp.191.2 > ../outputs/t4556
    if diff ../outputs/t4556 ../originals/t4556 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4557) timeout -s 9 2 ../source/replace.exe '[9-B]c@' 'a@n'  < ../inputs/temp-test/493.inp.216.1 > ../outputs/t4557
    if diff ../outputs/t4557 ../originals/t4557 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4558) timeout -s 9 2 ../source/replace.exe '[9-B]c@***' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4558
    if diff ../outputs/t4558 ../originals/t4558 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4559) timeout -s 9 2 ../source/replace.exe '[<]' 'v'  < ../inputs/input/ruin.799 > ../outputs/t4559
    if diff ../outputs/t4559 ../originals/t4559 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4560) timeout -s 9 2 ../source/replace.exe '[=]@n' 'u>{%9; ?S3&u@@LZ'  < ../inputs/input/ruin.1188 > ../outputs/t4560
    if diff ../outputs/t4560 ../originals/t4560 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4561) timeout -s 9 2 ../source/replace.exe '[>-A$>-A>-A]' 'BWOG;nsT|&v:1JbQ*sS{n)s'  < ../inputs/input/ruin.1782 > ../outputs/t4561
    if diff ../outputs/t4561 ../originals/t4561 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4562) timeout -s 9 2 ../source/replace.exe '[>-A0-9]$' 'O'  < ../inputs/input/ruin.750 > ../outputs/t4562
    if diff ../outputs/t4562 ../originals/t4562 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4563) timeout -s 9 2 ../source/replace.exe '[>-A>-A>-A<z-}c-a]@@' '(1FO34>$"?Wo1x\X'  < ../inputs/input/ruin.1642 > ../outputs/t4563
    if diff ../outputs/t4563 ../originals/t4563 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4564) timeout -s 9 2 ../source/replace.exe '[>-AA-G0-90-9z-}]' 'CH3_XX}'  < ../inputs/input/ruin.956 > ../outputs/t4564
    if diff ../outputs/t4564 ../originals/t4564 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4565) timeout -s 9 2 ../source/replace.exe '[>-AA-G]' 'S'  < ../inputs/input/ruin.309 > ../outputs/t4565
    if diff ../outputs/t4565 ../originals/t4565 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4566) timeout -s 9 2 ../source/replace.exe '[>-AA-G]' 'h+7%G2u6AJQk>L1WQsotq_n,vo'  < ../inputs/input/ruin.695 > ../outputs/t4566
    if diff ../outputs/t4566 ../originals/t4566 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4567) timeout -s 9 2 ../source/replace.exe '[>-A]$' '!'  < ../inputs/input/ruin.151 > ../outputs/t4567
    if diff ../outputs/t4567 ../originals/t4567 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4568) timeout -s 9 2 ../source/replace.exe '[>-A]' '&y#k-llLWk'  < ../inputs/input/ruin.279 > ../outputs/t4568
    if diff ../outputs/t4568 ../originals/t4568 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4569) timeout -s 9 2 ../source/replace.exe '[>-A]' 'V'  < ../inputs/input/ruin.1531 > ../outputs/t4569
    if diff ../outputs/t4569 ../originals/t4569 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4570) timeout -s 9 2 ../source/replace.exe '[>-A]' 'V'  < ../inputs/input/ruin.1829 > ../outputs/t4570
    if diff ../outputs/t4570 ../originals/t4570 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4571) timeout -s 9 2 ../source/replace.exe '[>-A]' 'Z}rl'  < ../inputs/input/ruin.1762 > ../outputs/t4571
    if diff ../outputs/t4571 ../originals/t4571 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4572) timeout -s 9 2 ../source/replace.exe '[>-A]' '^'  < ../inputs/input/ruin.685 > ../outputs/t4572
    if diff ../outputs/t4572 ../originals/t4572 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4573) timeout -s 9 2 ../source/replace.exe '[>-A]' 'l'  < ../inputs/input/ruin.1117 > ../outputs/t4573
    if diff ../outputs/t4573 ../originals/t4573 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4574) timeout -s 9 2 ../source/replace.exe '[>-A]' 'r'  < ../inputs/input/ruin.194 > ../outputs/t4574
    if diff ../outputs/t4574 ../originals/t4574 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4575) timeout -s 9 2 ../source/replace.exe '[>-A]' '|u,~, P+@h3f-q{-m^'  < ../inputs/input/ruin.455 > ../outputs/t4575
    if diff ../outputs/t4575 ../originals/t4575 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4576) timeout -s 9 2 ../source/replace.exe '[>-A]'\''gdh' '0(,(PKL.GW[Vb;PK[Ko(/'  < ../inputs/input/ruin.1628 > ../outputs/t4576
    if diff ../outputs/t4576 ../originals/t4576 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4577) timeout -s 9 2 ../source/replace.exe '[>-A]'\''o-]' '98lxUW$3UOKEX2a@El#=-t[^R%"'  < ../inputs/input/ruin.290 > ../outputs/t4577
    if diff ../outputs/t4577 ../originals/t4577 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4578) timeout -s 9 2 ../source/replace.exe '[>-A]'\''o-]@n' '98l&xUW$3UOKEX2a@El#=-t[^R%"'  < ../inputs/input/ruin.290 > ../outputs/t4578
    if diff ../outputs/t4578 ../originals/t4578 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4579) timeout -s 9 2 ../source/replace.exe '[>-A]*$' 'l'  < ../inputs/input/ruin.1117 > ../outputs/t4579
    if diff ../outputs/t4579 ../originals/t4579 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4580) timeout -s 9 2 ../source/replace.exe '[>-A]@n' 'a&y#k-llLWk'  < ../inputs/input/ruin.279 > ../outputs/t4580
    if diff ../outputs/t4580 ../originals/t4580 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4581) timeout -s 9 2 ../source/replace.exe '[>-A][>-A]' '1!{5i'\''s.:7mc9esJG16_BM+B-K'  < ../inputs/input/ruin.820 > ../outputs/t4581
    if diff ../outputs/t4581 ../originals/t4581 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4582) timeout -s 9 2 ../source/replace.exe '[>-Az-}]' '%}8@>aTrygnRh-u lvO3z#S['  < ../inputs/input/ruin.921 > ../outputs/t4582
    if diff ../outputs/t4582 ../originals/t4582 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4583) timeout -s 9 2 ../source/replace.exe '[>-Az-}]' '<~{gj:'  < ../inputs/input/ruin.603 > ../outputs/t4583
    if diff ../outputs/t4583 ../originals/t4583 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4584) timeout -s 9 2 ../source/replace.exe '[>-Az-}]' '=C8YI{._KxMa0~n=|EB1|'  < ../inputs/input/ruin.1042 > ../outputs/t4584
    if diff ../outputs/t4584 ../originals/t4584 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4585) timeout -s 9 2 ../source/replace.exe '[>-Az-}]' '=G:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JG:]y;Zm{7<\33O~h_JC8YI{._KxMa0~n=|EB1|'  < ../inputs/input/ruin.1042 > ../outputs/t4585
    if diff ../outputs/t4585 ../originals/t4585 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4586) timeout -s 9 2 ../source/replace.exe '[>-Az-}]*' '%}8@>aTrygnRh-u lvO3z#S['  < ../inputs/input/ruin.921 > ../outputs/t4586
    if diff ../outputs/t4586 ../originals/t4586 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4587) timeout -s 9 2 ../source/replace.exe '[@@]?@*[^@n]?' 'a@nb@tc'  < ../inputs/temp-test/1075.inp.463.1 > ../outputs/t4587
    if diff ../outputs/t4587 ../originals/t4587 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4588) timeout -s 9 2 ../source/replace.exe '[@t ]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4588
    if diff ../outputs/t4588 ../originals/t4588 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4589) timeout -s 9 2 ../source/replace.exe '[@t]' 'a@n'  < ../inputs/temp-test/235.inp.105.1 > ../outputs/t4589
    if diff ../outputs/t4589 ../originals/t4589 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4590) timeout -s 9 2 ../source/replace.exe '[@t]' 'a@n'  < ../inputs/temp-test/236.inp.105.2 > ../outputs/t4590
    if diff ../outputs/t4590 ../originals/t4590 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4591) timeout -s 9 2 ../source/replace.exe '[@t]' 'a@n'  < ../inputs/temp-test/237.inp.105.3 > ../outputs/t4591
    if diff ../outputs/t4591 ../originals/t4591 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4592) timeout -s 9 2 ../source/replace.exe '[@t]- [^0-9][^a-^?@n?' 'a&'  < ../inputs/temp-test/2250.inp.954.1 > ../outputs/t4592
    if diff ../outputs/t4592 ../originals/t4592 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4593) timeout -s 9 2 ../source/replace.exe '[@t]- [^0-9][^a-^?@n?' 'a&'  < ../inputs/temp-test/2251.inp.954.2 > ../outputs/t4593
    if diff ../outputs/t4593 ../originals/t4593 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4594) timeout -s 9 2 ../source/replace.exe '[@t]-[^9-B]--^*-?' 'a@n'  < ../inputs/temp-test/2082.inp.882.1 > ../outputs/t4594
    if diff ../outputs/t4594 ../originals/t4594 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4595) timeout -s 9 2 ../source/replace.exe '[@t]-^-' 'NEW'  < ../inputs/temp-test/683.inp.297.1 > ../outputs/t4595
    if diff ../outputs/t4595 ../originals/t4595 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4596) timeout -s 9 2 ../source/replace.exe '[@t]-^-' 'NEW'  < ../inputs/temp-test/684.inp.297.2 > ../outputs/t4596
    if diff ../outputs/t4596 ../originals/t4596 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4597) timeout -s 9 2 ../source/replace.exe '[@t]?' '&a@%'  < ../inputs/temp-test/882.inp.379.1 > ../outputs/t4597
    if diff ../outputs/t4597 ../originals/t4597 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4598) timeout -s 9 2 ../source/replace.exe '[@t]@*?[^-[9-B]-' 'b@t'  < ../inputs/temp-test/1731.inp.736.1 > ../outputs/t4598
    if diff ../outputs/t4598 ../originals/t4598 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4599) timeout -s 9 2 ../source/replace.exe '[@t][^0-9]' 'NEW'  < ../inputs/temp-test/1942.inp.825.1 > ../outputs/t4599
    if diff ../outputs/t4599 ../originals/t4599 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4600) timeout -s 9 2 ../source/replace.exe '[@t][^0-9]' 'NEW'  < ../inputs/temp-test/1943.inp.825.3 > ../outputs/t4600
    if diff ../outputs/t4600 ../originals/t4600 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4601) timeout -s 9 2 ../source/replace.exe '[A-G0-9c-a]' '0$'  < ../inputs/input/ruin.965 > ../outputs/t4601
    if diff ../outputs/t4601 ../originals/t4601 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4602) timeout -s 9 2 ../source/replace.exe '[A-G>-A0-9Z-a]^_`a-z-}z-}]$' 'evC g}bq'\''@;cuD;hR8`'  < ../inputs/input/ruin.1630 > ../outputs/t4602
    if diff ../outputs/t4602 ../originals/t4602 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4603) timeout -s 9 2 ../source/replace.exe '[A-G>-AZ-a]^_`a-z-}z-}-Z-aZ[]^_`a][A-G>-AZ-a]^_`a-z-}z-}-Z-aZ[]^_`a]:' 'A'  < ../inputs/input/ruin.298 > ../outputs/t4603
    if diff ../outputs/t4603 ../originals/t4603 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4604) timeout -s 9 2 ../source/replace.exe '[A-GZ-a]^_`a-Z-aZ[]^_`a]' '{M'  < ../inputs/input/ruin.864 > ../outputs/t4604
    if diff ../outputs/t4604 ../originals/t4604 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4605) timeout -s 9 2 ../source/replace.exe '[A-GZ-a]^_`a-z-}z-}->-A>-A-A-GABCDEFGy]' '9'  < ../inputs/input/ruin.327 > ../outputs/t4605
    if diff ../outputs/t4605 ../originals/t4605 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4606) timeout -s 9 2 ../source/replace.exe '[A-GZ-a]^_`a-z-}z-}->-A>-A-A-GABCDEFGy]B]ddB]@t]*[@t@][9-B]' '9'  < ../inputs/input/ruin.327 > ../outputs/t4606
    if diff ../outputs/t4606 ../originals/t4606 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4607) timeout -s 9 2 ../source/replace.exe '[A-GZ-a]^_`a]' 'ZuL'  < ../inputs/input/ruin.1986 > ../outputs/t4607
    if diff ../outputs/t4607 ../originals/t4607 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4608) timeout -s 9 2 ../source/replace.exe '[A-G]' '0YCrgUE!LL6G_5f<m,Jkg0xpW'  < ../inputs/input/ruin.777 > ../outputs/t4608
    if diff ../outputs/t4608 ../originals/t4608 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4609) timeout -s 9 2 ../source/replace.exe '[A-G]' '4'  < ../inputs/input/ruin.450 > ../outputs/t4609
    if diff ../outputs/t4609 ../originals/t4609 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4610) timeout -s 9 2 ../source/replace.exe '[A-G]' '6]^!oZ.:nm/o7[-L95B&K9V&3'  < ../inputs/input/ruin.694 > ../outputs/t4610
    if diff ../outputs/t4610 ../originals/t4610 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4611) timeout -s 9 2 ../source/replace.exe '[A-G]' ':MJ8*qY`8'\''vLKqNaKaK&HJQKlK)>A'  < ../inputs/input/ruin.657 > ../outputs/t4611
    if diff ../outputs/t4611 ../originals/t4611 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4612) timeout -s 9 2 ../source/replace.exe '[A-G]' 'E:H\y;lNQZu08<\]<'  < ../inputs/input/ruin.388 > ../outputs/t4612
    if diff ../outputs/t4612 ../originals/t4612 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4613) timeout -s 9 2 ../source/replace.exe '[A-G]' 'N'  < ../inputs/input/ruin.647 > ../outputs/t4613
    if diff ../outputs/t4613 ../originals/t4613 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4614) timeout -s 9 2 ../source/replace.exe '[A-G]' 'OmS[X@@s5c_'  < ../inputs/input/ruin.674 > ../outputs/t4614
    if diff ../outputs/t4614 ../originals/t4614 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4615) timeout -s 9 2 ../source/replace.exe '[A-G]' '_'  < ../inputs/input/ruin.632 > ../outputs/t4615
    if diff ../outputs/t4615 ../originals/t4615 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4616) timeout -s 9 2 ../source/replace.exe '[A-G]' 'ho]3#Ftwk3<O@P'  < ../inputs/input/ruin.1570 > ../outputs/t4616
    if diff ../outputs/t4616 ../originals/t4616 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4617) timeout -s 9 2 ../source/replace.exe '[A-G]' 'o'  < ../inputs/input/ruin.292 > ../outputs/t4617
    if diff ../outputs/t4617 ../originals/t4617 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4618) timeout -s 9 2 ../source/replace.exe '[A-G]*' 'CD?Kn2vz[1x#3A{vny,"]_gwInrWC<[9\(}S$J/>[V]^gj;jI2'  < ../inputs/input/ruin.1669 > ../outputs/t4618
    if diff ../outputs/t4618 ../originals/t4618 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4619) timeout -s 9 2 ../source/replace.exe '[A-G]?' 'x'  < ../inputs/input/ruin.1538 > ../outputs/t4619
    if diff ../outputs/t4619 ../originals/t4619 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4620) timeout -s 9 2 ../source/replace.exe '[A-G]@8' '`FtUy"ZE>GnU;'\''YIDS'\''X9"iFzSRIUUE%er[]kgNc}vQ@yAP>Uv$LK'\''l{hQxb'\''z|'  < ../inputs/input/ruin.1506 > ../outputs/t4620
    if diff ../outputs/t4620 ../originals/t4620 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4621) timeout -s 9 2 ../source/replace.exe '[A-G]@@' 'ZSfeyi|K>"6x;;rR<78XU=W{QrkUiM^S5tp<*{,9`9'  < ../inputs/input/ruin.329 > ../outputs/t4621
    if diff ../outputs/t4621 ../originals/t4621 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4622) timeout -s 9 2 ../source/replace.exe '[A-G]@@9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9]][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]-*[0-9][@t]*[@t@][9-B]' 'ZSfeyi|K>"6x;;rR<78XU=W{QrkUiM^S5tp<*{,9`9'  < ../inputs/input/ruin.329 > ../outputs/t4622
    if diff ../outputs/t4622 ../originals/t4622 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4623) timeout -s 9 2 ../source/replace.exe '[A-G]@n' 'o&;kasdlfkj'  < ../inputs/input/ruin.292 > ../outputs/t4623
    if diff ../outputs/t4623 ../originals/t4623 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4624) timeout -s 9 2 ../source/replace.exe '[A-Gk0-90-9z-}z-}]' '2'  < ../inputs/input/ruin.147 > ../outputs/t4624
    if diff ../outputs/t4624 ../originals/t4624 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4625) timeout -s 9 2 ../source/replace.exe '[A-Gz-}]' '[8='  < ../inputs/input/ruin.1073 > ../outputs/t4625
    if diff ../outputs/t4625 ../originals/t4625 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4626) timeout -s 9 2 ../source/replace.exe '[A-z]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4626
    if diff ../outputs/t4626 ../originals/t4626 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4627) timeout -s 9 2 ../source/replace.exe '[EZ-a]^_`a]?' 'B6'  < ../inputs/input/ruin.1344 > ../outputs/t4627
    if diff ../outputs/t4627 ../originals/t4627 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4628) timeout -s 9 2 ../source/replace.exe '[EZ-a]^_`a]?' 'Btemp-test/229.inp.1temp-test/229.inp.1temp-test/229.inp.1temp-test/229.inp.1temp-test/229.inp.1*?@t*[^0-9][0-9]*?@t*[^0-9][0-9]*?@t*[^0-9][0-9]*?@t*[^0-9][0-9]6*?@t*[^0-9][0-9]'  < ../inputs/input/ruin.1344 > ../outputs/t4628
    if diff ../outputs/t4628 ../originals/t4628 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4629) timeout -s 9 2 ../source/replace.exe '[EZ-a]^_`a]?[^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c][^a-c]*?--*?* *[a--b][^a-c]' 'B6'  < ../inputs/input/ruin.1344 > ../outputs/t4629
    if diff ../outputs/t4629 ../originals/t4629 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4630) timeout -s 9 2 ../source/replace.exe '[H]@@' 'Cvj;!/7QaWXcBn_:K4~nT[ &j/4fJh'  < ../inputs/input/ruin.1517 > ../outputs/t4630
    if diff ../outputs/t4630 ../originals/t4630 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4631) timeout -s 9 2 ../source/replace.exe '[J-P]@n' '`&`'  < ../inputs/input/ruin.278 > ../outputs/t4631
    if diff ../outputs/t4631 ../originals/t4631 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4632) timeout -s 9 2 ../source/replace.exe '[M]' ''  < ../inputs/input/ruin.456 > ../outputs/t4632
    if diff ../outputs/t4632 ../originals/t4632 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4633) timeout -s 9 2 ../source/replace.exe '[O>-A]' 'v'  < ../inputs/input/ruin.508 > ../outputs/t4633
    if diff ../outputs/t4633 ../originals/t4633 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4634) timeout -s 9 2 ../source/replace.exe '[T]' 'SaWpU='  < ../inputs/input/ruin.1721 > ../outputs/t4634
    if diff ../outputs/t4634 ../originals/t4634 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4635) timeout -s 9 2 ../source/replace.exe '[W]' ':'  < ../inputs/input/ruin.1717 > ../outputs/t4635
    if diff ../outputs/t4635 ../originals/t4635 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4636) timeout -s 9 2 ../source/replace.exe '[W]<' '1'  < ../inputs/input/ruin.300 > ../outputs/t4636
    if diff ../outputs/t4636 ../originals/t4636 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4637) timeout -s 9 2 ../source/replace.exe '[Y-a]^_' '&aaaaaaaaaaaaaaaaaaa&'  < ../inputs/input/ruin.506 > ../outputs/t4637
    if diff ../outputs/t4637 ../originals/t4637 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4638) timeout -s 9 2 ../source/replace.exe '[Z-a]' '&aNfc%bv4h]P(;lr%%=i&'  < ../inputs/input/ruin.506 > ../outputs/t4638
    if diff ../outputs/t4638 ../originals/t4638 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4639) timeout -s 9 2 ../source/replace.exe '[Z-a]^_' '&aNfc%bv4h]P(;lr%%=i&'  < ../inputs/input/ruin.506 > ../outputs/t4639
    if diff ../outputs/t4639 ../originals/t4639 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4640) timeout -s 9 2 ../source/replace.exe '[Z-a]^_' '&doesthecharactermat&'  < ../inputs/input/ruin.506 > ../outputs/t4640
    if diff ../outputs/t4640 ../originals/t4640 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4641) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a->-A>-A-0-90123456789-z-}z-}?-Z-aZ[]^_`aO->-A>-A-0-90123456789]' 'Vgq"#'\''/=PA@'  < ../inputs/input/ruin.369 > ../outputs/t4641
    if diff ../outputs/t4641 ../originals/t4641 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4642) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a-A-GABCDEFG-c-ac-a]' 'Eu!'  < ../inputs/input/ruin.218 > ../outputs/t4642
    if diff ../outputs/t4642 ../originals/t4642 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4643) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a-A-GABCDEFG]' '!'  < ../inputs/input/ruin.1844 > ../outputs/t4643
    if diff ../outputs/t4643 ../originals/t4643 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4644) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a-Z-aZ[]^_`a-A-GABCDEFG-z-}z-}-0-90123456789]' '`3d11q~?6`O91g=3eoBIC5qim`g8BS\|!}xE?01/),55cn*"[Oq_(Pr{liHN~G)'  < ../inputs/input/ruin.1146 > ../outputs/t4644
    if diff ../outputs/t4644 ../originals/t4644 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4645) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a-Z-aZ[]^_`a-z-}z-}-c-ac-a-c-ac-a]' '7:'  < ../inputs/input/ruin.1123 > ../outputs/t4645
    if diff ../outputs/t4645 ../originals/t4645 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4646) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a-c-ac-a]' '&aNfc%bv4h]P(;lr%%=i&'  < ../inputs/input/ruin.506 > ../outputs/t4646
    if diff ../outputs/t4646 ../originals/t4646 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4647) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a-c-ac-a]' '&aNfc%bv4h]P(;lr%%=i&+M7yZz'\''-}}{nQhj^V}:KKyM_j)'  < ../inputs/input/ruin.506 > ../outputs/t4647
    if diff ../outputs/t4647 ../originals/t4647 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4648) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a0-Z-aZ[]^_`a-A-GABCDEFG-0-90123456789-c-ac-a-z-}z-}-Z-aZ[]^_`a-Z-aZ[]^_`a-Z-aZ[]^_`a]' 'ix)<}kUWz8gj>OS7mesntcvv<ov '\''N{PJ+]l??jco'  < ../inputs/input/ruin.1350 > ../outputs/t4648
    if diff ../outputs/t4648 ../originals/t4648 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4649) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a0-Z-aZ[]^_`a-A-]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rY]~M\ Wz]`M0)y8H?fc7Phqi}@,5rYGABCDEFG-0-90123456789-c-ac-a-z-}z-}-Z-aZ[]^_`a-Z-aZ[]^_`a-Z-aZ[]^_`a] *[a--b][^a-c][^a--*?* *[a' 'ix)<}kUWz8gj>OS7mesntcvv<ov '\''N{PJ+]l??jco'  < ../inputs/input/ruin.1350 > ../outputs/t4649
    if diff ../outputs/t4649 ../originals/t4649 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4650) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`aLT6]' 'S%Rm9'  < ../inputs/input/ruin.1423 > ../outputs/t4650
    if diff ../outputs/t4650 ../originals/t4650 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4651) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]$' '<N#25jF0##%:+[kG}Yl0M'\''U\(&UQKc$V &/*K)n'  < ../inputs/input/ruin.1182 > ../outputs/t4651
    if diff ../outputs/t4651 ../originals/t4651 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4652) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' '#0F67ERJA=Hu9-H,>NK'  < ../inputs/input/ruin.1913 > ../outputs/t4652
    if diff ../outputs/t4652 ../originals/t4652 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4653) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' '(=?$W( CnR{$4.C~2N2!G>A8s&)n|{uPg;\eT'  < ../inputs/input/ruin.627 > ../outputs/t4653
    if diff ../outputs/t4653 ../originals/t4653 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4654) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' '+|>xCvy_Drp.ISXFXg'\''n`'  < ../inputs/input/ruin.1724 > ../outputs/t4654
    if diff ../outputs/t4654 ../originals/t4654 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4655) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' '9'  < ../inputs/input/ruin.1243 > ../outputs/t4655
    if diff ../outputs/t4655 ../originals/t4655 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4656) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' ':-dY=*uE-5KsKFXferbm `[CS;i4I$<41p45>~2nqF}*+Y.QBq'  < ../inputs/input/ruin.701 > ../outputs/t4656
    if diff ../outputs/t4656 ../originals/t4656 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4657) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' 'F'  < ../inputs/input/ruin.1906 > ../outputs/t4657
    if diff ../outputs/t4657 ../originals/t4657 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4658) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' 'JY2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{G2k|h=&-kA{I^m)l>oO{GXAlF<%'  < ../inputs/input/ruin.1032 > ../outputs/t4658
    if diff ../outputs/t4658 ../originals/t4658 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4659) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' 'JYXAlF<%'  < ../inputs/input/ruin.1032 > ../outputs/t4659
    if diff ../outputs/t4659 ../originals/t4659 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4660) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' 'L#\yx[]iZObU!WRS'  < ../inputs/input/ruin.1941 > ../outputs/t4660
    if diff ../outputs/t4660 ../originals/t4660 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4661) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' 'NgW3k~nFJWW0d%"'  < ../inputs/input/ruin.1110 > ../outputs/t4661
    if diff ../outputs/t4661 ../originals/t4661 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4662) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' 'UvR'  < ../inputs/input/ruin.979 > ../outputs/t4662
    if diff ../outputs/t4662 ../originals/t4662 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4663) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' '\/Jo n3Hj!!XA\!!Z;'\''k#\pku:-g*G ;iMw3]'  < ../inputs/input/ruin.1191 > ../outputs/t4663
    if diff ../outputs/t4663 ../originals/t4663 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4664) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]' 'l'  < ../inputs/input/ruin.61 > ../outputs/t4664
    if diff ../outputs/t4664 ../originals/t4664 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4665) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]*$' '9'  < ../inputs/input/ruin.1243 > ../outputs/t4665
    if diff ../outputs/t4665 ../originals/t4665 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4666) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]*' '3'  < ../inputs/input/ruin.281 > ../outputs/t4666
    if diff ../outputs/t4666 ../originals/t4666 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4667) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]*' 'B"StB'  < ../inputs/input/ruin.231 > ../outputs/t4667
    if diff ../outputs/t4667 ../originals/t4667 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4668) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]*@n' '3&4'  < ../inputs/input/ruin.281 > ../outputs/t4668
    if diff ../outputs/t4668 ../originals/t4668 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4669) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a]@n' '\/J&o n3Hj!!XA\!!Z;'\''k#\pku:-g*G ;iMw3]'  < ../inputs/input/ruin.1191 > ../outputs/t4669
    if diff ../outputs/t4669 ../originals/t4669 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4670) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a][Z-a]^_`a]$' 'm'  < ../inputs/input/ruin.1879 > ../outputs/t4670
    if diff ../outputs/t4670 ../originals/t4670 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4671) timeout -s 9 2 ../source/replace.exe '[Z-a]^_`a][Z-a]^_`a]@n#' 'R'  < ../inputs/input/ruin.417 > ../outputs/t4671
    if diff ../outputs/t4671 ../originals/t4671 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4672) timeout -s 9 2 ../source/replace.exe '[[]c' 'Sn{zDvs@tuu'  < ../inputs/input/ruin.1433 > ../outputs/t4672
    if diff ../outputs/t4672 ../originals/t4672 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4673) timeout -s 9 2 ../source/replace.exe '[]%?@*' 'NEW'  < ../inputs/temp-test/523.inp.226.5 > ../outputs/t4673
    if diff ../outputs/t4673 ../originals/t4673 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4674) timeout -s 9 2 ../source/replace.exe '[]%@*?' '@%&a'  < ../inputs/temp-test/199.inp.89.5 > ../outputs/t4674
    if diff ../outputs/t4674 ../originals/t4674 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4675) timeout -s 9 2 ../source/replace.exe '[]*' 'c'  < ../inputs/moni/f7.inp > ../outputs/t4675
    if diff ../outputs/t4675 ../originals/t4675 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4676) timeout -s 9 2 ../source/replace.exe '[]- ' '&'  < ../inputs/temp-test/524.inp.227.1 > ../outputs/t4676
    if diff ../outputs/t4676 ../originals/t4676 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4677) timeout -s 9 2 ../source/replace.exe '[]-*[^0-9]' '&'  < ../inputs/temp-test/200.inp.90.1 > ../outputs/t4677
    if diff ../outputs/t4677 ../originals/t4677 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4678) timeout -s 9 2 ../source/replace.exe '[]?@*' 'NEW'  < ../inputs/temp-test/521.inp.226.1 > ../outputs/t4678
    if diff ../outputs/t4678 ../originals/t4678 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4679) timeout -s 9 2 ../source/replace.exe '[]?@*' 'NEW'  < ../inputs/temp-test/522.inp.226.3 > ../outputs/t4679
    if diff ../outputs/t4679 ../originals/t4679 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4680) timeout -s 9 2 ../source/replace.exe '[][^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/526.inp.228.3 > ../outputs/t4680
    if diff ../outputs/t4680 ../originals/t4680 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4681) timeout -s 9 2 ../source/replace.exe '[][^9-B]@[' 'a@n'  < ../inputs/temp-test/220.inp.98.2 > ../outputs/t4681
    if diff ../outputs/t4681 ../originals/t4681 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4682) timeout -s 9 2 ../source/replace.exe '[][^9-B][9-B]' '@%&a'  < ../inputs/temp-test/203.inp.91.1 > ../outputs/t4682
    if diff ../outputs/t4682 ../originals/t4682 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4683) timeout -s 9 2 ../source/replace.exe '[][^a-c][9-B]' '@%&a'  < ../inputs/temp-test/223.inp.99.3 > ../outputs/t4683
    if diff ../outputs/t4683 ../originals/t4683 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4684) timeout -s 9 2 ../source/replace.exe '[][a-c?$' 'a&'  < ../inputs/temp-test/520.inp.225.8 > ../outputs/t4684
    if diff ../outputs/t4684 ../originals/t4684 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4685) timeout -s 9 2 ../source/replace.exe '[][a-c?' 'a&'  < ../inputs/temp-test/516.inp.225.1 > ../outputs/t4685
    if diff ../outputs/t4685 ../originals/t4685 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4686) timeout -s 9 2 ../source/replace.exe '[][a-c?' 'a&'  < ../inputs/temp-test/517.inp.225.2 > ../outputs/t4686
    if diff ../outputs/t4686 ../originals/t4686 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4687) timeout -s 9 2 ../source/replace.exe '[][a-c?' 'a&'  < ../inputs/temp-test/518.inp.225.3 > ../outputs/t4687
    if diff ../outputs/t4687 ../originals/t4687 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4688) timeout -s 9 2 ../source/replace.exe '[][a-c?' 'a&'  < ../inputs/temp-test/519.inp.225.4 > ../outputs/t4688
    if diff ../outputs/t4688 ../originals/t4688 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4689) timeout -s 9 2 ../source/replace.exe '[^!>-A]*' 'QdoJH\dI\~"(oA~yU11n~l'  < ../inputs/input/ruin.1697 > ../outputs/t4689
    if diff ../outputs/t4689 ../originals/t4689 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4690) timeout -s 9 2 ../source/replace.exe '[^&Z-a]^_`a-A-GABCDEFG]' '('\''5Z}NQGMdc/,=*#hydyO{Ga&=U<s+*G9cE}St6@wRb%L&s^*N0%U<cmItT-A|y.VJka@+1D]*&H#Avoj:kg6eHS(Ax|_N$.^U|h>^-9c0J'  < ../inputs/input/ruin.1969 > ../outputs/t4690
    if diff ../outputs/t4690 ../originals/t4690 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4691) timeout -s 9 2 ../source/replace.exe '[^- *$' '&a@%'  < ../inputs/temp-test/1616.inp.686.8 > ../outputs/t4691
    if diff ../outputs/t4691 ../originals/t4691 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4692) timeout -s 9 2 ../source/replace.exe '[^- *' '&a@%'  < ../inputs/temp-test/1614.inp.686.1 > ../outputs/t4692
    if diff ../outputs/t4692 ../originals/t4692 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4693) timeout -s 9 2 ../source/replace.exe '[^- *' '&a@%'  < ../inputs/temp-test/1615.inp.686.3 > ../outputs/t4693
    if diff ../outputs/t4693 ../originals/t4693 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4694) timeout -s 9 2 ../source/replace.exe '[^--$' '@n'  < ../inputs/temp-test/1594.inp.678.8 > ../outputs/t4694
    if diff ../outputs/t4694 ../originals/t4694 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4695) timeout -s 9 2 ../source/replace.exe '[^--$' '@n'  < ../inputs/temp-test/1595.inp.678.9 > ../outputs/t4695
    if diff ../outputs/t4695 ../originals/t4695 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4696) timeout -s 9 2 ../source/replace.exe '[^--' '&a@%'  < ../inputs/temp-test/66.inp.29.1 > ../outputs/t4696
    if diff ../outputs/t4696 ../originals/t4696 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4697) timeout -s 9 2 ../source/replace.exe '[^--' '&a@%'  < ../inputs/temp-test/67.inp.29.2 > ../outputs/t4697
    if diff ../outputs/t4697 ../originals/t4697 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4698) timeout -s 9 2 ../source/replace.exe '[^--' '&a@%'  < ../inputs/temp-test/68.inp.29.3 > ../outputs/t4698
    if diff ../outputs/t4698 ../originals/t4698 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4699) timeout -s 9 2 ../source/replace.exe '[^--' '@%&a'  < ../inputs/temp-test/1443.inp.619.1 > ../outputs/t4699
    if diff ../outputs/t4699 ../originals/t4699 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4700) timeout -s 9 2 ../source/replace.exe '[^--' '@%&a'  < ../inputs/temp-test/1444.inp.619.2 > ../outputs/t4700
    if diff ../outputs/t4700 ../originals/t4700 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4701) timeout -s 9 2 ../source/replace.exe '[^--' '@%&a'  < ../inputs/temp-test/1445.inp.619.3 > ../outputs/t4701
    if diff ../outputs/t4701 ../originals/t4701 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4702) timeout -s 9 2 ../source/replace.exe '[^--' '@n'  < ../inputs/temp-test/1591.inp.678.1 > ../outputs/t4702
    if diff ../outputs/t4702 ../originals/t4702 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4703) timeout -s 9 2 ../source/replace.exe '[^--' '@n'  < ../inputs/temp-test/1592.inp.678.3 > ../outputs/t4703
    if diff ../outputs/t4703 ../originals/t4703 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4704) timeout -s 9 2 ../source/replace.exe '[^--' '@n'  < ../inputs/temp-test/1593.inp.678.4 > ../outputs/t4704
    if diff ../outputs/t4704 ../originals/t4704 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4705) timeout -s 9 2 ../source/replace.exe '[^--z]%[9-B]' '@n'  < ../inputs/temp-test/19.inp.9.1 > ../outputs/t4705
    if diff ../outputs/t4705 ../originals/t4705 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4706) timeout -s 9 2 ../source/replace.exe '[^--z]%[9-B]' '@n'  < ../inputs/temp-test/20.inp.9.2 > ../outputs/t4706
    if diff ../outputs/t4706 ../originals/t4706 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4707) timeout -s 9 2 ../source/replace.exe '[^--z]%[9-B]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4707
    if diff ../outputs/t4707 ../originals/t4707 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4708) timeout -s 9 2 ../source/replace.exe '[^--z]A*??[_-z]' 'a&'  < ../inputs/temp-test/963.inp.415.1 > ../outputs/t4708
    if diff ../outputs/t4708 ../originals/t4708 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4709) timeout -s 9 2 ../source/replace.exe '[^--z]A*??[_-z]' 'a&'  < ../inputs/temp-test/964.inp.415.2 > ../outputs/t4709
    if diff ../outputs/t4709 ../originals/t4709 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4710) timeout -s 9 2 ../source/replace.exe '[^--z][9-B]$%' '@n'  < ../inputs/temp-test/22.inp.9.6 > ../outputs/t4710
    if diff ../outputs/t4710 ../originals/t4710 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4711) timeout -s 9 2 ../source/replace.exe '[^--z][9-B]$' '@n'  < ../inputs/temp-test/22.inp.9.6 > ../outputs/t4711
    if diff ../outputs/t4711 ../originals/t4711 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4712) timeout -s 9 2 ../source/replace.exe '[^--z][9-B]%' '@n'  < ../inputs/temp-test/21.inp.9.3 > ../outputs/t4712
    if diff ../outputs/t4712 ../originals/t4712 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4713) timeout -s 9 2 ../source/replace.exe '[^--z][9-B]' '@n'  < ../inputs/temp-test/19.inp.9.1 > ../outputs/t4713
    if diff ../outputs/t4713 ../originals/t4713 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4714) timeout -s 9 2 ../source/replace.exe '[^--z][9-B]' '@n'  < ../inputs/temp-test/20.inp.9.2 > ../outputs/t4714
    if diff ../outputs/t4714 ../originals/t4714 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4715) timeout -s 9 2 ../source/replace.exe '[^--z][9-B]' '@n'  < ../inputs/temp-test/21.inp.9.3 > ../outputs/t4715
    if diff ../outputs/t4715 ../originals/t4715 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4716) timeout -s 9 2 ../source/replace.exe '[^-?' 'NEW'  < ../inputs/temp-test/1328.inp.570.1 > ../outputs/t4716
    if diff ../outputs/t4716 ../originals/t4716 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4717) timeout -s 9 2 ../source/replace.exe '[^-?' 'NEW'  < ../inputs/temp-test/1329.inp.570.2 > ../outputs/t4717
    if diff ../outputs/t4717 ../originals/t4717 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4718) timeout -s 9 2 ../source/replace.exe '[^-c*$' '@%&a'  < ../inputs/temp-test/1440.inp.617.6 > ../outputs/t4718
    if diff ../outputs/t4718 ../originals/t4718 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4719) timeout -s 9 2 ../source/replace.exe '[^-c*' '@%&a'  < ../inputs/temp-test/1437.inp.617.1 > ../outputs/t4719
    if diff ../outputs/t4719 ../originals/t4719 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4720) timeout -s 9 2 ../source/replace.exe '[^-c*' '@%&a'  < ../inputs/temp-test/1438.inp.617.2 > ../outputs/t4720
    if diff ../outputs/t4720 ../originals/t4720 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4721) timeout -s 9 2 ../source/replace.exe '[^-c*' '@%&a'  < ../inputs/temp-test/1439.inp.617.3 > ../outputs/t4721
    if diff ../outputs/t4721 ../originals/t4721 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4722) timeout -s 9 2 ../source/replace.exe '[^-z] ' 'NEW'  < ../inputs/temp-test/246.inp.110.1 > ../outputs/t4722
    if diff ../outputs/t4722 ../originals/t4722 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4723) timeout -s 9 2 ../source/replace.exe '[^-z] ' 'NEW'  < ../inputs/temp-test/247.inp.110.3 > ../outputs/t4723
    if diff ../outputs/t4723 ../originals/t4723 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4724) timeout -s 9 2 ../source/replace.exe '[^-z]-$' '&a@%'  < ../inputs/temp-test/197.inp.88.6 > ../outputs/t4724
    if diff ../outputs/t4724 ../originals/t4724 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4725) timeout -s 9 2 ../source/replace.exe '[^-z]-' '&a@%'  < ../inputs/temp-test/195.inp.88.1 > ../outputs/t4725
    if diff ../outputs/t4725 ../originals/t4725 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4726) timeout -s 9 2 ../source/replace.exe '[^-z]-' '&a@%'  < ../inputs/temp-test/196.inp.88.2 > ../outputs/t4726
    if diff ../outputs/t4726 ../originals/t4726 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4727) timeout -s 9 2 ../source/replace.exe '[^-z]-*? ' 'NEW'  < ../inputs/temp-test/906.inp.390.1 > ../outputs/t4727
    if diff ../outputs/t4727 ../originals/t4727 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4728) timeout -s 9 2 ../source/replace.exe '[^-z]?' 'a@n'  < ../inputs/temp-test/1243.inp.534.1 > ../outputs/t4728
    if diff ../outputs/t4728 ../originals/t4728 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4729) timeout -s 9 2 ../source/replace.exe '[^-z]?' 'a@n'  < ../inputs/temp-test/1244.inp.534.2 > ../outputs/t4729
    if diff ../outputs/t4729 ../originals/t4729 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4730) timeout -s 9 2 ../source/replace.exe '[^-z]?' 'a@n'  < ../inputs/temp-test/1245.inp.534.3 > ../outputs/t4730
    if diff ../outputs/t4730 ../originals/t4730 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4731) timeout -s 9 2 ../source/replace.exe '[^-z]?' 'a@n'  < ../inputs/temp-test/1246.inp.534.4 > ../outputs/t4731
    if diff ../outputs/t4731 ../originals/t4731 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4732) timeout -s 9 2 ../source/replace.exe '[^-z]?*' '&a@%'  < ../inputs/temp-test/195.inp.88.1 > ../outputs/t4732
    if diff ../outputs/t4732 ../originals/t4732 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4733) timeout -s 9 2 ../source/replace.exe '[^-z][0-9][^0-9]-[^9-B]A[a-c]-' 'NEW'  < ../inputs/temp-test/1814.inp.771.1 > ../outputs/t4733
    if diff ../outputs/t4733 ../originals/t4733 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4734) timeout -s 9 2 ../source/replace.exe '[^-z][0-9][^0-9]-[^9-B]A[a-c]-' 'NEW'  < ../inputs/temp-test/1815.inp.771.3 > ../outputs/t4734
    if diff ../outputs/t4734 ../originals/t4734 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4735) timeout -s 9 2 ../source/replace.exe '[^-z][@t]' ''  < ../inputs/temp-test/288.inp.130.1 > ../outputs/t4735
    if diff ../outputs/t4735 ../originals/t4735 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4736) timeout -s 9 2 ../source/replace.exe '[^-z][@t]' ''  < ../inputs/temp-test/289.inp.130.2 > ../outputs/t4736
    if diff ../outputs/t4736 ../originals/t4736 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4737) timeout -s 9 2 ../source/replace.exe '[^-z][a-c]' '&a@%'  < ../inputs/temp-test/1205.inp.517.1 > ../outputs/t4737
    if diff ../outputs/t4737 ../originals/t4737 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4738) timeout -s 9 2 ../source/replace.exe '[^-z][a-c]' '&a@%'  < ../inputs/temp-test/1206.inp.517.2 > ../outputs/t4738
    if diff ../outputs/t4738 ../originals/t4738 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4739) timeout -s 9 2 ../source/replace.exe '[^0-8]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4739
    if diff ../outputs/t4739 ../originals/t4739 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4740) timeout -s 9 2 ../source/replace.exe '[^0-90-9u]' 'f'  < ../inputs/input/ruin.548 > ../outputs/t4740
    if diff ../outputs/t4740 ../originals/t4740 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4741) timeout -s 9 2 ../source/replace.exe '[^0-9;]$' '>'  < ../inputs/input/ruin.332 > ../outputs/t4741
    if diff ../outputs/t4741 ../originals/t4741 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4742) timeout -s 9 2 ../source/replace.exe '[^0-9Z-a]^_`a]' '4bd);DUiRc/4$MeR6|.'\''`S+S5?Svq*-:$3a%be-Mfw:wUM~'  < ../inputs/input/ruin.212 > ../outputs/t4742
    if diff ../outputs/t4742 ../originals/t4742 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4743) timeout -s 9 2 ../source/replace.exe '[^0-9Z-a]^_`a]' 'U'  < ../inputs/input/ruin.1193 > ../outputs/t4743
    if diff ../outputs/t4743 ../originals/t4743 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4744) timeout -s 9 2 ../source/replace.exe '[^0-9] ' '&'  < ../inputs/temp-test/542.inp.235.1 > ../outputs/t4744
    if diff ../outputs/t4744 ../originals/t4744 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4745) timeout -s 9 2 ../source/replace.exe '[^0-9] ' '&'  < ../inputs/temp-test/543.inp.235.2 > ../outputs/t4745
    if diff ../outputs/t4745 ../originals/t4745 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4746) timeout -s 9 2 ../source/replace.exe '[^0-9] [^9-B]--[0-9]??[a-c]?-' ''  < ../inputs/temp-test/566.inp.244.1 > ../outputs/t4746
    if diff ../outputs/t4746 ../originals/t4746 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4747) timeout -s 9 2 ../source/replace.exe '[^0-9] [^9-B]--[0-9]??[a-c]?-' ''  < ../inputs/temp-test/567.inp.244.2 > ../outputs/t4747
    if diff ../outputs/t4747 ../originals/t4747 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4748) timeout -s 9 2 ../source/replace.exe '[^0-9]$' '!ds4gkawP:i7J_3'\''>/n_R,P&3 M-8.V_Q:_"}~S<>|@o`/W(*k+9(jm043S9!G6]'\''z$~\Z]z[Q'  < ../inputs/input/ruin.1388 > ../outputs/t4748
    if diff ../outputs/t4748 ../originals/t4748 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4749) timeout -s 9 2 ../source/replace.exe '[^0-9]$' '5{>@K4{U'\'')}ombe;=z'  < ../inputs/input/ruin.382 > ../outputs/t4749
    if diff ../outputs/t4749 ../originals/t4749 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4750) timeout -s 9 2 ../source/replace.exe '[^0-9]$' '@%&a'  < ../inputs/temp-test/93.inp.41.6 > ../outputs/t4750
    if diff ../outputs/t4750 ../originals/t4750 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4751) timeout -s 9 2 ../source/replace.exe '[^0-9]$' 'Lj*D?G)%2iN-C+ARIR6:>9'\''YDdLk^UF%}+pBG'  < ../inputs/input/ruin.986 > ../outputs/t4751
    if diff ../outputs/t4751 ../originals/t4751 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4752) timeout -s 9 2 ../source/replace.exe '[^0-9]%' '&a@%'  < ../inputs/temp-test/2336.inp.991.1 > ../outputs/t4752
    if diff ../outputs/t4752 ../originals/t4752 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4753) timeout -s 9 2 ../source/replace.exe '[^0-9]%' '@t'  < ../inputs/temp-test/23.inp.10.1 > ../outputs/t4753
    if diff ../outputs/t4753 ../originals/t4753 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4754) timeout -s 9 2 ../source/replace.exe '[^0-9]' '%:ZqYa+)t&(X[6Q3?\Xa0eh-a'  < ../inputs/input/ruin.960 > ../outputs/t4754
    if diff ../outputs/t4754 ../originals/t4754 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4755) timeout -s 9 2 ../source/replace.exe '[^0-9]' '%GA1aneafjT*EQumxjb-hg\}lz$~TPz$Ac'  < ../inputs/input/ruin.77 > ../outputs/t4755
    if diff ../outputs/t4755 ../originals/t4755 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4756) timeout -s 9 2 ../source/replace.exe '[^0-9]' '&'  < ../inputs/temp-test/664.inp.289.1 > ../outputs/t4756
    if diff ../outputs/t4756 ../originals/t4756 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4757) timeout -s 9 2 ../source/replace.exe '[^0-9]' '&@n'  < ../inputs/temp-test/629.inp.272.1 > ../outputs/t4757
    if diff ../outputs/t4757 ../originals/t4757 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4758) timeout -s 9 2 ../source/replace.exe '[^0-9]' '&@n'  < ../inputs/temp-test/630.inp.272.3 > ../outputs/t4758
    if diff ../outputs/t4758 ../originals/t4758 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4759) timeout -s 9 2 ../source/replace.exe '[^0-9]' '&@n'  < ../inputs/temp-test/688.inp.299.1 > ../outputs/t4759
    if diff ../outputs/t4759 ../originals/t4759 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4760) timeout -s 9 2 ../source/replace.exe '[^0-9]' '&@n'  < ../inputs/temp-test/689.inp.299.3 > ../outputs/t4760
    if diff ../outputs/t4760 ../originals/t4760 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4761) timeout -s 9 2 ../source/replace.exe '[^0-9]' '&@n@ttt'  < ../inputs/temp-test/688.inp.299.1 > ../outputs/t4761
    if diff ../outputs/t4761 ../originals/t4761 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4762) timeout -s 9 2 ../source/replace.exe '[^0-9]' '&a@%'  < ../inputs/temp-test/2336.inp.991.1 > ../outputs/t4762
    if diff ../outputs/t4762 ../originals/t4762 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4763) timeout -s 9 2 ../source/replace.exe '[^0-9]' '*DyU/0]4LcsUAUsl4RUKt@z?h4?u1M'  < ../inputs/input/ruin.679 > ../outputs/t4763
    if diff ../outputs/t4763 ../originals/t4763 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4764) timeout -s 9 2 ../source/replace.exe '[^0-9]' '4'  < ../inputs/input/ruin.877 > ../outputs/t4764
    if diff ../outputs/t4764 ../originals/t4764 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4765) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@%&a'  < ../inputs/temp-test/91.inp.41.1 > ../outputs/t4765
    if diff ../outputs/t4765 ../originals/t4765 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4766) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@%&a'  < ../inputs/temp-test/92.inp.41.2 > ../outputs/t4766
    if diff ../outputs/t4766 ../originals/t4766 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4767) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@%@&'  < ../inputs/temp-test/1239.inp.532.1 > ../outputs/t4767
    if diff ../outputs/t4767 ../originals/t4767 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4768) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@%@&'  < ../inputs/temp-test/2002.inp.851.1 > ../outputs/t4768
    if diff ../outputs/t4768 ../originals/t4768 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4769) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@%@&'  < ../inputs/temp-test/2003.inp.851.2 > ../outputs/t4769
    if diff ../outputs/t4769 ../originals/t4769 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4770) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@%@&'  < ../inputs/temp-test/2004.inp.851.3 > ../outputs/t4770
    if diff ../outputs/t4770 ../originals/t4770 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4771) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@%@&'  < ../inputs/temp-test/2273.inp.963.1 > ../outputs/t4771
    if diff ../outputs/t4771 ../originals/t4771 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4772) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@%@&'  < ../inputs/temp-test/2274.inp.963.3 > ../outputs/t4772
    if diff ../outputs/t4772 ../originals/t4772 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4773) timeout -s 9 2 ../source/replace.exe '[^0-9]' '@t'  < ../inputs/temp-test/23.inp.10.1 > ../outputs/t4773
    if diff ../outputs/t4773 ../originals/t4773 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4774) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'KE>/]y#k0F!l)'  < ../inputs/input/ruin.444 > ../outputs/t4774
    if diff ../outputs/t4774 ../originals/t4774 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4775) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'NEW'  < ../inputs/temp-test/2176.inp.921.1 > ../outputs/t4775
    if diff ../outputs/t4775 ../originals/t4775 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4776) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'NEW'  < ../inputs/temp-test/2177.inp.921.2 > ../outputs/t4776
    if diff ../outputs/t4776 ../originals/t4776 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4777) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'NEW'  < ../inputs/temp-test/2178.inp.921.3 > ../outputs/t4777
    if diff ../outputs/t4777 ../originals/t4777 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4778) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'NEW'  < ../inputs/temp-test/660.inp.287.1 > ../outputs/t4778
    if diff ../outputs/t4778 ../originals/t4778 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4779) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'NEW'  < ../inputs/temp-test/661.inp.287.3 > ../outputs/t4779
    if diff ../outputs/t4779 ../originals/t4779 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4780) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'Y'  < ../inputs/input/ruin.160 > ../outputs/t4780
    if diff ../outputs/t4780 ../originals/t4780 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4781) timeout -s 9 2 ../source/replace.exe '[^0-9]' ']yO+C;|.#Ft_-n=^zs$NJA['  < ../inputs/input/ruin.1228 > ../outputs/t4781
    if diff ../outputs/t4781 ../originals/t4781 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4782) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'b@t'  < ../inputs/temp-test/1186.inp.511.1 > ../outputs/t4782
    if diff ../outputs/t4782 ../originals/t4782 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4783) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'd4<!_ait4(;qppZ;+yY=io19UK]0,*~YBq?P'  < ../inputs/input/ruin.195 > ../outputs/t4783
    if diff ../outputs/t4783 ../originals/t4783 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4784) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'd4<!_ait4(;qppZ;+yY=io19UK]0,*~YBq?d4<!_ait4(;qppZ;+yY=io19UK]0,*~YBq?d4<!_ait4(;qppZ;+yY=io19UK]0,*~YBq?d4<!_ait4(;qppZ;+yY=io19UK]0,*~YBq?d4<!_ait4(;qppZ;+yY=io19UK]0,*~YBq?d4<!_ait4(;qppZ;+yY=io19UK]0,*~YBq?d4<!_ait4(;qppZ;+yY=io19UK]0,*~YBq?P'  < ../inputs/input/ruin.195 > ../outputs/t4784
    if diff ../outputs/t4784 ../originals/t4784 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4785) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'h'  < ../inputs/input/ruin.1903 > ../outputs/t4785
    if diff ../outputs/t4785 ../originals/t4785 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4786) timeout -s 9 2 ../source/replace.exe '[^0-9]' 'q"'  < ../inputs/input/ruin.633 > ../outputs/t4786
    if diff ../outputs/t4786 ../originals/t4786 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4787) timeout -s 9 2 ../source/replace.exe '[^0-9]' '{'  < ../inputs/input/ruin.829 > ../outputs/t4787
    if diff ../outputs/t4787 ../originals/t4787 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4788) timeout -s 9 2 ../source/replace.exe '[^0-9]'\''' 'j'  < ../inputs/input/ruin.1346 > ../outputs/t4788
    if diff ../outputs/t4788 ../originals/t4788 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4789) timeout -s 9 2 ../source/replace.exe '[^0-9]'\''C|d<FQ' 'g99=H#ja[PxJokg/F\'  < ../inputs/input/ruin.1492 > ../outputs/t4789
    if diff ../outputs/t4789 ../originals/t4789 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4790) timeout -s 9 2 ../source/replace.exe '[^0-9]'\''V:W1pP' ':'  < ../inputs/input/ruin.662 > ../outputs/t4790
    if diff ../outputs/t4790 ../originals/t4790 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4791) timeout -s 9 2 ../source/replace.exe '[^0-9]'\''\2/L2y'\''@@*@@@=' ' +i`RYFz`5V/  W2?Y{N.1JW{5U"'\'''\''PH/yvFzwT=OI'  < ../inputs/input/ruin.1238 > ../outputs/t4791
    if diff ../outputs/t4791 ../originals/t4791 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4792) timeout -s 9 2 ../source/replace.exe '[^0-9]'\''\2/L2y'\''@@*@@@=*$' ' +i`RYFz`5V/  W2?Y{N.1JW{5U"'\'''\''PH/yvFzwT=OI'  < ../inputs/input/ruin.1238 > ../outputs/t4792
    if diff ../outputs/t4792 ../originals/t4792 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4793) timeout -s 9 2 ../source/replace.exe '[^0-9]-$' '@%@&'  < ../inputs/temp-test/968.inp.417.8 > ../outputs/t4793
    if diff ../outputs/t4793 ../originals/t4793 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4794) timeout -s 9 2 ../source/replace.exe '[^0-9]-' '@%&a'  < ../inputs/temp-test/1568.inp.670.1 > ../outputs/t4794
    if diff ../outputs/t4794 ../originals/t4794 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4795) timeout -s 9 2 ../source/replace.exe '[^0-9]-' '@%&a'  < ../inputs/temp-test/1569.inp.670.2 > ../outputs/t4795
    if diff ../outputs/t4795 ../originals/t4795 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4796) timeout -s 9 2 ../source/replace.exe '[^0-9]-' '@%&a'  < ../inputs/temp-test/1697.inp.724.1 > ../outputs/t4796
    if diff ../outputs/t4796 ../originals/t4796 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4797) timeout -s 9 2 ../source/replace.exe '[^0-9]-' '@%&a'  < ../inputs/temp-test/1698.inp.724.3 > ../outputs/t4797
    if diff ../outputs/t4797 ../originals/t4797 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4798) timeout -s 9 2 ../source/replace.exe '[^0-9]-' '@%&a'  < ../inputs/temp-test/1699.inp.724.4 > ../outputs/t4798
    if diff ../outputs/t4798 ../originals/t4798 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4799) timeout -s 9 2 ../source/replace.exe '[^0-9]-' '@%@&'  < ../inputs/temp-test/967.inp.417.1 > ../outputs/t4799
    if diff ../outputs/t4799 ../originals/t4799 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4800) timeout -s 9 2 ../source/replace.exe '[^0-9]-' 'NEW'  < ../inputs/temp-test/1589.inp.677.1 > ../outputs/t4800
    if diff ../outputs/t4800 ../originals/t4800 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4801) timeout -s 9 2 ../source/replace.exe '[^0-9]-' 'NEW'  < ../inputs/temp-test/1590.inp.677.2 > ../outputs/t4801
    if diff ../outputs/t4801 ../originals/t4801 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4802) timeout -s 9 2 ../source/replace.exe '[^0-9]-' 'a&'  < ../inputs/temp-test/1136.inp.489.1 > ../outputs/t4802
    if diff ../outputs/t4802 ../originals/t4802 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4803) timeout -s 9 2 ../source/replace.exe '[^0-9]-' 'a&'  < ../inputs/temp-test/1137.inp.489.2 > ../outputs/t4803
    if diff ../outputs/t4803 ../originals/t4803 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4804) timeout -s 9 2 ../source/replace.exe '[^0-9]-' 'a&'  < ../inputs/temp-test/1138.inp.489.3 > ../outputs/t4804
    if diff ../outputs/t4804 ../originals/t4804 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4805) timeout -s 9 2 ../source/replace.exe '[^0-9]-' 'a@nb@tc'  < ../inputs/temp-test/2091.inp.886.1 > ../outputs/t4805
    if diff ../outputs/t4805 ../originals/t4805 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4806) timeout -s 9 2 ../source/replace.exe '[^0-9]-' 'a@nb@tc'  < ../inputs/temp-test/2092.inp.886.2 > ../outputs/t4806
    if diff ../outputs/t4806 ../originals/t4806 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4807) timeout -s 9 2 ../source/replace.exe '[^0-9]-*' '&'  < ../inputs/temp-test/1014.inp.436.1 > ../outputs/t4807
    if diff ../outputs/t4807 ../originals/t4807 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4808) timeout -s 9 2 ../source/replace.exe '[^0-9]-*' '&'  < ../inputs/temp-test/1015.inp.436.2 > ../outputs/t4808
    if diff ../outputs/t4808 ../originals/t4808 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4809) timeout -s 9 2 ../source/replace.exe '[^0-9]--?@*-[9-B]@[' '@n'  < ../inputs/temp-test/1906.inp.809.1 > ../outputs/t4809
    if diff ../outputs/t4809 ../originals/t4809 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4810) timeout -s 9 2 ../source/replace.exe '[^0-9]--?@*-[9-B]@[' '@n'  < ../inputs/temp-test/1907.inp.809.2 > ../outputs/t4810
    if diff ../outputs/t4810 ../originals/t4810 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4811) timeout -s 9 2 ../source/replace.exe '[^0-9]-?' '&a@%'  < ../inputs/temp-test/2257.inp.957.1 > ../outputs/t4811
    if diff ../outputs/t4811 ../originals/t4811 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4812) timeout -s 9 2 ../source/replace.exe '[^0-9]-?' '&a@%'  < ../inputs/temp-test/2258.inp.957.3 > ../outputs/t4812
    if diff ../outputs/t4812 ../originals/t4812 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4813) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[9-B]*$' '@t'  < ../inputs/temp-test/525.inp.228.1 > ../outputs/t4813
    if diff ../outputs/t4813 ../originals/t4813 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4814) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[9-B]*' '@t'  < ../inputs/temp-test/525.inp.228.1 > ../outputs/t4814
    if diff ../outputs/t4814 ../originals/t4814 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4815) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[9-B]?-[9-B]*$' '@t'  < ../inputs/temp-test/526.inp.228.3 > ../outputs/t4815
    if diff ../outputs/t4815 ../originals/t4815 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4816) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[9-B]?-[9-B]*' '@t'  < ../inputs/temp-test/526.inp.228.3 > ../outputs/t4816
    if diff ../outputs/t4816 ../originals/t4816 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4817) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[9-B]?-[9-B]?'   < ../inputs/temp-test/525.inp.228.1 > ../outputs/t4817
    if diff ../outputs/t4817 ../originals/t4817 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4818) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[9-B]?-[9-B]?'   < ../inputs/temp-test/526.inp.228.3 > ../outputs/t4818
    if diff ../outputs/t4818 ../originals/t4818 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4819) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/525.inp.228.1 > ../outputs/t4819
    if diff ../outputs/t4819 ../originals/t4819 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4820) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/526.inp.228.3 > ../outputs/t4820
    if diff ../outputs/t4820 ../originals/t4820 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4821) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[][9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/525.inp.228.1 > ../outputs/t4821
    if diff ../outputs/t4821 ../originals/t4821 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4822) timeout -s 9 2 ../source/replace.exe '[^0-9]-?[^][9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/525.inp.228.1 > ../outputs/t4822
    if diff ../outputs/t4822 ../originals/t4822 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4823) timeout -s 9 2 ../source/replace.exe '[^0-9]-^-]??[9-B]?' '@t'  < ../inputs/temp-test/2321.inp.985.1 > ../outputs/t4823
    if diff ../outputs/t4823 ../originals/t4823 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4824) timeout -s 9 2 ../source/replace.exe '[^0-9]-^-]??[9-B]?' '@t'  < ../inputs/temp-test/2322.inp.985.3 > ../outputs/t4824
    if diff ../outputs/t4824 ../originals/t4824 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4825) timeout -s 9 2 ../source/replace.exe '[^0-9]?' '@%@&'  < ../inputs/temp-test/941.inp.404.1 > ../outputs/t4825
    if diff ../outputs/t4825 ../originals/t4825 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4826) timeout -s 9 2 ../source/replace.exe '[^0-9]?*' '@t'  < ../inputs/temp-test/525.inp.228.1 > ../outputs/t4826
    if diff ../outputs/t4826 ../originals/t4826 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4827) timeout -s 9 2 ../source/replace.exe '[^0-9]?*' '@t'  < ../inputs/temp-test/526.inp.228.3 > ../outputs/t4827
    if diff ../outputs/t4827 ../originals/t4827 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4828) timeout -s 9 2 ../source/replace.exe '[^0-9]?-?[^a--b]'   < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4828
    if diff ../outputs/t4828 ../originals/t4828 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4829) timeout -s 9 2 ../source/replace.exe '[^0-9]?-?[^a--b]' '&@n'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4829
    if diff ../outputs/t4829 ../originals/t4829 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4830) timeout -s 9 2 ../source/replace.exe '[^0-9]?-?[^a--b]' '&a@%'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4830
    if diff ../outputs/t4830 ../originals/t4830 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4831) timeout -s 9 2 ../source/replace.exe '[^0-9]?-?[^a--b]'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4831
    if diff ../outputs/t4831 ../originals/t4831 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4832) timeout -s 9 2 ../source/replace.exe '[^0-9]?-?[^a--b]*$' '&a@%'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4832
    if diff ../outputs/t4832 ../originals/t4832 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4833) timeout -s 9 2 ../source/replace.exe '[^0-9]?-?[^a--b]*$'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4833
    if diff ../outputs/t4833 ../originals/t4833 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4834) timeout -s 9 2 ../source/replace.exe '[^0-9]?-?[^a--b]*' '&a@%'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4834
    if diff ../outputs/t4834 ../originals/t4834 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4835) timeout -s 9 2 ../source/replace.exe '[^0-9]?-?[^a--b]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t4835
    if diff ../outputs/t4835 ../originals/t4835 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4836) timeout -s 9 2 ../source/replace.exe '[^0-9]?[^@@]a-]?A' ''  < ../inputs/temp-test/1432.inp.615.1 > ../outputs/t4836
    if diff ../outputs/t4836 ../originals/t4836 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4837) timeout -s 9 2 ../source/replace.exe '[^0-9]?[^@@]a-]?A' ''  < ../inputs/temp-test/1433.inp.615.2 > ../outputs/t4837
    if diff ../outputs/t4837 ../originals/t4837 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4838) timeout -s 9 2 ../source/replace.exe '[^0-9]?[^@@]a-]?A' ''  < ../inputs/temp-test/1434.inp.615.4 > ../outputs/t4838
    if diff ../outputs/t4838 ../originals/t4838 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4839) timeout -s 9 2 ../source/replace.exe '[^0-9]?[a-c] [^0-9]?[a-c]-[a--b]?^a-c]$' '&'  < ../inputs/temp-test/1269.inp.544.6 > ../outputs/t4839
    if diff ../outputs/t4839 ../originals/t4839 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4840) timeout -s 9 2 ../source/replace.exe '[^0-9]?[a-c] [^0-9]?[a-c]-[a--b]?^a-c]' '&'  < ../inputs/temp-test/1268.inp.544.1 > ../outputs/t4840
    if diff ../outputs/t4840 ../originals/t4840 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4841) timeout -s 9 2 ../source/replace.exe '[^0-9]?^[a-c]?[^a--?A*[^9-B]$' '@t'  < ../inputs/temp-test/1551.inp.663.9 > ../outputs/t4841
    if diff ../outputs/t4841 ../originals/t4841 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4842) timeout -s 9 2 ../source/replace.exe '[^0-9]?^[a-c]?[^a--?A*[^9-B]' '@t'  < ../inputs/temp-test/1549.inp.663.1 > ../outputs/t4842
    if diff ../outputs/t4842 ../originals/t4842 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4843) timeout -s 9 2 ../source/replace.exe '[^0-9]?^[a-c]?[^a--?A*[^9-B]' '@t'  < ../inputs/temp-test/1550.inp.663.2 > ../outputs/t4843
    if diff ../outputs/t4843 ../originals/t4843 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4844) timeout -s 9 2 ../source/replace.exe '[^0-9]@@' ''  < ../inputs/input/ruin.36 > ../outputs/t4844
    if diff ../outputs/t4844 ../originals/t4844 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4845) timeout -s 9 2 ../source/replace.exe '[^0-9]@@' 'b@t'  < ../inputs/temp-test/679.inp.295.1 > ../outputs/t4845
    if diff ../outputs/t4845 ../originals/t4845 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4846) timeout -s 9 2 ../source/replace.exe '[^0-9]@@' 'b@t'  < ../inputs/temp-test/680.inp.295.3 > ../outputs/t4846
    if diff ../outputs/t4846 ../originals/t4846 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4847) timeout -s 9 2 ../source/replace.exe '[^0-9]@[' '@%&a'  < ../inputs/temp-test/688.inp.299.1 > ../outputs/t4847
    if diff ../outputs/t4847 ../originals/t4847 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4848) timeout -s 9 2 ../source/replace.exe '[^0-9]@[' '@%&a'  < ../inputs/temp-test/689.inp.299.3 > ../outputs/t4848
    if diff ../outputs/t4848 ../originals/t4848 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4849) timeout -s 9 2 ../source/replace.exe '[^0-9]@[*' ''  < ../inputs/temp-test/1178.inp.508.1 > ../outputs/t4849
    if diff ../outputs/t4849 ../originals/t4849 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4850) timeout -s 9 2 ../source/replace.exe '[^0-9]@[*' ''  < ../inputs/temp-test/1179.inp.508.2 > ../outputs/t4850
    if diff ../outputs/t4850 ../originals/t4850 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4851) timeout -s 9 2 ../source/replace.exe '[^0-9]@[*' 'a&'  < ../inputs/temp-test/1821.inp.774.1 > ../outputs/t4851
    if diff ../outputs/t4851 ../originals/t4851 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4852) timeout -s 9 2 ../source/replace.exe '[^0-9]@[*- ?[^a-][9-B]- ' 'NEW'  < ../inputs/temp-test/58.inp.25.1 > ../outputs/t4852
    if diff ../outputs/t4852 ../originals/t4852 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4853) timeout -s 9 2 ../source/replace.exe '[^0-9]@[*- ?[^a-][9-B]- ' 'NEW'  < ../inputs/temp-test/59.inp.25.2 > ../outputs/t4853
    if diff ../outputs/t4853 ../originals/t4853 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4854) timeout -s 9 2 ../source/replace.exe '[^0-9]@[*- ?[^a-][9-B]- ' 'NEW'  < ../inputs/temp-test/60.inp.25.3 > ../outputs/t4854
    if diff ../outputs/t4854 ../originals/t4854 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4855) timeout -s 9 2 ../source/replace.exe '[^0-9]@n' '&a@%'  < ../inputs/temp-test/1498.inp.642.1 > ../outputs/t4855
    if diff ../outputs/t4855 ../originals/t4855 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4856) timeout -s 9 2 ../source/replace.exe '[^0-9]@n' '&a@%'  < ../inputs/temp-test/1499.inp.642.2 > ../outputs/t4856
    if diff ../outputs/t4856 ../originals/t4856 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4857) timeout -s 9 2 ../source/replace.exe '[^0-9]@t*$' '&a@%'  < ../inputs/temp-test/462.inp.202.9 > ../outputs/t4857
    if diff ../outputs/t4857 ../originals/t4857 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4858) timeout -s 9 2 ../source/replace.exe '[^0-9]@t*' '&a@%'  < ../inputs/temp-test/460.inp.202.1 > ../outputs/t4858
    if diff ../outputs/t4858 ../originals/t4858 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4859) timeout -s 9 2 ../source/replace.exe '[^0-9]A?' '@n'  < ../inputs/temp-test/1833.inp.780.1 > ../outputs/t4859
    if diff ../outputs/t4859 ../originals/t4859 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4860) timeout -s 9 2 ../source/replace.exe '[^0-9]A?' '@n'  < ../inputs/temp-test/1834.inp.780.2 > ../outputs/t4860
    if diff ../outputs/t4860 ../originals/t4860 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4861) timeout -s 9 2 ../source/replace.exe '[^0-9][0-9]$' 'a&'  < ../inputs/temp-test/1379.inp.591.9 > ../outputs/t4861
    if diff ../outputs/t4861 ../originals/t4861 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4862) timeout -s 9 2 ../source/replace.exe '[^0-9][0-9]' '&a@%'  < ../inputs/temp-test/621.inp.268.1 > ../outputs/t4862
    if diff ../outputs/t4862 ../originals/t4862 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4863) timeout -s 9 2 ../source/replace.exe '[^0-9][0-9]' '&a@%'  < ../inputs/temp-test/622.inp.268.3 > ../outputs/t4863
    if diff ../outputs/t4863 ../originals/t4863 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4864) timeout -s 9 2 ../source/replace.exe '[^0-9][0-9]' 'a&'  < ../inputs/temp-test/1377.inp.591.1 > ../outputs/t4864
    if diff ../outputs/t4864 ../originals/t4864 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4865) timeout -s 9 2 ../source/replace.exe '[^0-9][0-9]' 'a&'  < ../inputs/temp-test/1378.inp.591.4 > ../outputs/t4865
    if diff ../outputs/t4865 ../originals/t4865 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4866) timeout -s 9 2 ../source/replace.exe '[^0-9][0-9]' 'a@n'  < ../inputs/temp-test/2233.inp.947.1 > ../outputs/t4866
    if diff ../outputs/t4866 ../originals/t4866 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4867) timeout -s 9 2 ../source/replace.exe '[^0-9][0-9]' 'a@n'  < ../inputs/temp-test/2234.inp.947.2 > ../outputs/t4867
    if diff ../outputs/t4867 ../originals/t4867 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4868) timeout -s 9 2 ../source/replace.exe '[^0-9][0-9]' 'a@n'  < ../inputs/temp-test/2235.inp.947.4 > ../outputs/t4868
    if diff ../outputs/t4868 ../originals/t4868 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4869) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]' '&'  < ../inputs/temp-test/1106.inp.476.1 > ../outputs/t4869
    if diff ../outputs/t4869 ../originals/t4869 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4870) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]' '&'  < ../inputs/temp-test/1107.inp.476.2 > ../outputs/t4870
    if diff ../outputs/t4870 ../originals/t4870 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4871) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]' '&'  < ../inputs/temp-test/1108.inp.476.3 > ../outputs/t4871
    if diff ../outputs/t4871 ../originals/t4871 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4872) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]' '&a@%'  < ../inputs/temp-test/1172.inp.505.1 > ../outputs/t4872
    if diff ../outputs/t4872 ../originals/t4872 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4873) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]' '&a@%'  < ../inputs/temp-test/1173.inp.505.2 > ../outputs/t4873
    if diff ../outputs/t4873 ../originals/t4873 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4874) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]' '&a@%'  < ../inputs/temp-test/1174.inp.505.3 > ../outputs/t4874
    if diff ../outputs/t4874 ../originals/t4874 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4875) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]' ''  < ../inputs/temp-test/1175.inp.506.1 > ../outputs/t4875
    if diff ../outputs/t4875 ../originals/t4875 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4876) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]' ''  < ../inputs/temp-test/1176.inp.506.3 > ../outputs/t4876
    if diff ../outputs/t4876 ../originals/t4876 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4877) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]*' '@%&a'  < ../inputs/temp-test/139.inp.65.1 > ../outputs/t4877
    if diff ../outputs/t4877 ../originals/t4877 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4878) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]*' '@%&a'  < ../inputs/temp-test/140.inp.65.2 > ../outputs/t4878
    if diff ../outputs/t4878 ../originals/t4878 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4879) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]*' '@%&a'  < ../inputs/temp-test/141.inp.65.3 > ../outputs/t4879
    if diff ../outputs/t4879 ../originals/t4879 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4880) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]?' '&a@%'  < ../inputs/temp-test/1146.inp.493.1 > ../outputs/t4880
    if diff ../outputs/t4880 ../originals/t4880 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4881) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B]?' '&a@%'  < ../inputs/temp-test/1147.inp.493.2 > ../outputs/t4881
    if diff ../outputs/t4881 ../originals/t4881 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4882) timeout -s 9 2 ../source/replace.exe '[^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B][^0-9][9-B]' '&a@%'  < ../inputs/temp-test/1172.inp.505.1 > ../outputs/t4882
    if diff ../outputs/t4882 ../originals/t4882 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4883) timeout -s 9 2 ../source/replace.exe '[^0-9][]?-?[^a--b]' '&a@%'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4883
    if diff ../outputs/t4883 ../originals/t4883 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4884) timeout -s 9 2 ../source/replace.exe '[^0-9][^0-9]@n@@@@' '9oW5!fFgN1 7tZf>k'  < ../inputs/input/ruin.927 > ../outputs/t4884
    if diff ../outputs/t4884 ../originals/t4884 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4885) timeout -s 9 2 ../source/replace.exe '[^0-9][^0-9][^9-B]' '@n'  < ../inputs/temp-test/1952.inp.829.1 > ../outputs/t4885
    if diff ../outputs/t4885 ../originals/t4885 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4886) timeout -s 9 2 ../source/replace.exe '[^0-9][^0-9][^9-B]' '@n'  < ../inputs/temp-test/1953.inp.829.2 > ../outputs/t4886
    if diff ../outputs/t4886 ../originals/t4886 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4887) timeout -s 9 2 ../source/replace.exe '[^0-9][^0-9][^9-B]' '@n'  < ../inputs/temp-test/1954.inp.829.3 > ../outputs/t4887
    if diff ../outputs/t4887 ../originals/t4887 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4888) timeout -s 9 2 ../source/replace.exe '[^0-9][^]?-?[^a--b]' '&a@%'  < ../inputs/temp-test/206.inp.92.1 > ../outputs/t4888
    if diff ../outputs/t4888 ../originals/t4888 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4889) timeout -s 9 2 ../source/replace.exe '[^0-9][a--]' '&@n'  < ../inputs/temp-test/696.inp.301.2 > ../outputs/t4889
    if diff ../outputs/t4889 ../originals/t4889 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4890) timeout -s 9 2 ../source/replace.exe '[^0-9][a--]' '&@n'  < ../inputs/temp-test/697.inp.301.4 > ../outputs/t4890
    if diff ../outputs/t4890 ../originals/t4890 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4891) timeout -s 9 2 ../source/replace.exe '[^0-9][a--]' '&@n@tandsome'  < ../inputs/temp-test/697.inp.301.4 > ../outputs/t4891
    if diff ../outputs/t4891 ../originals/t4891 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4892) timeout -s 9 2 ../source/replace.exe '[^0-9][a--]' '&@nmoretext'  < ../inputs/temp-test/696.inp.301.2 > ../outputs/t4892
    if diff ../outputs/t4892 ../originals/t4892 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4893) timeout -s 9 2 ../source/replace.exe '[^0-9][a--]- ' '&@n'  < ../inputs/temp-test/695.inp.301.1 > ../outputs/t4893
    if diff ../outputs/t4893 ../originals/t4893 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4894) timeout -s 9 2 ../source/replace.exe '[^0-9][a--]- *[^@t]-?' '@t'  < ../inputs/temp-test/695.inp.301.1 > ../outputs/t4894
    if diff ../outputs/t4894 ../originals/t4894 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4895) timeout -s 9 2 ../source/replace.exe '[^0-9][a--]- *[^@t]-?' '@t'  < ../inputs/temp-test/696.inp.301.2 > ../outputs/t4895
    if diff ../outputs/t4895 ../originals/t4895 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4896) timeout -s 9 2 ../source/replace.exe '[^0-9][a--]- *[^@t]-?' '@t'  < ../inputs/temp-test/697.inp.301.4 > ../outputs/t4896
    if diff ../outputs/t4896 ../originals/t4896 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4897) timeout -s 9 2 ../source/replace.exe '[^0-9][a--][^9-B][^-z]' 'a@nb@tc'  < ../inputs/temp-test/2254.inp.956.1 > ../outputs/t4897
    if diff ../outputs/t4897 ../originals/t4897 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4898) timeout -s 9 2 ../source/replace.exe '[^0-9][a--][^9-B][^-z]' 'a@nb@tc'  < ../inputs/temp-test/2255.inp.956.2 > ../outputs/t4898
    if diff ../outputs/t4898 ../originals/t4898 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4899) timeout -s 9 2 ../source/replace.exe '[^0-9][a-]' ''  < ../inputs/temp-test/147.inp.68.1 > ../outputs/t4899
    if diff ../outputs/t4899 ../originals/t4899 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4900) timeout -s 9 2 ../source/replace.exe '[^0-9][a-]' ''  < ../inputs/temp-test/148.inp.68.2 > ../outputs/t4900
    if diff ../outputs/t4900 ../originals/t4900 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4901) timeout -s 9 2 ../source/replace.exe '[^0-9][a-]' ''  < ../inputs/temp-test/149.inp.68.3 > ../outputs/t4901
    if diff ../outputs/t4901 ../originals/t4901 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4902) timeout -s 9 2 ../source/replace.exe '[^0-9][a-]' ''  < ../inputs/temp-test/150.inp.68.4 > ../outputs/t4902
    if diff ../outputs/t4902 ../originals/t4902 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4903) timeout -s 9 2 ../source/replace.exe '[^0-9][a-c?--[^0-9][^9-B]?' '@n'  < ../inputs/temp-test/1396.inp.599.1 > ../outputs/t4903
    if diff ../outputs/t4903 ../originals/t4903 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4904) timeout -s 9 2 ../source/replace.exe '[^0-9][a-c]' ''  < ../inputs/temp-test/726.inp.313.1 > ../outputs/t4904
    if diff ../outputs/t4904 ../originals/t4904 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4905) timeout -s 9 2 ../source/replace.exe '[^0-9][a-c]' ''  < ../inputs/temp-test/727.inp.313.2 > ../outputs/t4905
    if diff ../outputs/t4905 ../originals/t4905 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4906) timeout -s 9 2 ../source/replace.exe '[^0-9]\q2#' 'N_j  maExCfe(RK#?/SXIIyOqB[%kuLjKCnrk'  < ../inputs/input/ruin.853 > ../outputs/t4906
    if diff ../outputs/t4906 ../originals/t4906 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4907) timeout -s 9 2 ../source/replace.exe '[^0-9]^$' '@%&a'  < ../inputs/temp-test/1011.inp.434.8 > ../outputs/t4907
    if diff ../outputs/t4907 ../originals/t4907 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4908) timeout -s 9 2 ../source/replace.exe '[^0-9]^' '@%&a'  < ../inputs/temp-test/1009.inp.434.1 > ../outputs/t4908
    if diff ../outputs/t4908 ../originals/t4908 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4909) timeout -s 9 2 ../source/replace.exe '[^0-9]^' '@%&a'  < ../inputs/temp-test/1010.inp.434.2 > ../outputs/t4909
    if diff ../outputs/t4909 ../originals/t4909 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4910) timeout -s 9 2 ../source/replace.exe '[^0-9]^*[0-9]?[0-9]-c-@@*[9-B][^-z]?' '@n'  < ../inputs/temp-test/1068.inp.459.1 > ../outputs/t4910
    if diff ../outputs/t4910 ../originals/t4910 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4911) timeout -s 9 2 ../source/replace.exe '[^0-9]^*[0-9]?[0-9]-c-@@*[9-B][^-z]?' '@n'  < ../inputs/temp-test/1069.inp.459.3 > ../outputs/t4911
    if diff ../outputs/t4911 ../originals/t4911 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4912) timeout -s 9 2 ../source/replace.exe '[^0-9]a-c]-@*?' 'a@nb@tc'  < ../inputs/temp-test/851.inp.366.1 > ../outputs/t4912
    if diff ../outputs/t4912 ../originals/t4912 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4913) timeout -s 9 2 ../source/replace.exe '[^0-9]a-c]-@*?' 'a@nb@tc'  < ../inputs/temp-test/852.inp.366.3 > ../outputs/t4913
    if diff ../outputs/t4913 ../originals/t4913 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4914) timeout -s 9 2 ../source/replace.exe '[^0-9o]' 'A'  < ../inputs/input/ruin.1222 > ../outputs/t4914
    if diff ../outputs/t4914 ../originals/t4914 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4915) timeout -s 9 2 ../source/replace.exe '[^0-9z-}c-a]' 'X'  < ../inputs/input/ruin.1842 > ../outputs/t4915
    if diff ../outputs/t4915 ../originals/t4915 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4916) timeout -s 9 2 ../source/replace.exe '[^0[^0-9]-?[9-B]?-[9-B]?[^0-9]-?[9-B]?-[9-B]?[^0-9]-?[9-B]?-[9-B]?[^0-9]-?[9-B]?-[9-B]?[^0-9]-?[9-B]?-[9-B]?[^0-9]-?[9-B]?-[9-B]?[^0-9]-?[9-B]?-[9-B]?[^0-9]-?[9-B]?-[9-B]?-9]-?[9-B]?-[9-B]*?[[^0-9]-?[9-B]?-[9-B]?^0-9]*-?[9-B]?-[9-B]?' 'a'  < ../inputs/input/ruin.1517 > ../outputs/t4916
    if diff ../outputs/t4916 ../originals/t4916 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4917) timeout -s 9 2 ../source/replace.exe '[^1]' 'Iaz-cZ"a'\''A:(eeGG\^<6w1DDcCJ,9$Yr26[8Ap4Xuo=ZZ%dkomXc8sOhWnlrc0S'  < ../inputs/input/ruin.1248 > ../outputs/t4917
    if diff ../outputs/t4917 ../originals/t4917 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4918) timeout -s 9 2 ../source/replace.exe '[^1]*$' 'Iaz-cZ"a'\''A:(eeGG\^<6w1DDcCJ,9$Yr26[8Ap4Xuo=ZZ%dkomXc8sOhWnlrc0S'  < ../inputs/input/ruin.1248 > ../outputs/t4918
    if diff ../outputs/t4918 ../originals/t4918 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4919) timeout -s 9 2 ../source/replace.exe '[^2]' '!'  < ../inputs/input/ruin.558 > ../outputs/t4919
    if diff ../outputs/t4919 ../originals/t4919 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4920) timeout -s 9 2 ../source/replace.exe '[^4]' 'H'  < ../inputs/input/ruin.50 > ../outputs/t4920
    if diff ../outputs/t4920 ../originals/t4920 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4921) timeout -s 9 2 ../source/replace.exe '[^6]' 'p7/\=6eLD*=^?('  < ../inputs/input/ruin.1297 > ../outputs/t4921
    if diff ../outputs/t4921 ../originals/t4921 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4922) timeout -s 9 2 ../source/replace.exe '[^6]*?' '%'  < ../inputs/moni/f7.inp > ../outputs/t4922
    if diff ../outputs/t4922 ../originals/t4922 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4923) timeout -s 9 2 ../source/replace.exe '[^9-B] *' '&a@%'  < ../inputs/temp-test/2074.inp.879.1 > ../outputs/t4923
    if diff ../outputs/t4923 ../originals/t4923 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4924) timeout -s 9 2 ../source/replace.exe '[^9-B] *' '&a@%'  < ../inputs/temp-test/2075.inp.879.3 > ../outputs/t4924
    if diff ../outputs/t4924 ../originals/t4924 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4925) timeout -s 9 2 ../source/replace.exe '[^9-B] *' 'a&'  < ../inputs/temp-test/295.inp.133.1 > ../outputs/t4925
    if diff ../outputs/t4925 ../originals/t4925 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4926) timeout -s 9 2 ../source/replace.exe '[^9-B] *' 'a&'  < ../inputs/temp-test/296.inp.133.2 > ../outputs/t4926
    if diff ../outputs/t4926 ../originals/t4926 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4927) timeout -s 9 2 ../source/replace.exe '[^9-B] *' 'a&'  < ../inputs/temp-test/297.inp.133.3 > ../outputs/t4927
    if diff ../outputs/t4927 ../originals/t4927 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4928) timeout -s 9 2 ../source/replace.exe '[^9-B] *' 'a@n'  < ../inputs/temp-test/1748.inp.743.1 > ../outputs/t4928
    if diff ../outputs/t4928 ../originals/t4928 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4929) timeout -s 9 2 ../source/replace.exe '[^9-B] *' 'a@n'  < ../inputs/temp-test/1749.inp.743.2 > ../outputs/t4929
    if diff ../outputs/t4929 ../originals/t4929 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4930) timeout -s 9 2 ../source/replace.exe '[^9-B] *' 'a@n'  < ../inputs/temp-test/1750.inp.743.3 > ../outputs/t4930
    if diff ../outputs/t4930 ../originals/t4930 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4931) timeout -s 9 2 ../source/replace.exe '[^9-B]' '&@n$'  < ../inputs/temp-test/640.inp.276.2 > ../outputs/t4931
    if diff ../outputs/t4931 ../originals/t4931 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4932) timeout -s 9 2 ../source/replace.exe '[^9-B]' '&@n'  < ../inputs/temp-test/639.inp.276.1 > ../outputs/t4932
    if diff ../outputs/t4932 ../originals/t4932 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4933) timeout -s 9 2 ../source/replace.exe '[^9-B]' '&@n'  < ../inputs/temp-test/640.inp.276.2 > ../outputs/t4933
    if diff ../outputs/t4933 ../originals/t4933 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4934) timeout -s 9 2 ../source/replace.exe '[^9-B]' '&@n^'  < ../inputs/temp-test/639.inp.276.1 > ../outputs/t4934
    if diff ../outputs/t4934 ../originals/t4934 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4935) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'NEW'  < ../inputs/temp-test/398.inp.174.1 > ../outputs/t4935
    if diff ../outputs/t4935 ../originals/t4935 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4936) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'NEW'  < ../inputs/temp-test/399.inp.174.2 > ../outputs/t4936
    if diff ../outputs/t4936 ../originals/t4936 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4937) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'NEW'  < ../inputs/temp-test/400.inp.174.3 > ../outputs/t4937
    if diff ../outputs/t4937 ../originals/t4937 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4938) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'a&'  < ../inputs/temp-test/1537.inp.658.1 > ../outputs/t4938
    if diff ../outputs/t4938 ../originals/t4938 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4939) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'a&'  < ../inputs/temp-test/1538.inp.658.3 > ../outputs/t4939
    if diff ../outputs/t4939 ../originals/t4939 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4940) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'a@n'  < ../inputs/temp-test/76.inp.33.1 > ../outputs/t4940
    if diff ../outputs/t4940 ../originals/t4940 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4941) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'a@n'  < ../inputs/temp-test/77.inp.33.3 > ../outputs/t4941
    if diff ../outputs/t4941 ../originals/t4941 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4942) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'a@n'  < ../inputs/temp-test/78.inp.33.4 > ../outputs/t4942
    if diff ../outputs/t4942 ../originals/t4942 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4943) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'a@nb@tc'  < ../inputs/temp-test/1119.inp.481.1 > ../outputs/t4943
    if diff ../outputs/t4943 ../originals/t4943 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4944) timeout -s 9 2 ../source/replace.exe '[^9-B]' 'a@nb@tc'  < ../inputs/temp-test/1120.inp.481.3 > ../outputs/t4944
    if diff ../outputs/t4944 ../originals/t4944 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4945) timeout -s 9 2 ../source/replace.exe '[^9-B]*$' 'a@n'  < ../inputs/temp-test/220.inp.98.2 > ../outputs/t4945
    if diff ../outputs/t4945 ../originals/t4945 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4946) timeout -s 9 2 ../source/replace.exe '[^9-B]*$' 'a@n'  < ../inputs/temp-test/221.inp.98.3 > ../outputs/t4946
    if diff ../outputs/t4946 ../originals/t4946 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4947) timeout -s 9 2 ../source/replace.exe '[^9-B]*' 'a@n'  < ../inputs/temp-test/220.inp.98.2 > ../outputs/t4947
    if diff ../outputs/t4947 ../originals/t4947 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4948) timeout -s 9 2 ../source/replace.exe '[^9-B]*' 'a@n'  < ../inputs/temp-test/221.inp.98.3 > ../outputs/t4948
    if diff ../outputs/t4948 ../originals/t4948 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4949) timeout -s 9 2 ../source/replace.exe '[^9-B]*'  < ../inputs/temp-test/219.inp.98.1 > ../outputs/t4949
    if diff ../outputs/t4949 ../originals/t4949 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4950) timeout -s 9 2 ../source/replace.exe '[^9-B]**'  'a'  < ../inputs/moni/f7.inp > ../outputs/t4950
    if diff ../outputs/t4950 ../originals/t4950 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4951) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '&a@%'  < ../inputs/temp-test/639.inp.276.1 > ../outputs/t4951
    if diff ../outputs/t4951 ../originals/t4951 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4952) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '&a@%'  < ../inputs/temp-test/640.inp.276.2 > ../outputs/t4952
    if diff ../outputs/t4952 ../originals/t4952 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4953) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '@%&a'  < ../inputs/temp-test/2128.inp.902.1 > ../outputs/t4953
    if diff ../outputs/t4953 ../originals/t4953 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4954) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '@%&a'  < ../inputs/temp-test/2129.inp.902.2 > ../outputs/t4954
    if diff ../outputs/t4954 ../originals/t4954 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4955) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '@%&a'  < ../inputs/temp-test/2130.inp.902.3 > ../outputs/t4955
    if diff ../outputs/t4955 ../originals/t4955 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4956) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '@%@&'  < ../inputs/temp-test/1500.inp.643.1 > ../outputs/t4956
    if diff ../outputs/t4956 ../originals/t4956 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4957) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '@%@&'  < ../inputs/temp-test/1501.inp.643.2 > ../outputs/t4957
    if diff ../outputs/t4957 ../originals/t4957 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4958) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '@n'  < ../inputs/temp-test/2183.inp.924.1 > ../outputs/t4958
    if diff ../outputs/t4958 ../originals/t4958 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4959) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '@n'  < ../inputs/temp-test/2184.inp.924.2 > ../outputs/t4959
    if diff ../outputs/t4959 ../originals/t4959 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4960) timeout -s 9 2 ../source/replace.exe '[^9-B]-' '@n'  < ../inputs/temp-test/2185.inp.924.3 > ../outputs/t4960
    if diff ../outputs/t4960 ../originals/t4960 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4961) timeout -s 9 2 ../source/replace.exe '[^9-B]-' 'b@t'  < ../inputs/temp-test/886.inp.381.1 > ../outputs/t4961
    if diff ../outputs/t4961 ../originals/t4961 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4962) timeout -s 9 2 ../source/replace.exe '[^9-B]-' 'b@t'  < ../inputs/temp-test/887.inp.381.2 > ../outputs/t4962
    if diff ../outputs/t4962 ../originals/t4962 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4963) timeout -s 9 2 ../source/replace.exe '[^9-B]-*' 'b@t'  < ../inputs/temp-test/1606.inp.683.1 > ../outputs/t4963
    if diff ../outputs/t4963 ../originals/t4963 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4964) timeout -s 9 2 ../source/replace.exe '[^9-B]-*' 'b@t'  < ../inputs/temp-test/1607.inp.683.2 > ../outputs/t4964
    if diff ../outputs/t4964 ../originals/t4964 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4965) timeout -s 9 2 ../source/replace.exe '[^9-B]-*' 'b@t'  < ../inputs/temp-test/1608.inp.683.4 > ../outputs/t4965
    if diff ../outputs/t4965 ../originals/t4965 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4966) timeout -s 9 2 ../source/replace.exe '[^9-B]--?[9-B]-[a--b]-?^?[^9-B]' '@%&a'  < ../inputs/temp-test/1035.inp.445.1 > ../outputs/t4966
    if diff ../outputs/t4966 ../originals/t4966 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4967) timeout -s 9 2 ../source/replace.exe '[^9-B]--?[9-B]-[a--b]-?^?[^9-B]' '@%&a'  < ../inputs/temp-test/1036.inp.445.3 > ../outputs/t4967
    if diff ../outputs/t4967 ../originals/t4967 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4968) timeout -s 9 2 ../source/replace.exe '[^9-B]--[a--b][^9-B]?[a--b]-' '@%&a'  < ../inputs/temp-test/1581.inp.674.1 > ../outputs/t4968
    if diff ../outputs/t4968 ../originals/t4968 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4969) timeout -s 9 2 ../source/replace.exe '[^9-B]--[a--b][^9-B]?[a--b]-' '@%&a'  < ../inputs/temp-test/1582.inp.674.2 > ../outputs/t4969
    if diff ../outputs/t4969 ../originals/t4969 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4970) timeout -s 9 2 ../source/replace.exe '[^9-B]--[a--b][^9-B]?[a--b]-' '@%&a'  < ../inputs/temp-test/1583.inp.674.3 > ../outputs/t4970
    if diff ../outputs/t4970 ../originals/t4970 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4971) timeout -s 9 2 ../source/replace.exe '[^9-B]-@**[^9-B]?-*' 'b@t'  < ../inputs/temp-test/1628.inp.692.1 > ../outputs/t4971
    if diff ../outputs/t4971 ../originals/t4971 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4972) timeout -s 9 2 ../source/replace.exe '[^9-B]-[^0-9]?[^9-B]--??^-[^a--b]-?' '@t'  < ../inputs/temp-test/780.inp.336.1 > ../outputs/t4972
    if diff ../outputs/t4972 ../originals/t4972 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4973) timeout -s 9 2 ../source/replace.exe '[^9-B]-[^0-9]?[^9-B]--??^-[^a--b]-?' '@t'  < ../inputs/temp-test/781.inp.336.2 > ../outputs/t4973
    if diff ../outputs/t4973 ../originals/t4973 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4974) timeout -s 9 2 ../source/replace.exe '[^9-B]-[^0-9]?[^9-B]--??^-[^a--b]-?' '@t'  < ../inputs/temp-test/782.inp.336.3 > ../outputs/t4974
    if diff ../outputs/t4974 ../originals/t4974 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4975) timeout -s 9 2 ../source/replace.exe '[^9-B]-[^9-B][9-B]-[0-9]' '@t'  < ../inputs/temp-test/356.inp.156.1 > ../outputs/t4975
    if diff ../outputs/t4975 ../originals/t4975 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4976) timeout -s 9 2 ../source/replace.exe '[^9-B]-[^9-B][9-B]-[0-9]' '@t'  < ../inputs/temp-test/357.inp.156.3 > ../outputs/t4976
    if diff ../outputs/t4976 ../originals/t4976 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4977) timeout -s 9 2 ../source/replace.exe '[^9-B]-[^9-B][9-B]-[0-9]' '@t@'  < ../inputs/temp-test/357.inp.156.3 > ../outputs/t4977
    if diff ../outputs/t4977 ../originals/t4977 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4978) timeout -s 9 2 ../source/replace.exe '[^9-B]-[^9-B][9-B]-[0-9]@' '@t'  < ../inputs/temp-test/356.inp.156.1 > ../outputs/t4978
    if diff ../outputs/t4978 ../originals/t4978 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4979) timeout -s 9 2 ../source/replace.exe '[^9-B]? -?-[9-B]-[^9-B][^9-B]-' '&a@%'  < ../inputs/temp-test/1317.inp.565.1 > ../outputs/t4979
    if diff ../outputs/t4979 ../originals/t4979 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4980) timeout -s 9 2 ../source/replace.exe '[^9-B]? -?-[9-B]-[^9-B][^9-B]-' '&a@%'  < ../inputs/temp-test/1318.inp.565.3 > ../outputs/t4980
    if diff ../outputs/t4980 ../originals/t4980 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4981) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '&'  < ../inputs/temp-test/1603.inp.682.1 > ../outputs/t4981
    if diff ../outputs/t4981 ../originals/t4981 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4982) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '&'  < ../inputs/temp-test/1604.inp.682.2 > ../outputs/t4982
    if diff ../outputs/t4982 ../originals/t4982 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4983) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '&'  < ../inputs/temp-test/1605.inp.682.3 > ../outputs/t4983
    if diff ../outputs/t4983 ../originals/t4983 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4984) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '&'  < ../inputs/temp-test/2158.inp.914.1 > ../outputs/t4984
    if diff ../outputs/t4984 ../originals/t4984 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4985) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '&'  < ../inputs/temp-test/2159.inp.914.2 > ../outputs/t4985
    if diff ../outputs/t4985 ../originals/t4985 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4986) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '&'  < ../inputs/temp-test/2160.inp.914.3 > ../outputs/t4986
    if diff ../outputs/t4986 ../originals/t4986 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4987) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '@%&a'  < ../inputs/temp-test/1874.inp.795.1 > ../outputs/t4987
    if diff ../outputs/t4987 ../originals/t4987 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4988) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '@%&a'  < ../inputs/temp-test/1875.inp.795.3 > ../outputs/t4988
    if diff ../outputs/t4988 ../originals/t4988 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4989) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '@%&a'  < ../inputs/temp-test/1876.inp.795.4 > ../outputs/t4989
    if diff ../outputs/t4989 ../originals/t4989 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4990) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '@%@&'  < ../inputs/temp-test/1157.inp.498.1 > ../outputs/t4990
    if diff ../outputs/t4990 ../originals/t4990 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4991) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '@%@&'  < ../inputs/temp-test/1553.inp.665.1 > ../outputs/t4991
    if diff ../outputs/t4991 ../originals/t4991 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4992) timeout -s 9 2 ../source/replace.exe '[^9-B]?' '@%@&'  < ../inputs/temp-test/1554.inp.665.2 > ../outputs/t4992
    if diff ../outputs/t4992 ../originals/t4992 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4993) timeout -s 9 2 ../source/replace.exe '[^9-B]?' 'NEW'  < ../inputs/temp-test/1080.inp.465.1 > ../outputs/t4993
    if diff ../outputs/t4993 ../originals/t4993 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4994) timeout -s 9 2 ../source/replace.exe '[^9-B]?' 'NEW'  < ../inputs/temp-test/507.inp.221.1 > ../outputs/t4994
    if diff ../outputs/t4994 ../originals/t4994 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4995) timeout -s 9 2 ../source/replace.exe '[^9-B]?' 'NEW'  < ../inputs/temp-test/508.inp.221.3 > ../outputs/t4995
    if diff ../outputs/t4995 ../originals/t4995 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4996) timeout -s 9 2 ../source/replace.exe '[^9-B]?-' '&'  < ../inputs/temp-test/439.inp.193.1 > ../outputs/t4996
    if diff ../outputs/t4996 ../originals/t4996 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4997) timeout -s 9 2 ../source/replace.exe '[^9-B]?-' '&'  < ../inputs/temp-test/440.inp.193.2 > ../outputs/t4997
    if diff ../outputs/t4997 ../originals/t4997 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4998) timeout -s 9 2 ../source/replace.exe '[^9-B]?-' '&'  < ../inputs/temp-test/441.inp.193.3 > ../outputs/t4998
    if diff ../outputs/t4998 ../originals/t4998 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p4999) timeout -s 9 2 ../source/replace.exe '[^9-B]?-' '&'  < ../inputs/temp-test/442.inp.193.4 > ../outputs/t4999
    if diff ../outputs/t4999 ../originals/t4999 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5000) timeout -s 9 2 ../source/replace.exe '[^9-B]?-?[^a--b]-' ''  < ../inputs/temp-test/969.inp.418.1 > ../outputs/t5000
    if diff ../outputs/t5000 ../originals/t5000 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5001) timeout -s 9 2 ../source/replace.exe '[^9-B]?-?[^a--b]-' ''  < ../inputs/temp-test/970.inp.418.2 > ../outputs/t5001
    if diff ../outputs/t5001 ../originals/t5001 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5002) timeout -s 9 2 ../source/replace.exe '[^9-B]?-?[^a--b]-' ''  < ../inputs/temp-test/971.inp.418.3 > ../outputs/t5002
    if diff ../outputs/t5002 ../originals/t5002 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5003) timeout -s 9 2 ../source/replace.exe '[^9-B]?-[^0-9]' '&'  < ../inputs/temp-test/1912.inp.812.1 > ../outputs/t5003
    if diff ../outputs/t5003 ../originals/t5003 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5004) timeout -s 9 2 ../source/replace.exe '[^9-B]?-[^0-9]' '&'  < ../inputs/temp-test/1913.inp.812.3 > ../outputs/t5004
    if diff ../outputs/t5004 ../originals/t5004 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5005) timeout -s 9 2 ../source/replace.exe '[^9-B]?-[^9-B]-*-[^9-B][^0-9]-*-[^0-9]' '@%&a'  < ../inputs/temp-test/1081.inp.466.1 > ../outputs/t5005
    if diff ../outputs/t5005 ../originals/t5005 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5006) timeout -s 9 2 ../source/replace.exe '[^9-B]?-[^9-B]-*-[^9-B][^0-9]-*-[^0-9]' '@%&a'  < ../inputs/temp-test/1082.inp.466.3 > ../outputs/t5006
    if diff ../outputs/t5006 ../originals/t5006 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5007) timeout -s 9 2 ../source/replace.exe '[^9-B]??[a-c]?[^9-B]-' '&'  < ../inputs/temp-test/656.inp.285.1 > ../outputs/t5007
    if diff ../outputs/t5007 ../originals/t5007 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5008) timeout -s 9 2 ../source/replace.exe '[^9-B]?[9-B]a-c]' '&'  < ../inputs/temp-test/242.inp.108.1 > ../outputs/t5008
    if diff ../outputs/t5008 ../originals/t5008 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5009) timeout -s 9 2 ../source/replace.exe '[^9-B]?[9-B]a-c]' '&'  < ../inputs/temp-test/243.inp.108.3 > ../outputs/t5009
    if diff ../outputs/t5009 ../originals/t5009 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5010) timeout -s 9 2 ../source/replace.exe '[^9-B]?[^a-]-' '@%&a'  < ../inputs/temp-test/2188.inp.926.1 > ../outputs/t5010
    if diff ../outputs/t5010 ../originals/t5010 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5011) timeout -s 9 2 ../source/replace.exe '[^9-B]?[a-c-?a-][^a-]-?-[9-B][0-9][^a-c*[0-9][^0-9]@[[9-B][^a-c]$' ''  < ../inputs/temp-test/1223.inp.525.6 > ../outputs/t5011
    if diff ../outputs/t5011 ../originals/t5011 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5012) timeout -s 9 2 ../source/replace.exe '[^9-B]?[a-c-?a-][^a-]-?-[9-B][0-9][^a-c*[0-9][^0-9]@[[9-B][^a-c]' ''  < ../inputs/temp-test/1221.inp.525.1 > ../outputs/t5012
    if diff ../outputs/t5012 ../originals/t5012 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5013) timeout -s 9 2 ../source/replace.exe '[^9-B]?[a-c-?a-][^a-]-?-[9-B][0-9][^a-c*[0-9][^0-9]@[[9-B][^a-c]' ''  < ../inputs/temp-test/1222.inp.525.4 > ../outputs/t5013
    if diff ../outputs/t5013 ../originals/t5013 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5014) timeout -s 9 2 ../source/replace.exe '[^9-B]@*' '@%&a'  < ../inputs/temp-test/2270.inp.962.1 > ../outputs/t5014
    if diff ../outputs/t5014 ../originals/t5014 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5015) timeout -s 9 2 ../source/replace.exe '[^9-B]@*' '@%&a'  < ../inputs/temp-test/2271.inp.962.2 > ../outputs/t5015
    if diff ../outputs/t5015 ../originals/t5015 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5016) timeout -s 9 2 ../source/replace.exe '[^9-B]@*' '@%&a'  < ../inputs/temp-test/2272.inp.962.3 > ../outputs/t5016
    if diff ../outputs/t5016 ../originals/t5016 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5017) timeout -s 9 2 ../source/replace.exe '[^9-B]@**' ''  < ../inputs/temp-test/1285.inp.552.1 > ../outputs/t5017
    if diff ../outputs/t5017 ../originals/t5017 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5018) timeout -s 9 2 ../source/replace.exe '[^9-B]@**' ''  < ../inputs/temp-test/1286.inp.552.2 > ../outputs/t5018
    if diff ../outputs/t5018 ../originals/t5018 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5019) timeout -s 9 2 ../source/replace.exe '[^9-B]@**' '@%@&'  < ../inputs/temp-test/1916.inp.814.1 > ../outputs/t5019
    if diff ../outputs/t5019 ../originals/t5019 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5020) timeout -s 9 2 ../source/replace.exe '[^9-B]@**-[^a-^*-^-]^*' 'a@nb@tc'  < ../inputs/temp-test/1281.inp.550.1 > ../outputs/t5020
    if diff ../outputs/t5020 ../originals/t5020 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5021) timeout -s 9 2 ../source/replace.exe '[^9-B]@*^[^-z]-?[9-B]?-[0-9][^a-c[9-B]$' 'a@n'  < ../inputs/temp-test/452.inp.197.6 > ../outputs/t5021
    if diff ../outputs/t5021 ../originals/t5021 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5022) timeout -s 9 2 ../source/replace.exe '[^9-B]@*^[^-z]-?[9-B]?-[0-9][^a-c[9-B]' 'a@n'  < ../inputs/temp-test/450.inp.197.1 > ../outputs/t5022
    if diff ../outputs/t5022 ../originals/t5022 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5023) timeout -s 9 2 ../source/replace.exe '[^9-B]@*^[^-z]-?[9-B]?-[0-9][^a-c[9-B]' 'a@n'  < ../inputs/temp-test/451.inp.197.3 > ../outputs/t5023
    if diff ../outputs/t5023 ../originals/t5023 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5024) timeout -s 9 2 ../source/replace.exe '[^9-B]@['   < ../inputs/temp-test/220.inp.98.2 > ../outputs/t5024
    if diff ../outputs/t5024 ../originals/t5024 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5025) timeout -s 9 2 ../source/replace.exe '[^9-B]@['   < ../inputs/temp-test/221.inp.98.3 > ../outputs/t5025
    if diff ../outputs/t5025 ../originals/t5025 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5026) timeout -s 9 2 ../source/replace.exe '[^9-B]@[' 'a@n'  < ../inputs/temp-test/219.inp.98.1 > ../outputs/t5026
    if diff ../outputs/t5026 ../originals/t5026 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5027) timeout -s 9 2 ../source/replace.exe '[^9-B]@[' 'a@n'  < ../inputs/temp-test/220.inp.98.2 > ../outputs/t5027
    if diff ../outputs/t5027 ../originals/t5027 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5028) timeout -s 9 2 ../source/replace.exe '[^9-B]@[' 'a@n'  < ../inputs/temp-test/221.inp.98.3 > ../outputs/t5028
    if diff ../outputs/t5028 ../originals/t5028 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5029) timeout -s 9 2 ../source/replace.exe '[^9-B]@[*$' '&'  < ../inputs/temp-test/2030.inp.861.8 > ../outputs/t5029
    if diff ../outputs/t5029 ../originals/t5029 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5030) timeout -s 9 2 ../source/replace.exe '[^9-B]@[*' '&'  < ../inputs/temp-test/2029.inp.861.1 > ../outputs/t5030
    if diff ../outputs/t5030 ../originals/t5030 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5031) timeout -s 9 2 ../source/replace.exe '[^9-B]@[*?[^0-9]-??a-][^a-@t@@?' 'a@n'  < ../inputs/temp-test/1520.inp.651.1 > ../outputs/t5031
    if diff ../outputs/t5031 ../originals/t5031 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5032) timeout -s 9 2 ../source/replace.exe '[^9-B]@[*?[^0-9]-??a-][^a-@t@@?' 'a@n'  < ../inputs/temp-test/1521.inp.651.2 > ../outputs/t5032
    if diff ../outputs/t5032 ../originals/t5032 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5033) timeout -s 9 2 ../source/replace.exe '[^9-B]@t*[^9-B]-[a--b][-z]-$' ''  < ../inputs/temp-test/835.inp.359.6 > ../outputs/t5033
    if diff ../outputs/t5033 ../originals/t5033 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5034) timeout -s 9 2 ../source/replace.exe '[^9-B]@t*[^9-B]-[a--b][-z]-' ''  < ../inputs/temp-test/833.inp.359.1 > ../outputs/t5034
    if diff ../outputs/t5034 ../originals/t5034 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5035) timeout -s 9 2 ../source/replace.exe '[^9-B]@t*[^9-B]-[a--b][-z]-' ''  < ../inputs/temp-test/834.inp.359.3 > ../outputs/t5035
    if diff ../outputs/t5035 ../originals/t5035 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5036) timeout -s 9 2 ../source/replace.exe '[^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]-[a--b][-z][^9-B]@t*[^9-B]-[a--b][-z]-' ''  < ../inputs/temp-test/833.inp.359.1 > ../outputs/t5036
    if diff ../outputs/t5036 ../originals/t5036 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5037) timeout -s 9 2 ../source/replace.exe '[^9-B]A*' 'a&'  < ../inputs/temp-test/1130.inp.486.1 > ../outputs/t5037
    if diff ../outputs/t5037 ../originals/t5037 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5038) timeout -s 9 2 ../source/replace.exe '[^9-B]A*' 'a&'  < ../inputs/temp-test/1131.inp.486.2 > ../outputs/t5038
    if diff ../outputs/t5038 ../originals/t5038 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5039) timeout -s 9 2 ../source/replace.exe '[^9-B]A*' 'a&'  < ../inputs/temp-test/1132.inp.486.3 > ../outputs/t5039
    if diff ../outputs/t5039 ../originals/t5039 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5040) timeout -s 9 2 ../source/replace.exe '[^9-B][-z]?[0-9][@t]?[0-9]?' 'a@n'  < ../inputs/temp-test/55.inp.24.1 > ../outputs/t5040
    if diff ../outputs/t5040 ../originals/t5040 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5041) timeout -s 9 2 ../source/replace.exe '[^9-B][-z]?[0-9][@t]?[0-9]?' 'a@n'  < ../inputs/temp-test/56.inp.24.2 > ../outputs/t5041
    if diff ../outputs/t5041 ../originals/t5041 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5042) timeout -s 9 2 ../source/replace.exe '[^9-B][-z]?[0-9][@t]?[0-9]?' 'a@n'  < ../inputs/temp-test/57.inp.24.4 > ../outputs/t5042
    if diff ../outputs/t5042 ../originals/t5042 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5043) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]'  '&@n' < ../inputs/temp-test/204.inp.91.2 > ../outputs/t5043
    if diff ../outputs/t5043 ../originals/t5043 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5044) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]'   < ../inputs/temp-test/203.inp.91.1 > ../outputs/t5044
    if diff ../outputs/t5044 ../originals/t5044 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5045) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]'   < ../inputs/temp-test/204.inp.91.2 > ../outputs/t5045
    if diff ../outputs/t5045 ../originals/t5045 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5046) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]'   < ../inputs/temp-test/205.inp.91.3 > ../outputs/t5046
    if diff ../outputs/t5046 ../originals/t5046 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5047) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]' '&@n'  < ../inputs/temp-test/203.inp.91.1 > ../outputs/t5047
    if diff ../outputs/t5047 ../originals/t5047 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5048) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]' '@%&a'  < ../inputs/temp-test/203.inp.91.1 > ../outputs/t5048
    if diff ../outputs/t5048 ../originals/t5048 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5049) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]' '@%&a'  < ../inputs/temp-test/204.inp.91.2 > ../outputs/t5049
    if diff ../outputs/t5049 ../originals/t5049 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5050) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]' '@%&a'  < ../inputs/temp-test/205.inp.91.3 > ../outputs/t5050
    if diff ../outputs/t5050 ../originals/t5050 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5051) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]' 'a&'  < ../inputs/temp-test/2103.inp.891.1 > ../outputs/t5051
    if diff ../outputs/t5051 ../originals/t5051 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5052) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]' 'a@nb@tc'  < ../inputs/temp-test/856.inp.368.1 > ../outputs/t5052
    if diff ../outputs/t5052 ../originals/t5052 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5053) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]' 'a@nb@tc'  < ../inputs/temp-test/857.inp.368.3 > ../outputs/t5053
    if diff ../outputs/t5053 ../originals/t5053 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5054) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]*$'   < ../inputs/temp-test/203.inp.91.1 > ../outputs/t5054
    if diff ../outputs/t5054 ../originals/t5054 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5055) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]*$'   < ../inputs/temp-test/204.inp.91.2 > ../outputs/t5055
    if diff ../outputs/t5055 ../originals/t5055 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5056) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]*$' '@%&a'  < ../inputs/temp-test/203.inp.91.1 > ../outputs/t5056
    if diff ../outputs/t5056 ../originals/t5056 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5057) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]*$' '@%&a'  < ../inputs/temp-test/204.inp.91.2 > ../outputs/t5057
    if diff ../outputs/t5057 ../originals/t5057 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5058) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]*$' '@%&a'  < ../inputs/temp-test/205.inp.91.3 > ../outputs/t5058
    if diff ../outputs/t5058 ../originals/t5058 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5059) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]*' '@%&a'  < ../inputs/temp-test/203.inp.91.1 > ../outputs/t5059
    if diff ../outputs/t5059 ../originals/t5059 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5060) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]*' '@%&a'  < ../inputs/temp-test/204.inp.91.2 > ../outputs/t5060
    if diff ../outputs/t5060 ../originals/t5060 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5061) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]*' '@%&a'  < ../inputs/temp-test/205.inp.91.3 > ../outputs/t5061
    if diff ../outputs/t5061 ../originals/t5061 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5062) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]-' 'b@t'  < ../inputs/temp-test/1041.inp.448.1 > ../outputs/t5062
    if diff ../outputs/t5062 ../originals/t5062 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5063) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]-*?[^@@]-a-]-' '@%&a'  < ../inputs/temp-test/2140.inp.907.1 > ../outputs/t5063
    if diff ../outputs/t5063 ../originals/t5063 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5064) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]-*?[^@@]-a-]-' '@%&a'  < ../inputs/temp-test/2141.inp.907.2 > ../outputs/t5064
    if diff ../outputs/t5064 ../originals/t5064 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5065) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]-*?[^@@]-a-]-' '@%&a'  < ../inputs/temp-test/2142.inp.907.3 > ../outputs/t5065
    if diff ../outputs/t5065 ../originals/t5065 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5066) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]-^-]^-][^a-]-' ''  < ../inputs/temp-test/1708.inp.728.1 > ../outputs/t5066
    if diff ../outputs/t5066 ../originals/t5066 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5067) timeout -s 9 2 ../source/replace.exe '[^9-B][9-B]-^-]^-][^a-]-' ''  < ../inputs/temp-test/1709.inp.728.3 > ../outputs/t5067
    if diff ../outputs/t5067 ../originals/t5067 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5068) timeout -s 9 2 ../source/replace.exe '[^9-B][]@[' 'a@n'  < ../inputs/temp-test/219.inp.98.1 > ../outputs/t5068
    if diff ../outputs/t5068 ../originals/t5068 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5069) timeout -s 9 2 ../source/replace.exe '[^9-B][]@[' 'a@n'  < ../inputs/temp-test/221.inp.98.3 > ../outputs/t5069
    if diff ../outputs/t5069 ../originals/t5069 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5070) timeout -s 9 2 ../source/replace.exe '[^9-B][][9-B]' '@%&a'  < ../inputs/temp-test/204.inp.91.2 > ../outputs/t5070
    if diff ../outputs/t5070 ../originals/t5070 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5071) timeout -s 9 2 ../source/replace.exe '[^9-B][^0-9]-?[^0-9]?--' 'a&'  < ../inputs/temp-test/1526.inp.654.1 > ../outputs/t5071
    if diff ../outputs/t5071 ../originals/t5071 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5072) timeout -s 9 2 ../source/replace.exe '[^9-B][^0-9]-?[^0-9]?--' 'a&'  < ../inputs/temp-test/1527.inp.654.2 > ../outputs/t5072
    if diff ../outputs/t5072 ../originals/t5072 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5073) timeout -s 9 2 ../source/replace.exe '[^9-B][^]@[' 'a@n'  < ../inputs/temp-test/219.inp.98.1 > ../outputs/t5073
    if diff ../outputs/t5073 ../originals/t5073 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5074) timeout -s 9 2 ../source/replace.exe '[^9-B][^]@[' 'a@n'  < ../inputs/temp-test/221.inp.98.3 > ../outputs/t5074
    if diff ../outputs/t5074 ../originals/t5074 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5075) timeout -s 9 2 ../source/replace.exe '[^9-B][^]@[**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t5075
    if diff ../outputs/t5075 ../originals/t5075 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5076) timeout -s 9 2 ../source/replace.exe '[^9-B][^][9-B]' '@%&a'  < ../inputs/temp-test/204.inp.91.2 > ../outputs/t5076
    if diff ../outputs/t5076 ../originals/t5076 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5077) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' '&a@%'  < ../inputs/temp-test/1441.inp.618.1 > ../outputs/t5077
    if diff ../outputs/t5077 ../originals/t5077 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5078) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' '&a@%'  < ../inputs/temp-test/1442.inp.618.3 > ../outputs/t5078
    if diff ../outputs/t5078 ../originals/t5078 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5079) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' ''  < ../inputs/temp-test/1674.inp.714.1 > ../outputs/t5079
    if diff ../outputs/t5079 ../originals/t5079 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5080) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' ''  < ../inputs/temp-test/1675.inp.714.2 > ../outputs/t5080
    if diff ../outputs/t5080 ../originals/t5080 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5081) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' ''  < ../inputs/temp-test/1676.inp.714.3 > ../outputs/t5081
    if diff ../outputs/t5081 ../originals/t5081 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5082) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' ''  < ../inputs/temp-test/1677.inp.714.4 > ../outputs/t5082
    if diff ../outputs/t5082 ../originals/t5082 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5083) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' '@%&a'  < ../inputs/temp-test/1304.inp.561.1 > ../outputs/t5083
    if diff ../outputs/t5083 ../originals/t5083 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5084) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' '@%&a'  < ../inputs/temp-test/1305.inp.561.3 > ../outputs/t5084
    if diff ../outputs/t5084 ../originals/t5084 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5085) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' '@n'  < ../inputs/temp-test/1825.inp.777.1 > ../outputs/t5085
    if diff ../outputs/t5085 ../originals/t5085 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5086) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' '@n'  < ../inputs/temp-test/1826.inp.777.2 > ../outputs/t5086
    if diff ../outputs/t5086 ../originals/t5086 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5087) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]' '@n'  < ../inputs/temp-test/1827.inp.777.3 > ../outputs/t5087
    if diff ../outputs/t5087 ../originals/t5087 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5088) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]?[^0-9]-' '@%&a'  < ../inputs/temp-test/1276.inp.548.1 > ../outputs/t5088
    if diff ../outputs/t5088 ../originals/t5088 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5089) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]?[^0-9]-' '@%&a'  < ../inputs/temp-test/1277.inp.548.3 > ../outputs/t5089
    if diff ../outputs/t5089 ../originals/t5089 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5090) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-' '@%&a'  < ../inputs/temp-test/1276.inp.548.1 > ../outputs/t5090
    if diff ../outputs/t5090 ../originals/t5090 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5091) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c][9-B]' '&@n'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t5091
    if diff ../outputs/t5091 ../originals/t5091 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5092) timeout -s 9 2 ../source/replace.exe '[^9-B][a-c][9-B]'  < ../inputs/temp-test/529.inp.229.2 > ../outputs/t5092
    if diff ../outputs/t5092 ../originals/t5092 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5093) timeout -s 9 2 ../source/replace.exe '[^9-B]^-?[a-c][^9-B]^a-c][-z]?a-c]' 'a@nb@tc'  < ../inputs/temp-test/1658.inp.707.1 > ../outputs/t5093
    if diff ../outputs/t5093 ../originals/t5093 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5094) timeout -s 9 2 ../source/replace.exe '[^9-B]^-?[a-c][^9-B]^a-c][-z]?a-c]' 'a@nb@tc'  < ../inputs/temp-test/1659.inp.707.3 > ../outputs/t5094
    if diff ../outputs/t5094 ../originals/t5094 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5095) timeout -s 9 2 ../source/replace.exe '[^9-B]^-?[a-c][^9-B]^a-c][-z]?a-c]' 'a@nb@tc'  < ../inputs/temp-test/1660.inp.707.4 > ../outputs/t5095
    if diff ../outputs/t5095 ../originals/t5095 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5096) timeout -s 9 2 ../source/replace.exe '[^9-B]a-c]' '@%&a'  < ../inputs/temp-test/1177.inp.507.1 > ../outputs/t5096
    if diff ../outputs/t5096 ../originals/t5096 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5097) timeout -s 9 2 ../source/replace.exe '[^9-B]c' '@%&a'  < ../inputs/temp-test/2236.inp.948.1 > ../outputs/t5097
    if diff ../outputs/t5097 ../originals/t5097 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5098) timeout -s 9 2 ../source/replace.exe '[^9-B]c' '@%&a'  < ../inputs/temp-test/2237.inp.948.2 > ../outputs/t5098
    if diff ../outputs/t5098 ../originals/t5098 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5099) timeout -s 9 2 ../source/replace.exe '[^<]' 'v?,P"%A`LsBP\u4d; CqOH,&_r=)BCe9t#gvb<Wt>raU4E4x'  < ../inputs/input/ruin.1484 > ../outputs/t5099
    if diff ../outputs/t5099 ../originals/t5099 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5100) timeout -s 9 2 ../source/replace.exe '[^>-A0-9]' '5%-v^<c1y2IcI}I/_G%E/:epn= `B:MO'  < ../inputs/input/ruin.304 > ../outputs/t5100
    if diff ../outputs/t5100 ../originals/t5100 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5101) timeout -s 9 2 ../source/replace.exe '[^>-A>-AA-G0-90-9A-G]O\.K' '`'  < ../inputs/input/ruin.278 > ../outputs/t5101
    if diff ../outputs/t5101 ../originals/t5101 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5102) timeout -s 9 2 ../source/replace.exe '[^>-AA-G]' '.'  < ../inputs/input/ruin.1307 > ../outputs/t5102
    if diff ../outputs/t5102 ../originals/t5102 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5103) timeout -s 9 2 ../source/replace.exe '[^>-AA-Gc-a]' ';=bn:S4Ymbn'  < ../inputs/input/ruin.1234 > ../outputs/t5103
    if diff ../outputs/t5103 ../originals/t5103 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5104) timeout -s 9 2 ../source/replace.exe '[^>-A]$' '~IL;#{y,f"Kv+2t6x'  < ../inputs/input/ruin.112 > ../outputs/t5104
    if diff ../outputs/t5104 ../originals/t5104 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5105) timeout -s 9 2 ../source/replace.exe '[^>-A]' ''  < ../inputs/input/ruin.1644 > ../outputs/t5105
    if diff ../outputs/t5105 ../originals/t5105 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5106) timeout -s 9 2 ../source/replace.exe '[^>-A]' '04++/5T7m;q&X>WdTwHm!3/9e)&'  < ../inputs/input/ruin.1608 > ../outputs/t5106
    if diff ../outputs/t5106 ../originals/t5106 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5107) timeout -s 9 2 ../source/replace.exe '[^>-A]' '96Nl[*)'  < ../inputs/input/ruin.1489 > ../outputs/t5107
    if diff ../outputs/t5107 ../originals/t5107 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5108) timeout -s 9 2 ../source/replace.exe '[^>-A]' '@'  < ../inputs/input/ruin.873 > ../outputs/t5108
    if diff ../outputs/t5108 ../originals/t5108 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5109) timeout -s 9 2 ../source/replace.exe '[^>-A]' 'H'  < ../inputs/input/ruin.1206 > ../outputs/t5109
    if diff ../outputs/t5109 ../originals/t5109 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5110) timeout -s 9 2 ../source/replace.exe '[^>-A]' 'J'  < ../inputs/input/ruin.1539 > ../outputs/t5110
    if diff ../outputs/t5110 ../originals/t5110 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5111) timeout -s 9 2 ../source/replace.exe '[^>-A]' 'SyR'  < ../inputs/input/ruin.980 > ../outputs/t5111
    if diff ../outputs/t5111 ../originals/t5111 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5112) timeout -s 9 2 ../source/replace.exe '[^>-A]' '}5$dExu:2n)dfDa6,}^W.u#[w1}E_A'  < ../inputs/input/ruin.1850 > ../outputs/t5112
    if diff ../outputs/t5112 ../originals/t5112 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5113) timeout -s 9 2 ../source/replace.exe '[^>-A]?*' '04++/5T7m;q&X>WdTwHm!3/9e)&'  < ../inputs/input/ruin.1608 > ../outputs/t5113
    if diff ../outputs/t5113 ../originals/t5113 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5114) timeout -s 9 2 ../source/replace.exe '[^>-AzZ-a]^_`a-z-}z-}]' 'Z}~ZyBzkd3:;$=h'  < ../inputs/input/ruin.216 > ../outputs/t5114
    if diff ../outputs/t5114 ../originals/t5114 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5115) timeout -s 9 2 ../source/replace.exe '[^>]' 'C<t,7!I$c'  < ../inputs/input/ruin.69 > ../outputs/t5115
    if diff ../outputs/t5115 ../originals/t5115 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5116) timeout -s 9 2 ../source/replace.exe '[^@@]%-' 'a&'  < ../inputs/temp-test/2350.inp.998.1 > ../outputs/t5116
    if diff ../outputs/t5116 ../originals/t5116 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5117) timeout -s 9 2 ../source/replace.exe '[^@@]%-' 'a&'  < ../inputs/temp-test/2351.inp.998.2 > ../outputs/t5117
    if diff ../outputs/t5117 ../originals/t5117 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5118) timeout -s 9 2 ../source/replace.exe '[^@@]-%' 'a&'  < ../inputs/temp-test/2352.inp.998.3 > ../outputs/t5118
    if diff ../outputs/t5118 ../originals/t5118 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5119) timeout -s 9 2 ../source/replace.exe '[^@@]-' 'a&'  < ../inputs/temp-test/2350.inp.998.1 > ../outputs/t5119
    if diff ../outputs/t5119 ../originals/t5119 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5120) timeout -s 9 2 ../source/replace.exe '[^@@]-' 'a&'  < ../inputs/temp-test/2351.inp.998.2 > ../outputs/t5120
    if diff ../outputs/t5120 ../originals/t5120 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5121) timeout -s 9 2 ../source/replace.exe '[^@@]-' 'a&'  < ../inputs/temp-test/2352.inp.998.3 > ../outputs/t5121
    if diff ../outputs/t5121 ../originals/t5121 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5122) timeout -s 9 2 ../source/replace.exe '[^@@][@@]@n[a-c' ''  < ../inputs/temp-test/587.inp.252.1 > ../outputs/t5122
    if diff ../outputs/t5122 ../originals/t5122 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5123) timeout -s 9 2 ../source/replace.exe '[^@@][@@]@n[a-c' ''  < ../inputs/temp-test/588.inp.252.3 > ../outputs/t5123
    if diff ../outputs/t5123 ../originals/t5123 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5124) timeout -s 9 2 ../source/replace.exe '[^@@][a-cc*-[-z]-?[^0-9][^@n][a-c@[-' '@%&a'  < ../inputs/temp-test/1739.inp.740.1 > ../outputs/t5124
    if diff ../outputs/t5124 ../originals/t5124 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5125) timeout -s 9 2 ../source/replace.exe '[^@@][a-cc*-[-z]-?[^0-9][^@n][a-c@[-' '@%&a'  < ../inputs/temp-test/1740.inp.740.2 > ../outputs/t5125
    if diff ../outputs/t5125 ../originals/t5125 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5126) timeout -s 9 2 ../source/replace.exe '[^@]' 'K'  < ../inputs/input/ruin.1974 > ../outputs/t5126
    if diff ../outputs/t5126 ../originals/t5126 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5127) timeout -s 9 2 ../source/replace.exe '[^@]' 'Y'  < ../inputs/input/ruin.1729 > ../outputs/t5127
    if diff ../outputs/t5127 ../originals/t5127 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5128) timeout -s 9 2 ../source/replace.exe '[^@n]' '&'  < ../inputs/temp-test/1098.inp.473.1 > ../outputs/t5128
    if diff ../outputs/t5128 ../originals/t5128 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5129) timeout -s 9 2 ../source/replace.exe '[^@n]?' ''  < ../inputs/temp-test/1905.inp.808.1 > ../outputs/t5129
    if diff ../outputs/t5129 ../originals/t5129 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5130) timeout -s 9 2 ../source/replace.exe '[^@n]?? *?^a-c][9-B]??-?-[^0-9]$' 'a@n'  < ../inputs/temp-test/2170.inp.917.6 > ../outputs/t5130
    if diff ../outputs/t5130 ../originals/t5130 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5131) timeout -s 9 2 ../source/replace.exe '[^@n]?? *?^a-c][9-B]??-?-[^0-9]' 'a@n'  < ../inputs/temp-test/2168.inp.917.1 > ../outputs/t5131
    if diff ../outputs/t5131 ../originals/t5131 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5132) timeout -s 9 2 ../source/replace.exe '[^@n]?? *?^a-c][9-B]??-?-[^0-9]' 'a@n'  < ../inputs/temp-test/2169.inp.917.4 > ../outputs/t5132
    if diff ../outputs/t5132 ../originals/t5132 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5133) timeout -s 9 2 ../source/replace.exe '[^@n]@n?@[[^-z]a-]?a-][^a-c-[^a--]' '&'  < ../inputs/temp-test/79.inp.34.1 > ../outputs/t5133
    if diff ../outputs/t5133 ../originals/t5133 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5134) timeout -s 9 2 ../source/replace.exe '[^@t] $' 'a&'  < ../inputs/temp-test/1185.inp.510.6 > ../outputs/t5134
    if diff ../outputs/t5134 ../originals/t5134 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5135) timeout -s 9 2 ../source/replace.exe '[^@t] ' 'a&'  < ../inputs/temp-test/1183.inp.510.1 > ../outputs/t5135
    if diff ../outputs/t5135 ../originals/t5135 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5136) timeout -s 9 2 ../source/replace.exe '[^@t] ' 'a&'  < ../inputs/temp-test/1184.inp.510.4 > ../outputs/t5136
    if diff ../outputs/t5136 ../originals/t5136 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5137) timeout -s 9 2 ../source/replace.exe '[^A-G0-9Z-a]^_`a-A-GABCDEFG]' '7'  < ../inputs/input/ruin.1287 > ../outputs/t5137
    if diff ../outputs/t5137 ../originals/t5137 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5138) timeout -s 9 2 ../source/replace.exe '[^A-G0-9]' ' t;btzU%_Q3*,&<&9'  < ../inputs/input/ruin.1825 > ../outputs/t5138
    if diff ../outputs/t5138 ../originals/t5138 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5139) timeout -s 9 2 ../source/replace.exe '[^A-G0-9z-}]' '6qn`J_lW>TE~j|(+QIxZ[~_-#xQ'\''T'  < ../inputs/input/ruin.1702 > ../outputs/t5139
    if diff ../outputs/t5139 ../originals/t5139 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5140) timeout -s 9 2 ../source/replace.exe '[^A-GA-GA-Gc-aZ-a]^_`a][^A-GA-GA-Gc-aZ-a]^_`a]' 'p'  < ../inputs/input/ruin.663 > ../outputs/t5140
    if diff ../outputs/t5140 ../originals/t5140 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5141) timeout -s 9 2 ../source/replace.exe '[^A-GZ-a]^_`a]' ':'  < ../inputs/input/ruin.1089 > ../outputs/t5141
    if diff ../outputs/t5141 ../originals/t5141 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5142) timeout -s 9 2 ../source/replace.exe '[^A-GZ-a]^_`a]' 'nb>?q$.;cKX_xZHjjQ<3,7j|'  < ../inputs/input/ruin.1853 > ../outputs/t5142
    if diff ../outputs/t5142 ../originals/t5142 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5143) timeout -s 9 2 ../source/replace.exe '[^A-G]' '$'  < ../inputs/input/ruin.997 > ../outputs/t5143
    if diff ../outputs/t5143 ../originals/t5143 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5144) timeout -s 9 2 ../source/replace.exe '[^A-G]' '3'  < ../inputs/input/ruin.1993 > ../outputs/t5144
    if diff ../outputs/t5144 ../originals/t5144 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5145) timeout -s 9 2 ../source/replace.exe '[^A-G]' '8(taNmoh5G<.1@&eZ{_/NNPSZT<l`wW%-PGz=0TF'  < ../inputs/input/ruin.1212 > ../outputs/t5145
    if diff ../outputs/t5145 ../originals/t5145 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5146) timeout -s 9 2 ../source/replace.exe '[^A-G]' '='  < ../inputs/input/ruin.615 > ../outputs/t5146
    if diff ../outputs/t5146 ../originals/t5146 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5147) timeout -s 9 2 ../source/replace.exe '[^A-G]' '?NKkky:[kyHQAcp-0g*J6%]|{c'  < ../inputs/input/ruin.665 > ../outputs/t5147
    if diff ../outputs/t5147 ../originals/t5147 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5148) timeout -s 9 2 ../source/replace.exe '[^A-G]' 'CzPGix*Bb(l^H^r63iE<=zqCo'  < ../inputs/input/ruin.1801 > ../outputs/t5148
    if diff ../outputs/t5148 ../originals/t5148 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5149) timeout -s 9 2 ../source/replace.exe '[^A-G]' 'S q2fRrNoKYz'  < ../inputs/input/ruin.1292 > ../outputs/t5149
    if diff ../outputs/t5149 ../originals/t5149 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5150) timeout -s 9 2 ../source/replace.exe '[^A-G]' '[`nuc|R-<Hwk'\''VjNT0GK}y42aaJD*q;p=y.B ,V^\'\''yUvqN0:tC+`GE| RPYRK#CQ-F.]@QEs@MP$+](mI7<'  < ../inputs/input/ruin.170 > ../outputs/t5150
    if diff ../outputs/t5150 ../originals/t5150 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5151) timeout -s 9 2 ../source/replace.exe '[^A-G]' '`'  < ../inputs/input/ruin.18 > ../outputs/t5151
    if diff ../outputs/t5151 ../originals/t5151 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5152) timeout -s 9 2 ../source/replace.exe '[^A-G]' '`T0QCI\YA:p1`8M(v)J.;m+=d_V]a@uddt@#`;*d7EupFJ%SV1"Wczcv&\ma2 .{N[G:X8[+*yj\!*B#%#6.&JU(l6^U1mTncrlWq'  < ../inputs/input/ruin.1893 > ../outputs/t5152
    if diff ../outputs/t5152 ../originals/t5152 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5153) timeout -s 9 2 ../source/replace.exe '[^A-G]' 'dY?s%djpY}ZoPrp@$E8wLalV3!OK|6dCMk.xt}K"T&3#OEnKHvf}\<rwJ5@`G(.Afmx'  < ../inputs/input/ruin.791 > ../outputs/t5153
    if diff ../outputs/t5153 ../originals/t5153 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5154) timeout -s 9 2 ../source/replace.exe '[^A-G]' 'e1 n@lk)dOmuvvM8V'  < ../inputs/input/ruin.551 > ../outputs/t5154
    if diff ../outputs/t5154 ../originals/t5154 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5155) timeout -s 9 2 ../source/replace.exe '[^A-G]' 'jhIKJsma3Dy7'  < ../inputs/input/ruin.1534 > ../outputs/t5155
    if diff ../outputs/t5155 ../originals/t5155 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5156) timeout -s 9 2 ../source/replace.exe '[^A-G]' 'k/bmA,d@Ho|K*j/g.0;>s!'  < ../inputs/input/ruin.1309 > ../outputs/t5156
    if diff ../outputs/t5156 ../originals/t5156 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5157) timeout -s 9 2 ../source/replace.exe '[^A-G]??' 'i'  < ../inputs/input/ruin.1178 > ../outputs/t5157
    if diff ../outputs/t5157 ../originals/t5157 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5158) timeout -s 9 2 ../source/replace.exe '[^A-Gc-aLA-G]' 'Z'  < ../inputs/input/ruin.538 > ../outputs/t5158
    if diff ../outputs/t5158 ../originals/t5158 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5159) timeout -s 9 2 ../source/replace.exe '[^A-G~]' '{f'  < ../inputs/input/ruin.228 > ../outputs/t5159
    if diff ../outputs/t5159 ../originals/t5159 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5160) timeout -s 9 2 ../source/replace.exe '[^BA-Gc-a]' '\'  < ../inputs/input/ruin.619 > ../outputs/t5160
    if diff ../outputs/t5160 ../originals/t5160 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5161) timeout -s 9 2 ../source/replace.exe '[^C]' 'O'  < ../inputs/input/ruin.1023 > ../outputs/t5161
    if diff ../outputs/t5161 ../originals/t5161 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5162) timeout -s 9 2 ../source/replace.exe '[^D]' '!Sc2Bq xEh9%Q/E?O'  < ../inputs/input/ruin.1964 > ../outputs/t5162
    if diff ../outputs/t5162 ../originals/t5162 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5163) timeout -s 9 2 ../source/replace.exe '[^J]' 'L'  < ../inputs/input/ruin.1240 > ../outputs/t5163
    if diff ../outputs/t5163 ../originals/t5163 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5164) timeout -s 9 2 ../source/replace.exe '[^J]' 'QM'  < ../inputs/input/ruin.81 > ../outputs/t5164
    if diff ../outputs/t5164 ../originals/t5164 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5165) timeout -s 9 2 ../source/replace.exe '[^J]*$' 'L'  < ../inputs/input/ruin.1240 > ../outputs/t5165
    if diff ../outputs/t5165 ../originals/t5165 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5166) timeout -s 9 2 ../source/replace.exe '[^L]' '&=3PUz)'  < ../inputs/input/ruin.21 > ../outputs/t5166
    if diff ../outputs/t5166 ../originals/t5166 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5167) timeout -s 9 2 ../source/replace.exe '[^N.Z-a]^_`a]X' 'S@'  < ../inputs/input/ruin.1502 > ../outputs/t5167
    if diff ../outputs/t5167 ../originals/t5167 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5168) timeout -s 9 2 ../source/replace.exe '[^U]' '"c9`I|c[Y#fc?)'  < ../inputs/input/ruin.182 > ../outputs/t5168
    if diff ../outputs/t5168 ../originals/t5168 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5169) timeout -s 9 2 ../source/replace.exe '[^W]' '$3)'  < ../inputs/input/ruin.174 > ../outputs/t5169
    if diff ../outputs/t5169 ../originals/t5169 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5170) timeout -s 9 2 ../source/replace.exe '[^X]' ')S!M:mm9v3&y.W'  < ../inputs/input/ruin.1001 > ../outputs/t5170
    if diff ../outputs/t5170 ../originals/t5170 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5171) timeout -s 9 2 ../source/replace.exe '[^Z-a]' 'Xi]{E>{[.5?-L6'\''TGdSR-lMJd/,znD|npnWvV]}:P0~<Vr;0Re'  < ../inputs/input/ruin.760 > ../outputs/t5171
    if diff ../outputs/t5171 ../originals/t5171 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5172) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a-0-90123456789C-0-90123456789r-z-}z-}-Z-aZ[]^_`a]' '%'  < ../inputs/input/ruin.856 > ../outputs/t5172
    if diff ../outputs/t5172 ../originals/t5172 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5173) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a-Z-aZ[]^_`a]' '!5-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_-aA-GZ-a]^_s#S?%gG"i*'  < ../inputs/input/ruin.1051 > ../outputs/t5173
    if diff ../outputs/t5173 ../originals/t5173 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5174) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a-Z-aZ[]^_`a]' '!5s#S?%gG"i*'  < ../inputs/input/ruin.1051 > ../outputs/t5174
    if diff ../outputs/t5174 ../originals/t5174 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5175) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a-c-ac-a-A-GABCDEFG]' '/&dr!{2h/LY=2Sb#WM=uI'  < ../inputs/input/ruin.1522 > ../outputs/t5175
    if diff ../outputs/t5175 ../originals/t5175 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5176) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a-c-ac-a]' 'h'  < ../inputs/input/ruin.641 > ../outputs/t5176
    if diff ../outputs/t5176 ../originals/t5176 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5177) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a-z-}z-}-A-GABCDEFG-0-90123456789-z-}z-}-0-90123456789]' 'pF)HeS a`g9$#F>7z9x$'  < ../inputs/input/ruin.572 > ../outputs/t5177
    if diff ../outputs/t5177 ../originals/t5177 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5178) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`aP-Z-aZ[]^_`a-0-90123456789]' '='  < ../inputs/input/ruin.461 > ../outputs/t5178
    if diff ../outputs/t5178 ../originals/t5178 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5179) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`aV-0-90123456789]' '_'  < ../inputs/input/ruin.871 > ../outputs/t5179
    if diff ../outputs/t5179 ../originals/t5179 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5180) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' '#CQ3@U,)/aDf|9p jfjO3Y[H:AI[f|8Wz)'  < ../inputs/input/ruin.1475 > ../outputs/t5180
    if diff ../outputs/t5180 ../originals/t5180 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5181) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' ')'  < ../inputs/input/ruin.258 > ../outputs/t5181
    if diff ../outputs/t5181 ../originals/t5181 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5182) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' '.'  < ../inputs/input/ruin.421 > ../outputs/t5182
    if diff ../outputs/t5182 ../originals/t5182 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5183) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' '/'  < ../inputs/input/ruin.128 > ../outputs/t5183
    if diff ../outputs/t5183 ../originals/t5183 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5184) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' '<w2G+@s,+~@V#/k%Z6lmTA 6(wV6-6!+Mk$H=Q'  < ../inputs/input/ruin.1677 > ../outputs/t5184
    if diff ../outputs/t5184 ../originals/t5184 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5185) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' '>,gDlLZK3'  < ../inputs/input/ruin.1274 > ../outputs/t5185
    if diff ../outputs/t5185 ../originals/t5185 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5186) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' '?K&QWk{]S_'  < ../inputs/input/ruin.1618 > ../outputs/t5186
    if diff ../outputs/t5186 ../originals/t5186 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5187) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' 'FAl8eCyn8mwJA=!.|Xn"s*I\H1JJhky#,D4RAuz*[}'  < ../inputs/input/ruin.595 > ../outputs/t5187
    if diff ../outputs/t5187 ../originals/t5187 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5188) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' 'H'  < ../inputs/input/ruin.460 > ../outputs/t5188
    if diff ../outputs/t5188 ../originals/t5188 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5189) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' 'OV9D!H{O-Vw_tNc8I'  < ../inputs/input/ruin.1802 > ../outputs/t5189
    if diff ../outputs/t5189 ../originals/t5189 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5190) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' 'Q0}@_^cnC7s.L'  < ../inputs/input/ruin.522 > ../outputs/t5190
    if diff ../outputs/t5190 ../originals/t5190 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5191) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' 'QP2S'  < ../inputs/input/ruin.1410 > ../outputs/t5191
    if diff ../outputs/t5191 ../originals/t5191 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5192) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' 'Xi]{E>{[1d2qd.5?-L6'\''TGdSR-lMJd/,znD|npnWvV]}:P0~<Vr;0Re'  < ../inputs/input/ruin.760 > ../outputs/t5192
    if diff ../outputs/t5192 ../originals/t5192 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5193) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]' 'n'  < ../inputs/input/ruin.454 > ../outputs/t5193
    if diff ../outputs/t5193 ../originals/t5193 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5194) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]?*' '?K&QWk{]S_'  < ../inputs/input/ruin.1618 > ../outputs/t5194
    if diff ../outputs/t5194 ../originals/t5194 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5195) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]@n' 'H&@t@t@t'  < ../inputs/input/ruin.460 > ../outputs/t5195
    if diff ../outputs/t5195 ../originals/t5195 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5196) timeout -s 9 2 ../source/replace.exe '[^Z-a]^_`a]\p@fz[@@' 'K'  < ../inputs/input/ruin.146 > ../outputs/t5196
    if diff ../outputs/t5196 ../originals/t5196 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5197) timeout -s 9 2 ../source/replace.exe '[^Z]@@' 'Q5"'  < ../inputs/input/ruin.1666 > ../outputs/t5197
    if diff ../outputs/t5197 ../originals/t5197 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5198) timeout -s 9 2 ../source/replace.exe '[^]%?@*' 'NEW'  < ../inputs/temp-test/523.inp.226.5 > ../outputs/t5198
    if diff ../outputs/t5198 ../originals/t5198 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5199) timeout -s 9 2 ../source/replace.exe '[^]%@*?' '@%&a'  < ../inputs/temp-test/199.inp.89.5 > ../outputs/t5199
    if diff ../outputs/t5199 ../originals/t5199 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5200) timeout -s 9 2 ../source/replace.exe '[^]' '@n67@n67@n'  < ../inputs/moni/f8.inp > ../outputs/t5200
    if diff ../outputs/t5200 ../originals/t5200 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5201) timeout -s 9 2 ../source/replace.exe '[^]- ' '&'  < ../inputs/temp-test/524.inp.227.1 > ../outputs/t5201
    if diff ../outputs/t5201 ../originals/t5201 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5202) timeout -s 9 2 ../source/replace.exe '[^]-*[^0-9]' '&'  < ../inputs/temp-test/200.inp.90.1 > ../outputs/t5202
    if diff ../outputs/t5202 ../originals/t5202 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5203) timeout -s 9 2 ../source/replace.exe '[^]?@*' 'NEW'  < ../inputs/temp-test/521.inp.226.1 > ../outputs/t5203
    if diff ../outputs/t5203 ../originals/t5203 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5204) timeout -s 9 2 ../source/replace.exe '[^]?@*' 'NEW'  < ../inputs/temp-test/522.inp.226.3 > ../outputs/t5204
    if diff ../outputs/t5204 ../originals/t5204 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5205) timeout -s 9 2 ../source/replace.exe '[^][^0-9]-?[9-B]?-[9-B]?' '@t'  < ../inputs/temp-test/526.inp.228.3 > ../outputs/t5205
    if diff ../outputs/t5205 ../originals/t5205 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5206) timeout -s 9 2 ../source/replace.exe '[^][^9-B]@[' 'a@n'  < ../inputs/temp-test/220.inp.98.2 > ../outputs/t5206
    if diff ../outputs/t5206 ../originals/t5206 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5207) timeout -s 9 2 ../source/replace.exe '[^][^9-B][9-B]' '@%&a'  < ../inputs/temp-test/203.inp.91.1 > ../outputs/t5207
    if diff ../outputs/t5207 ../originals/t5207 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5208) timeout -s 9 2 ../source/replace.exe '[^][^a-c][9-B]' '@%&a'  < ../inputs/temp-test/223.inp.99.3 > ../outputs/t5208
    if diff ../outputs/t5208 ../originals/t5208 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5209) timeout -s 9 2 ../source/replace.exe '[^][a-c?$' 'a&'  < ../inputs/temp-test/520.inp.225.8 > ../outputs/t5209
    if diff ../outputs/t5209 ../originals/t5209 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5210) timeout -s 9 2 ../source/replace.exe '[^][a-c?' 'a&'  < ../inputs/temp-test/516.inp.225.1 > ../outputs/t5210
    if diff ../outputs/t5210 ../originals/t5210 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5211) timeout -s 9 2 ../source/replace.exe '[^][a-c?' 'a&'  < ../inputs/temp-test/517.inp.225.2 > ../outputs/t5211
    if diff ../outputs/t5211 ../originals/t5211 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5212) timeout -s 9 2 ../source/replace.exe '[^][a-c?' 'a&'  < ../inputs/temp-test/518.inp.225.3 > ../outputs/t5212
    if diff ../outputs/t5212 ../originals/t5212 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5213) timeout -s 9 2 ../source/replace.exe '[^][a-c?' 'a&'  < ../inputs/temp-test/519.inp.225.4 > ../outputs/t5213
    if diff ../outputs/t5213 ../originals/t5213 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5214) timeout -s 9 2 ../source/replace.exe '[^a-' '&'  < ../inputs/temp-test/2315.inp.982.1 > ../outputs/t5214
    if diff ../outputs/t5214 ../originals/t5214 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5215) timeout -s 9 2 ../source/replace.exe '[^a-' '&a@%'  < ../inputs/temp-test/1363.inp.585.2 > ../outputs/t5215
    if diff ../outputs/t5215 ../originals/t5215 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5216) timeout -s 9 2 ../source/replace.exe '[^a-' '&a@%'  < ../inputs/temp-test/1364.inp.585.3 > ../outputs/t5216
    if diff ../outputs/t5216 ../originals/t5216 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5217) timeout -s 9 2 ../source/replace.exe '[^a--' '@%&a'  < ../inputs/temp-test/704.inp.305.1 > ../outputs/t5217
    if diff ../outputs/t5217 ../originals/t5217 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5218) timeout -s 9 2 ../source/replace.exe '[^a--' '@%&a'  < ../inputs/temp-test/705.inp.305.2 > ../outputs/t5218
    if diff ../outputs/t5218 ../originals/t5218 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5219) timeout -s 9 2 ../source/replace.exe '[^a--?[9-B]?[0-9]' 'a@n'  < ../inputs/temp-test/1361.inp.584.1 > ../outputs/t5219
    if diff ../outputs/t5219 ../originals/t5219 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5220) timeout -s 9 2 ../source/replace.exe '[^a--?[9-B]?[0-9]' 'a@n'  < ../inputs/temp-test/1362.inp.584.2 > ../outputs/t5220
    if diff ../outputs/t5220 ../originals/t5220 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5221) timeout -s 9 2 ../source/replace.exe '[^a--]' 'b@t'  < ../inputs/temp-test/1502.inp.644.1 > ../outputs/t5221
    if diff ../outputs/t5221 ../originals/t5221 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5222) timeout -s 9 2 ../source/replace.exe '[^a--]' 'b@t'  < ../inputs/temp-test/1503.inp.644.3 > ../outputs/t5222
    if diff ../outputs/t5222 ../originals/t5222 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5223) timeout -s 9 2 ../source/replace.exe '[^a--]' 'b@t'  < ../inputs/temp-test/1504.inp.644.4 > ../outputs/t5223
    if diff ../outputs/t5223 ../originals/t5223 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5224) timeout -s 9 2 ../source/replace.exe '[^a--]??[0-9]' '@%@&'  < ../inputs/temp-test/1930.inp.820.1 > ../outputs/t5224
    if diff ../outputs/t5224 ../originals/t5224 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5225) timeout -s 9 2 ../source/replace.exe '[^a--]??[0-9]' '@%@&'  < ../inputs/temp-test/1931.inp.820.4 > ../outputs/t5225
    if diff ../outputs/t5225 ../originals/t5225 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5226) timeout -s 9 2 ../source/replace.exe '[^a--]@*$' 'a@nb@tc'  < ../inputs/temp-test/383.inp.166.8 > ../outputs/t5226
    if diff ../outputs/t5226 ../originals/t5226 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5227) timeout -s 9 2 ../source/replace.exe '[^a--]@*' 'a@nb@tc'  < ../inputs/temp-test/381.inp.166.1 > ../outputs/t5227
    if diff ../outputs/t5227 ../originals/t5227 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5228) timeout -s 9 2 ../source/replace.exe '[^a--]@*' 'a@nb@tc'  < ../inputs/temp-test/382.inp.166.3 > ../outputs/t5228
    if diff ../outputs/t5228 ../originals/t5228 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5229) timeout -s 9 2 ../source/replace.exe '[^a--]a-c]--]?[^9-B][a--b]@[*-' '@%&a'  < ../inputs/temp-test/1795.inp.763.1 > ../outputs/t5229
    if diff ../outputs/t5229 ../originals/t5229 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5230) timeout -s 9 2 ../source/replace.exe '[^a--b]' '&a@%'  < ../inputs/temp-test/1417.inp.608.1 > ../outputs/t5230
    if diff ../outputs/t5230 ../originals/t5230 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5231) timeout -s 9 2 ../source/replace.exe '[^a--b]' 'a@nb@tc'  < ../inputs/temp-test/946.inp.407.1 > ../outputs/t5231
    if diff ../outputs/t5231 ../originals/t5231 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5232) timeout -s 9 2 ../source/replace.exe '[^a--b]-[9-B]$' 'a&'  < ../inputs/temp-test/838.inp.360.9 > ../outputs/t5232
    if diff ../outputs/t5232 ../originals/t5232 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5233) timeout -s 9 2 ../source/replace.exe '[^a--b]-[9-B]' 'a&'  < ../inputs/temp-test/836.inp.360.1 > ../outputs/t5233
    if diff ../outputs/t5233 ../originals/t5233 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5234) timeout -s 9 2 ../source/replace.exe '[^a--b]-[9-B]' 'a&'  < ../inputs/temp-test/837.inp.360.2 > ../outputs/t5234
    if diff ../outputs/t5234 ../originals/t5234 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5235) timeout -s 9 2 ../source/replace.exe '[^a--b]?[^9-B]? *[^0-9]-' 'NEW'  < ../inputs/temp-test/2117.inp.898.1 > ../outputs/t5235
    if diff ../outputs/t5235 ../originals/t5235 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5236) timeout -s 9 2 ../source/replace.exe '[^a--b]?[^9-B]? *[^0-9]-' 'NEW'  < ../inputs/temp-test/2118.inp.898.2 > ../outputs/t5236
    if diff ../outputs/t5236 ../originals/t5236 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5237) timeout -s 9 2 ../source/replace.exe '[^a--b]?[^9-B]? *[^0-9]-' 'NEW'  < ../inputs/temp-test/2119.inp.898.3 > ../outputs/t5237
    if diff ../outputs/t5237 ../originals/t5237 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5238) timeout -s 9 2 ../source/replace.exe '[^a-?[a-]?-?-]' '&'  < ../inputs/temp-test/46.inp.20.1 > ../outputs/t5238
    if diff ../outputs/t5238 ../originals/t5238 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5239) timeout -s 9 2 ../source/replace.exe '[^a-?[a-]?-?-]' '&'  < ../inputs/temp-test/47.inp.20.2 > ../outputs/t5239
    if diff ../outputs/t5239 ../originals/t5239 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5240) timeout -s 9 2 ../source/replace.exe '[^a-?[a-]?-?-]' '&'  < ../inputs/temp-test/48.inp.20.3 > ../outputs/t5240
    if diff ../outputs/t5240 ../originals/t5240 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5241) timeout -s 9 2 ../source/replace.exe '[^a-@[' 'a&'  < ../inputs/temp-test/190.inp.86.1 > ../outputs/t5241
    if diff ../outputs/t5241 ../originals/t5241 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5242) timeout -s 9 2 ../source/replace.exe '[^a-[9-B]?' '&'  < ../inputs/temp-test/1469.inp.630.1 > ../outputs/t5242
    if diff ../outputs/t5242 ../originals/t5242 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5243) timeout -s 9 2 ../source/replace.exe '[^a-[9-B]?' '&'  < ../inputs/temp-test/1470.inp.630.2 > ../outputs/t5243
    if diff ../outputs/t5243 ../originals/t5243 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5244) timeout -s 9 2 ../source/replace.exe '[^a-]' 'a&'  < ../inputs/temp-test/595.inp.256.1 > ../outputs/t5244
    if diff ../outputs/t5244 ../originals/t5244 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5245) timeout -s 9 2 ../source/replace.exe '[^a-]' 'a&'  < ../inputs/temp-test/596.inp.256.2 > ../outputs/t5245
    if diff ../outputs/t5245 ../originals/t5245 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5246) timeout -s 9 2 ../source/replace.exe '[^a-]?' '&a@%'  < ../inputs/temp-test/1518.inp.650.1 > ../outputs/t5246
    if diff ../outputs/t5246 ../originals/t5246 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5247) timeout -s 9 2 ../source/replace.exe '[^a-]?' '&a@%'  < ../inputs/temp-test/1519.inp.650.3 > ../outputs/t5247
    if diff ../outputs/t5247 ../originals/t5247 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5248) timeout -s 9 2 ../source/replace.exe '[^a-]?' '@%&a'  < ../inputs/temp-test/2041.inp.866.1 > ../outputs/t5248
    if diff ../outputs/t5248 ../originals/t5248 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5249) timeout -s 9 2 ../source/replace.exe '[^a-]?' '@%&a'  < ../inputs/temp-test/2042.inp.866.2 > ../outputs/t5249
    if diff ../outputs/t5249 ../originals/t5249 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5250) timeout -s 9 2 ../source/replace.exe '[^a-]?' '@%&a'  < ../inputs/temp-test/2043.inp.866.3 > ../outputs/t5250
    if diff ../outputs/t5250 ../originals/t5250 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5251) timeout -s 9 2 ../source/replace.exe '[^a-]?[0-9]-a-c]--*-@[' '&a@%'  < ../inputs/temp-test/544.inp.236.1 > ../outputs/t5251
    if diff ../outputs/t5251 ../originals/t5251 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5252) timeout -s 9 2 ../source/replace.exe '[^a-]?[0-9]-a-c]--*-@[' '&a@%'  < ../inputs/temp-test/545.inp.236.2 > ../outputs/t5252
    if diff ../outputs/t5252 ../originals/t5252 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5253) timeout -s 9 2 ../source/replace.exe '[^a-]?[0-9]-a-c]--*-@[' '&a@%'  < ../inputs/temp-test/546.inp.236.3 > ../outputs/t5253
    if diff ../outputs/t5253 ../originals/t5253 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5254) timeout -s 9 2 ../source/replace.exe '[^a-][0-9]' 'a@n'  < ../inputs/temp-test/553.inp.239.1 > ../outputs/t5254
    if diff ../outputs/t5254 ../originals/t5254 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5255) timeout -s 9 2 ../source/replace.exe '[^a-][0-9]' 'a@n'  < ../inputs/temp-test/554.inp.239.3 > ../outputs/t5255
    if diff ../outputs/t5255 ../originals/t5255 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5256) timeout -s 9 2 ../source/replace.exe '[^a-][9-B]' '@t'  < ../inputs/temp-test/326.inp.145.1 > ../outputs/t5256
    if diff ../outputs/t5256 ../originals/t5256 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5257) timeout -s 9 2 ../source/replace.exe '[^a-][9-B]' '@t'  < ../inputs/temp-test/327.inp.145.2 > ../outputs/t5257
    if diff ../outputs/t5257 ../originals/t5257 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5258) timeout -s 9 2 ../source/replace.exe '[^a-][9-B]' '@t'  < ../inputs/temp-test/328.inp.145.3 > ../outputs/t5258
    if diff ../outputs/t5258 ../originals/t5258 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5259) timeout -s 9 2 ../source/replace.exe '[^a-][a-c]' 'NEW'  < ../inputs/temp-test/1084.inp.467.1 > ../outputs/t5259
    if diff ../outputs/t5259 ../originals/t5259 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5260) timeout -s 9 2 ../source/replace.exe '[^a-][a-c]' 'NEW'  < ../inputs/temp-test/1085.inp.467.3 > ../outputs/t5260
    if diff ../outputs/t5260 ../originals/t5260 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5261) timeout -s 9 2 ../source/replace.exe '[^a-][a-c]' 'NEW'  < ../inputs/temp-test/1086.inp.467.4 > ../outputs/t5261
    if diff ../outputs/t5261 ../originals/t5261 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5262) timeout -s 9 2 ../source/replace.exe '[^a-c' 'NEW'  < ../inputs/temp-test/1864.inp.791.1 > ../outputs/t5262
    if diff ../outputs/t5262 ../originals/t5262 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5263) timeout -s 9 2 ../source/replace.exe '[^a-c--[^9-B][0-9]@[[^@@]-' '@%&a'  < ../inputs/temp-test/2120.inp.899.1 > ../outputs/t5263
    if diff ../outputs/t5263 ../originals/t5263 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5264) timeout -s 9 2 ../source/replace.exe '[^a-c--[^9-B][0-9]@[[^@@]-' '@%&a'  < ../inputs/temp-test/2121.inp.899.3 > ../outputs/t5264
    if diff ../outputs/t5264 ../originals/t5264 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5265) timeout -s 9 2 ../source/replace.exe '[^a-c?-$' '&a@%'  < ../inputs/temp-test/1002.inp.431.8 > ../outputs/t5265
    if diff ../outputs/t5265 ../originals/t5265 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5266) timeout -s 9 2 ../source/replace.exe '[^a-c?-' '&a@%'  < ../inputs/temp-test/1000.inp.431.1 > ../outputs/t5266
    if diff ../outputs/t5266 ../originals/t5266 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5267) timeout -s 9 2 ../source/replace.exe '[^a-c?-' '&a@%'  < ../inputs/temp-test/1001.inp.431.3 > ../outputs/t5267
    if diff ../outputs/t5267 ../originals/t5267 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5268) timeout -s 9 2 ../source/replace.exe '[^a-c] ' '&'  < ../inputs/temp-test/404.inp.177.1 > ../outputs/t5268
    if diff ../outputs/t5268 ../originals/t5268 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5269) timeout -s 9 2 ../source/replace.exe '[^a-c] ' '&'  < ../inputs/temp-test/405.inp.177.2 > ../outputs/t5269
    if diff ../outputs/t5269 ../originals/t5269 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5270) timeout -s 9 2 ../source/replace.exe '[^a-c]' '@%@&'  < ../inputs/temp-test/1778.inp.758.1 > ../outputs/t5270
    if diff ../outputs/t5270 ../originals/t5270 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5271) timeout -s 9 2 ../source/replace.exe '[^a-c]' '@%@&'  < ../inputs/temp-test/1779.inp.758.2 > ../outputs/t5271
    if diff ../outputs/t5271 ../originals/t5271 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5272) timeout -s 9 2 ../source/replace.exe '[^a-c]' '@%@&'  < ../inputs/temp-test/1780.inp.758.3 > ../outputs/t5272
    if diff ../outputs/t5272 ../originals/t5272 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5273) timeout -s 9 2 ../source/replace.exe '[^a-c]' '@%@&'  < ../inputs/temp-test/2279.inp.966.1 > ../outputs/t5273
    if diff ../outputs/t5273 ../originals/t5273 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5274) timeout -s 9 2 ../source/replace.exe '[^a-c]' '@%@&'  < ../inputs/temp-test/2280.inp.966.2 > ../outputs/t5274
    if diff ../outputs/t5274 ../originals/t5274 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5275) timeout -s 9 2 ../source/replace.exe '[^a-c]' '@%@&'  < ../inputs/temp-test/2281.inp.966.4 > ../outputs/t5275
    if diff ../outputs/t5275 ../originals/t5275 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5276) timeout -s 9 2 ../source/replace.exe '[^a-c]' 'NEW'  < ../inputs/temp-test/1541.inp.660.1 > ../outputs/t5276
    if diff ../outputs/t5276 ../originals/t5276 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5277) timeout -s 9 2 ../source/replace.exe '[^a-c]' 'NEW'  < ../inputs/temp-test/1542.inp.660.3 > ../outputs/t5277
    if diff ../outputs/t5277 ../originals/t5277 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5278) timeout -s 9 2 ../source/replace.exe '[^a-c]**' 'a'  < ../inputs/moni/f7.inp > ../outputs/t5278
    if diff ../outputs/t5278 ../originals/t5278 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5279) timeout -s 9 2 ../source/replace.exe '[^a-c]*-[0-9]?[@@]?[^9-B]A ?' ''  < ../inputs/temp-test/116.inp.53.1 > ../outputs/t5279
    if diff ../outputs/t5279 ../originals/t5279 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5280) timeout -s 9 2 ../source/replace.exe '[^a-c]*?' 'a&'  < ../inputs/temp-test/126.inp.59.1 > ../outputs/t5280
    if diff ../outputs/t5280 ../originals/t5280 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5281) timeout -s 9 2 ../source/replace.exe '[^a-c]*?' 'a&'  < ../inputs/temp-test/127.inp.59.2 > ../outputs/t5281
    if diff ../outputs/t5281 ../originals/t5281 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5282) timeout -s 9 2 ../source/replace.exe '[^a-c]*?--*?* *[a--b][^a-c]' 'a@nb@tc'  < ../inputs/temp-test/6.inp.3.1 > ../outputs/t5282
    if diff ../outputs/t5282 ../originals/t5282 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5283) timeout -s 9 2 ../source/replace.exe '[^a-c]*?--*?* *[a--b][^a-c]' 'a@nb@tc'  < ../inputs/temp-test/7.inp.3.3 > ../outputs/t5283
    if diff ../outputs/t5283 ../originals/t5283 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5284) timeout -s 9 2 ../source/replace.exe '[^a-c]*?--*?* *[a--b][^a-c]' 'a@nb@tc'  < ../inputs/temp-test/8.inp.3.4 > ../outputs/t5284
    if diff ../outputs/t5284 ../originals/t5284 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5285) timeout -s 9 2 ../source/replace.exe '[^a-c]-' '&'  < ../inputs/temp-test/1571.inp.671.1 > ../outputs/t5285
    if diff ../outputs/t5285 ../originals/t5285 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5286) timeout -s 9 2 ../source/replace.exe '[^a-c]-' '&'  < ../inputs/temp-test/1572.inp.671.4 > ../outputs/t5286
    if diff ../outputs/t5286 ../originals/t5286 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5287) timeout -s 9 2 ../source/replace.exe '[^a-c]-' '&a@%'  < ../inputs/temp-test/2014.inp.855.1 > ../outputs/t5287
    if diff ../outputs/t5287 ../originals/t5287 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5288) timeout -s 9 2 ../source/replace.exe '[^a-c]-' '&a@%'  < ../inputs/temp-test/2015.inp.855.3 > ../outputs/t5288
    if diff ../outputs/t5288 ../originals/t5288 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5289) timeout -s 9 2 ../source/replace.exe '[^a-c]-' '&a@%'  < ../inputs/temp-test/2016.inp.855.4 > ../outputs/t5289
    if diff ../outputs/t5289 ../originals/t5289 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5290) timeout -s 9 2 ../source/replace.exe '[^a-c]-' '@%@&'  < ../inputs/temp-test/601.inp.259.1 > ../outputs/t5290
    if diff ../outputs/t5290 ../originals/t5290 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5291) timeout -s 9 2 ../source/replace.exe '[^a-c]-' '@%@&'  < ../inputs/temp-test/602.inp.259.3 > ../outputs/t5291
    if diff ../outputs/t5291 ../originals/t5291 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5292) timeout -s 9 2 ../source/replace.exe '[^a-c]-' 'a&'  < ../inputs/temp-test/1810.inp.769.1 > ../outputs/t5292
    if diff ../outputs/t5292 ../originals/t5292 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5293) timeout -s 9 2 ../source/replace.exe '[^a-c]-' 'a&'  < ../inputs/temp-test/1811.inp.769.3 > ../outputs/t5293
    if diff ../outputs/t5293 ../originals/t5293 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5294) timeout -s 9 2 ../source/replace.exe '[^a-c]-?[_-z][^--' '@%&a'  < ../inputs/temp-test/261.inp.116.1 > ../outputs/t5294
    if diff ../outputs/t5294 ../originals/t5294 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5295) timeout -s 9 2 ../source/replace.exe '[^a-c]-?[_-z][^--' '@%&a'  < ../inputs/temp-test/262.inp.116.2 > ../outputs/t5295
    if diff ../outputs/t5295 ../originals/t5295 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5296) timeout -s 9 2 ../source/replace.exe '[^a-c]-?[_-z][^--' '@%&a'  < ../inputs/temp-test/263.inp.116.3 > ../outputs/t5296
    if diff ../outputs/t5296 ../originals/t5296 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5297) timeout -s 9 2 ../source/replace.exe '[^a-c]-]' '&a@%'  < ../inputs/temp-test/2053.inp.871.1 > ../outputs/t5297
    if diff ../outputs/t5297 ../originals/t5297 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5298) timeout -s 9 2 ../source/replace.exe '[^a-c]-]' '&a@%'  < ../inputs/temp-test/2054.inp.871.2 > ../outputs/t5298
    if diff ../outputs/t5298 ../originals/t5298 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5299) timeout -s 9 2 ../source/replace.exe '[^a-c]-]' '&a@%'  < ../inputs/temp-test/2055.inp.871.4 > ../outputs/t5299
    if diff ../outputs/t5299 ../originals/t5299 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5300) timeout -s 9 2 ../source/replace.exe 'abc'   < ../inputs/moni/t4.inp > ../outputs/t5300
    if diff ../outputs/t5300 ../originals/t5300 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5301) timeout -s 9 2 ../source/replace.exe 'abc'   < ../inputs/moni/t5.inp > ../outputs/t5301
    if diff ../outputs/t5301 ../originals/t5301 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5302) timeout -s 9 2 ../source/replace.exe '@abc'   < ../inputs/moni/t5.inp > ../outputs/t5302
    if diff ../outputs/t5302 ../originals/t5302 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5303) timeout -s 9 2 ../source/replace.exe 'tt'   < ../inputs/moni/t1.inp > ../outputs/t5303
    if diff ../outputs/t5303 ../originals/t5303 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5304) timeout -s 9 2 ../source/replace.exe 'abc'   < ../inputs/moni/t2.inp > ../outputs/t5304
    if diff ../outputs/t5304 ../originals/t5304 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5305) timeout -s 9 2 ../source/replace.exe '77'   < ../inputs/moni/t3.inp > ../outputs/t5305
    if diff ../outputs/t5305 ../originals/t5305 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5306) timeout -s 9 2 ../source/replace.exe '@77'   < ../inputs/moni/t3.inp > ../outputs/t5306
    if diff ../outputs/t5306 ../originals/t5306 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5307) timeout -s 9 2 ../source/replace.exe 'IlG'  < ../inputs/moni/t6.inp > ../outputs/t5307
    if diff ../outputs/t5307 ../originals/t5307 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5308) timeout -s 9 2 ../source/replace.exe '@IlG'  < ../inputs/moni/t6.inp > ../outputs/t5308
    if diff ../outputs/t5308 ../originals/t5308 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5309) timeout -s 9 2 ../source/replace.exe '%abc'   < ../inputs/moni/t5.inp > ../outputs/t5309
    if diff ../outputs/t5309 ../originals/t5309 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5310) timeout -s 9 2 ../source/replace.exe '%IlG'  < ../inputs/moni/t6.inp > ../outputs/t5310
    if diff ../outputs/t5310 ../originals/t5310 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5311) timeout -s 9 2 ../source/replace.exe '%77'   < ../inputs/moni/t3.inp > ../outputs/t5311
    if diff ../outputs/t5311 ../originals/t5311 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5312) timeout -s 9 2 ../source/replace.exe 'IlG\a88888888888888888$'  < ../inputs/moni/t6.inp > ../outputs/t5312
    if diff ../outputs/t5312 ../originals/t5312 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5313) timeout -s 9 2 ../source/replace.exe 'Da*'  < ../inputs/moni/t7.inp > ../outputs/t5313
    if diff ../outputs/t5313 ../originals/t5313 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5314) timeout -s 9 2 ../source/replace.exe '%77*'   < ../inputs/moni/t3.inp > ../outputs/t5314
    if diff ../outputs/t5314 ../originals/t5314 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5315) timeout -s 9 2 ../source/replace.exe '[0-7][0-7]'  < ../inputs/moni/t3.inp > ../outputs/t5315
    if diff ../outputs/t5315 ../originals/t5315 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5316) timeout -s 9 2 ../source/replace.exe '[0-7]*'  < ../inputs/moni/t3.inp > ../outputs/t5316
    if diff ../outputs/t5316 ../originals/t5316 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5317) timeout -s 9 2 ../source/replace.exe 'abc*'  < ../inputs/moni/t2.inp > ../outputs/t5317
    if diff ../outputs/t5317 ../originals/t5317 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5318) timeout -s 9 2 ../source/replace.exe '77?'  < ../inputs/moni/t3.inp > ../outputs/t5318
    if diff ../outputs/t5318 ../originals/t5318 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5319) timeout -s 9 2 ../source/replace.exe '7?7'  < ../inputs/moni/t3.inp > ../outputs/t5319
    if diff ../outputs/t5319 ../originals/t5319 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5320) timeout -s 9 2 ../source/replace.exe '[a-z]*'  < ../inputs/moni/t2.inp > ../outputs/t5320
    if diff ../outputs/t5320 ../originals/t5320 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5321) timeout -s 9 2 ../source/replace.exe '77[6-9]'   < ../inputs/moni/t3.inp > ../outputs/t5321
    if diff ../outputs/t5321 ../originals/t5321 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5322) timeout -s 9 2 ../source/replace.exe '[am]*$' 'foo'  < ../inputs/moni/nn1.t > ../outputs/t5322
    if diff ../outputs/t5322 ../originals/t5322 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5323) timeout -s 9 2 ../source/replace.exe '[a-Z(1-9]*$' 'foo'  < ../inputs/moni/nn1.t > ../outputs/t5323
    if diff ../outputs/t5323 ../originals/t5323 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5324) timeout -s 9 2 ../source/replace.exe '[a-Z(1-9]*$' 'foo'  < ../inputs/input/ruin.624 > ../outputs/t5324
    if diff ../outputs/t5324 ../originals/t5324 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5325) timeout -s 9 2 ../source/replace.exe '[Cm]*$' 'a@f'  < ../inputs/input/ruin.304 > ../outputs/t5325
    if diff ../outputs/t5325 ../originals/t5325 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5326) timeout -s 9 2 ../source/replace.exe '[Cm]*$' 'a&'  < ../inputs/input/ruin.304 > ../outputs/t5326
    if diff ../outputs/t5326 ../originals/t5326 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5327) timeout -s 9 2 ../source/replace.exe '[Cm]*$'   < ../inputs/input/ruin.304 > ../outputs/t5327
    if diff ../outputs/t5327 ../originals/t5327 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5328) timeout -s 9 2 ../source/replace.exe '[Da]*$' 'a&'  < ../inputs/input/ruin.717 > ../outputs/t5328
    if diff ../outputs/t5328 ../originals/t5328 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5329) timeout -s 9 2 ../source/replace.exe '$' '@t'  < ../inputs/input/ruin.1121 > ../outputs/t5329
    if diff ../outputs/t5329 ../originals/t5329 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5330) timeout -s 9 2 ../source/replace.exe '$' '%&'  < ../inputs/input/ruin.1122 > ../outputs/t5330
    if diff ../outputs/t5330 ../originals/t5330 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5331) timeout -s 9 2 ../source/replace.exe '[>dE]*$' '@n'  < ../inputs/input/ruin.1782 > ../outputs/t5331
    if diff ../outputs/t5331 ../originals/t5331 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5332) timeout -s 9 2 ../source/replace.exe '[1-8;a-Z]*$' '@@n'  < ../inputs/input/ruin.714 > ../outputs/t5332
    if diff ../outputs/t5332 ../originals/t5332 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5333) timeout -s 9 2 ../source/replace.exe '@@*$' '&E9p\6X[t<jnR3{*3PQSno!);(&'  < ../inputs/input/ruin.1256 > ../outputs/t5333
    if diff ../outputs/t5333 ../originals/t5333 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5334) timeout -s 9 2 ../source/replace.exe '@@*$' '@tW'  < ../inputs/input/ruin.1247 > ../outputs/t5334
    if diff ../outputs/t5334 ../originals/t5334 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5335) timeout -s 9 2 ../source/replace.exe '@t*$' '&a&'  < ../inputs/input/ruin.1244 > ../outputs/t5335
    if diff ../outputs/t5335 ../originals/t5335 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5336) timeout -s 9 2 ../source/replace.exe 'd*$' '@t'  < ../inputs/moni/nn2.t > ../outputs/t5336
    if diff ../outputs/t5336 ../originals/t5336 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5337) timeout -s 9 2 ../source/replace.exe 'W' 'cCeuNv}}<pw83QZL=`?=f9b?1A'  < ../inputs/input/ruin.24 > ../outputs/t5337
    if diff ../outputs/t5337 ../originals/t5337 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5338) timeout -s 9 2 ../source/replace.exe '-[9-B][9-B] *-^*^a-][@n]' '@t&@n'  < ../inputs/temp-test/1044.inp.450.2 > ../outputs/t5338
    if diff ../outputs/t5338 ../originals/t5338 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5339) timeout -s 9 2 ../source/replace.exe 'W' 'cCeuNv}}<pw83QZLabcefghijz[`?=f9b?1A'  < ../inputs/input/ruin.24 > ../outputs/t5339
    if diff ../outputs/t5339 ../originals/t5339 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5340) timeout -s 9 2 ../source/replace.exe '@@' 'abcdefghigjklmnhijklmopqrstuvwxyz012345678901234567890123456'  < ../inputs/input/ruin.98 > ../outputs/t5340
    if diff ../outputs/t5340 ../originals/t5340 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5341) timeout -s 9 2 ../source/replace.exe '-?-@**[^0-9]-@@*[^9-B]?@n*$' 'abcdefg@&'  < ../inputs/temp-test/2078.inp.880.6 > ../outputs/t5341
    if diff ../outputs/t5341 ../originals/t5341 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5342) timeout -s 9 2 ../source/replace.exe '@@' 'anystringthatisquitelongwillworkithinkforgettingthisduexercisedforthiserr'  < ../inputs/input/ruin.150 > ../outputs/t5342
    if diff ../outputs/t5342 ../originals/t5342 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5343) timeout -s 9 2 ../source/replace.exe '@@*'\'*$',^P&Sh6@@' '@titsthe & in this string that matters'  < ../inputs/input/ruin.1119 > ../outputs/t5343
    if diff ../outputs/t5343 ../originals/t5343 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5344) timeout -s 9 2 ../source/replace.exe '9@@*[^Z-a]^_a]' 'thisoneIdontunderstandunlessthestringisalreadylong'  < ../inputs/input/ruin.28 > ../outputs/t5344
    if diff ../outputs/t5344 ../originals/t5344 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5345) timeout -s 9 2 ../source/replace.exe '7979797979@n' 'a&&a'  < ../inputs/moni/rr2.t > ../outputs/t5345
    if diff ../outputs/t5345 ../originals/t5345 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5346) timeout -s 9 2 ../source/replace.exe '[79]*@n' 'a&&a'  < ../inputs/moni/rr2.t > ../outputs/t5346
    if diff ../outputs/t5346 ../originals/t5346 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5347) timeout -s 9 2 ../source/replace.exe '[79]*@n' 'a@4&@t&a'  < ../inputs/moni/rr2.t > ../outputs/t5347
    if diff ../outputs/t5347 ../originals/t5347 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5348) timeout -s 9 2 ../source/replace.exe '[1-9]*@n' 'a@4&@t&a'  < ../inputs/moni/rr2.t > ../outputs/t5348
    if diff ../outputs/t5348 ../originals/t5348 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5349) timeout -s 9 2 ../source/replace.exe '?[1-9]*@n' 'a@4&@t&a'  < ../inputs/moni/rr2.t > ../outputs/t5349
    if diff ../outputs/t5349 ../originals/t5349 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5350) timeout -s 9 2 ../source/replace.exe '?[!]*@n' 'a&[0-9]'  < ../inputs/moni/rr3.t > ../outputs/t5350
    if diff ../outputs/t5350 ../originals/t5350 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5351) timeout -s 9 2 ../source/replace.exe '!!!!!!777!!@n' 'a&[0-9]'  < ../inputs/moni/rr3.t > ../outputs/t5351
    if diff ../outputs/t5351 ../originals/t5351 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5352) timeout -s 9 2 ../source/replace.exe '!!!*777!!@n' 'a&[0-9]'  < ../inputs/moni/rr3.t > ../outputs/t5352
    if diff ../outputs/t5352 ../originals/t5352 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5353) timeout -s 9 2 ../source/replace.exe '[7]*!!@n' 'a&[0-9]'  < ../inputs/moni/rr3.t > ../outputs/t5353
    if diff ../outputs/t5353 ../originals/t5353 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5354) timeout -s 9 2 ../source/replace.exe '[1]*@n' '11&@t@t@@'  < ../inputs/moni/rr4.t > ../outputs/t5354
    if diff ../outputs/t5354 ../originals/t5354 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5355) timeout -s 9 2 ../source/replace.exe '%11111@nl[^6]inbetweend@t@n%%88*erwhatjustgettingvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5355
    if diff ../outputs/t5355 ../originals/t5355 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5356) timeout -s 9 2 ../source/replace.exe '%11111@nl[^6]inbetweend@t@n%%88*erwhatjust@t@t@tgvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5356
    if diff ../outputs/t5356 ../originals/t5356 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5357) timeout -s 9 2 ../source/replace.exe '&11111@nl[^1-6]betweend@t@n%%88*erwhatjust@t@t@tgvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5357
    if diff ../outputs/t5357 ../originals/t5357 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5358) timeout -s 9 2 ../source/replace.exe '@1@n11@nl[^1-6]betweend@t@n%%88*erwhatjust@t@t@tgvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5358
    if diff ../outputs/t5358 ../originals/t5358 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5359) timeout -s 9 2 ../source/replace.exe '@1@t11%%l[1-60]betweend@t@n%%88*erwhatjust999999gvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5359
    if diff ../outputs/t5359 ../originals/t5359 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5360) timeout -s 9 2 ../source/replace.exe  '#@@[^0-9]@**^[^@@]-[0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5360
    if diff ../outputs/t5360 ../originals/t5360 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5361) timeout -s 9 2 ../source/replace.exe  '%@@@^0-9]@**^[^@@]-[0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5361
    if diff ../outputs/t5361 ../originals/t5361 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5362) timeout -s 9 2 ../source/replace.exe  '%@@@^0-9]@**^[^@@]-[0-9][@t][^0-9]@**^*8*8*[9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5362
    if diff ../outputs/t5362 ../originals/t5362 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5363) timeout -s 9 2 ../source/replace.exe  '%@**^0-9]@**^[^@@]-[0-9][@t][^0-9]@**^*8*8*[9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5363
    if diff ../outputs/t5363 ../originals/t5363 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5364) timeout -s 9 2 ../source/replace.exe  '@n33[^9-0]omea%harlongstringdoesntmatt@twhatitisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcharcacterswilldojusttypinginsomechars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' 'substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5364
    if diff ../outputs/t5364 ../originals/t5364 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5365) timeout -s 9 2 ../source/replace.exe  '%n33123456&&&a%harlongstringdoesntmatt@t*t*t*tisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcharcacterswilldojusttypinginsomechars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' 'substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5365
    if diff ../outputs/t5365 ../originals/t5365 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5366) timeout -s 9 2 ../source/replace.exe  '%n331*3456&&&a%@**rlongstringdoesntmatt@t*t*t*tisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcharcacterswilldojusttypinginsomechars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' 'substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5366
    if diff ../outputs/t5366 ../originals/t5366 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5367) timeout -s 9 2 ../source/replace.exe  '%n331*3456&&&a%@**rlongstringdoesntmatt@t*t*t*tisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcha[]acterswilldojusttypingins[0-9]ars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' '[0-9]substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5367
    if diff ../outputs/t5367 ../originals/t5367 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5368) timeout -s 9 2 ../source/replace.exe  '%n331*3456&&&a%@**rlongstringdoesntmatt@t*t*t*tisbutmustbeverylongwhateverthecharactersaredonesntmatteraslonga[![estringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcha[]acterswilldojusttypingins[0-9]ars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' '[0-9]substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5368
    if diff ../outputs/t5368 ../originals/t5368 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5369) timeout -s 9 2 ../source/replace.exe  '%n331*3456&&&a%@**rlongstringdoesntmatt@t*t*t*tisbutmustbeverylongwhateverthecharactersaredonesntmatteraslonga[![estringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcha[]acter]]illdojusttypingins[0-9]ars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' '[0-9]substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5369
    if diff ../outputs/t5369 ../originals/t5369 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5370) timeout -s 9 2 ../source/replace.exe  '@n331*34[&*]&a%@**rlongstringdoesntmatt@t*t*t*tisbutmustbeverylongwhateverthecharactersaredon@@@ntteraslonga[![estringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcha[]acter]]illdojusttypingins[0-9]ars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' '[0-9]substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5370
    if diff ../outputs/t5370 ../originals/t5370 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5371) timeout -s 9 2 ../source/replace.exe  '@n3@t@t@t&*]&a%@**rlongstringdoesntmatt@t*t*t*tisbutmustbeverylongwhateverthecharactersaredon@@@ntteraslonga[![estringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcha[]acter]]illdojusttypingins[0-9]ars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' '[0-9]substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5371
    if diff ../outputs/t5371 ../originals/t5371 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5372) timeout -s 9 2 ../source/replace.exe '%)0J&Y6XsPqpxC53aKh3HTW9ITsk@m9aFOys4{Ym@&Eg1[G|ntmx;o|2xwF})0J&Y6XsPqpxC53aKh3HTW9ITsk@m9[]Oys4{Ym@&Eg*[G|ntmx;o|2xwF})0J&Y6XsPqpxC53aKh3HTW9ITsk@m9aFOys4{Ym@&Eg1[G|ntmx;o|2xwF[Z-a]^_[Z-a]^_*[Z-a]^_*' 'a'   < ../inputs/input/ruin.1616 > ../outputs/t5372
    if diff ../outputs/t5372 ../originals/t5372 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5373) timeout -s 9 2 ../source/replace.exe '@n@nEq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QS[8-9]V0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$Q*0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<A[^a-c][0-9]@[*' '&a@%'  < ../inputs/temp-test/589.inp.253.1 > ../outputs/t5373
    if diff ../outputs/t5373 ../originals/t5373 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5374) timeout -s 9 2 ../source/replace.exe '123??!*' '&&&&'   < ../inputs/moni/rr3.t > ../outputs/t5374
    if diff ../outputs/t5374 ../originals/t5374 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5375) timeout -s 9 2 ../source/replace.exe '[d]*' '&@@&@@&@@@@'  < ../inputs/moni/rr7.t > ../outputs/t5375
    if diff ../outputs/t5375 ../originals/t5375 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5376) timeout -s 9 2 ../source/replace.exe '8?8?8?88??88??8888888888' '&@t&@t&'   < ../inputs/moni/rr6.t > ../outputs/t5376
    if diff ../outputs/t5376 ../originals/t5376 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5377) timeout -s 9 2 ../source/replace.exe 'th?si?aca?etha[t]isalongline' '&aa&'  < ../inputs/moni/rr1.t > ../outputs/t5377
    if diff ../outputs/t5377 ../originals/t5377 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5378) timeout -s 9 2 ../source/replace.exe 'th?si?aca?etha[t]isalong[li]*ne' '&aa&'  < ../inputs/moni/rr1.t > ../outputs/t5378
    if diff ../outputs/t5378 ../originals/t5378 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5379) timeout -s 9 2 ../source/replace.exe '[0-9]*ddd' '&[0-9]&[^0-9]&'  < ../inputs/moni/rr7.t > ../outputs/t5379
    if diff ../outputs/t5379 ../originals/t5379 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5380) timeout -s 9 2 ../source/replace.exe '12?!*' '&&&&'   < ../inputs/moni/rr3.t > ../outputs/t5380
    if diff ../outputs/t5380 ../originals/t5380 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5381) timeout -s 9 2 ../source/replace.exe '%thisisacase' '&a@@[0-9]a&'  < ../inputs/moni/rr1.t > ../outputs/t5381
    if diff ../outputs/t5381 ../originals/t5381 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5382) timeout -s 9 2 ../source/replace.exe '%[a-b]*$' '&@t&@t&'   < ../inputs/moni/rr5.t > ../outputs/t5382
    if diff ../outputs/t5382 ../originals/t5382 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5383) timeout -s 9 2 ../source/replace.exe '[0-3]!*$' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr3.t > ../outputs/t5383
    if diff ../outputs/t5383 ../originals/t5383 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5384) timeout -s 9 2 ../source/replace.exe '%@@ [^0-*]@**^[^@@]-[0-9][@t][^0-9]@*f^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5384
    if diff ../outputs/t5384 ../originals/t5384 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5385) timeout -s 9 2 ../source/replace.exe 'for $his du the key $hing is to hav* a ccl at exactly the right length more [@@]' 'sub doesnt matter'  < ../inputs/moni/rr1.t > ../outputs/t5385
    if diff ../outputs/t5385 ../originals/t5385 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5386) timeout -s 9 2 ../source/replace.exe '[^0[^0-9]abc^[^@@]-[0-9][^0-9]1234[^0-9]@**^[^@@][9-B -[0-9]!!0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5386
    if diff ../outputs/t5386 ../originals/t5386 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5387) timeout -s 9 2 ../source/replace.exe '[0-^9]@nl[^ ]inbeweendoesntmatterwhatjustgettingvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5387
    if diff ../outputs/t5387 ../originals/t5387 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5388) timeout -s 9 2 ../source/replace.exe 'NEW*EW-[0-9][^0-9][@t][^0-9]@**^[^@@][erg-[0-9][^0-9][@t][3459]@**^[^@@][9-B]-[0-9][^0-9][@t][^0abc-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5388
    if diff ../outputs/t5388 ../originals/t5388 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5389) timeout -s 9 2 ../source/replace.exe '@11111@nl[^6]i@retweend@t@t%%88*erwha[0-st@t@t@tgvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5389
    if diff ../outputs/t5389 ../originals/t5389 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5390) timeout -s 9 2 ../source/replace.exe 'theccl *ust contain an @ and {}[]nt know wa*at else [a-z]* stuff is OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5390
    if diff ../outputs/t5390 ../originals/t5390 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5391) timeout -s 9 2 ../source/replace.exe '[0-&]aal[^!]inbetweendoesntmatterwhatjustgettingvariety%finthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5391
    if diff ../outputs/t5391 ../originals/t5391 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5392) timeout -s 9 2 ../source/replace.exe '[50123495123412345512345123]123!56@a35123451234551234512345612341234564444[^@@]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5392
    if diff ../outputs/t5392 ../originals/t5392 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5393) timeout -s 9 2 ../source/replace.exe '%)0J&Y6XsP[0-9]3aKh3HTW9ITsk@m9* * s4{Ym@&Eg1[G|ntmx;o|2xwF})0J&Y6XsPqpxC53aKh3HTW9ITsk@m9[]Oys4{Ym@&Eg*[G|ntmx;o|2xwF})0J&Y6XsPqpxC53aKh3HTW9ITsk@m9aFOys4{Ym@&Eg1[G|ntmx;o|2xwF[Z-a]^_[Z-a]^_*[Z-a]^_*' 'a'   < ../inputs/input/ruin.1616 > ../outputs/t5393
    if diff ../outputs/t5393 ../originals/t5393 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5394) timeout -s 9 2 ../source/replace.exe '@n%%Eq/SH{S$QV0"e<bz-[(*Z9QSH{@tQV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QS[8-9]V0"$<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$Q*0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<p-f]Eq/SH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<bz-[(*Z9QSH{S$QV0"e<A[^a-c][0-9]@[*' '&a@%'  < ../inputs/temp-test/589.inp.253.1 > ../outputs/t5394
    if diff ../outputs/t5394 ../originals/t5394 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5395) timeout -s 9 2 ../source/replace.exe '%%331*34[&*]&a%@**^longstringdoesntmatt@t*t*t*tisbutmustbeverylongwhateverthecharactersaredon@@@ntteraslonga[![^stringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcha[]acter]]illdojusttypingins[0-9]ars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' '[0-9]substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5395
    if diff ../outputs/t5395 ../originals/t5395 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5396) timeout -s 9 2 ../source/replace.exe '45' '&abdfegh123456789123412345678912345678956789123456789123456789123312345678945678912345678912345678912345679123456789'  < ../inputs/moni/f1.inp > ../outputs/t5396
    if diff ../outputs/t5396 ../originals/t5396 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5397) timeout -s 9 2 ../source/replace.exe '4' '&abdfegh1234567891234123451234567890872348793847239847234234234324367891234312345678945678912345678912345678912345679123456789'  < ../inputs/moni/f1.inp > ../outputs/t5397
    if diff ../outputs/t5397 ../originals/t5397 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5398) timeout -s 9 2 ../source/replace.exe '66' '&abdfegh1234567891234&1234512345678908723487938&4723984723423423432436&312345678945678912345678912345678912345679123456789'  < ../inputs/moni/f5.inp > ../outputs/t5398
    if diff ../outputs/t5398 ../originals/t5398 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5399) timeout -s 9 2 ../source/replace.exe 'thisisacasethatisalongline' '&aa&'  < ../inputs/moni/rr1.t > ../outputs/t5399
    if diff ../outputs/t5399 ../originals/t5399 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5400) timeout -s 9 2 ../source/replace.exe 'thisisacasethatisa' '&aa&'  < ../inputs/moni/rr1.t > ../outputs/t5400
    if diff ../outputs/t5400 ../originals/t5400 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5401) timeout -s 9 2 ../source/replace.exe 'this[a-z]*' '&a&a&'  < ../inputs/moni/rr1.t > ../outputs/t5401
    if diff ../outputs/t5401 ../originals/t5401 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5402) timeout -s 9 2 ../source/replace.exe 'this[a-z]*$' '&a&a&'  < ../inputs/moni/rr1.t > ../outputs/t5402
    if diff ../outputs/t5402 ../originals/t5402 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5403) timeout -s 9 2 ../source/replace.exe '%thi[a-z]*' '&@t&'  < ../inputs/moni/rr1.t > ../outputs/t5403
    if diff ../outputs/t5403 ../originals/t5403 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5404) timeout -s 9 2 ../source/replace.exe '123[7-9]*' '&@t&'   < ../inputs/moni/rr2.t > ../outputs/t5404
    if diff ../outputs/t5404 ../originals/t5404 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5405) timeout -s 9 2 ../source/replace.exe '%123[7-9]*' '&@t&'   < ../inputs/moni/rr2.t > ../outputs/t5405
    if diff ../outputs/t5405 ../originals/t5405 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5406) timeout -s 9 2 ../source/replace.exe '%123[7-9]*$' '&@t&'   < ../inputs/moni/rr2.t > ../outputs/t5406
    if diff ../outputs/t5406 ../originals/t5406 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5407) timeout -s 9 2 ../source/replace.exe '%123[7-9]*$' '&@t@t&'   < ../inputs/moni/rr2.t > ../outputs/t5407
    if diff ../outputs/t5407 ../originals/t5407 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5408) timeout -s 9 2 ../source/replace.exe '123[7-9]*' '&@&&'   < ../inputs/moni/rr2.t > ../outputs/t5408
    if diff ../outputs/t5408 ../originals/t5408 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5409) timeout -s 9 2 ../source/replace.exe '123?[7-9]*' '&@&&'   < ../inputs/moni/rr2.t > ../outputs/t5409
    if diff ../outputs/t5409 ../originals/t5409 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5410) timeout -s 9 2 ../source/replace.exe '123[^1-6]*' '&@&&'   < ../inputs/moni/rr2.t > ../outputs/t5410
    if diff ../outputs/t5410 ../originals/t5410 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5411) timeout -s 9 2 ../source/replace.exe '%123[^1-6]*' '&@&&'   < ../inputs/moni/rr2.t > ../outputs/t5411
    if diff ../outputs/t5411 ../originals/t5411 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5412) timeout -s 9 2 ../source/replace.exe '123[^1-6]*$' '&@&&'   < ../inputs/moni/rr2.t > ../outputs/t5412
    if diff ../outputs/t5412 ../originals/t5412 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5413) timeout -s 9 2 ../source/replace.exe '123[^1-6]*$' '&[0-9]&'   < ../inputs/moni/rr2.t > ../outputs/t5413
    if diff ../outputs/t5413 ../originals/t5413 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5414) timeout -s 9 2 ../source/replace.exe '123[1-9]*$' '&&'   < ../inputs/moni/rr2.t > ../outputs/t5414
    if diff ../outputs/t5414 ../originals/t5414 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5415) timeout -s 9 2 ../source/replace.exe '123[1-9]*$' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr2.t > ../outputs/t5415
    if diff ../outputs/t5415 ../originals/t5415 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5416) timeout -s 9 2 ../source/replace.exe '123[1-9abcdefgh]*$' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr2.t > ../outputs/t5416
    if diff ../outputs/t5416 ../originals/t5416 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5417) timeout -s 9 2 ../source/replace.exe '%123[1-9abcdefgh]*' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr2.t > ../outputs/t5417
    if diff ../outputs/t5417 ../originals/t5417 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5418) timeout -s 9 2 ../source/replace.exe '%123[1-9@t]*' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr2.t > ../outputs/t5418
    if diff ../outputs/t5418 ../originals/t5418 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5419) timeout -s 9 2 ../source/replace.exe '%123[1-9@f]*' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr2.t > ../outputs/t5419
    if diff ../outputs/t5419 ../originals/t5419 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5420) timeout -s 9 2 ../source/replace.exe '123[@1-9]*' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr2.t > ../outputs/t5420
    if diff ../outputs/t5420 ../originals/t5420 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5421) timeout -s 9 2 ../source/replace.exe '[0-3]!*' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr3.t > ../outputs/t5421
    if diff ../outputs/t5421 ../originals/t5421 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5422) timeout -s 9 2 ../source/replace.exe '123!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr3.t > ../outputs/t5422
    if diff ../outputs/t5422 ../originals/t5422 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5423) timeout -s 9 2 ../source/replace.exe '123!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr3.t > ../outputs/t5423
    if diff ../outputs/t5423 ../originals/t5423 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5424) timeout -s 9 2 ../source/replace.exe '[0-9!]*' '&[lkjasdlkjdf]&'   < ../inputs/moni/rr3.t > ../outputs/t5424
    if diff ../outputs/t5424 ../originals/t5424 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5425) timeout -s 9 2 ../source/replace.exe '%[0-9!]*' '&@t@t#45678[0-9]&'   < ../inputs/moni/rr3.t > ../outputs/t5425
    if diff ../outputs/t5425 ../originals/t5425 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5426) timeout -s 9 2 ../source/replace.exe '123[!]*' '&@t@t#45678[0-9]&'   < ../inputs/moni/rr3.t > ../outputs/t5426
    if diff ../outputs/t5426 ../originals/t5426 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5427) timeout -s 9 2 ../source/replace.exe '123[!!!!!!!!!!!!!]*7' '&@t@t#45678[0-9]&'   < ../inputs/moni/rr3.t > ../outputs/t5427
    if diff ../outputs/t5427 ../originals/t5427 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5428) timeout -s 9 2 ../source/replace.exe 'more[0-9a-z]*' '&@t@t#45678[0-9]&'   < ../inputs/moni/rr4.t > ../outputs/t5428
    if diff ../outputs/t5428 ../originals/t5428 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5429) timeout -s 9 2 ../source/replace.exe 'morestuffinalongline111111111111111111111111111' '&aaaaa&'   < ../inputs/moni/rr4.t > ../outputs/t5429
    if diff ../outputs/t5429 ../originals/t5429 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5430) timeout -s 9 2 ../source/replace.exe 'this**' 'sub'  < ../inputs/moni/rr1.t > ../outputs/t5430
    if diff ../outputs/t5430 ../originals/t5430 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5431) timeout -s 9 2 ../source/replace.exe '123[7-9]**' '&a&'  < ../inputs/moni/rr2.t > ../outputs/t5431
    if diff ../outputs/t5431 ../originals/t5431 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5432) timeout -s 9 2 ../source/replace.exe '[!]**' '&@t[6-0]&'  < ../inputs/moni/rr3.t > ../outputs/t5432
    if diff ../outputs/t5432 ../originals/t5432 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5433) timeout -s 9 2 ../source/replace.exe '[1]**' '&alachamazoo@t@t@&&'  < ../inputs/moni/rr4.t > ../outputs/t5433
    if diff ../outputs/t5433 ../originals/t5433 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5434) timeout -s 9 2 ../source/replace.exe '?[1]**' '&alachamazoo@t@t@&&'  < ../inputs/moni/rr4.t > ../outputs/t5434
    if diff ../outputs/t5434 ../originals/t5434 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5435) timeout -s 9 2 ../source/replace.exe '%[a-z]*[1]**' '&alachamazoo@t@t@&&'  < ../inputs/moni/rr4.t > ../outputs/t5435
    if diff ../outputs/t5435 ../originals/t5435 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5436) timeout -s 9 2 ../source/replace.exe '[a-z]*'   < ../inputs/moni/t5.inp > ../outputs/t5436
    if diff ../outputs/t5436 ../originals/t5436 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5437) timeout -s 9 2 ../source/replace.exe 'this'  < ../inputs/moni/rr1.t > ../outputs/t5437
    if diff ../outputs/t5437 ../originals/t5437 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5438) timeout -s 9 2 ../source/replace.exe 'nomatch@n' 'a&'  < ../inputs/moni/rr1.t > ../outputs/t5438
    if diff ../outputs/t5438 ../originals/t5438 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5439) timeout -s 9 2 ../source/replace.exe 'thisisacasethatisalongline@n' '&a&'  < ../inputs/moni/rr1.t > ../outputs/t5439
    if diff ../outputs/t5439 ../originals/t5439 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5440) timeout -s 9 2 ../source/replace.exe ']@n' '=@t&lk'  < ../inputs/input/ruin.277 > ../outputs/t5440
    if diff ../outputs/t5440 ../originals/t5440 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5441) timeout -s 9 2 ../source/replace.exe '@t@n' '/&q@t@t'  < ../inputs/input/ruin.539 > ../outputs/t5441
    if diff ../outputs/t5441 ../originals/t5441 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5442) timeout -s 9 2 ../source/replace.exe '@**^[^@@][9-B]-[0-9][^0-9][@t][^0[^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5442
    if diff ../outputs/t5442 ../originals/t5442 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5443) timeout -s 9 2 ../source/replace.exe '[^0[^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5443
    if diff ../outputs/t5443 ../originals/t5443 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5444) timeout -s 9 2 ../source/replace.exe '[^0[^0-9]@**^[^@@]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5444
    if diff ../outputs/t5444 ../originals/t5444 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5445) timeout -s 9 2 ../source/replace.exe '[^0[^0-9]@**^[^@@]-[0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]' '@%@&'  < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5445
    if diff ../outputs/t5445 ../originals/t5445 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5446) timeout -s 9 2 ../source/replace.exe '[^0[^0-9]@**^[^@@]-[0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@][9-B]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5446
    if diff ../outputs/t5446 ../originals/t5446 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5447) timeout -s 9 2 ../source/replace.exe '[^0[^0-9]@**^[^@@]-[0-9][@t][^0-9]@**^[^@@][9-B]-[0-9][^0-9][@t][^0-9]@**^[^@@]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5447
    if diff ../outputs/t5447 ../originals/t5447 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5448) timeout -s 9 2 ../source/replace.exe '[^0123495@**^[^@@]-12345[@t]123456@**^[^@@]12345-12345123456[@t][^0-9]@**^[^@@]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5448
    if diff ../outputs/t5448 ../originals/t5448 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5449) timeout -s 9 2 ../source/replace.exe '[^0123495123412345-123451234123456@**51234512345-123451234561234123456@**^[^@@]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5449
    if diff ../outputs/t5449 ../originals/t5449 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5450) timeout -s 9 2 ../source/replace.exe '[5012349512341234551234512341234561235123451234551234512345612341234564444[^@@]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5450
    if diff ../outputs/t5450 ../originals/t5450 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5451) timeout -s 9 2 ../source/replace.exe '[501234951234123455123451234123456123512345123455123451234561234123456444412[@@]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5451
    if diff ../outputs/t5451 ../originals/t5451 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5452) timeout -s 9 2 ../source/replace.exe '4501234951234123455123451234123456123512345123455123451234561234123456444412[@@]'   < ../inputs/temp-test/1397.inp.600.1 > ../outputs/t5452
    if diff ../outputs/t5452 ../originals/t5452 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5453) timeout -s 9 2 ../source/replace.exe 'for this du the key thing is to have a ccl at exactly the right length more [@@]' 'sub doesnt matter'  < ../inputs/moni/rr1.t > ../outputs/t5453
    if diff ../outputs/t5453 ../originals/t5453 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5454) timeout -s 9 2 ../source/replace.exe 'theccl must contain an @ and I dont know wahat else [a-z]* stuff is OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5454
    if diff ../outputs/t5454 ../originals/t5454 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5455) timeout -s 9 2 ../source/replace.exe '@t@nlongtextinbetweendoesntmatterwhatjustgettingvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5455
    if diff ../outputs/t5455 ../originals/t5455 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5456) timeout -s 9 2 ../source/replace.exe '[0-9]@nl[^6]inbetweendoesntmatterwhatjustgettingvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5456
    if diff ../outputs/t5456 ../originals/t5456 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5457) timeout -s 9 2 ../source/replace.exe '[0-9]@nl[^6]inbetweend@t@n%%$$*erwhatjustgettingvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5457
    if diff ../outputs/t5457 ../originals/t5457 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5458) timeout -s 9 2 ../source/replace.exe '[0-9]@nl[^6]inbetweend@t@n%%88*erwhatjustgettingvariety%$inthestr&& OK here[@@]'  < ../inputs/moni/rr2.t > ../outputs/t5458
    if diff ../outputs/t5458 ../originals/t5458 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5459) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c ][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c][a-c]?[^0-9]-' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5459
    if diff ../outputs/t5459 ../originals/t5459 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5460) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c ][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c][a-c]?' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5460
    if diff ../outputs/t5460 ../originals/t5460 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5461) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z]12345?123456-[^9-B]12345?[^0-9]-1234561234512345?123456-12345612345?123456-1234561234512345?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c ][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c][a-c]?' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5461
    if diff ../outputs/t5461 ../originals/t5461 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5462) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z]12345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?[^0-9]-[^9-B][a][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c ][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c][a-c]?' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5462
    if diff ../outputs/t5462 ../originals/t5462 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5463) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z]12345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-12345612312345?123456-123456[a-c]?[^0-9]-[^9-B][a-c ][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c][a-c]?' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5463
    if diff ../outputs/t5463 ../originals/t5463 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5464) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z]12345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-12345612312345?123456-12345612345?123456-12345612345612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-123456[a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c][a-c]?' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5464
    if diff ../outputs/t5464 ../originals/t5464 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5465) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z]12345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-12345612312345?123456-12345612345?123456-12345612345612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c][a-c]?' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5465
    if diff ../outputs/t5465 ../originals/t5465 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5466) timeout -s 9 2 ../source/replace.exe '?p&y=3[Z]12345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-12345612312345?123456-12345612345?123456-12345612345612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c]' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5466
    if diff ../outputs/t5466 ../originals/t5466 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5467) timeout -s 9 2 ../source/replace.exe 'someacharlongstringdoesntmatterwhatitisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-12345612312345?123456-12345612345?123456-12345612345612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-[^9-B][a-c][a-c]?[^0-9]-[^9-B][a-c]?[^0-9]-[^9-B][a-c-c]' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5467
    if diff ../outputs/t5467 ../originals/t5467 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5468) timeout -s 9 2 ../source/replace.exe 'someacharlongstringdoesntmatterwhatitisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?123456-1234561234512345?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-12345612312345?123456-12345612345?123456-12345612345612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?[^0-9]-[^9-B][a-c-c]' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5468
    if diff ../outputs/t5468 ../originals/t5468 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5469) timeout -s 9 2 ../source/replace.exe 'someacharlongstringdoesntmatterwhatitisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?123456hereanycharcharcacterswilldojusttypinginsomechars@nandsomeflags@n@t-12345612345?123456-12345612312345?123456-12345612345?123456-12345612345612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-c]' '~'  < ../inputs/input/ruin.1338 > ../outputs/t5469
    if diff ../outputs/t5469 ../originals/t5469 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5470) timeout -s 9 2 ../source/replace.exe 'someacharlongstringdoesntmatterwhatitisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?123456hereanycharcharcacterswilldojusttypinginsomechars@nandsomeflags@n@t-12345612345?123456-12345612312345?123456-12345612345?123456-12345612345612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' 'substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5470
    if diff ../outputs/t5470 ../originals/t5470 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5471) timeout -s 9 2 ../source/replace.exe '%omeacharlongstringdoesntmatt@twhatitisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?123456hereanych$rcharcacterswilldojusttypinginsomechars@nandsomeflags@n@t-12345612345?123456-inputfiledoesntmattereitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' 'substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5471
    if diff ../outputs/t5471 ../originals/t5471 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5472) timeout -s 9 2 ../source/replace.exe '@t@@[^9-0]omeacharlongstringdoesntmatt@twhatitisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcharcacterswilldojusttypinginsomechars@nandsomeflags@n@t-12345612345?123456-inputfiledoesntmattereitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' 'substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5472
    if diff ../outputs/t5472 ../originals/t5472 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5473) timeout -s 9 2 ../source/replace.exe '@t@@[^9-0]omeacharlongstringdoesntmatt@twhatitisbutmustbeverylongwhateverthecharactersaredonesntmatteraslongasthestringistherightlengthandendswiththerightcharacterlkj45?1234ch$rcharcacterswilldojusttypinginsomechars@nandsomeflags@n@t-12345612345?123456-@3@##filedoesntmatt&&eitherasitsneverprocessed&&@@45612345?123456-123456123455?123456-1234561234512345?123456-12345612345?123456-1234561234567890?123456-12345612345?123456-1234561234512345?123456-12345612345?123456-123456[a-c-9]' 'substringdoesntmatter'  < ../inputs/input/ruin.1338 > ../outputs/t5473
    if diff ../outputs/t5473 ../originals/t5473 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5474) timeout -s 9 2 ../source/replace.exe '123!*' '&&&&'   < ../inputs/moni/rr3.t > ../outputs/t5474
    if diff ../outputs/t5474 ../originals/t5474 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5475) timeout -s 9 2 ../source/replace.exe '?!*' '&&&&'   < ../inputs/moni/rr3.t > ../outputs/t5475
    if diff ../outputs/t5475 ../originals/t5475 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5476) timeout -s 9 2 ../source/replace.exe 'a*$' '&&&&'   < ../inputs/moni/rr5.t > ../outputs/t5476
    if diff ../outputs/t5476 ../originals/t5476 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5477) timeout -s 9 2 ../source/replace.exe '%[a-b]*' '&&&&'   < ../inputs/moni/rr5.t > ../outputs/t5477
    if diff ../outputs/t5477 ../originals/t5477 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5478) timeout -s 9 2 ../source/replace.exe '[a-b]*' '&@t&@t&'   < ../inputs/moni/rr5.t > ../outputs/t5478
    if diff ../outputs/t5478 ../originals/t5478 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5479) timeout -s 9 2 ../source/replace.exe '[^b-z]*' '&@t&@t&'   < ../inputs/moni/rr5.t > ../outputs/t5479
    if diff ../outputs/t5479 ../originals/t5479 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5480) timeout -s 9 2 ../source/replace.exe 'aa' '&@t&@t&'   < ../inputs/moni/rr5.t > ../outputs/t5480
    if diff ../outputs/t5480 ../originals/t5480 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5481) timeout -s 9 2 ../source/replace.exe '88888888888888888888888888' '&@t&@t&'   < ../inputs/moni/rr6.t > ../outputs/t5481
    if diff ../outputs/t5481 ../originals/t5481 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5482) timeout -s 9 2 ../source/replace.exe '8888888888888?8888888888888' '&@t&@t&'   < ../inputs/moni/rr6.t > ../outputs/t5482
    if diff ../outputs/t5482 ../originals/t5482 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5483) timeout -s 9 2 ../source/replace.exe '8888888888888?8888888888888$' '&@t&@t&'   < ../inputs/moni/rr6.t > ../outputs/t5483
    if diff ../outputs/t5483 ../originals/t5483 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5484) timeout -s 9 2 ../source/replace.exe '[0-9]*' '&@t&@t&'   < ../inputs/moni/rr6.t > ../outputs/t5484
    if diff ../outputs/t5484 ../originals/t5484 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5485) timeout -s 9 2 ../source/replace.exe '[6-8@3]*' '&&@t&'   < ../inputs/moni/rr6.t > ../outputs/t5485
    if diff ../outputs/t5485 ../originals/t5485 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5486) timeout -s 9 2 ../source/replace.exe '[8-8]*' '&foo&foo&'   < ../inputs/moni/rr6.t > ../outputs/t5486
    if diff ../outputs/t5486 ../originals/t5486 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5487) timeout -s 9 2 ../source/replace.exe '[+#()1-9]*' '&77&@t&'  < ../inputs/moni/rr6.t > ../outputs/t5487
    if diff ../outputs/t5487 ../originals/t5487 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5488) timeout -s 9 2 ../source/replace.exe 'ddd' '&@t&@t&'  < ../inputs/moni/rr7.t > ../outputs/t5488
    if diff ../outputs/t5488 ../originals/t5488 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5489) timeout -s 9 2 ../source/replace.exe '[d]*' '&@t&@t&'  < ../inputs/moni/rr7.t > ../outputs/t5489
    if diff ../outputs/t5489 ../originals/t5489 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5490) timeout -s 9 2 ../source/replace.exe '[d]*' '&&@t&'  < ../inputs/moni/rr7.t > ../outputs/t5490
    if diff ../outputs/t5490 ../originals/t5490 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5491) timeout -s 9 2 ../source/replace.exe '[d]*' '&ababababababababababababababababa&@t&'  < ../inputs/moni/rr7.t > ../outputs/t5491
    if diff ../outputs/t5491 ../originals/t5491 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5492) timeout -s 9 2 ../source/replace.exe '}EB0$FtY|' 'd`?K#C~VsV'  < ../inputs/input/ruin.10 > ../outputs/t5492
    if diff ../outputs/t5492 ../originals/t5492 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5493) timeout -s 9 2 ../source/replace.exe 'foobarf foobarfoobarfoobarfoobarfoobarfoobarfoobar'  < ../inputs/input/ruin.2 > ../outputs/t5493
    if diff ../outputs/t5493 ../originals/t5493 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5494) timeout -s 9 2 ../source/replace.exe '[d]*' '&@t&@t&'  < ../inputs/moni/rr8.t > ../outputs/t5494
    if diff ../outputs/t5494 ../originals/t5494 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5495) timeout -s 9 2 ../source/replace.exe '[d]*' '&@t&@t&'  < ../inputs/moni/rr9.t > ../outputs/t5495
    if diff ../outputs/t5495 ../originals/t5495 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5496) timeout -s 9 2 ../source/replace.exe '[d]*' '&@t&@t&'  < ../inputs/moni/rr10.t > ../outputs/t5496
    if diff ../outputs/t5496 ../originals/t5496 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5497) timeout -s 9 2 ../source/replace.exe '[d]*' '&@t&@t&'  < ../inputs/moni/rr11.t > ../outputs/t5497
    if diff ../outputs/t5497 ../originals/t5497 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5498) timeout -s 9 2 ../source/replace.exe '[d]*' '&@t&@t&'  < ../inputs/moni/rr12.t > ../outputs/t5498
    if diff ../outputs/t5498 ../originals/t5498 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5499) timeout -s 9 2 ../source/replace.exe '[d]*' '&@t&@t&'  < ../inputs/moni/rr13.t > ../outputs/t5499
    if diff ../outputs/t5499 ../originals/t5499 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5500) timeout -s 9 2 ../source/replace.exe 'a*' '&@t&@t&'  < ../inputs/moni/rr14.t > ../outputs/t5500
    if diff ../outputs/t5500 ../originals/t5500 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5501) timeout -s 9 2 ../source/replace.exe 'l*' '&@t&@t&'  < ../inputs/moni/rr14.t > ../outputs/t5501
    if diff ../outputs/t5501 ../originals/t5501 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5502) timeout -s 9 2 ../source/replace.exe '@l*' '&@t&@t&'  < ../inputs/moni/rr15.t > ../outputs/t5502
    if diff ../outputs/t5502 ../originals/t5502 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5503) timeout -s 9 2 ../source/replace.exe '[1-9]*' '&@t&@t&'  < ../inputs/moni/rr16.t > ../outputs/t5503
    if diff ../outputs/t5503 ../originals/t5503 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5504) timeout -s 9 2 ../source/replace.exe '[^0a-z]*' '&@t&@t&'  < ../inputs/moni/rr16.t > ../outputs/t5504
    if diff ../outputs/t5504 ../originals/t5504 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5505) timeout -s 9 2 ../source/replace.exe '[1-8@t]*' '&@t&@t&'  < ../inputs/moni/rr17.t > ../outputs/t5505
    if diff ../outputs/t5505 ../originals/t5505 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5506) timeout -s 9 2 ../source/replace.exe '[1-8@t!()]*' '&@t&@t&'  < ../inputs/moni/rr17.t > ../outputs/t5506
    if diff ../outputs/t5506 ../originals/t5506 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5507) timeout -s 9 2 ../source/replace.exe '[1]*' '&@t&@t&'  < ../inputs/moni/rr17.t > ../outputs/t5507
    if diff ../outputs/t5507 ../originals/t5507 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5508) timeout -s 9 2 ../source/replace.exe '[1]*' '&@t&                      &'  < ../inputs/moni/rr17.t > ../outputs/t5508
    if diff ../outputs/t5508 ../originals/t5508 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5509) timeout -s 9 2 ../source/replace.exe '1*' '&      &          &'  < ../inputs/moni/rr17.t > ../outputs/t5509
    if diff ../outputs/t5509 ../originals/t5509 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5510) timeout -s 9 2 ../source/replace.exe '[1@&@@@n]*' '&@t&          &'  < ../inputs/moni/rr17.t > ../outputs/t5510
    if diff ../outputs/t5510 ../originals/t5510 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5511) timeout -s 9 2 ../source/replace.exe '1*' '&@t@t&&'  < ../inputs/moni/rr17.t > ../outputs/t5511
    if diff ../outputs/t5511 ../originals/t5511 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5512) timeout -s 9 2 ../source/replace.exe '1*' '&&@p@q[0-9]&'  < ../inputs/moni/rr17.t > ../outputs/t5512
    if diff ../outputs/t5512 ../originals/t5512 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5513) timeout -s 9 2 ../source/replace.exe '1*' '&@5%&[0-9 &'  < ../inputs/moni/rr18.t > ../outputs/t5513
    if diff ../outputs/t5513 ../originals/t5513 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5514) timeout -s 9 2 ../source/replace.exe '[1-8@t!()]*' '&plain&textl&'  < ../inputs/moni/rr17.t > ../outputs/t5514
    if diff ../outputs/t5514 ../originals/t5514 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5515) timeout -s 9 2 ../source/replace.exe '[1-8@t[]]*' '&plain&textl&'  < ../inputs/moni/rr17.t > ../outputs/t5515
    if diff ../outputs/t5515 ../originals/t5515 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5516) timeout -s 9 2 ../source/replace.exe '[^0a-z@t%]*' '&@t&@t&'  < ../inputs/moni/rr16.t > ../outputs/t5516
    if diff ../outputs/t5516 ../originals/t5516 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5517) timeout -s 9 2 ../source/replace.exe '[^0a-z%]*' '&@t&@t&'  < ../inputs/moni/rr16.t > ../outputs/t5517
    if diff ../outputs/t5517 ../originals/t5517 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5518) timeout -s 9 2 ../source/replace.exe '[1-9]*' '&@5%&[0-9 &'  < ../inputs/moni/rr18.t > ../outputs/t5518
    if diff ../outputs/t5518 ../originals/t5518 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5519) timeout -s 9 2 ../source/replace.exe '[@n1-9]*' '&@5%&[0-9 &'  < ../inputs/moni/rr18.t > ../outputs/t5519
    if diff ../outputs/t5519 ../originals/t5519 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5520) timeout -s 9 2 ../source/replace.exe '1*' '&[[[]]]@t&&'  < ../inputs/moni/rr17.t > ../outputs/t5520
    if diff ../outputs/t5520 ../originals/t5520 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5521) timeout -s 9 2 ../source/replace.exe '1*' '&%[-]]]@t&&'  < ../inputs/moni/rr17.t > ../outputs/t5521
    if diff ../outputs/t5521 ../originals/t5521 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5522) timeout -s 9 2 ../source/replace.exe '[-1-9]*' '&@5%&[0-9 &'  < ../inputs/moni/rr18.t > ../outputs/t5522
    if diff ../outputs/t5522 ../originals/t5522 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5523) timeout -s 9 2 ../source/replace.exe '[%1-9]*' '&@5%&[0-9 &'  < ../inputs/moni/rr18.t > ../outputs/t5523
    if diff ../outputs/t5523 ../originals/t5523 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5524) timeout -s 9 2 ../source/replace.exe '[%1-9]*' '&@t&[0]9 &'  < ../inputs/moni/rr18.t > ../outputs/t5524
    if diff ../outputs/t5524 ../originals/t5524 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5525) timeout -s 9 2 ../source/replace.exe '[1@&@@@@#@%%^*@@n]*' '&@t&          &'  < ../inputs/moni/rr17.t > ../outputs/t5525
    if diff ../outputs/t5525 ../originals/t5525 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5526) timeout -s 9 2 ../source/replace.exe '[1@&@*@@#@%%^@@n]*' '&@t&          &'  < ../inputs/moni/rr17.t > ../outputs/t5526
    if diff ../outputs/t5526 ../originals/t5526 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5527) timeout -s 9 2 ../source/replace.exe '[d]*' '&@t& lkj[0-9]&'  < ../inputs/moni/rr19.t > ../outputs/t5527
    if diff ../outputs/t5527 ../originals/t5527 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5528) timeout -s 9 2 ../source/replace.exe '[d*]*' '&@t&@t&'  < ../inputs/moni/rr8.t > ../outputs/t5528
    if diff ../outputs/t5528 ../originals/t5528 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5529) timeout -s 9 2 ../source/replace.exe '[*d]*' '&@t&@t&'  < ../inputs/moni/rr9.t > ../outputs/t5529
    if diff ../outputs/t5529 ../originals/t5529 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5530) timeout -s 9 2 ../source/replace.exe '[d]*' '&$$$$$&@t&'  < ../inputs/moni/rr10.t > ../outputs/t5530
    if diff ../outputs/t5530 ../originals/t5530 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5531) timeout -s 9 2 ../source/replace.exe '[$d%]*' '&@t&@t&'  < ../inputs/moni/rr11.t > ../outputs/t5531
    if diff ../outputs/t5531 ../originals/t5531 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5532) timeout -s 9 2 ../source/replace.exe '[@^d]*' '&@t&@t&'  < ../inputs/moni/rr12.t > ../outputs/t5532
    if diff ../outputs/t5532 ../originals/t5532 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5533) timeout -s 9 2 ../source/replace.exe '[@!d]*' '&@t&@t&'  < ../inputs/moni/rr13.t > ../outputs/t5533
    if diff ../outputs/t5533 ../originals/t5533 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5534) timeout -s 9 2 ../source/replace.exe '[@]*1*' '&&@p@q[0-9]&'  < ../inputs/moni/rr17.t > ../outputs/t5534
    if diff ../outputs/t5534 ../originals/t5534 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5535) timeout -s 9 2 ../source/replace.exe '1*' '&[[[]]]&@t@@&'  < ../inputs/moni/rr17.t > ../outputs/t5535
    if diff ../outputs/t5535 ../originals/t5535 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5536) timeout -s 9 2 ../source/replace.exe '[@t1-8@t]*' '&&@t@t&'  < ../inputs/moni/rr17.t > ../outputs/t5536
    if diff ../outputs/t5536 ../originals/t5536 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5537) timeout -s 9 2 ../source/replace.exe '[dab]*' '&@t&@t&'  < ../inputs/moni/rr8.t > ../outputs/t5537
    if diff ../outputs/t5537 ../originals/t5537 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5538) timeout -s 9 2 ../source/replace.exe '[d1]*' '&@t&@t&'  < ../inputs/moni/rr9.t > ../outputs/t5538
    if diff ../outputs/t5538 ../originals/t5538 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5539) timeout -s 9 2 ../source/replace.exe '[^ad]*' '&@t&@t&'  < ../inputs/moni/rr10.t > ../outputs/t5539
    if diff ../outputs/t5539 ../originals/t5539 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5540) timeout -s 9 2 ../source/replace.exe '[d]*' '&&@t@t&'  < ../inputs/moni/rr11.t > ../outputs/t5540
    if diff ../outputs/t5540 ../originals/t5540 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5541) timeout -s 9 2 ../source/replace.exe '[d]*' '&&@y@Y@Y@Y@Y@Y@Y@Y&'  < ../inputs/moni/rr12.t > ../outputs/t5541
    if diff ../outputs/t5541 ../originals/t5541 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  p5542) timeout -s 9 2 ../source/replace.exe '[d]*' '&&()*()*()*)(*))(*&'  < ../inputs/moni/rr13.t > ../outputs/t5542
    if diff ../outputs/t5542 ../originals/t5542 >/dev/null 2>&1; then exit 1; else exit 0; fi  ;;
  *) exit 2 ;;
esac
